@@ -6,6 +6,8 @@
 
 // clang-format off
 
+#include "cdi.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -13,7 +15,18 @@ extern "C" {
 void decode_calday(int daysPerYear, int days, int *year, int *month, int *day);
 int64_t encode_calday(int daysPerYear, int year, int month, int day);
 
-int calendar_dpy(int calendar);
+static inline int
+calendar_dpy(int calendar)
+{
+  int daysPerYear = 0;
+
+  if      (calendar == CALENDAR_360DAYS) daysPerYear = 360;
+  else if (calendar == CALENDAR_365DAYS) daysPerYear = 365;
+  else if (calendar == CALENDAR_366DAYS) daysPerYear = 366;
+
+  return daysPerYear;
+}
+
 int days_per_year(int calendar, int year);
 int days_per_month(int calendar, int year, int month);
 
@@ -23,4 +36,4 @@ int days_per_month(int calendar, int year, int month);
 
 // clang-format on
 
-#endif /* CALENDAR_H */
+#endif
