@@ -4,6 +4,7 @@
 #ifdef HAVE_LIBNETCDF
 
 #include <netcdf.h>
+#include <stdint.h>  // int64_t
 
 void cdf__create(const char *path, int cmode, int *idp);
 void cdf_create(const char *path, int cmode, int *idp);
@@ -11,8 +12,8 @@ int cdf_open(const char *path, int omode, int *idp);
 void cdf_close(int ncid);
 
 void cdf_redef(int ncid);
-void cdf_enddef(int ncid);
-void cdf__enddef(const int ncid, const size_t hdr_pad);
+void cdf_enddef(int ncid, int streamID);
+void cdf__enddef(int ncid, int streamID, const size_t hdr_pad);
 void cdf_sync(int ncid);
 
 void cdf_inq(int ncid, int *ndimsp, int *nvarsp, int *ngattsp, int *unlimdimidp);
@@ -79,6 +80,7 @@ void cdf_put_att_double(int ncid, int varid, const char *name, nc_type xtype, si
 void cdf_get_att_string(int ncid, int varid, const char *name, char **tp);
 void cdf_get_att_text(int ncid, int varid, const char *name, char *tp);
 void cdf_get_att_int(int ncid, int varid, const char *name, int *ip);
+void cdf_get_att_int64(int ncid, int varid, const char *name, int64_t *ip);
 void cdf_get_att_double(int ncid, int varid, const char *name, double *dp);
 
 void cdf_inq_att(int ncid, int varid, const char *name, nc_type *xtypep, size_t *lenp);
@@ -93,6 +95,10 @@ typedef int (*cdi_nc__create_funcp)(const char *path, int cmode, size_t initials
 
 typedef void (*cdi_cdf_def_var_funcp)(int ncid, const char *name, nc_type xtype, int ndims, const int dimids[], int *varidp);
 
+int cdi_nc_enddef_serial(int ncid, int streamID);
+int cdi_nc__enddef_serial(int ncid, int streamID, size_t hdr_pad, size_t v_align, size_t v_minfree, size_t r_align);
+typedef int (*cdi_nc_enddef_funcp)(int ncid, int streamID);
+typedef int (*cdi_nc__enddef_funcp)(int ncid, int streamID, size_t hdr_pad, size_t v_align, size_t v_minfree, size_t r_align);
 #endif
 
 #endif /* CDF_INT_H */
