@@ -8,7 +8,7 @@
 #include "error.h"
 
 char *
-strToLower(char *str)
+str_to_lower(char *str)
 {
   if (str)
     for (size_t i = 0; str[i]; ++i) str[i] = (char) tolower((int) str[i]);
@@ -22,8 +22,8 @@ strStartsWith(const char *vstr, const char *cstr)
   bool is_equal = false;
   if (vstr && cstr)
     {
-      const size_t clen = strlen(cstr);
-      const size_t vlen = strlen(vstr);
+      size_t clen = strlen(cstr);
+      size_t vlen = strlen(vstr);
       if (clen <= vlen) is_equal = (memcmp(vstr, cstr, clen) == 0);
     }
   return is_equal;
@@ -63,16 +63,14 @@ is_time_units(const char *timeunits)
   while (isspace(*timeunits)) timeunits++;
 
   // clang-format off
-  bool status = strStartsWith(timeunits, "sec")
-             || strStartsWith(timeunits, "minute")
-             || strStartsWith(timeunits, "hour")
-             || strStartsWith(timeunits, "day")
-             || strStartsWith(timeunits, "month")
-             || strStartsWith(timeunits, "calendar_month")
-             || strStartsWith(timeunits, "year");
+  return (strStartsWith(timeunits, "sec")
+       || strStartsWith(timeunits, "minute")
+       || strStartsWith(timeunits, "hour")
+       || strStartsWith(timeunits, "day")
+       || strStartsWith(timeunits, "month")
+       || strStartsWith(timeunits, "calendar_month")
+       || strStartsWith(timeunits, "year"));
   // clang-format on
-
-  return status;
 }
 
 bool
@@ -80,22 +78,21 @@ is_timeaxis_units(const char *timeunits)
 {
   bool status = false;
 
-  const size_t len = strlen(timeunits);
+  size_t len = strlen(timeunits);
   char *tu = (char *) malloc((len + 1) * sizeof(char));
-  memcpy(tu, timeunits, (len + 1) * sizeof(char));
-  char *ptu = tu;
 
-  for (size_t i = 0; i < len; i++) ptu[i] = (char) tolower((int) ptu[i]);
+  for (size_t i = 0; i < len; i++) tu[i] = (char) tolower((int) timeunits[i]);
 
-  int timeunit = get_time_units(len, ptu);
+  int timeunit = get_time_units(len, tu);
   if (timeunit != -1)
     {
-      while (!isspace(*ptu) && *ptu != 0) ptu++;
-      if (*ptu)
+      size_t pos = 0;
+      while (!isspace(tu[pos]) && tu[pos] != 0) pos++;
+      if (tu[pos])
         {
-          while (isspace(*ptu)) ptu++;
-          int timetype = strStartsWith(ptu, "as") ? TAXIS_ABSOLUTE : strStartsWith(ptu, "since") ? TAXIS_RELATIVE : -1;
-          status = (timetype != -1);
+          while (isspace(tu[pos])) pos++;
+
+          status = strStartsWith(tu + pos, "as") || strStartsWith(tu + pos, "since");
         }
     }
 
@@ -107,79 +104,77 @@ is_timeaxis_units(const char *timeunits)
 bool
 is_height_units(const char *units)
 {
-  const int u0 = units[0];
+  int u0 = units[0];
 
   // clang-format off
-  bool status = (u0=='m' && (!units[1] || strStartsWith(units, "meter")))
-    || (!units[2] && units[1]=='m' && (u0=='c' || u0=='d' || u0=='k'))
-    || (strStartsWith(units, "decimeter"))
-    || (strStartsWith(units, "centimeter"))
-    || (strStartsWith(units, "millimeter"))
-    || (strStartsWith(units, "kilometer"));
+  return ((u0=='m' && (!units[1] || strStartsWith(units, "meter")))
+       || (!units[2] && units[1]=='m' && (u0=='c' || u0=='d' || u0=='k'))
+       || (strStartsWith(units, "decimeter"))
+       || (strStartsWith(units, "centimeter"))
+       || (strStartsWith(units, "millimeter"))
+       || (strStartsWith(units, "kilometer")));
   // clang-format on
-
-  return status;
 }
 
 bool
 is_pressure_units(const char *units)
 {
   // clang-format off
-  bool status = strStartsWith(units, "millibar")
-             || strStartsWith(units, "mb")
-             || strStartsWith(units, "hectopas")
-             || strStartsWith(units, "hPa")
-             || strStartsWith(units, "Pa");
+  return (strStartsWith(units, "millibar")
+       || strStartsWith(units, "mb")
+       || strStartsWith(units, "hectopas")
+       || strStartsWith(units, "hPa")
+       || strStartsWith(units, "pa")
+       || strStartsWith(units, "Pa"));
   // clang-format on
-
-  return status;
 }
 
 bool
 is_DBL_axis(const char *longname)
 {
   // clang-format off
-  bool status = strIsEqual(longname, "depth below land")
-             || strIsEqual(longname, "depth_below_land")
-             || strIsEqual(longname, "levels below the surface");
+  return (str_is_equal(longname, "depth below land")
+       || str_is_equal(longname, "depth_below_land")
+       || str_is_equal(longname, "levels below the surface"));
   // clang-format on
-
-  return status;
 }
 
 bool
 is_depth_axis(const char *stdname, const char *longname)
 {
   // clang-format off
-  bool status = strIsEqual(stdname, "depth")
-             || strIsEqual(longname, "depth_below_sea")
-             || strIsEqual(longname, "depth below sea");
+  return (str_is_equal(stdname, "depth")
+       || str_is_equal(longname, "depth_below_sea")
+       || str_is_equal(longname, "depth below sea"));
   // clang-format ofn
-
-  return status;
 }
 
 
 bool is_height_axis(const char *stdname, const char *longname)
 {
   // clang-format off
-  bool status = strIsEqual(stdname, "height")
-             || strIsEqual(longname, "height")
-             || strIsEqual(longname, "height above the surface");
+  return (str_is_equal(stdname, "height")
+       || str_is_equal(longname, "height")
+       || str_is_equal(longname, "height above the surface"));
   // clang-format on
-
-  return status;
 }
 
 bool
 is_altitude_axis(const char *stdname, const char *longname)
 {
   // clang-format off
-  bool status = strIsEqual(stdname, "altitude")
-             || strIsEqual(longname, "altitude");
+  return (str_is_equal(stdname, "altitude")
+       || str_is_equal(longname, "altitude"));
   // clang-format on
+}
 
-  return status;
+bool
+is_reference_axis(const char *stdname, const char *longname)
+{
+  // clang-format off
+  return ((str_is_equal(longname, "generalized_height") || str_is_equal(longname, "generalized height"))
+        && str_is_equal(stdname, "height"));
+  // clang-format on
 }
 
 bool
@@ -190,7 +185,7 @@ is_lon_axis(const char *units, const char *stdname)
 
   memcpy(lc_units, units, 15);
   lc_units[15] = 0;
-  strToLower(lc_units);
+  str_to_lower(lc_units);
 
   if ((strStartsWith(lc_units, "degree") || strStartsWith(lc_units, "radian"))
       && (strStartsWith(stdname, "grid_longitude") || strStartsWith(stdname, "longitude")))
@@ -217,7 +212,7 @@ is_lat_axis(const char *units, const char *stdname)
 
   memcpy(lc_units, units, 15);
   lc_units[15] = 0;
-  strToLower(lc_units);
+  str_to_lower(lc_units);
 
   if ((strStartsWith(lc_units, "degree") || strStartsWith(lc_units, "radian"))
       && (strStartsWith(stdname, "grid_latitude") || strStartsWith(stdname, "latitude")))
@@ -240,34 +235,34 @@ bool
 is_x_axis(const char *units, const char *stdname)
 {
   (void) units;
-  return (strIsEqual(stdname, "projection_x_coordinate"));
+  return (str_is_equal(stdname, "projection_x_coordinate"));
 }
 
 bool
 is_y_axis(const char *units, const char *stdname)
 {
   (void) units;
-  return (strIsEqual(stdname, "projection_y_coordinate"));
+  return (str_is_equal(stdname, "projection_y_coordinate"));
 }
 
 void
 cdf_set_gridtype(const char *attstring, int *gridtype)
 {
   // clang-format off
-  if      (strIsEqual(attstring, "gaussian_reduced")) *gridtype = GRID_GAUSSIAN_REDUCED;
-  else if (strIsEqual(attstring, "gaussian"))         *gridtype = GRID_GAUSSIAN;
+  if      (str_is_equal(attstring, "gaussian_reduced")) *gridtype = GRID_GAUSSIAN_REDUCED;
+  else if (str_is_equal(attstring, "gaussian"))         *gridtype = GRID_GAUSSIAN;
   else if (strStartsWith(attstring, "spectral"))      *gridtype = GRID_SPECTRAL;
   else if (strStartsWith(attstring, "fourier"))       *gridtype = GRID_FOURIER;
-  else if (strIsEqual(attstring, "trajectory"))       *gridtype = GRID_TRAJECTORY;
-  else if (strIsEqual(attstring, "generic"))          *gridtype = GRID_GENERIC;
-  else if (strIsEqual(attstring, "cell"))             *gridtype = GRID_UNSTRUCTURED;
-  else if (strIsEqual(attstring, "unstructured"))     *gridtype = GRID_UNSTRUCTURED;
-  else if (strIsEqual(attstring, "curvilinear")) ;
-  else if (strIsEqual(attstring, "characterxy"))      *gridtype = GRID_CHARXY;
-  else if (strIsEqual(attstring, "sinusoidal")) ;
-  else if (strIsEqual(attstring, "laea")) ;
-  else if (strIsEqual(attstring, "lcc2")) ;
-  else if (strIsEqual(attstring, "linear")) ; // ignore grid type linear
+  else if (str_is_equal(attstring, "trajectory"))       *gridtype = GRID_TRAJECTORY;
+  else if (str_is_equal(attstring, "generic"))          *gridtype = GRID_GENERIC;
+  else if (str_is_equal(attstring, "cell"))             *gridtype = GRID_UNSTRUCTURED;
+  else if (str_is_equal(attstring, "unstructured"))     *gridtype = GRID_UNSTRUCTURED;
+  else if (str_is_equal(attstring, "curvilinear")) ;
+  else if (str_is_equal(attstring, "characterxy"))      *gridtype = GRID_CHARXY;
+  else if (str_is_equal(attstring, "sinusoidal")) ;
+  else if (str_is_equal(attstring, "laea")) ;
+  else if (str_is_equal(attstring, "lcc2")) ;
+  else if (str_is_equal(attstring, "linear")) ; // ignore grid type linear
   else
     {
       static bool warn = true;
@@ -284,18 +279,18 @@ void
 cdf_set_zaxistype(const char *attstring, int *zaxistype)
 {
   // clang-format off
-  if      (strIsEqual(attstring, "toa"))              *zaxistype = ZAXIS_TOA;
-  else if (strIsEqual(attstring, "tropopause"))       *zaxistype = ZAXIS_TROPOPAUSE;
-  else if (strIsEqual(attstring, "cloudbase"))        *zaxistype = ZAXIS_CLOUD_BASE;
-  else if (strIsEqual(attstring, "cloudtop"))         *zaxistype = ZAXIS_CLOUD_TOP;
-  else if (strIsEqual(attstring, "isotherm0"))        *zaxistype = ZAXIS_ISOTHERM_ZERO;
-  else if (strIsEqual(attstring, "seabottom"))        *zaxistype = ZAXIS_SEA_BOTTOM;
-  else if (strIsEqual(attstring, "lakebottom"))       *zaxistype = ZAXIS_LAKE_BOTTOM;
-  else if (strIsEqual(attstring, "sedimentbottom"))   *zaxistype = ZAXIS_SEDIMENT_BOTTOM;
-  else if (strIsEqual(attstring, "sedimentbottomta")) *zaxistype = ZAXIS_SEDIMENT_BOTTOM_TA;
-  else if (strIsEqual(attstring, "sedimentbottomtw")) *zaxistype = ZAXIS_SEDIMENT_BOTTOM_TW;
-  else if (strIsEqual(attstring, "mixlayer"))         *zaxistype = ZAXIS_MIX_LAYER;
-  else if (strIsEqual(attstring, "atmosphere"))       *zaxistype = ZAXIS_ATMOSPHERE;
+  if      (str_is_equal(attstring, "toa"))              *zaxistype = ZAXIS_TOA;
+  else if (str_is_equal(attstring, "tropopause"))       *zaxistype = ZAXIS_TROPOPAUSE;
+  else if (str_is_equal(attstring, "cloudbase"))        *zaxistype = ZAXIS_CLOUD_BASE;
+  else if (str_is_equal(attstring, "cloudtop"))         *zaxistype = ZAXIS_CLOUD_TOP;
+  else if (str_is_equal(attstring, "isotherm0"))        *zaxistype = ZAXIS_ISOTHERM_ZERO;
+  else if (str_is_equal(attstring, "seabottom"))        *zaxistype = ZAXIS_SEA_BOTTOM;
+  else if (str_is_equal(attstring, "lakebottom"))       *zaxistype = ZAXIS_LAKE_BOTTOM;
+  else if (str_is_equal(attstring, "sedimentbottom"))   *zaxistype = ZAXIS_SEDIMENT_BOTTOM;
+  else if (str_is_equal(attstring, "sedimentbottomta")) *zaxistype = ZAXIS_SEDIMENT_BOTTOM_TA;
+  else if (str_is_equal(attstring, "sedimentbottomtw")) *zaxistype = ZAXIS_SEDIMENT_BOTTOM_TW;
+  else if (str_is_equal(attstring, "mixlayer"))         *zaxistype = ZAXIS_MIX_LAYER;
+  else if (str_is_equal(attstring, "atmosphere"))       *zaxistype = ZAXIS_ATMOSPHERE;
   else
     {
       static bool warn = true;
