@@ -40,6 +40,7 @@ int CDI_Read_Cell_Corners = 1;
 int CDI_CMOR_Mode = 0;
 int CDI_Reduce_Dim = 0;
 int CDI_Shuffle = 0;
+int CDI_Test = 0;
 size_t CDI_Netcdf_Hdr_Pad = 0UL;
 size_t CDI_Chunk_Cache = 0UL;
 size_t CDI_Chunk_Cache_Max = 0UL;
@@ -101,7 +102,7 @@ cdi_getenv_int(const char *envName)
                 case 'g': fact = 1073741824; break;
                 default:
                   fact = 0;
-                  Message("Invalid number string in %s: %s", envName, envString);
+                  Warning("Invalid number string in %s: %s", envName, envString);
                   Warning("%s must comprise only digits [0-9].", envName);
                   break;
                 }
@@ -145,9 +146,6 @@ cdiPrintVersion(void)
 #ifdef HAVE_LIBNETCDF
   fprintf(stdout, "  NetCDF library version : %s\n", cdfLibraryVersion());
 #endif
-#ifdef HAVE_NC4HDF5
-  fprintf(stdout, "    HDF5 library version : %s\n", hdfLibraryVersion());
-#endif
 #ifdef HAVE_LIBSERVICE
   fprintf(stdout, "    exse library version : %s\n", srvLibraryVersion());
 #endif
@@ -209,17 +207,13 @@ cdiPrintDatatypes(void)
 void
 cdiDebug(int level)
 {
-  unsigned ulevel = (unsigned) level;
+  unsigned ulevel = (level == 1) ? (1U << 16) : (unsigned) level;
 
-  if (ulevel == 1 || (ulevel & 2)) CDI_Debug = 1;
+  if (ulevel & 2) CDI_Debug = 1;
+  if (ulevel & 4) memDebug(1);
+  if (ulevel & 8) fileDebug(1);
 
-  if (CDI_Debug) Message("debug level %d", level);
-
-  if (ulevel == 1 || (ulevel & 4)) memDebug(1);
-
-  if (ulevel == 1 || (ulevel & 8)) fileDebug(1);
-
-  if (ulevel == 1 || (ulevel & 16))
+  if (ulevel & 16)
     {
 #ifdef HAVE_LIBCGRIBEX
       gribSetDebug(1);
@@ -373,6 +367,9 @@ cdiInitialize(void)
       value = cdi_getenv_int("CDI_CHUNK_CACHE_MAX");
       if (value >= 0) CDI_Chunk_Cache_Max = (size_t) value;
 
+      value = cdi_getenv_int("CDI_TEST");
+      if (value >= 0) CDI_Test = (size_t) value;
+
       envstr = getenv("CDI_GRIB1_TEMPLATE");
       if (envstr) CDI_GRIB1_Template = envstr;
 
@@ -413,7 +410,7 @@ cdiInitialize(void)
       envstr = getenv("CDI_CONVENTION");
       if (envstr)
         {
-          if (strcmp(envstr, "CF") == 0 || strcmp(envstr, "cf") == 0)
+          if (str_is_equal(envstr, "CF") || str_is_equal(envstr, "cf"))
             {
               CDI_Convention = CDI_CONVENTION_CF;
               if (CDI_Debug) Message("CDI convention was set to CF!");
@@ -500,18 +497,18 @@ void
 cdiDefGlobal(const char *string, int value)
 {
   // clang-format off
-  if      (strIsEqual(string, "REGULARGRID")          ) cdiDataUnreduced = value;
-  else if (strIsEqual(string, "ECCODES_DEBUG")        ) CDI_gribapi_debug = (bool) value;
-  else if (strIsEqual(string, "ECCODES_GRIB1")        ) cdiSetEccodesGrib1((bool) value);
-  else if (strIsEqual(string, "SORTNAME")             ) cdiSortName = value;
-  else if (strIsEqual(string, "SORTPARAM")            ) cdiSortParam = value;
-  else if (strIsEqual(string, "HAVE_MISSVAL")         ) cdiHaveMissval = value;
-  else if (strIsEqual(string, "NC_CHUNKSIZEHINT")     ) CDI_Netcdf_Chunksizehint = value;
-  else if (strIsEqual(string, "READ_CELL_CORNERS")    ) CDI_Read_Cell_Corners = value;
-  else if (strIsEqual(string, "CMOR_MODE")            ) CDI_CMOR_Mode = value;
-  else if (strIsEqual(string, "REDUCE_DIM")           ) CDI_Reduce_Dim = value;
-  else if (strIsEqual(string, "NETCDF_HDR_PAD")       ) CDI_Netcdf_Hdr_Pad = (size_t) value;
-  else if (strIsEqual(string, "NETCDF_LAZY_GRID_LOAD")) CDI_Netcdf_Lazy_Grid_Load = (bool) value;
+  if      (str_is_equal(string, "REGULARGRID")          ) cdiDataUnreduced = value;
+  else if (str_is_equal(string, "ECCODES_DEBUG")        ) CDI_gribapi_debug = (bool) value;
+  else if (str_is_equal(string, "ECCODES_GRIB1")        ) cdiSetEccodesGrib1((bool) value);
+  else if (str_is_equal(string, "SORTNAME")             ) cdiSortName = value;
+  else if (str_is_equal(string, "SORTPARAM")            ) cdiSortParam = value;
+  else if (str_is_equal(string, "HAVE_MISSVAL")         ) cdiHaveMissval = value;
+  else if (str_is_equal(string, "NC_CHUNKSIZEHINT")     ) CDI_Netcdf_Chunksizehint = value;
+  else if (str_is_equal(string, "READ_CELL_CORNERS")    ) CDI_Read_Cell_Corners = value;
+  else if (str_is_equal(string, "CMOR_MODE")            ) CDI_CMOR_Mode = value;
+  else if (str_is_equal(string, "REDUCE_DIM")           ) CDI_Reduce_Dim = value;
+  else if (str_is_equal(string, "NETCDF_HDR_PAD")       ) CDI_Netcdf_Hdr_Pad = (size_t) value;
+  else if (str_is_equal(string, "NETCDF_LAZY_GRID_LOAD")) CDI_Netcdf_Lazy_Grid_Load = (bool) value;
   else Warning("Unsupported global key: %s", string);
   // clang-format on
 }
@@ -543,13 +540,14 @@ cdiBaseFiletype(int filetype)
 {
   switch (filetype)
     {
+    case CDI_FILETYPE_GRB:
+    case CDI_FILETYPE_GRB2: return CDI_FILETYPE_GRIB;
     case CDI_FILETYPE_NC:
     case CDI_FILETYPE_NC2:
     case CDI_FILETYPE_NC4:
     case CDI_FILETYPE_NC4C:
     case CDI_FILETYPE_NCZARR:
     case CDI_FILETYPE_NC5: return CDI_FILETYPE_NETCDF;
-    default: return filetype;
     }
 
   return filetype;
