@@ -63,7 +63,7 @@ cgribexInit(cgribexrec_t *cgribexp)
 }
 
 void *
-cgribexNew()
+cgribexNew(void)
 {
   cgribexrec_t *cgribexp = (cgribexrec_t *) Malloc(sizeof(cgribexrec_t));
   cgribexInit(cgribexp);
@@ -199,9 +199,9 @@ cgribexGetTimeUnit(int *isec1)
     case ISEC1_TABLE4_12HOURS:   timeunit = TUNIT_12HOURS;   break;
     case ISEC1_TABLE4_DAY:       timeunit = TUNIT_DAY;       break;
     default:
-      if ( lprint )
+      if (lprint)
 	{
-	  Message("GRIB time unit %d unsupported!", ISEC1_TimeUnit);
+	  Warning("GRIB time unit %d unsupported!", ISEC1_TimeUnit);
 	  lprint = false;
 	}
       break;
@@ -235,9 +235,9 @@ cgribexGetTsteptype(int timerange)
     case  5:  tsteptype = TSTEP_DIFF;     break;
     case 10:  tsteptype = TSTEP_INSTANT3; break;
     default:
-      if ( lprint )
+      if (lprint)
 	{
-	  Message("Time range indicator %d unsupported, set to 0!", timerange);
+	  Warning("Time range indicator %d unsupported, set to 0!", timerange);
 	  lprint = false;
 	}
       break;
@@ -250,12 +250,12 @@ cgribexGetTsteptype(int timerange)
 static bool
 cgribexGetGridRegular(int *isec2, int *isec4, grid_t *grid, int gridtype, bool compyinc)
 {
-  const bool ijDirectionIncrementGiven = gribbyte_get_bit(ISEC2_ResFlag, 1);
-  const bool uvRelativeToGrid = gribbyte_get_bit(ISEC2_ResFlag, 5);
+  bool ijDirectionIncrementGiven = gribbyte_get_bit(ISEC2_ResFlag, 1);
+  bool uvRelativeToGrid = gribbyte_get_bit(ISEC2_ResFlag, 5);
 
-  const size_t nvalues = (size_t) ISEC4_NumValues;
-  const size_t nlon = (size_t) ISEC2_NumLon;
-  const size_t nlat = (size_t) ISEC2_NumLat;
+  size_t nvalues = (size_t) ISEC4_NumValues;
+  size_t nlon = (size_t) ISEC2_NumLon;
+  size_t nlat = (size_t) ISEC2_NumLat;
   if (nvalues != nlon * nlat) Error("numberOfPoints (%zu) and gridSize (%zu) differ!", nvalues, nlon * nlat);
 
   grid->size = nvalues;
@@ -336,12 +336,16 @@ cgribexGetGridRegular(int *isec2, int *isec4, grid_t *grid, int gridtype, bool c
 static bool
 cgribexGetGridReduced(int *isec2, int *isec4, grid_t *grid)
 {
-  const bool ijDirectionIncrementGiven = gribbyte_get_bit(ISEC2_ResFlag, 1);
-  const bool uvRelativeToGrid = gribbyte_get_bit(ISEC2_ResFlag, 5);
+  bool ijDirectionIncrementGiven = gribbyte_get_bit(ISEC2_ResFlag, 1);
+  bool uvRelativeToGrid = gribbyte_get_bit(ISEC2_ResFlag, 5);
   grid->np = ISEC2_NumPar;
   grid->size = (size_t) ISEC4_NumValues;
-  grid->reducedPoints = ISEC2_ReducedPointsPtr;
-  grid->reducedPointsSize = (size_t) ISEC2_NumLat;
+
+  size_t reducedPointsSize = (size_t) ISEC2_NumLat;
+  grid->reducedPointsSize = reducedPointsSize;
+  grid->reducedPoints = (int *) Malloc(reducedPointsSize * sizeof(int));
+  memcpy(grid->reducedPoints, ISEC2_ReducedPointsPtr, reducedPointsSize * sizeof(int));
+
   grid->y.size = (size_t) ISEC2_NumLat;
   grid->x.inc = 0;
   grid->y.inc = 0;
@@ -381,11 +385,11 @@ cgribexGetGridReduced(int *isec2, int *isec4, grid_t *grid)
 static bool
 cgribexGetGridLCC(int *isec2, int *isec4, grid_t *grid)
 {
-  const bool uvRelativeToGrid = gribbyte_get_bit(ISEC2_ResFlag, 5);
+  bool uvRelativeToGrid = gribbyte_get_bit(ISEC2_ResFlag, 5);
 
-  const size_t nvalues = (size_t) ISEC4_NumValues;
-  const size_t nlon = (size_t) ISEC2_NumLon;
-  const size_t nlat = (size_t) ISEC2_NumLat;
+  size_t nvalues = (size_t) ISEC4_NumValues;
+  size_t nlon = (size_t) ISEC2_NumLon;
+  size_t nlat = (size_t) ISEC2_NumLat;
   if (nvalues != nlon * nlat) Error("numberOfPoints (%zu) and gridSize (%zu) differ!", nvalues, nlon * nlat);
 
   grid->size = nvalues;
@@ -492,7 +496,7 @@ cgribexDefProjLCC(int *isec2, int gridID)
   struct CDI_GridProjParams gpp;
   gridProjParamsInit(&gpp);
 
-  const bool earthIsOblate = gribbyte_get_bit(ISEC2_ResFlag, 2);
+  bool earthIsOblate = gribbyte_get_bit(ISEC2_ResFlag, 2);
   if (earthIsOblate)
     {
       gpp.a = 6378160.0;
@@ -509,7 +513,7 @@ cgribexDefProjLCC(int *isec2, int gridID)
   gpp.lon_0 = ISEC2_Lambert_Lov * 0.001;
   gpp.lat_1 = ISEC2_Lambert_LatS1 * 0.001;
   gpp.lat_2 = ISEC2_Lambert_LatS2 * 0.001;
-  const bool lsouth = gribbyte_get_bit(ISEC2_Lambert_ProjFlag, 1);
+  bool lsouth = gribbyte_get_bit(ISEC2_Lambert_ProjFlag, 1);
   if (lsouth)
     {
       gpp.lat_1 = -gpp.lat_1;
@@ -546,12 +550,12 @@ cgribexAddRecord(stream_t *streamptr, cgribexrec_t *cgribexp, int param, size_t
   if (datatype > 32) datatype = CDI_DATATYPE_PACK32;
   if (datatype < 0) datatype = CDI_DATATYPE_PACK;
 
-  const int vlistID = streamptr->vlistID;
-  const int tsID = streamptr->curTsID;
-  const int recID = recordNewEntry(streamptr, tsID);
+  int vlistID = streamptr->vlistID;
+  int tsID = streamptr->curTsID;
+  int recID = recordNewEntry(streamptr, tsID);
   record_t *record = &streamptr->tsteps[tsID].records[recID];
 
-  const int tsteptype = cgribexGetTsteptype(ISEC1_TimeRange);
+  int tsteptype = cgribexGetTsteptype(ISEC1_TimeRange);
 
   int leveltype, level1, level2;
   cgribexGetLevel(isec1, &leveltype, &level1, &level2);
@@ -567,43 +571,36 @@ cgribexAddRecord(stream_t *streamptr, cgribexrec_t *cgribexp, int param, size_t
   record->tsteptype = (short) tsteptype;
 
   grid_t *gridptr = (grid_t *) Malloc(sizeof(*gridptr));
-  const bool uvRelativeToGrid = cgribexGetGrid(streamptr, isec2, isec4, gridptr, iret);
+  bool uvRelativeToGrid = cgribexGetGrid(streamptr, isec2, isec4, gridptr, iret);
 
   struct addIfNewRes gridAdded = cdiVlistAddGridIfNew(vlistID, gridptr, 0);
   int gridID = gridAdded.Id;
-  if (gridAdded.isNew)
+  if (!gridAdded.isNew)
     {
-      if (gridptr->reducedPointsSize)
-        {
-          const size_t reducedPointsSize = (size_t) gridptr->reducedPointsSize;
-          int *reducedPoints = gridptr->reducedPoints;
-          gridptr->reducedPoints = (int *) Malloc(reducedPointsSize * sizeof(int));
-          memcpy(gridptr->reducedPoints, reducedPoints, reducedPointsSize * sizeof(int));
-        }
-      else if (gridptr->projtype == CDI_PROJ_RLL)
-        {
-          const double xpole = ISEC2_LonSP * 0.001 - 180;
-          const double ypole = -ISEC2_LatSP * 0.001;
-          const double angle = -FSEC2_RotAngle;
-          gridDefParamRLL(gridID, xpole, ypole, angle);
-        }
-      else if (gridptr->projtype == CDI_PROJ_LCC)
-        {
-          cgribexDefProjLCC(isec2, gridID);
-        }
+      grid_free(gridptr);
+      Free(gridptr);
+    }
+  else if (gridptr->projtype == CDI_PROJ_RLL)
+    {
+      double xpole = ISEC2_LonSP * 0.001 - 180;
+      double ypole = -ISEC2_LatSP * 0.001;
+      double angle = -FSEC2_RotAngle;
+      gridDefParamRLL(gridID, xpole, ypole, angle);
+    }
+  else if (gridptr->projtype == CDI_PROJ_LCC)
+    {
+      cgribexDefProjLCC(isec2, gridID);
     }
-  else
-    Free(gridptr);
 
-  const int zaxistype = grib1ltypeToZaxisType(leveltype);
+  int zaxistype = grib1ltypeToZaxisType(leveltype);
   if (zaxistype == ZAXIS_HYBRID || zaxistype == ZAXIS_HYBRID_HALF)
     {
-      const size_t vctsize = (size_t) ISEC2_NumVCP;
+      size_t vctsize = (size_t) ISEC2_NumVCP;
       double *vctptr = &fsec2[10];
       varDefVCT(vctsize, vctptr);
     }
 
-  const bool lbounds = cgribexGetZaxisHasBounds(leveltype);
+  bool lbounds = cgribexGetZaxisHasBounds(leveltype);
 
   int varID = 0, levelID = 0;
   varAddRecord(recID, param, gridID, zaxistype, lbounds, level1, level2, 0, 0, datatype, &varID, &levelID, tsteptype, leveltype, -1,
@@ -636,8 +633,8 @@ cgribexAddRecord(stream_t *streamptr, cgribexrec_t *cgribexp, int param, size_t
 
   if (varInqInst(varID) == CDI_UNDEFID)
     {
-      const int center = ISEC1_CenterID;
-      const int subcenter = ISEC1_SubCenterID;
+      int center = ISEC1_CenterID;
+      int subcenter = ISEC1_SubCenterID;
       int instID = institutInq(center, subcenter, NULL, NULL);
       if (instID == CDI_UNDEFID) instID = institutDef(center, subcenter, NULL, NULL);
       varDefInst(varID, instID);
@@ -731,13 +728,14 @@ cgribexVarSet(int param, int level1, int level2, int leveltype, int trange)
 }
 
 static inline int
-cgribexVarCompare(compvar_t compVar, record_t record, int flag)
+cgribexVarCompare(const compvar_t *compVar, const record_t *record, int flag)
 {
-  bool vinst = compVar.tsteptype == TSTEP_INSTANT || compVar.tsteptype == TSTEP_INSTANT2 || compVar.tsteptype == TSTEP_INSTANT3;
-  bool rinst = record.tsteptype == TSTEP_INSTANT || record.tsteptype == TSTEP_INSTANT2 || record.tsteptype == TSTEP_INSTANT3;
-  int tstepDiff = (!((flag == 0) & (vinst && rinst))) & (compVar.tsteptype != record.tsteptype);
-  int rstatus = (compVar.param != record.param) | (compVar.level1 != record.ilevel) | (compVar.level2 != record.ilevel2)
-                | (compVar.ltype != record.ltype) | tstepDiff;
+  bool vinst
+      = (compVar->tsteptype == TSTEP_INSTANT || compVar->tsteptype == TSTEP_INSTANT2 || compVar->tsteptype == TSTEP_INSTANT3);
+  bool rinst = (record->tsteptype == TSTEP_INSTANT || record->tsteptype == TSTEP_INSTANT2 || record->tsteptype == TSTEP_INSTANT3);
+  int tstepDiff = (!((flag == 0) & (vinst && rinst))) & (compVar->tsteptype != record->tsteptype);
+  int rstatus = (compVar->param != record->param) | (compVar->level1 != record->ilevel) | (compVar->level2 != record->ilevel2)
+                | (compVar->ltype != record->ltype) | tstepDiff;
   return rstatus;
 }
 
@@ -745,15 +743,15 @@ cgribexVarCompare(compvar_t compVar, record_t record, int flag)
   Warning("Record %2d (id=%s lev1=%d lev2=%d) timestep %d: %s", nrecs, paramstr, level1, level2, timestep, text)
 
 static void
-cgribexSkipRecords(const int fileID)
+cgribexSkipRecords(int fileID)
 {
   int nskip = CDI_Skip_Records;
   while (nskip-- > 0)
     {
-      const size_t recsize = gribGetSize(fileID);
+      size_t recsize = gribGetSize(fileID);
       if (recsize == 0) Error("Skipping of %d records failed!", CDI_Skip_Records);
 
-      const off_t recpos = fileGetPos(fileID);
+      off_t recpos = fileGetPos(fileID);
       fileSetPos(fileID, recpos, SEEK_CUR);
     }
 }
@@ -791,19 +789,19 @@ cgribexScanTimestep1(stream_t *streamptr)
 
   cgribexrec_t *cgribexp = (cgribexrec_t *) streamptr->record->objectp;
 
-  const int tsID = tstepsNewEntry(streamptr);
+  int tsID = tstepsNewEntry(streamptr);
   if (tsID != 0) Error("Internal problem! tstepsNewEntry returns %d", tsID);
 
   taxis_t *taxis = &streamptr->tsteps[tsID].taxis;
 
-  const int fileID = streamptr->fileID;
+  int fileID = streamptr->fileID;
 
   if (CDI_Skip_Records) cgribexSkipRecords(fileID);
 
   unsigned nrecs = 0;
   while (true)
     {
-      const size_t recsize = gribGetSize(fileID);
+      size_t recsize = gribGetSize(fileID);
       recpos = fileGetPos(fileID);
 
       if (recsize == 0)
@@ -819,9 +817,9 @@ cgribexScanTimestep1(stream_t *streamptr)
       // Search for next 'GRIB', read the following record, and position file offset after it.
       if (gribRead(fileID, gribbuffer, &readsize)) break;
 
-      const int comptype = grbDecompress(recsize, &buffersize, &gribbuffer);
+      int comptype = grbDecompress(recsize, &buffersize, &gribbuffer);
 
-      const size_t sec2len = cgribexSection2Length(gribbuffer, buffersize);
+      size_t sec2len = cgribexSection2Length(gribbuffer, buffersize);
       if (sec2len > cgribexp->sec2len)
         {
           cgribexp->sec2len = sec2len;
@@ -833,13 +831,13 @@ cgribexScanTimestep1(stream_t *streamptr)
       nrecsScanned++;
       cgribexDecodeHeader(cgribexp, (int *) gribbuffer, (int) recsize, &lmv, &iret);
 
-      const int param = cdiEncodeParam(ISEC1_Parameter, ISEC1_CodeTable, 255);
+      int param = cdiEncodeParam(ISEC1_Parameter, ISEC1_CodeTable, 255);
       cdiParamToString(param, paramstr, sizeof(paramstr));
 
       cgribexGetLevel(isec1, &leveltype, &level1, &level2);
 
       CdiDateTime sDateTime;
-      const CdiDateTime vDateTime = cgribexDateTimeX(isec1, &sDateTime);
+      CdiDateTime vDateTime = cgribexDateTimeX(isec1, &sDateTime);
 
       if (nrecs == 0)
         {
@@ -858,7 +856,7 @@ cgribexScanTimestep1(stream_t *streamptr)
           record_t *records = streamptr->tsteps[tsID].records;
           for (recID = 0; recID < nrecs; recID++)
             {
-              if (cgribexVarCompare(compVar, records[recID], 0) == 0) break;
+              if (cgribexVarCompare(&compVar, &records[recID], 0) == 0) break;
             }
 
           if (CDI_Inventory_Mode == 1)
@@ -899,7 +897,8 @@ cgribexScanTimestep1(stream_t *streamptr)
       nrecs++;
 
       if (CDI_Debug)
-        Message("Read record %2d (id=%s lev1=%d lev2=%d) %s", nrecsScanned, paramstr, level1, level2, CdiDateTime_string(vDateTime));
+        Message("Read record %2d (id=%s lev1=%d lev2=%d) %s", nrecsScanned, paramstr, level1, level2,
+                CdiDateTime_string(vDateTime));
 
       cgribexAddRecord(streamptr, cgribexp, param, recsize, recpos, comptype, lmv, iret);
     }
@@ -911,9 +910,9 @@ cgribexScanTimestep1(stream_t *streamptr)
   cdi_generate_vars(streamptr);
 
   taxis->type = fcast ? TAXIS_RELATIVE : TAXIS_ABSOLUTE;
-  const int taxisID = taxisCreate(taxis->type);
+  int taxisID = taxisCreate(taxis->type);
 
-  const int vlistID = streamptr->vlistID;
+  int vlistID = streamptr->vlistID;
   vlistDefTaxis(vlistID, taxisID);
 
   streamScanResizeRecords1(streamptr);
@@ -945,8 +944,8 @@ cgribexScanTimestep2(stream_t *streamptr)
   int *isec1 = cgribexp->sec1;
   int *isec2 = cgribexp->sec2;
 
-  const int fileID = streamptr->fileID;
-  const int vlistID = streamptr->vlistID;
+  int fileID = streamptr->fileID;
+  int vlistID = streamptr->vlistID;
 
   void *gribbuffer = streamptr->record->buffer;
   size_t buffersize = streamptr->record->buffersize;
@@ -961,7 +960,7 @@ cgribexScanTimestep2(stream_t *streamptr)
   cdi_create_records(streamptr, tsID);
   record_t *records = streamptr->tsteps[tsID].records;
 
-  const int nrecords = streamScanInitRecords2(streamptr);
+  int nrecords = streamScanInitRecords2(streamptr);
 
   int nrecsScanned = nrecords;
   int rindex = 0;
@@ -969,7 +968,7 @@ cgribexScanTimestep2(stream_t *streamptr)
     {
       if (rindex > nrecords) break;
 
-      const size_t recsize = gribGetSize(fileID);
+      size_t recsize = gribGetSize(fileID);
       recpos = fileGetPos(fileID);
       if (recsize == 0)
         {
@@ -987,18 +986,18 @@ cgribexScanTimestep2(stream_t *streamptr)
       nrecsScanned++;
       cgribexDecodeHeader(cgribexp, (int *) gribbuffer, (int) recsize, &lmv, &iret);
 
-      const int param = cdiEncodeParam(ISEC1_Parameter, ISEC1_CodeTable, 255);
+      int param = cdiEncodeParam(ISEC1_Parameter, ISEC1_CodeTable, 255);
       cdiParamToString(param, paramstr, sizeof(paramstr));
 
       cgribexGetLevel(isec1, &leveltype, &level1, &level2);
 
       CdiDateTime sDateTime;
-      const CdiDateTime vDateTime = cgribexDateTimeX(isec1, &sDateTime);
+      CdiDateTime vDateTime = cgribexDateTimeX(isec1, &sDateTime);
 
       if (rindex == 0)
         {
           vDateTime0 = vDateTime;
-          const int taxisID = vlistInqTaxis(vlistID);
+          int taxisID = vlistInqTaxis(vlistID);
           if (taxisInqType(taxisID) == TAXIS_RELATIVE)
             {
               taxis->type = TAXIS_RELATIVE;
@@ -1017,7 +1016,7 @@ cgribexScanTimestep2(stream_t *streamptr)
           if (cdiDateTime_isLT(sDateTime, taxis->sDateTime)) taxis->sDateTime = sDateTime;
         }
 
-      const int tsteptype = cgribexGetTsteptype(ISEC1_TimeRange);
+      int tsteptype = cgribexGetTsteptype(ISEC1_TimeRange);
 
       if (ISEC1_AvgNum)
         {
@@ -1031,7 +1030,7 @@ cgribexScanTimestep2(stream_t *streamptr)
 
       for (recID = 0; recID < nrecords; recID++)
         {
-          if (cgribexVarCompare(compVar, records[recID], 0) == 0) break;
+          if (cgribexVarCompare(&compVar, &records[recID], 0) == 0) break;
         }
 
       if (recID == nrecords)
@@ -1069,9 +1068,10 @@ cgribexScanTimestep2(stream_t *streamptr)
         }
 
       if (CDI_Debug)
-        Message("Read record %2d (id=%s lev1=%d lev2=%d) %s", nrecsScanned, paramstr, level1, level2, CdiDateTime_string(vDateTime));
+        Message("Read record %2d (id=%s lev1=%d lev2=%d) %s", nrecsScanned, paramstr, level1, level2,
+                CdiDateTime_string(vDateTime));
 
-      if (cgribexVarCompare(compVar, streamptr->tsteps[tsID].records[recID], 0) != 0)
+      if (cgribexVarCompare(&compVar, &streamptr->tsteps[tsID].records[recID], 0) != 0)
         {
           Message("tsID = %d recID = %d param = %3d new %3d  level = %3d new %3d", tsID, recID, records[recID].param, param,
                   records[recID].ilevel, level1);
@@ -1081,8 +1081,8 @@ cgribexScanTimestep2(stream_t *streamptr)
       records[recID].position = recpos;
       records[recID].size = recsize;
 
-      const int varID = records[recID].varID;
-      const int gridID = vlistInqVarGrid(vlistID, varID);
+      int varID = records[recID].varID;
+      int gridID = vlistInqVarGrid(vlistID, varID);
       if (gridInqSize(gridID) == 1 && gridInqType(gridID) == GRID_LONLAT)
         {
           if (IS_NOT_EQUAL(gridInqXval(gridID, 0), ISEC2_FirstLon * 0.001)
@@ -1145,7 +1145,7 @@ cgribexScanTimestep(stream_t *streamptr)
 
       nrecs = streamScanInitRecords(streamptr, tsID);
 
-      const int fileID = streamptr->fileID;
+      int fileID = streamptr->fileID;
 
       fileSetPos(fileID, streamptr->tsteps[tsID].position, SEEK_SET);
 
@@ -1155,7 +1155,7 @@ cgribexScanTimestep(stream_t *streamptr)
         {
           if (rindex > nrecs) break;
 
-          const size_t recsize = gribGetSize(fileID);
+          size_t recsize = gribGetSize(fileID);
           recpos = fileGetPos(fileID);
           if (recsize == 0)
             {
@@ -1177,21 +1177,21 @@ cgribexScanTimestep(stream_t *streamptr)
           nrecsScanned++;
           cgribexDecodeHeader(cgribexp, (int *) gribbuffer, (int) recsize, &lmv, &iret);
 
-          const int param = cdiEncodeParam(ISEC1_Parameter, ISEC1_CodeTable, 255);
+          int param = cdiEncodeParam(ISEC1_Parameter, ISEC1_CodeTable, 255);
           cdiParamToString(param, paramstr, sizeof(paramstr));
 
           cgribexGetLevel(isec1, &leveltype, &level1, &level2);
 
           CdiDateTime sDateTime;
-          const CdiDateTime vDateTime = cgribexDateTimeX(isec1, &sDateTime);
+          CdiDateTime vDateTime = cgribexDateTimeX(isec1, &sDateTime);
 
           if (rindex == nrecs) break;
 
           if (rindex == 0)
             {
               vDateTime0 = vDateTime;
-              const int vlistID = streamptr->vlistID;
-              const int taxisID = vlistInqTaxis(vlistID);
+              int vlistID = streamptr->vlistID;
+              int taxisID = vlistInqTaxis(vlistID);
               if (taxisInqType(taxisID) == TAXIS_RELATIVE)
                 {
                   taxis->type = TAXIS_RELATIVE;
@@ -1223,7 +1223,7 @@ cgribexScanTimestep(stream_t *streamptr)
           for (vrecID = 0; vrecID < nrecs; vrecID++)
             {
               recID = streamptr->tsteps[1].recIDs[vrecID];
-              if (cgribexVarCompare(compVar, records[recID], 0) == 0) break;
+              if (cgribexVarCompare(&compVar, &records[recID], 0) == 0) break;
             }
 
           if (vrecID == nrecs)
@@ -1263,9 +1263,10 @@ cgribexScanTimestep(stream_t *streamptr)
             }
 
           if (CDI_Debug)
-            Message("Read record %2d (id=%s lev1=%d lev2=%d) %s", nrecsScanned, paramstr, level1, level2, CdiDateTime_string(vDateTime));
+            Message("Read record %2d (id=%s lev1=%d lev2=%d) %s", nrecsScanned, paramstr, level1, level2,
+                    CdiDateTime_string(vDateTime));
 
-          if (cgribexVarCompare(compVar, records[recID], 0) != 0)
+          if (cgribexVarCompare(&compVar, &records[recID], 0) != 0)
             {
               Message("tsID = %d recID = %d param = %3d new %3d  level = %3d new %3d", tsID, recID, records[recID].param, param,
                       records[recID].ilevel, level1);
@@ -1441,18 +1442,18 @@ cgribexDefTimerange(int tsteptype, int factor, int calendar, CdiDateTime rDateTi
 {
   JulianDate julianDate1 = julianDate_encode(calendar, rDateTime);
   JulianDate julianDate2 = julianDate_encode(calendar, vDateTime);
-  const JulianDate julianDate = julianDate_sub(julianDate2, julianDate1);
+  JulianDate julianDate = julianDate_sub(julianDate2, julianDate1);
 
   int timerange = -1;
   int ip1 = 0, ip2 = 0;
   if (!(int) (fmod(julianDate_to_seconds(julianDate), factor)))
     {
-      const int ip = (int) lround(julianDate_to_seconds(julianDate) / factor);
+      int ip = (int) lround(julianDate_to_seconds(julianDate) / factor);
       if ((ip > 255) && (tsteptype == TSTEP_INSTANT)) tsteptype = TSTEP_INSTANT3;
 
       int ipx = 0;
-      if (!cdiDateTime_isNull(sDateTime) &&
-          (tsteptype == TSTEP_RANGE || tsteptype == TSTEP_AVG || tsteptype == TSTEP_ACCUM || tsteptype == TSTEP_DIFF))
+      if (!cdiDateTime_isNull(sDateTime)
+          && (tsteptype == TSTEP_RANGE || tsteptype == TSTEP_AVG || tsteptype == TSTEP_ACCUM || tsteptype == TSTEP_DIFF))
         {
           julianDate2 = julianDate_encode(calendar, sDateTime);
           ipx = (int) lround(julianDate_to_seconds(julianDate_sub(julianDate2, julianDate1)) / factor);
@@ -1487,7 +1488,6 @@ cgribexDefDateTime(int *isec1, int timeunit, CdiDateTime dt)
   cdiTime_decode(dt.time, &hour, &minute, &second, &ms);
 
   int century = year / 100;
-
   ISEC1_Year = year - century * 100;
 
   if (year < 0)
@@ -1545,7 +1545,8 @@ cgribexDefTime(int *isec1, CdiDateTime vDateTime, int tsteptype, int numavg, int
 
   if (timetype == TAXIS_RELATIVE)
     {
-      const int calendar = taxisInqCalendar(taxisID);
+      int ip1 = 0, ip2 = 0;
+      int calendar = taxisInqCalendar(taxisID);
 
       CdiDateTime rDateTime = taxisInqRdatetime(taxisID);
       if (cdiDateTime_isLT(vDateTime, rDateTime)) rDateTime = vDateTime;
@@ -1553,22 +1554,28 @@ cgribexDefTime(int *isec1, CdiDateTime vDateTime, int tsteptype, int numavg, int
       CdiDateTime sDateTime = taxisInqSdatetime(taxisID);
 
       int factor = cgribexDefDateTime(isec1, timeunit, rDateTime);
-      int ip1 = 0, ip2 = 0;
       int timerange = cgribexDefTimerange(tsteptype, factor, calendar, rDateTime, vDateTime, sDateTime, &ip1, &ip2);
 
+      if (ip2 > 0xFF)
+        {
+          rDateTime = vDateTime;
+          factor = cgribexDefDateTime(isec1, timeunit, rDateTime);
+          timerange = cgribexDefTimerange(tsteptype, factor, calendar, rDateTime, vDateTime, sDateTime, &ip1, &ip2);
+        }
+      /*
       if (ip2 > 0xFF && timeunit < TUNIT_YEAR)
         {
           timeunit++;
           factor = cgribexDefDateTime(isec1, timeunit, rDateTime);
           timerange = cgribexDefTimerange(tsteptype, factor, calendar, rDateTime, vDateTime, sDateTime, &ip1, &ip2);
         }
-
+      */
       if (timerange == -1 || timerange == 1 || timerange == 3) timetype = TAXIS_ABSOLUTE;
       /*
-      else if ( timerange == 10 )
+      else if (timerange == 10)
         {
-          if ( ip1 < 0 || ip1 > 0xFFFF ) timetype = TAXIS_ABSOLUTE;
-          if ( ip2 < 0 || ip2 > 0xFFFF ) timetype = TAXIS_ABSOLUTE;
+          if (ip1 < 0 || ip1 > 0xFFFF) timetype = TAXIS_ABSOLUTE;
+          if (ip2 < 0 || ip2 > 0xFFFF) timetype = TAXIS_ABSOLUTE;
         }
       */
       else
@@ -1576,17 +1583,13 @@ cgribexDefTime(int *isec1, CdiDateTime vDateTime, int tsteptype, int numavg, int
           if (ip1 < 0 || ip1 > 0xFF) timetype = TAXIS_ABSOLUTE;
           if (ip2 < 0 || ip2 > 0xFF) timetype = TAXIS_ABSOLUTE;
         }
-      /*
-      static bool lwarn = true;
-      if ( lwarn && timetype == TAXIS_ABSOLUTE )
+
+      if (timetype != TAXIS_ABSOLUTE)
         {
-          lwarn = false;
-          Warning("Can't store forecast time %d %d relative to %d %d, converted to absolute time!", vdate, vtime, rdate, rtime);
+          ISEC1_TimeRange = timerange;
+          ISEC1_TimePeriod1 = ip1;
+          ISEC1_TimePeriod2 = ip2;
         }
-      */
-      ISEC1_TimeRange = timerange;
-      ISEC1_TimePeriod1 = ip1;
-      ISEC1_TimePeriod2 = ip2;
     }
 
   if (timetype == TAXIS_ABSOLUTE)
@@ -1594,7 +1597,7 @@ cgribexDefTime(int *isec1, CdiDateTime vDateTime, int tsteptype, int numavg, int
       (void) cgribexDefDateTime(isec1, timeunit, vDateTime);
 
       /*
-      if ( numavg > 0 )
+      if (numavg > 0)
         ISEC1_TimeRange = 0;
       else
       */
@@ -1712,8 +1715,8 @@ cgribexDefGridRegular(int *isec2, double *fsec2, int gridID, int gridtype, bool
 static void
 cgribexDefGridLambert(int *isec2, int gridID, int uvRelativeToGrid)
 {
-  const int xsize = (int) gridInqXsize(gridID);
-  const int ysize = (int) gridInqYsize(gridID);
+  int xsize = (int) gridInqXsize(gridID);
+  int ysize = (int) gridInqYsize(gridID);
 
   struct CDI_GridProjParams gpp;
   gridInqParamsLCC(gridID, &gpp);
@@ -1724,7 +1727,7 @@ cgribexDefGridLambert(int *isec2, int gridID, int uvRelativeToGrid)
     }
   gridVerifyProjParamsLCC(&gpp);
 
-  const bool lsouth = (gpp.lat_1 < 0);
+  bool lsouth = (gpp.lat_1 < 0);
   if (lsouth)
     {
       gpp.lat_1 = -gpp.lat_2;
@@ -1751,7 +1754,7 @@ cgribexDefGridLambert(int *isec2, int gridID, int uvRelativeToGrid)
   ISEC2_Lambert_ProjFlag = 0;
   if (lsouth) gribbyte_set_bit(&ISEC2_Lambert_ProjFlag, 1);
 
-  const bool earthIsOblate = (IS_EQUAL(gpp.a, 6378160.0) && IS_EQUAL(gpp.rf, 297.0));
+  bool earthIsOblate = (IS_EQUAL(gpp.a, 6378160.0) && IS_EQUAL(gpp.rf, 297.0));
   ISEC2_ResFlag = 0;
   if (ISEC2_Lambert_dx && ISEC2_Lambert_dy) gribbyte_set_bit(&ISEC2_ResFlag, 1);
   if (earthIsOblate) gribbyte_set_bit(&ISEC2_ResFlag, 2);
@@ -1812,10 +1815,10 @@ cgribexDefGrid(int *isec1, int *isec2, double *fsec2, int *isec4, int gridID, in
   ISEC2_Reduced = false;
   ISEC2_ScanFlag = 0;
 
-  const int gridsize = (int) gridInqSize(gridID);
+  int gridsize = (int) gridInqSize(gridID);
   bool gridIsRotated = false;
   bool gridIsCurvilinear = false;
-  const int gridtype = grbGetGridtype(&gridID, gridsize, &gridIsRotated, &gridIsCurvilinear);
+  int gridtype = grbGetGridtype(&gridID, gridsize, &gridIsRotated, &gridIsCurvilinear);
 
   switch (gridtype)
     {
@@ -1879,14 +1882,14 @@ cgribexDefLevel(int *isec1, int *isec2, double *fsec2, int zaxisID, int levelID)
   int ltype = 0;
   cdiInqKeyInt(zaxisID, CDI_GLOBAL, CDI_KEY_TYPEOFFIRSTFIXEDSURFACE, &ltype);
 
-  const bool hasBounds = (zaxisInqLbounds(zaxisID, NULL) && zaxisInqUbounds(zaxisID, NULL));
+  bool hasBounds = (zaxisInqLbounds(zaxisID, NULL) && zaxisInqUbounds(zaxisID, NULL));
   double level = zaxisInqLevels(zaxisID, NULL) ? zaxisInqLevel(zaxisID, levelID) : levelID + 1;
-  const double dlevel1 = hasBounds ? zaxisInqLbound(zaxisID, levelID) : level;
-  const double dlevel2 = hasBounds ? zaxisInqUbound(zaxisID, levelID) : 0.0;
+  double dlevel1 = hasBounds ? zaxisInqLbound(zaxisID, levelID) : level;
+  double dlevel2 = hasBounds ? zaxisInqUbound(zaxisID, levelID) : 0.0;
 
   if (zaxistype == ZAXIS_GENERIC && ltype == 0)
     {
-      Message("Changed zaxis type from %s to %s", zaxisNamePtr(zaxistype), zaxisNamePtr(ZAXIS_PRESSURE));
+      Warning("Changed zaxis type from %s to %s", zaxisNamePtr(zaxistype), zaxisNamePtr(ZAXIS_PRESSURE));
       zaxistype = ZAXIS_PRESSURE;
       zaxisChangeType(zaxisID, zaxistype);
       cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS, "Pa");
@@ -2021,9 +2024,9 @@ cgribexDefEnsembleVar(int *isec1, int vlistID, int varID)
   // Put2Byte(isec1[39]);        // number of forecasts in ensemble
 
   int perturbationNumber, numberOfForecastsInEnsemble, typeOfEnsembleForecast;
-  const int r1 = cdiInqKeyInt(vlistID, varID, CDI_KEY_PERTURBATIONNUMBER, &perturbationNumber);
-  const int r2 = cdiInqKeyInt(vlistID, varID, CDI_KEY_NUMBEROFFORECASTSINENSEMBLE, &numberOfForecastsInEnsemble);
-  const int r3 = cdiInqKeyInt(vlistID, varID, CDI_KEY_TYPEOFENSEMBLEFORECAST, &typeOfEnsembleForecast);
+  int r1 = cdiInqKeyInt(vlistID, varID, CDI_KEY_PERTURBATIONNUMBER, &perturbationNumber);
+  int r2 = cdiInqKeyInt(vlistID, varID, CDI_KEY_NUMBEROFFORECASTSINENSEMBLE, &numberOfForecastsInEnsemble);
+  int r3 = cdiInqKeyInt(vlistID, varID, CDI_KEY_TYPEOFENSEMBLEFORECAST, &typeOfEnsembleForecast);
 
   if (r1 == 0 && r2 == 0 && r3 == 0)
     {
@@ -2044,7 +2047,7 @@ cgribexEncode(int memtype, int varID, int levelID, int vlistID, int gridID, int
 {
   cgribexrec_t *cgribexp = (cgribexrec_t *) cgribexNew();
 
-  const size_t sec2len = 1024 + 2 * gridInqYsize(gridID);  // Gaussian reduced grid
+  size_t sec2len = 1024 + 2 * gridInqYsize(gridID);  // Gaussian reduced grid
   if (sec2len > cgribexp->sec2len)
     {
       cgribexp->sec2len = sec2len;
@@ -2067,8 +2070,8 @@ cgribexEncode(int memtype, int varID, int levelID, int vlistID, int gridID, int
   fsec2f[0] = 0;
   fsec2f[1] = 0;
 
-  const int gribsize = (int) (gribbuffersize / sizeof(int));
-  const int param = vlistInqVarParam(vlistID, varID);
+  int gribsize = (int) (gribbuffersize / sizeof(int));
+  int param = vlistInqVarParam(vlistID, varID);
 
   cgribexDefaultSec0(isec0);
   cgribexDefaultSec1(isec1);
@@ -2077,7 +2080,7 @@ cgribexEncode(int memtype, int varID, int levelID, int vlistID, int gridID, int
   cgribexDefInstitut(isec1, vlistID, varID);
   cgribexDefModel(isec1, vlistID, varID);
 
-  const int datatype = vlistInqVarDatatype(vlistID, varID);
+  int datatype = vlistInqVarDatatype(vlistID, varID);
 
   int uvRelativeToGrid = -1;
   cdiInqKeyInt(vlistID, varID, CDI_KEY_UVRELATIVETOGRID, &uvRelativeToGrid);
@@ -2130,7 +2133,7 @@ cgribexEncode(int memtype, int varID, int levelID, int vlistID, int gridID, int
 
   if (iret) Error("Problem during GRIB encode (errno = %d)!", iret);
 
-  const size_t nbytes = (size_t) iword * sizeof(int);
+  size_t nbytes = (size_t) iword * sizeof(int);
   return nbytes;
 }
 
