@@ -32,24 +32,24 @@
 
 // compute insitu temperature from potential temperature
 static inline double
-adisit(const double tpot, const double sal, const double p)
+adisit(double tpot, double sal, double p)
 {
   constexpr double a_a1 = 3.6504E-4, a_a2 = 8.3198E-5, a_a3 = 5.4065E-7, a_a4 = 4.0274E-9, a_b1 = 1.7439E-5, a_b2 = 2.9778E-7,
                    a_c1 = 8.9309E-7, a_c2 = 3.1628E-8, a_c3 = 2.1987E-10, a_d = 4.1057E-9, a_e1 = 1.6056E-10, a_e2 = 5.0484E-12;
 
-  const double qc = p * (a_a1 + p * (a_c1 - a_e1 * p));
-  const double qv = p * (a_b1 - a_d * p);
-  const double dc = 1.0 + p * (-a_a2 + p * (a_c2 - a_e2 * p));
-  const double dv = a_b2 * p;
-  const double qnq = -p * (-a_a3 + p * a_c3);
-  const double qn3 = -p * a_a4;
+  double qc = p * (a_a1 + p * (a_c1 - a_e1 * p));
+  double qv = p * (a_b1 - a_d * p);
+  double dc = 1.0 + p * (-a_a2 + p * (a_c2 - a_e2 * p));
+  double dv = a_b2 * p;
+  double qnq = -p * (-a_a3 + p * a_c3);
+  double qn3 = -p * a_a4;
 
-  const double tpo = tpot;
-  const double qvs = qv * (sal - 35.0) + qc;
-  const double dvs = dv * (sal - 35.0) + dc;
+  double tpo = tpot;
+  double qvs = qv * (sal - 35.0) + qc;
+  double dvs = dv * (sal - 35.0) + dc;
   double t = (tpo + qvs) / dvs;
-  const double fne = -qvs + t * (dvs + t * (qnq + t * qn3)) - tpo;
-  const double fst = dvs + t * (2.0 * qnq + 3.0 * qn3 * t);
+  double fne = -qvs + t * (dvs + t * (qnq + t * qn3)) - tpo;
+  double fst = dvs + t * (2.0 * qnq + 3.0 * qn3 * t);
   t = t - fne / fst;
 
   return t;
@@ -58,20 +58,20 @@ adisit(const double tpot, const double sal, const double p)
 // compute potential temperature from insitu temperature
 // Ref: Gill, p. 602, Section A3.5:Potential Temperature
 static inline double
-adipot(const double t, const double s, const double p)
+adipot(double t, double s, double p)
 {
   constexpr double a_a1 = 3.6504E-4, a_a2 = 8.3198E-5, a_a3 = 5.4065E-7, a_a4 = 4.0274E-9, a_b1 = 1.7439E-5, a_b2 = 2.9778E-7,
                    a_c1 = 8.9309E-7, a_c2 = 3.1628E-8, a_c3 = 2.1987E-10, a_d = 4.1057E-9, a_e1 = 1.6056E-10, a_e2 = 5.0484E-12;
 
-  const double s_rel = s - 35.0;
+  double s_rel = s - 35.0;
 
-  const double aa = (a_a1 + t * (a_a2 - t * (a_a3 - a_a4 * t)));
-  const double bb = s_rel * (a_b1 - a_b2 * t);
-  const double cc = (a_c1 + t * (-a_c2 + a_c3 * t));
-  const double cc1 = a_d * s_rel;
-  const double dd = (-a_e1 + a_e2 * t);
+  double aa = (a_a1 + t * (a_a2 - t * (a_a3 - a_a4 * t)));
+  double bb = s_rel * (a_b1 - a_b2 * t);
+  double cc = (a_c1 + t * (-a_c2 + a_c3 * t));
+  double cc1 = a_d * s_rel;
+  double dd = (-a_e1 + a_e2 * t);
 
-  const double tpot = t - p * (aa + bb + p * (cc - cc1 + p * dd));
+  double tpot = t - p * (aa + bb + p * (cc - cc1 + p * dd));
 
   return tpot;
 }
@@ -89,12 +89,12 @@ calc_adisit(size_t gridsize, size_t nlevel, const Varray<double> &pressure, cons
       const auto &thovec = tho[levelID].vec_d;
       const auto &saovec = sao[levelID].vec_d;
       auto &tisvec = tis[levelID].vec_d;
-      const auto thoMissval = tho[levelID].missval;
-      const auto saoMissval = sao[levelID].missval;
-      const auto tisMissval = tis[levelID].missval;
+      auto thoMissval = tho[levelID].missval;
+      auto saoMissval = sao[levelID].missval;
+      auto tisMissval = tis[levelID].missval;
       for (size_t i = 0; i < gridsize; ++i)
         {
-          const auto isMissing = (DBL_IS_EQUAL(thovec[i], thoMissval) || DBL_IS_EQUAL(saovec[i], saoMissval));
+          auto isMissing = (dbl_is_equal(thovec[i], thoMissval) || dbl_is_equal(saovec[i], saoMissval));
           tisvec[i] = isMissing ? tisMissval : adisit(thovec[i], saovec[i], pressure[levelID]);
         }
     }
@@ -113,46 +113,33 @@ calc_adipot(size_t gridsize, size_t nlevel, const Varray<double> &pressure, cons
       const auto &tvec = t[levelID].vec_d;
       const auto &svec = s[levelID].vec_d;
       auto &tpotvec = tpot[levelID].vec_d;
-      const auto tMissval = t[levelID].missval;
-      const auto sMissval = s[levelID].missval;
-      const auto tpotMissval = tpot[levelID].missval;
+      auto tMissval = t[levelID].missval;
+      auto sMissval = s[levelID].missval;
+      auto tpotMissval = tpot[levelID].missval;
       for (size_t i = 0; i < gridsize; ++i)
         {
-          const auto isMissing = (DBL_IS_EQUAL(tvec[i], tMissval) || DBL_IS_EQUAL(svec[i], sMissval));
+          auto isMissing = (dbl_is_equal(tvec[i], tMissval) || dbl_is_equal(svec[i], sMissval));
           tpotvec[i] = isMissing ? tpotMissval : adipot(tvec[i], svec[i], pressure[levelID]);
         }
     }
 }
 
 int
-getCode(const int vlistID1, const int varID, const std::string &cname)
+get_code(int vlistID1, int varID, const std::string &cname)
 {
-  char varname[CDI_MAX_NAME];
-  char stdname[CDI_MAX_NAME];
-
-  int code = vlistInqVarCode(vlistID1, varID);
+  auto code = vlistInqVarCode(vlistID1, varID);
   if (code <= 0)
     {
-      vlistInqVarName(vlistID1, varID, varname);
-      cstr_to_lower_case(varname);
+      auto varname = string_to_lower(cdo::inq_var_name(vlistID1, varID));
+      auto stdname = string_to_lower(cdo::inq_key_string(vlistID1, varID, CDI_KEY_STDNAME));
 
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(vlistID1, varID, CDI_KEY_STDNAME, stdname, &length);
-      cstr_to_lower_case(stdname);
-
-      if (cdo_cmpstr(varname, "s") || cdo_cmpstr(stdname, "sea_water_salinity"))
-        {
-          code = 5;
-        }
-      else if (cdo_cmpstr(varname, "t"))
+      if (varname == "s" || stdname == "sea_water_salinity") { code = 5; }
+      else if (varname == "t")
         {
           code = 2;
         }
 
-      if (cdo_cmpstr(stdname, cname.c_str()))
-        {
-          code = 2;
-        }
+      if (stdname == cname) code = 2;
     }
 
   return code;
@@ -161,38 +148,36 @@ getCode(const int vlistID1, const int varID, const std::string &cname)
 struct IOSettings
 {
   CdoStreamID streamID2;
-  const int vlistID2;
-  const size_t gridsize;
-  const int nlevels;
-  const int taxisID1;
-  const int taxisID2;
-  const int tisID2;
-  const int saoID2;
+  int vlistID2;
+  size_t gridsize;
+  int nlevels;
+  int taxisID1;
+  int taxisID2;
+  int tisID2;
+  int saoID2;
 };
 
 IOSettings
-configureOutput(const std::function<void(const int, const int)> &outputSettingFunc, const int vlistID1, const int thoID,
-                const int saoID, char *units, FieldVector &tho, FieldVector &sao, FieldVector &tis, Varray<double> &pressure)
+configureOutput(const std::function<void(const int, const int)> &outputSettingFunc, int vlistID1, int thoID, int saoID,
+                FieldVector &tho, FieldVector &sao, FieldVector &tis, Varray<double> &pressure)
 {
-  const double pin = (cdo_operator_argc() == 1) ? parameter_to_double(cdo_operator_argv(0)) : -1.0;
+  double pin = (cdo_operator_argc() == 1) ? parameter_to_double(cdo_operator_argv(0)) : -1.0;
 
-  int length = CDI_MAX_NAME;
-  cdiInqKeyString(vlistID1, thoID, CDI_KEY_UNITS, units, &length);
-  if (length == 0)
-    {
-      strcpy(units, "Celcius");
-    }
+  VarList varList1;
+  varListInit(varList1, vlistID1);
 
-  const int gridID = vlistGrid(vlistID1, 0);
-  const size_t gridsize = vlist_check_gridsize(vlistID1);
+  auto units = varList1[thoID].units;
+  if (units.empty()) units = "Celcius";
 
-  auto zaxisID = vlistInqVarZaxis(vlistID1, saoID);
-  const auto nlevels1 = zaxisInqSize(zaxisID);
-  zaxisID = vlistInqVarZaxis(vlistID1, thoID);
-  const auto nlevels2 = zaxisInqSize(zaxisID);
+  auto gridID = vlistGrid(vlistID1, 0);
+  auto gridsize = vlist_check_gridsize(vlistID1);
+
+  auto nlevels1 = varList1[saoID].nlevels;
+  auto nlevels2 = varList1[thoID].nlevels;
+  auto zaxisID = varList1[thoID].zaxisID;
 
   if (nlevels1 != nlevels2) cdo_abort("temperature and salinity have different number of levels!");
-  const auto nlevels = nlevels1;
+  auto nlevels = nlevels1;
 
   pressure.resize(nlevels);
   cdo_zaxis_inq_levels(zaxisID, pressure.data());
@@ -216,26 +201,26 @@ configureOutput(const std::function<void(const int, const int)> &outputSettingFu
       tho[levelID].resize(gridsize);
       sao[levelID].resize(gridsize);
       tis[levelID].resize(gridsize);
-      tho[levelID].missval = vlistInqVarMissval(vlistID1, thoID);
-      sao[levelID].missval = vlistInqVarMissval(vlistID1, saoID);
+      tho[levelID].missval = varList1[thoID].missval;
+      sao[levelID].missval = varList1[saoID].missval;
       tis[levelID].missval = tho[levelID].missval;
     }
 
   int datatype = CDI_DATATYPE_FLT32;
-  if (vlistInqVarDatatype(vlistID1, thoID) == CDI_DATATYPE_FLT64 && vlistInqVarDatatype(vlistID1, saoID) == CDI_DATATYPE_FLT64)
+  if (varList1[thoID].datatype == CDI_DATATYPE_FLT64 && varList1[saoID].datatype == CDI_DATATYPE_FLT64)
     datatype = CDI_DATATYPE_FLT64;
 
-  const int vlistID2 = vlistCreate();
+  auto vlistID2 = vlistCreate();
   vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
 
-  const int tisID2 = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
+  auto tisID2 = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
 
   outputSettingFunc(vlistID2, tisID2);
-  cdiDefKeyString(vlistID2, tisID2, CDI_KEY_UNITS, units);
+  cdiDefKeyString(vlistID2, tisID2, CDI_KEY_UNITS, units.c_str());
   vlistDefVarMissval(vlistID2, tisID2, tis[0].missval);
   vlistDefVarDatatype(vlistID2, tisID2, datatype);
 
-  const auto saoID2 = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
+  auto saoID2 = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
   vlistDefVarParam(vlistID2, saoID2, cdiEncodeParam(5, 255, 255));
   cdiDefKeyString(vlistID2, saoID2, CDI_KEY_NAME, "s");
   cdiDefKeyString(vlistID2, saoID2, CDI_KEY_LONGNAME, "Sea water salinity");
@@ -244,11 +229,11 @@ configureOutput(const std::function<void(const int, const int)> &outputSettingFu
   vlistDefVarMissval(vlistID2, saoID2, sao[0].missval);
   vlistDefVarDatatype(vlistID2, saoID2, datatype);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
   return IOSettings{ streamID2, vlistID2, gridsize, nlevels, taxisID1, taxisID2, tisID2, saoID2 };
@@ -258,76 +243,74 @@ void *
 Adisit(void *process)
 {
   int thoID = -1, saoID = -1;
-  char units[CDI_MAX_NAME] = { 0 };
 
   cdo_initialize(process);
 
-  const int ADISIT = cdo_operator_add("adisit", 0, 0, "");
-  const int ADIPOT = cdo_operator_add("adipot", 0, 0, "");
+  auto ADISIT = cdo_operator_add("adisit", 0, 0, "");
+  auto ADIPOT = cdo_operator_add("adipot", 0, 0, "");
 
-  const int operatorID = cdo_operator_id();
+  auto operatorID = cdo_operator_id();
 
-  const CdoStreamID streamID1 = cdo_open_read(0);
-  const int vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto streamID1 = cdo_open_read(0);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
-  const std::string cname_ADISIT{ "sea_water_potential_temperature" };
-  const std::string cname_ADIPOT{ "sea_water_temperature" };
-  const std::string cname = std::string{ (operatorID == ADISIT) ? cname_ADISIT : cname_ADIPOT };
+  std::string cname_ADISIT{ "sea_water_potential_temperature" };
+  std::string cname_ADIPOT{ "sea_water_temperature" };
+  std::string cname = std::string{ (operatorID == ADISIT) ? cname_ADISIT : cname_ADIPOT };
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const int code = getCode(vlistID1, varID, cname);
+      auto code = get_code(vlistID1, varID, cname);
 
-      if (code == 2)
-        {
-          thoID = varID;
-        }
+      if (code == 2) { thoID = varID; }
       else if (code == 20 && operatorID == ADIPOT)
         {
           thoID = varID;
         }
       else if (code == 5)
-        saoID = varID;
+        {
+          saoID = varID;
+        }
     }
 
   if (saoID == -1) cdo_abort("Sea water salinity not found!");
   if (thoID == -1) cdo_abort("%s temperature not found!", (operatorID == ADISIT) ? "Potential" : "Insitu");
 
-  auto outputSetting_ADISIT = [](const int vlistID2, const int tisID2) {
+  auto outputSetting_ADISIT = [](int vlistID2, int tisID2) {
     vlistDefVarParam(vlistID2, tisID2, cdiEncodeParam(20, 255, 255));
     cdiDefKeyString(vlistID2, tisID2, CDI_KEY_NAME, "to");
     cdiDefKeyString(vlistID2, tisID2, CDI_KEY_LONGNAME, "Sea water temperature");
     cdiDefKeyString(vlistID2, tisID2, CDI_KEY_STDNAME, "sea_water_temperature");
   };
 
-  auto outputSetting_ADIPOT = [](const int vlistID2, const int tisID2) {
+  auto outputSetting_ADIPOT = [](int vlistID2, int tisID2) {
     vlistDefVarParam(vlistID2, tisID2, cdiEncodeParam(2, 255, 255));
     cdiDefKeyString(vlistID2, tisID2, CDI_KEY_NAME, "tho");
     cdiDefKeyString(vlistID2, tisID2, CDI_KEY_LONGNAME, "Sea water potential temperature");
     cdiDefKeyString(vlistID2, tisID2, CDI_KEY_STDNAME, "sea_water_potential_temperature");
   };
 
-  const auto outputSettingFunc = (operatorID == ADISIT) ? outputSetting_ADISIT : outputSetting_ADIPOT;
+  auto outputSettingFunc = (operatorID == ADISIT) ? outputSetting_ADISIT : outputSetting_ADIPOT;
 
   FieldVector tho, sao, tis;
   Varray<double> pressure;
-  const auto &configResults = configureOutput(outputSettingFunc, vlistID1, thoID, saoID, units, tho, sao, tis, pressure);
+  const auto &configResults = configureOutput(outputSettingFunc, vlistID1, thoID, saoID, tho, sao, tis, pressure);
 
-  const CdoStreamID streamID2 = configResults.streamID2;
-  const int vlistID2 = configResults.vlistID2;
-  const size_t gridsize = configResults.gridsize;
-  const int nlevels = configResults.nlevels;
-  const int taxisID1 = configResults.taxisID1;
-  const int taxisID2 = configResults.taxisID2;
-  const int tisID2 = configResults.tisID2;
-  const int saoID2 = configResults.saoID2;
+  auto streamID2 = configResults.streamID2;
+  auto vlistID2 = configResults.vlistID2;
+  auto gridsize = configResults.gridsize;
+  auto nlevels = configResults.nlevels;
+  auto taxisID1 = configResults.taxisID1;
+  auto taxisID2 = configResults.taxisID2;
+  auto tisID2 = configResults.tisID2;
+  auto saoID2 = configResults.saoID2;
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -344,7 +327,7 @@ Adisit(void *process)
             {
               constexpr double MIN_T = -10.0;
               constexpr double MAX_T = 40.0;
-              const auto mm = field_min_max(tho[levelID]);
+              auto mm = field_min_max(tho[levelID]);
               if (mm.min < MIN_T || mm.max > MAX_T)
                 cdo_warning("Temperature in degree Celsius out of range (min=%g max=%g) [timestep:%d levelIndex:%d]!", mm.min,
                             mm.max, tsID + 1, levelID + 1);
