@@ -46,15 +46,15 @@ addOperators(void)
 void *
 Arith(void *process)
 {
-  enum
+  enum class FillType
   {
-    FILL_NONE,
-    FILL_TS,
-    FILL_VAR,
-    FILL_VARTS,
-    FILL_FILE
+    NONE,
+    TS,
+    VAR,
+    VARTS,
+    FILE
   };
-  int fillType = FILL_NONE;
+  auto fillType{ FillType::NONE };
   int nlevels2 = 1;
   int levelID2 = -1;
   Varray2D<size_t> varnmiss;
@@ -66,9 +66,9 @@ Arith(void *process)
 
   addOperators();
 
-  const auto operatorID = cdo_operator_id();
-  const auto operfunc = cdo_operator_f1(operatorID);
-  const bool opercplx = cdo_operator_f2(operatorID);
+  auto operatorID = cdo_operator_id();
+  auto operfunc = cdo_operator_f1(operatorID);
+  bool opercplx = cdo_operator_f2(operatorID);
 
   operator_check_argc(0);
 
@@ -97,8 +97,8 @@ Arith(void *process)
   if (ntsteps1 == 0) ntsteps1 = 1;
   if (ntsteps2 == 0) ntsteps2 = 1;
 
-  const auto nvars1 = vlistNvars(vlistID1);
-  const auto nvars2 = vlistNvars(vlistID2);
+  auto nvars1 = vlistNvars(vlistID1);
+  auto nvars2 = vlistNvars(vlistID2);
 
   auto fillStream1 = false, fillStream2 = false, fillStream1x = false;
   if (nvars1 == 1 && nvars2 == 1)
@@ -122,7 +122,7 @@ Arith(void *process)
     {
       nlevels2 = vlist_compare_x(vlistID2, vlistID1, CMP_DIM);
 
-      fillType = FILL_NONE;
+      fillType = FillType::NONE;
       cdo_print("Filling up stream1 >%s< by copying the first variable of each timestep.", cdo_get_stream_name(0));
     }
   else if (fillStream2)
@@ -131,12 +131,12 @@ Arith(void *process)
 
       if (ntsteps1 != 1 && ntsteps2 == 1)
         {
-          fillType = FILL_VAR;
+          fillType = FillType::VAR;
           cdo_print("Filling up stream2 >%s< by copying the first variable.", cdo_get_stream_name(1));
         }
       else
         {
-          fillType = FILL_VARTS;
+          fillType = FillType::VARTS;
           cdo_print("Filling up stream2 >%s< by copying the first variable of each timestep.", cdo_get_stream_name(1));
         }
     }
@@ -146,12 +146,12 @@ Arith(void *process)
 
       if (ntsteps1 == 1 && ntsteps2 != 1)
         {
-          fillType = FILL_VAR;
+          fillType = FillType::VAR;
           cdo_print("Filling up stream1 >%s< by copying the first variable.", cdo_get_stream_name(0));
         }
       else
         {
-          fillType = FILL_VARTS;
+          fillType = FillType::VARTS;
           cdo_print("Filling up stream1 >%s< by copying the first variable of each timestep.", cdo_get_stream_name(0));
         }
 
@@ -163,16 +163,16 @@ Arith(void *process)
       fieldx2 = &field1;
     }
 
-  if (fillStream1x == false && fillType == FILL_NONE) vlist_compare(vlistID1, vlistID2, CMP_ALL);
+  if (fillStream1x == false && fillType == FillType::NONE) vlist_compare(vlistID1, vlistID2, CMP_ALL);
 
-  const size_t nwpv = (vlistNumber(vlistID1x) == CDI_COMP && vlistNumber(vlistID2x) == CDI_COMP) ? 2 : 1;
+  size_t nwpv = (vlistNumber(vlistID1x) == CDI_COMP && vlistNumber(vlistID2x) == CDI_COMP) ? 2 : 1;
   if (nwpv == 2 && !opercplx) cdo_abort("Fields with complex numbers are not supported by this operator!");
-  const auto gridsizemax = nwpv * vlistGridsizeMax(vlistID1x);
+  auto gridsizemax = nwpv * vlistGridsizeMax(vlistID1x);
 
   field1.resize(gridsizemax);
   field2.resize(gridsizemax);
 
-  if (fillStream1x || fillType == FILL_VAR || fillType == FILL_VARTS)
+  if (fillStream1x || fillType == FillType::VAR || fillType == FillType::VARTS)
     {
       vardata2.resize(gridsizemax * nlevels2);
       varnmiss2.resize(nlevels2);
@@ -180,16 +180,16 @@ Arith(void *process)
 
   if (Options::cdoVerbose) cdo_print("Number of timesteps: file1 %d, file2 %d", ntsteps1, ntsteps2);
 
-  if (fillType == FILL_NONE)
+  if (fillType == FillType::NONE)
     {
       if (ntsteps1 != 1 && ntsteps2 == 1)
         {
-          fillType = FILL_TS;
+          fillType = FillType::TS;
           cdo_print("Filling up stream2 >%s< by copying the first timestep.", cdo_get_stream_name(1));
         }
       else if (ntsteps1 == 1 && ntsteps2 != 1)
         {
-          fillType = FILL_TS;
+          fillType = FillType::TS;
           cdo_print("Filling up stream1 >%s< by copying the first timestep.", cdo_get_stream_name(0));
 
           std::swap(streamID1, streamID2);
@@ -200,29 +200,29 @@ Arith(void *process)
           fieldx2 = &field1;
         }
 
-      if (fillType == FILL_TS) cdo_fill_ts(vlistID2x, vardata, varnmiss);
+      if (fillType == FillType::TS) cdo_fill_ts(vlistID2x, vardata, varnmiss);
     }
 
-  const auto streamsSwaped = (fillType == FILL_TS && vlistID1x != vlistID1);
+  auto streamsSwaped = (fillType == FillType::TS && vlistID1x != vlistID1);
 
-  const auto vlistID3 = vlistDuplicate(streamsSwaped ? vlistID1 : vlistID1x);
+  auto vlistID3 = vlistDuplicate(streamsSwaped ? vlistID1 : vlistID1x);
   if (streamsSwaped)
     {
-      const auto nvars = vlistNvars(vlistID1);
+      auto nvars = vlistNvars(vlistID1);
       for (int varID = 0; varID < nvars; ++varID) vlistDefVarMissval(vlistID3, varID, vlistInqVarMissval(vlistID1, varID));
       for (int varID = 0; varID < nvars; ++varID) vlistDefVarTimetype(vlistID3, varID, vlistInqVarTimetype(vlistID1x, varID));
     }
 
   if (fillStream1x)
     {
-      const auto zaxisID2 = vlistZaxis(vlistID2x, 0);
+      auto zaxisID2 = vlistZaxis(vlistID2x, 0);
       vlistChangeZaxisIndex(vlistID3, 0, zaxisID2);
     }
 
-  const auto taxisID3 = taxisDuplicate(taxisID1);
+  auto taxisID3 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID3, taxisID3);
 
-  const auto streamID3 = cdo_open_write(2);
+  auto streamID3 = cdo_open_write(2);
   cdo_def_vlist(streamID3, vlistID3);
 
   VarList varList1, varList2;
@@ -237,20 +237,20 @@ Arith(void *process)
       nrecs = cdo_stream_inq_timestep(streamID1, tsID);
 
       nrecs2 = 0;
-      if (tsID == 0 || fillType == FILL_NONE || fillType == FILL_FILE || fillType == FILL_VARTS)
+      if (tsID == 0 || fillType == FillType::NONE || fillType == FillType::FILE || fillType == FillType::VARTS)
         {
           nrecs2 = cdo_stream_inq_timestep(streamID2, tsID2);
           if (nrecs2 == 0)
             {
               if (nrecs == 0) break;
 
-              if (fillType == FILL_NONE && streamID2x == streamID2)
+              if (fillType == FillType::NONE && streamID2x == streamID2)
                 {
-                  fillType = FILL_FILE;
+                  fillType = FillType::FILE;
                   cdo_print("Filling up stream2 >%s< by copying all timesteps.", cdo_get_stream_name(1));
                 }
 
-              if (fillType == FILL_FILE)
+              if (fillType == FillType::FILE)
                 {
                   cdo_stream_close(streamID2);
 
@@ -272,12 +272,12 @@ Arith(void *process)
             }
         }
 
-      if (nrecs == 0 || (nrecs2 == 0 && fillType != FILL_TS && fillType != FILL_VAR)) break;
+      if (nrecs == 0 || (nrecs2 == 0 && fillType != FillType::TS && fillType != FillType::VAR)) break;
 
       cdo_taxis_copy_timestep(taxisID3, taxisID1);
       cdo_def_timestep(streamID3, tsID);
 
-      const auto numrecs = fillStream1x ? nrecs2 : nrecs;
+      auto numrecs = fillStream1x ? nrecs2 : nrecs;
       for (int recID = 0; recID < numrecs; ++recID)
         {
           auto lread1 = true;
@@ -290,7 +290,7 @@ Arith(void *process)
 
               if (fillStream1x)
                 {
-                  const auto gridsize = nwpv * varList1[varID].gridsize;
+                  auto gridsize = nwpv * varList1[varID].gridsize;
                   array_copy(gridsize, fieldx1->vec_d.data(), &vardata2[0]);
                   varnmiss2[0] = fieldx1->nmiss;
                 }
@@ -300,10 +300,10 @@ Arith(void *process)
 
           auto varID2 = varID;
 
-          if (tsID == 0 || fillType == FILL_NONE || fillType == FILL_FILE || fillType == FILL_VARTS)
+          if (tsID == 0 || fillType == FillType::NONE || fillType == FillType::FILE || fillType == FillType::VARTS)
             {
-              const auto lstatus = (nlevels2 > 1) ? (varID == 0) : (recID == 0);
-              if (lstatus || (fillType != FILL_VAR && fillType != FILL_VARTS))
+              auto lstatus = (nlevels2 > 1) ? (varID == 0) : (recID == 0);
+              if (lstatus || (fillType != FillType::VAR && fillType != FillType::VARTS))
                 {
                   cdo_inq_record(streamID2, &varID2, &levelID2);
                   cdo_read_record(streamID2, fieldx2->vec_d.data(), &fieldx2->nmiss);
@@ -311,32 +311,32 @@ Arith(void *process)
                   if (fillStream1x == false && levelID != levelID2) cdo_abort("Internal error, levelIDs of input streams differ!");
                 }
 
-              if (fillType == FILL_TS)
+              if (fillType == FillType::TS)
                 {
-                  const auto gridsize = nwpv * varList2[varID].gridsize;
-                  const auto offset = gridsize * levelID;
+                  auto gridsize = nwpv * varList2[varID].gridsize;
+                  auto offset = gridsize * levelID;
                   array_copy(gridsize, fieldx2->vec_d.data(), &vardata[varID][offset]);
                   varnmiss[varID][levelID] = fieldx2->nmiss;
                 }
-              else if (lstatus && (fillType == FILL_VAR || fillType == FILL_VARTS))
+              else if (lstatus && (fillType == FillType::VAR || fillType == FillType::VARTS))
                 {
-                  const auto gridsize = nwpv * varList2[0].gridsize;
-                  const auto offset = gridsize * levelID2;
+                  auto gridsize = nwpv * varList2[0].gridsize;
+                  auto offset = gridsize * levelID2;
                   array_copy(gridsize, fieldx2->vec_d.data(), &vardata2[offset]);
                   varnmiss2[levelID2] = fieldx2->nmiss;
                 }
             }
-          else if (fillType == FILL_TS)
+          else if (fillType == FillType::TS)
             {
-              const auto gridsize = nwpv * varList2[varID2].gridsize;
-              const auto offset = gridsize * levelID;
+              auto gridsize = nwpv * varList2[varID2].gridsize;
+              auto offset = gridsize * levelID;
               array_copy(gridsize, &vardata[varID][offset], fieldx2->vec_d.data());
               fieldx2->nmiss = varnmiss[varID][levelID];
             }
 
           if (fillStream1x)
             {
-              const auto gridsize = nwpv * varList1[0].gridsize;
+              auto gridsize = nwpv * varList1[0].gridsize;
               array_copy(gridsize, &vardata2[0], fieldx1->vec_d.data());
               fieldx1->nmiss = varnmiss2[0];
             }
@@ -345,11 +345,11 @@ Arith(void *process)
           fieldx1->missval = varList1[varID].missval;
           fieldx1->nwpv = varList1[varID].nwpv;
 
-          if (fillType == FILL_VAR || fillType == FILL_VARTS)
+          if (fillType == FillType::VAR || fillType == FillType::VARTS)
             {
               levelID2 = (nlevels2 > 1) ? levelID : 0;
-              const auto gridsize = nwpv * varList2[0].gridsize;
-              const auto offset = gridsize * levelID2;
+              auto gridsize = nwpv * varList2[0].gridsize;
+              auto offset = gridsize * levelID2;
               array_copy(gridsize, &vardata2[offset], fieldx2->vec_d.data());
               fieldx2->nmiss = varnmiss2[levelID2];
               fieldx2->grid = varList2[0].gridID;
@@ -377,7 +377,7 @@ Arith(void *process)
     }
 
   if (nrecs == 0 && nrecs2 > 0) cdo_warning("stream2 has more time steps than stream1!");
-  //if (nrecs > 0 && nrecs2 == 0) cdo_warning("stream1 has more time steps than stream2!");
+  // if (nrecs > 0 && nrecs2 == 0) cdo_warning("stream1 has more time steps than stream2!");
 
   cdo_stream_close(streamID3);
   cdo_stream_close(streamID2);
