@@ -9,13 +9,13 @@
 #include "julian_date.h"
 
 #include "cdo_options.h"
+#include "cdo_timer.h"
 #include "cdo_zaxis.h"
 #include "process_int.h"
 #include "param_conversion.h"
 #include "pmlist.h"
 #include <mpim_grid.h>
 #include "griddes.h"
-#include "timer.h"
 #include "util_files.h"
 
 static double
@@ -120,9 +120,9 @@ get_parameter(void)
 static void
 verify_parameter(Params &params)
 {
-  params.nruns = std::min(std::max(params.nruns, 0), 9999);
+  params.nruns = std::clamp(params.nruns, 0, 9999);
   params.nvars = std::max(params.nvars, 1);
-  params.nlevs = std::min(std::max(params.nlevs, 1), 255);
+  params.nlevs = std::clamp(params.nlevs, 1, 255);
   params.nsteps = std::max(params.nsteps, 1);
 }
 
@@ -134,7 +134,7 @@ CDIwrite(void *process)
   char sinfo[64] = { 0 };
   off_t nvalues = 0;
   double fileSize = 0, dataSize = 0;
-  double tw, twsum = 0;
+  double runTimeSum = 0.0;
 
   cdo_initialize(process);
 
@@ -200,7 +200,7 @@ CDIwrite(void *process)
 
   for (int irun = 0; irun < params.nruns; ++irun)
     {
-      auto tw0 = timer_val(timer_write);
+      cdo::timer runTimer;
       dataSize = 0;
       nvalues = 0;
 
@@ -213,10 +213,9 @@ CDIwrite(void *process)
 
       auto julday = date_to_julday(CALENDAR_PROLEPTIC, 19870101);
 
-      auto t0 = timer_val(timer_write);
-
       for (int tsID = 0; tsID < params.nsteps; ++tsID)
         {
+          cdo::timer stepTimer;
           CdiDateTime vDateTime{};
           vDateTime.date = cdiDate_set(julday_to_date(CALENDAR_PROLEPTIC, julday + tsID));
           taxisDefVdatetime(taxisID, vDateTime);
@@ -262,27 +261,22 @@ CDIwrite(void *process)
                 }
             }
 
-          if (Options::cdoVerbose)
-            {
-              tw = timer_val(timer_write) - t0;
-              t0 = timer_val(timer_write);
-              cdo_print("Timestep %d: %.2f seconds", tsID + 1, tw);
-            }
+          if (Options::cdoVerbose) { cdo_print("Timestep %d: %.3f seconds", tsID + 1, stepTimer.elapsed()); }
         }
 
       cdo_stream_close(streamID);
 
-      tw = timer_val(timer_write) - tw0;
-      twsum += tw;
+      auto runTime = runTimer.elapsed();
+      runTimeSum += runTime;
 
       fileSize = (double) FileUtils::size(cdo_get_stream_name(0));
 
       if (params.nruns > 1) std::snprintf(sinfo, sizeof(sinfo), "(run %d)", irun + 1);
 
-      print_stat(sinfo, memtype, datatype, filetype, nvalues, dataSize, fileSize, tw);
+      print_stat(sinfo, memtype, datatype, filetype, nvalues, dataSize, fileSize, runTime);
     }
 
-  if (params.nruns > 1) print_stat("(mean)", memtype, datatype, filetype, nvalues, dataSize, fileSize, twsum / params.nruns);
+  if (params.nruns > 1) print_stat("(mean)", memtype, datatype, filetype, nvalues, dataSize, fileSize, runTimeSum / params.nruns);
 
   vlistDestroy(vlistID);
 
