@@ -14,7 +14,7 @@
 #include <cdi.h>
 
 #include "process_int.h"
-#include "cdo_wtime.h"
+#include "cdo_timer.h"
 #include "cdo_vlist.h"
 #include "timer.h"
 #include "util_files.h"
@@ -25,10 +25,10 @@ void *
 Cat(void *process)
 {
   enum class StreamMode
-    {
-      APPEND,
-      CREATE
-    };
+  {
+    APPEND,
+    CREATE
+  };
   auto streamMode = StreamMode::APPEND;
   auto hasConstVars = true;
   int tsID2 = 0;
@@ -41,38 +41,32 @@ Cat(void *process)
 
   operator_check_argc(0);
 
-  const auto dataIsUnchanged = data_is_unchanged();
+  auto dataIsUnchanged = data_is_unchanged();
 
-  const auto streamCnt = cdo_stream_cnt();
-  const auto nfiles = streamCnt - 1;
+  auto streamCnt = cdo_stream_cnt();
+  auto nfiles = streamCnt - 1;
 
   progress::init();
 
   for (int indf = 0; indf < nfiles; ++indf)
     {
-      const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+      cdo::timer timer;
 
-      const auto streamID1 = cdo_open_read(indf);
-      const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-      const auto taxisID1 = vlistInqTaxis(vlistID1);
+      auto streamID1 = cdo_open_read(indf);
+      auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+      auto taxisID1 = vlistInqTaxis(vlistID1);
 
       VarList varList1;
       varListInit(varList1, vlistID1);
 
       if (indf == 0)
         {
-          const auto nvars = vlistNvars(vlistID1);
+          auto nvars = vlistNvars(vlistID1);
 
           auto ntsteps = vlistNtsteps(vlistID1);
-          if (ntsteps == 1)
-            {
-              int varID;
-              for (varID = 0; varID < nvars; ++varID)
-                if (varList1[varID].timetype != TIME_CONSTANT) break;
-              if (varID == nvars) ntsteps = 0;
-            }
+          if (ntsteps == 1 && varList_numVaryingVars(varList1) == 0) ntsteps = 0;
 
-          const bool file_exists = Options::cdoOverwriteMode ? false : FileUtils::file_exists(cdo_get_stream_name(nfiles));
+          bool file_exists = Options::cdoOverwriteMode ? false : FileUtils::file_exists(cdo_get_stream_name(nfiles));
           if (file_exists)
             {
               streamID2 = cdo_open_append(nfiles);
@@ -107,17 +101,14 @@ Cat(void *process)
               cdo_def_vlist(streamID2, vlistID2);
             }
         }
-      else
-        {
-          vlist_compare(vlistID1, vlistID2, CMP_ALL);
-        }
+      else { vlist_compare(vlistID1, vlistID2, CMP_ALL); }
 
-      const auto ntsteps = vlistNtsteps(vlistID1);
+      auto ntsteps = vlistNtsteps(vlistID1);
 
       int tsID1 = 0;
       while (true)
         {
-          const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID1);
+          auto nrecs = cdo_stream_inq_timestep(streamID1, tsID1);
           if (nrecs == 0) break;
 
           const double fstatus = (ntsteps > 1) ? indf + (tsID1 + 1.0) / ntsteps : indf + 1.0;
@@ -132,14 +123,11 @@ Cat(void *process)
               cdo_inq_record(streamID1, &varID, &levelID);
 
               if (hasConstVars && tsID2 > 0 && tsID1 == 0)
-                if (varList1[varID].timetype == TIME_CONSTANT) continue;
+                if (varList1[varID].isConstant) continue;
 
               cdo_def_record(streamID2, varID, levelID);
 
-              if (dataIsUnchanged)
-                {
-                  cdo_copy_record(streamID2, streamID1);
-                }
+              if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
               else
                 {
                   field.init(varList1[varID]);
@@ -154,7 +142,7 @@ Cat(void *process)
 
       cdo_stream_close(streamID1);
 
-      if (Options::cdoVerbose) cdo_print("Processed file: %s   %.2f seconds", cdo_get_stream_name(indf), cdo_get_wtime() - start);
+      if (Options::cdoVerbose) cdo_print("Processed file: %s   %.2f seconds", cdo_get_stream_name(indf), timer.elapsed());
     }
 
   cdo_stream_close(streamID2);
