@@ -17,25 +17,14 @@
 #include <iterator>
 
 #include "cdo_options.h"
+#include "cdo_timer.h"
 #include "process_int.h"
-#include "counter.h"
 #include "varray.h"
 
 static bool mode_auto = false;
 static bool mode_demo = false;
 
-struct vars_t
-{
-  int param;
-  int nlevels;
-  size_t gridsize;
-  double missval;
-  char name[CDI_MAX_NAME];
-  char longname[CDI_MAX_NAME];
-  char units[CDI_MAX_NAME];
-};
-
-static std::vector<vars_t> all_vars;
+static VarList varList;
 
 static CdiStreamID gl_streamID = 0;
 static int gl_vlistID = 0;
@@ -143,16 +132,16 @@ com_quit(const std::string &arg)
 static int
 com_stat(const std::string &arg)
 {
-  (void) (arg);  // CDO_UNUSED
+  (void) (arg);  // unused
 
-  auto name = all_vars[gl_varID].name;
+  auto name = varList[gl_varID].name.c_str();
 
   auto tsID2 = gl_tsID2;
   if (tsID2 == -1) tsID2 = (gl_ntsteps != -1) ? gl_ntsteps - 1 : INT_MAX - 1;
 
   for (int tsID = gl_tsID1; tsID <= tsID2; ++tsID)
     {
-      const auto nrecs = streamInqTimestep(gl_streamID, tsID);
+      auto nrecs = streamInqTimestep(gl_streamID, tsID);
       if (nrecs == 0)
         {
           if (gl_ntsteps == -1)
@@ -163,23 +152,21 @@ com_stat(const std::string &arg)
         }
       else
         {
-          cdo::Counter counter;
-          counter.start();
+          cdo::timer stepTimer;
 
-          const auto nlevels = all_vars[gl_varID].nlevels;
-          const auto gridsize = all_vars[gl_varID].gridsize;
-          const auto missval = all_vars[gl_varID].missval;
+          auto nlevels = varList[gl_varID].nlevels;
+          auto gridsize = varList[gl_varID].gridsize;
+          auto missval = varList[gl_varID].missval;
 
-          const auto levelID = (nlevels > 1) ? gl_levelID : 0;
+          auto levelID = (nlevels > 1) ? gl_levelID : 0;
 
           size_t nmiss;
           streamReadVarSlice(gl_streamID, gl_varID, levelID, gl_data.data(), &nmiss);
 
-          const auto mmm = varray_min_max_mean_mv(gridsize, gl_data, missval);
+          auto mmm = varray_min_max_mean_mv(gridsize, gl_data, missval);
 
-          counter.stop();
           fprintf(stdout, "%s:  z=%d  t=%d  size=%zu nmiss=%zu  min=%.5g mean=%.5g max=%.5g [%.2fs]\n", name, levelID + 1, tsID + 1,
-                  gridsize, nmiss, mmm.min, mmm.mean, mmm.max, counter.cputime());
+                  gridsize, nmiss, mmm.min, mmm.mean, mmm.max, stepTimer.elapsed());
         }
     }
 
@@ -196,7 +183,7 @@ int
 param2int(const std::string &str)
 {
   char *endptr = nullptr;
-  const int ival = (int) strtol(str.c_str(), &endptr, 10);
+  int ival = (int) strtol(str.c_str(), &endptr, 10);
   if (*endptr) paramWarning("Integer", str.c_str(), endptr);
   return ival;
 }
@@ -227,7 +214,7 @@ set_tsID(int tsID1, int tsID2)
 static int
 check_levelID(int levelID)
 {
-  const auto nlevels = all_vars[gl_varID].nlevels;
+  auto nlevels = varList[gl_varID].nlevels;
   if (levelID >= nlevels)
     {
       fprintf(stdout, "z=%d out of range (max=%d)!\n", levelID + 1, nlevels);
@@ -249,9 +236,9 @@ set_levelID(int levelID)
 static int
 check_varID(int varID)
 {
-  if (varID < 0 || varID >= (int) all_vars.size())
+  if (varID < 0 || varID >= (int) varList.size())
     {
-      fprintf(stdout, "varID out of range (max=%d)!\n", (int) all_vars.size());
+      fprintf(stdout, "varID out of range (max=%d)!\n", (int) varList.size());
       return 1;
     }
 
@@ -325,7 +312,7 @@ set_var(const std::vector<std::string> &argv)
   auto lfound = false;
   for (int varID = 0; varID < gl_nvars; ++varID)
     {
-      if (name == all_vars[varID].name)
+      if (name == varList[varID].name)
         {
           lfound = true;
           set_varID(varID);
@@ -373,10 +360,10 @@ com_vars(const std::string &arg)
 
   for (int varID = 0; varID < gl_nvars; ++varID)
     {
-      cdiParamToString(all_vars[varID].param, paramstr, sizeof(paramstr));
+      cdiParamToString(varList[varID].param, paramstr, sizeof(paramstr));
 
-      fprintf(stdout, "varID=%3d, param=%s, name=%s, longname=\"%s\", units=\"%s\"\n", varID + 1, paramstr, all_vars[varID].name,
-              all_vars[varID].longname, all_vars[varID].units);
+      fprintf(stdout, "varID=%3d, param=%s, name=%s, longname=\"%s\", units=\"%s\"\n", varID + 1, paramstr,
+              varList[varID].name.c_str(), varList[varID].longname.c_str(), varList[varID].units.c_str());
     }
 
   return 0;
@@ -407,7 +394,7 @@ execute_line(const std::string &line)
   while (line[i] && !isspace(line[i])) i++;
   int count = i;
 
-  const auto word = line.substr(pos, count);
+  auto word = line.substr(pos, count);
 
   const command_t *command = find_command(word);
   if (!command)
@@ -428,9 +415,9 @@ execute_line(const std::string &line)
 std::string
 trim(const std::string &str, const std::string &chars = "\t\n\v\f\r ")
 {
-  const auto first = str.find_first_not_of(chars);
+  auto first = str.find_first_not_of(chars);
   if (std::string::npos == first) return str;
-  const auto last = str.find_last_not_of(chars);
+  auto last = str.find_last_not_of(chars);
 
   return str.substr(first, (last - first + 1));
 }
@@ -452,7 +439,7 @@ peakRSS_string()
           memmax /= 1024;
           muindex++;
         }
-      snprintf(memstring, sizeof(memstring), "%zu%s", memmax, mu[muindex]);
+      std::snprintf(memstring, sizeof(memstring), "%zu%s", memmax, mu[muindex]);
     }
 
   return memstring;
@@ -479,29 +466,18 @@ command_init()
 {
   gl_vlistID = streamInqVlist(gl_streamID);
 
-  const auto taxisID = vlistInqTaxis(gl_vlistID);
-  (void) (taxisID);  // CDO_UNUSED
+  auto taxisID = vlistInqTaxis(gl_vlistID);
+  (void) (taxisID);  // unused
 
   auto ntsteps = vlistNtsteps(gl_vlistID);
   if (ntsteps == 0) ntsteps = 1;
   gl_ntsteps = ntsteps;
 
-  const auto gridsizemax = vlistGridsizeMax(gl_vlistID);
+  auto gridsizemax = vlistGridsizeMax(gl_vlistID);
   gl_data.resize(gridsizemax);
 
   gl_nvars = vlistNvars(gl_vlistID);
-  all_vars.resize(gl_nvars);
-
-  for (int varID = 0; varID < gl_nvars; ++varID)
-    {
-      all_vars[varID].nlevels = zaxisInqSize(vlistInqVarZaxis(gl_vlistID, varID));
-      all_vars[varID].gridsize = gridInqSize(vlistInqVarGrid(gl_vlistID, varID));
-      all_vars[varID].missval = vlistInqVarMissval(gl_vlistID, varID);
-      all_vars[varID].param = vlistInqVarParam(gl_vlistID, varID);
-      vlistInqVarName(gl_vlistID, varID, all_vars[varID].name);
-      vlistInqVarLongname(gl_vlistID, varID, all_vars[varID].longname);
-      vlistInqVarUnits(gl_vlistID, varID, all_vars[varID].units);
-    }
+  varListInit(varList, gl_vlistID);
 
   set_varID(0);
 }
@@ -513,12 +489,12 @@ run_demo()
   gl_tsID2 = -1;
   for (int varID = 0; varID < gl_nvars; ++varID)
     {
-      const auto nlevels = all_vars[varID].nlevels;
+      auto nlevels = varList[varID].nlevels;
       for (int levelID = 0; levelID < nlevels; ++levelID)
         {
           set_varID(varID);
           set_levelID(levelID);
-          com_stat(all_vars[varID].name);
+          com_stat(varList[varID].name);
         }
     }
 }
@@ -542,10 +518,7 @@ Command(void *process)
 
   command_init();
 
-  if (mode_demo)
-    {
-      run_demo();
-    }
+  if (mode_demo) { run_demo(); }
   else
     {
       // Loop reading and executing lines until the user quits.
