@@ -23,24 +23,25 @@
 #include "cdo_options.h"
 #include "process_int.h"
 #include "cdo_vlist.h"
-#include "cdo_cdi_wrapper.h"
 #include "cdo_fill.h"
+#include "field_functions.h"
 
-static
-auto func_comp = [](auto hasMissvals, auto n, auto mv1, auto mv2, const auto &vIn1, const auto &vIn2, auto &vOut, auto binray_operator)
-{
-  if (hasMissvals)
-    {
-      if (std::isnan(mv1) || std::isnan(mv2))
-        for (size_t i = 0; i < n; ++i) vOut[i] = (dbl_is_equal(vIn1[i], mv1) || dbl_is_equal(vIn2[i], mv2)) ? mv1 : binray_operator(vIn1[i], vIn2[i]);
-      else
-        for (size_t i = 0; i < n; ++i) vOut[i] = (is_equal(vIn1[i], mv1) || is_equal(vIn2[i], mv2)) ? mv1 : binray_operator(vIn1[i], vIn2[i]);
-    }
-  else
-    {
-      for (size_t i = 0; i < n; ++i) vOut[i] = binray_operator(vIn1[i], vIn2[i]);
-    }
-};
+static auto func_comp
+    = [](auto hasMissvals, auto n, auto mv1, auto mv2, const auto &vIn1, const auto &vIn2, auto &vOut, auto binray_operator) {
+        if (hasMissvals)
+          {
+            if (std::isnan(mv1) || std::isnan(mv2))
+              for (size_t i = 0; i < n; ++i)
+                vOut[i] = (dbl_is_equal(vIn1[i], mv1) || dbl_is_equal(vIn2[i], mv2)) ? mv1 : binray_operator(vIn1[i], vIn2[i]);
+            else
+              for (size_t i = 0; i < n; ++i)
+                vOut[i] = (is_equal(vIn1[i], mv1) || is_equal(vIn2[i], mv2)) ? mv1 : binray_operator(vIn1[i], vIn2[i]);
+          }
+        else
+          {
+            for (size_t i = 0; i < n; ++i) vOut[i] = binray_operator(vIn1[i], vIn2[i]);
+          }
+      };
 
 void *
 Comp(void *process)
@@ -56,14 +57,15 @@ Comp(void *process)
 
   cdo_initialize(process);
 
-  const auto EQ = cdo_operator_add("eq", 0, 0, nullptr);
-  const auto NE = cdo_operator_add("ne", 0, 0, nullptr);
-  const auto LE = cdo_operator_add("le", 0, 0, nullptr);
-  const auto LT = cdo_operator_add("lt", 0, 0, nullptr);
-  const auto GE = cdo_operator_add("ge", 0, 0, nullptr);
-  const auto GT = cdo_operator_add("gt", 0, 0, nullptr);
+  cdo_operator_add("eq", FieldFunc_EQ, 0, nullptr);
+  cdo_operator_add("ne", FieldFunc_NE, 0, nullptr);
+  cdo_operator_add("le", FieldFunc_LE, 0, nullptr);
+  cdo_operator_add("lt", FieldFunc_LT, 0, nullptr);
+  cdo_operator_add("ge", FieldFunc_GE, 0, nullptr);
+  cdo_operator_add("gt", FieldFunc_GT, 0, nullptr);
 
-  const auto operatorID = cdo_operator_id();
+  auto operatorID = cdo_operator_id();
+  auto operFunc = cdo_operator_f1(operatorID);
 
   operator_check_argc(0);
 
@@ -102,7 +104,7 @@ Comp(void *process)
 
   if (filltype == FILL_NONE) vlist_compare(vlistID1, vlistID2, CMP_ALL);
 
-  const auto gridsizemax = vlistGridsizeMax(vlistID1);
+  auto gridsizemax = vlistGridsizeMax(vlistID1);
   Varray<double> vaIn1(gridsizemax), vaIn2(gridsizemax), vaOut(gridsizemax);
 
   double *arrayx1 = vaIn1.data();
@@ -140,23 +142,23 @@ Comp(void *process)
   varListInit(varList1, vlistID1);
   varListInit(varList2, vlistID2);
 
-  const auto vlistID3 = vlistDuplicate(vlistID1);
+  auto vlistID3 = vlistDuplicate(vlistID1);
 
-  const auto taxisID3 = taxisDuplicate(taxisID1);
+  auto taxisID3 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID3, taxisID3);
 
-  const auto streamID3 = cdo_open_write(2);
+  auto streamID3 = cdo_open_write(2);
   cdo_def_vlist(streamID3, vlistID3);
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       if (tsID == 0 || filltype == FILL_NONE)
         {
-          const auto nrecs2 = cdo_stream_inq_timestep(streamID2, tsID);
+          auto nrecs2 = cdo_stream_inq_timestep(streamID2, tsID);
           if (nrecs2 == 0) cdo_abort("Input streams have different number of timesteps!");
         }
 
@@ -180,29 +182,29 @@ Comp(void *process)
 
               if (filltype == FILL_TS)
                 {
-                  const auto offset = varList2[varID].gridsize * levelID;
+                  auto offset = varList2[varID].gridsize * levelID;
                   array_copy(varList2[varID].gridsize, arrayx2, &vardata[varID][offset]);
                 }
             }
           else if (filltype == FILL_TS)
             {
-              const auto offset = varList2[varID].gridsize * levelID;
+              auto offset = varList2[varID].gridsize * levelID;
               array_copy(varList2[varID].gridsize, &vardata[varID][offset], arrayx2);
             }
 
-          const auto datatype1 = varList1[varID].datatype;
-          const auto gridsize1 = varList1[varID].gridsize;
+          auto datatype1 = varList1[varID].datatype;
+          auto gridsize1 = varList1[varID].gridsize;
           auto missval1 = varList1[varID].missval;
 
-          const auto xvarID = (filltype == FILL_REC) ? 0 : varID;
-          const auto datatype2 = varList2[xvarID].datatype;
-          const auto gridsize2 = varList2[xvarID].gridsize;
+          auto xvarID = (filltype == FILL_REC) ? 0 : varID;
+          auto datatype2 = varList2[xvarID].datatype;
+          auto gridsize2 = varList2[xvarID].gridsize;
           auto missval2 = varList2[xvarID].missval;
 
           if (gridsize1 != gridsize2)
             cdo_abort("Streams have different gridsize (gridsize1 = %zu; gridsize2 = %zu)!", gridsize1, gridsize2);
 
-          const auto ngp = gridsize1;
+          auto ngp = gridsize1;
 
           if (datatype1 != datatype2)
             {
@@ -221,18 +223,18 @@ Comp(void *process)
           if (nmiss1 > 0) cdo_check_missval(missval1, varList1[varID].name);
           // if (nmiss2 > 0) cdo_check_missval(missval2, varList2[varID].name);
 
-          const auto hasMissvals = (nmiss1 > 0 || nmiss2 > 0);
+          auto hasMissvals = (nmiss1 > 0 || nmiss2 > 0);
           // clang-format off
-          if      (operatorID == EQ) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_EQ);
-          else if (operatorID == NE) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_NE);
-          else if (operatorID == LE) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_LE);
-          else if (operatorID == LT) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_LT);
-          else if (operatorID == GE) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_GE);
-          else if (operatorID == GT) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_GT);
+          if      (operFunc == FieldFunc_EQ) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_EQ);
+          else if (operFunc == FieldFunc_NE) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_NE);
+          else if (operFunc == FieldFunc_LE) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_LE);
+          else if (operFunc == FieldFunc_LT) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_LT);
+          else if (operFunc == FieldFunc_GE) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_GE);
+          else if (operFunc == FieldFunc_GT) func_comp(hasMissvals, ngp, missval1, missval2, vaIn1, vaIn2, vaOut, binary_op_GT);
           else cdo_abort("Operator not implemented!");
           // clang-format on
 
-          const auto nmissOut = varray_num_mv(ngp, vaOut, missval1);
+          auto nmissOut = varray_num_mv(ngp, vaOut, missval1);
           cdo_def_record(streamID3, varID, levelID);
           cdo_write_record(streamID3, vaOut.data(), nmissOut);
         }
