@@ -54,23 +54,23 @@ Cond(void *process)
   cdo_initialize(process);
 
   // clang-format off
-  const auto IFTHEN    = cdo_operator_add("ifthen",    0, 0, nullptr);
-  const auto IFNOTTHEN = cdo_operator_add("ifnotthen", 0, 0, nullptr);
+  auto IFTHEN    = cdo_operator_add("ifthen",    0, 0, nullptr);
+  auto IFNOTTHEN = cdo_operator_add("ifnotthen", 0, 0, nullptr);
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
+  auto operatorID = cdo_operator_id();
 
   operator_check_argc(0);
 
-  const auto streamID1 = cdo_open_read(0);
-  const auto streamID2 = cdo_open_read(1);
+  auto streamID1 = cdo_open_read(0);
+  auto streamID2 = cdo_open_read(1);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = cdo_stream_inq_vlist(streamID2);
-  const auto vlistID3 = vlistDuplicate(vlistID2);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = cdo_stream_inq_vlist(streamID2);
+  auto vlistID3 = vlistDuplicate(vlistID2);
 
-  const auto taxisID2 = vlistInqTaxis(vlistID2);
-  const auto taxisID3 = taxisDuplicate(taxisID2);
+  auto taxisID2 = vlistInqTaxis(vlistID2);
+  auto taxisID3 = taxisDuplicate(taxisID2);
   vlistDefTaxis(vlistID3, taxisID3);
 
   auto ntsteps1 = vlistNtsteps(vlistID1);
@@ -90,10 +90,10 @@ Cond(void *process)
   varListInit(varList1, vlistID1);
   varListInit(varList2, vlistID2);
 
-  const auto streamID3 = cdo_open_write(2);
+  auto streamID3 = cdo_open_write(2);
   cdo_def_vlist(streamID3, vlistID3);
 
-  const auto gridsizemax = vlistGridsizeMax(vlistID2);
+  auto gridsizemax = vlistGridsizeMax(vlistID2);
 
   if (filltype == FILL_REC && gridsizemax != gridInqSize(vlistGrid(vlistID1, 0)))
     cdo_abort("Stream1 >%s< has wrong gridsize!", cdo_get_stream_name(0));
@@ -116,12 +116,12 @@ Cond(void *process)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID2, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID2, tsID);
       if (nrecs == 0) break;
 
       if (tsID == 0 || filltype == FILL_NONE)
         {
-          const auto nrecs2 = cdo_stream_inq_timestep(streamID1, tsID);
+          auto nrecs2 = cdo_stream_inq_timestep(streamID1, tsID);
           if (nrecs2 == 0) cdo_abort("Input streams have different number of timesteps!");
         }
 
@@ -145,20 +145,20 @@ Cond(void *process)
 
               if (filltype == FILL_TS)
                 {
-                  const auto offset = varList1[varID].gridsize * levelID;
+                  auto offset = varList1[varID].gridsize * levelID;
                   array_copy(varList1[varID].gridsize, &vaIn1[0], &vardata1[varID][offset]);
                   varnmiss1[varID][levelID] = nmiss1;
                 }
             }
           else if (filltype == FILL_TS)
             {
-              const auto offset = varList1[varID].gridsize * levelID;
+              auto offset = varList1[varID].gridsize * levelID;
               array_copy(varList1[varID].gridsize, &vardata1[varID][offset], &vaIn1[0]);
               nmiss1 = varnmiss1[varID][levelID];
             }
 
-          const auto ngp = varList2[varID].gridsize;
-          const auto missval2 = varList2[varID].missval;
+          auto ngp = varList2[varID].gridsize;
+          auto missval2 = varList2[varID].missval;
           if (recID == 0 || filltype != FILL_REC) missval1 = varList1[varID].missval;
 
           if (nmiss1 > 0) cdo_check_missval(missval1, varList1[varID].name);
@@ -169,7 +169,7 @@ Cond(void *process)
           else cdo_abort("Operator not implemented!");
           // clang-format on
 
-          const auto nmiss3 = varray_num_mv(ngp, vaOut, missval2);
+          auto nmiss3 = varray_num_mv(ngp, vaOut, missval2);
           cdo_def_record(streamID3, varID, levelID);
           cdo_write_record(streamID3, vaOut.data(), nmiss3);
         }
