@@ -65,10 +65,7 @@ selEndOfPeriod(Field &periods, const Field &history, const Field &current, int i
                   else  // DBL_IS_EQUAL(carray[i], cmissval)
                     parray[i] = (IS_NOT_EQUAL(harray[i], 0.0)) ? harray[i] : pmissval;
                 }
-              else /* DBL_IS_EQUAL(harray[i], hmissval) */
-                {
-                  parray[i] = pmissval;
-                }
+              else /* DBL_IS_EQUAL(harray[i], hmissval) */ { parray[i] = pmissval; }
             }
         }
       else
@@ -108,8 +105,8 @@ selEndOfPeriod(Field &periods, const Field &history, const Field &current, int i
 void *
 Consecstat(void *process)
 {
-  CdiDateTime vDateTime = { };
-  CdiDateTime histDateTime = { };
+  CdiDateTime vDateTime{};
+  CdiDateTime histDateTime{};
   double refval = 0.0;
 
   cdo_initialize(process);
