@@ -21,7 +21,7 @@
 bool
 is_fdb_stream(const char *filename)
 {
-  auto pathlen = (int)strlen(filename);
+  auto pathlen = (int) strlen(filename);
   return (pathlen >= 4 && memcmp(filename, "fdb:", 4) == 0);
 }
 
@@ -33,8 +33,7 @@ is_fdb_copy(bool dataIsUnchanged, int nfiles)
   if (dataIsUnchanged)
     {
       isFdbCopy = is_fdb_stream(cdo_get_stream_name(nfiles));
-      if (nfiles == 1 && !isFdbCopy)
-        isFdbCopy = is_fdb_stream(cdo_get_stream_name(0));
+      if (nfiles == 1 && !isFdbCopy) isFdbCopy = is_fdb_stream(cdo_get_stream_name(0));
     }
 
   return isFdbCopy;
@@ -51,15 +50,15 @@ Copy(void *process)
 
   cdo_initialize(process);
 
-  const auto dataIsUnchanged = data_is_unchanged();
+  auto dataIsUnchanged = data_is_unchanged();
 
   // clang-format off
-                       cdo_operator_add("copy",  0, 0, nullptr);
-  const auto CLONE   = cdo_operator_add("clone", 0, 0, nullptr);
-  const auto SZIP    = cdo_operator_add("szip",  0, 0, nullptr);
+                 cdo_operator_add("copy",  0, 0, nullptr);
+  auto CLONE   = cdo_operator_add("clone", 0, 0, nullptr);
+  auto SZIP    = cdo_operator_add("szip",  0, 0, nullptr);
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
+  auto operatorID = cdo_operator_id();
   if (operatorID == SZIP)
     {
       Options::cdoCompType = CDI_COMPRESS_SZIP;
@@ -68,10 +67,10 @@ Copy(void *process)
 
   operator_check_argc(0);
 
-  const auto streamCnt = cdo_stream_cnt();
-  const auto nfiles = streamCnt - 1;
+  auto streamCnt = cdo_stream_cnt();
+  auto nfiles = streamCnt - 1;
 
-  const auto isFdbCopy = is_fdb_copy(dataIsUnchanged, nfiles);
+  auto isFdbCopy = is_fdb_copy(dataIsUnchanged, nfiles);
 
   progress::init();
 
@@ -80,9 +79,9 @@ Copy(void *process)
     {
       if (Options::cdoVerbose) cdo_print("Process file: %s", cdo_get_stream_name(indf));
 
-      const auto streamID1 = cdo_open_read(indf);
-      const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-      const auto taxisID1 = vlistInqTaxis(vlistID1);
+      auto streamID1 = cdo_open_read(indf);
+      auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+      auto taxisID1 = vlistInqTaxis(vlistID1);
 
       VarList varList1;
       varListInit(varList1, vlistID1);
@@ -93,16 +92,10 @@ Copy(void *process)
           taxisID2 = taxisDuplicate(taxisID1);
           vlistDefTaxis(vlistID2, taxisID2);
 
-          const auto nvars = vlistNvars(vlistID1);
+          auto nvars = vlistNvars(vlistID1);
 
           auto ntsteps = vlistNtsteps(vlistID1);
-          if (ntsteps == 1)
-            {
-              int varID;
-              for (varID = 0; varID < nvars; ++varID)
-                if (varList1[varID].timetype != TIME_CONSTANT) break;
-              if (varID == nvars) ntsteps = 0;
-            }
+          if (ntsteps == 1 && varList_numVaryingVars(varList1) == 0) ntsteps = 0;
 
           if (ntsteps == 0 && nfiles > 1)
             {
@@ -110,10 +103,7 @@ Copy(void *process)
               for (int varID = 0; varID < nvars; ++varID) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
             }
         }
-      else
-        {
-          vlist_compare(vlistID1, vlistID2, CMP_ALL);
-        }
+      else { vlist_compare(vlistID1, vlistID2, CMP_ALL); }
 
       if (streamID2 == CDO_STREAM_UNDEF)
         {
@@ -121,12 +111,12 @@ Copy(void *process)
           cdo_def_vlist(streamID2, vlistID2);
         }
 
-      const auto ntsteps = vlistNtsteps(vlistID1);
+      auto ntsteps = vlistNtsteps(vlistID1);
 
       int tsID1 = 0;
       while (true)
         {
-          const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID1);
+          auto nrecs = cdo_stream_inq_timestep(streamID1, tsID1);
           if (nrecs == 0) break;
 
           cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -134,14 +124,14 @@ Copy(void *process)
 
           for (int recID = 0; recID < nrecs; ++recID)
             {
-              const double fstatus = indf + ((ntsteps > 1) ? (tsID1 + (recID + 1.0) / nrecs) / ntsteps : 1.0);
+              double fstatus = indf + ((ntsteps > 1) ? (tsID1 + (recID + 1.0) / nrecs) / ntsteps : 1.0);
               if (!Options::cdoVerbose) progress::update(0, 1, fstatus / nfiles);
 
               int varID, levelID;
               cdo_inq_record(streamID1, &varID, &levelID);
 
               if (hasConstantFields && tsID2 > 0 && tsID1 == 0)
-                if (varList1[varID].timetype == TIME_CONSTANT) continue;
+                if (varList1[varID].isConstant) continue;
 
               cdo_def_record(streamID2, varID, levelID);
 
