@@ -19,16 +19,16 @@ Deltime(void *process)
 
   cdo_initialize(process);
 
-  const auto dataIsUnchanged = data_is_unchanged();
+  auto dataIsUnchanged = data_is_unchanged();
 
   // clang-format off
-  const auto DELDAY   = cdo_operator_add("delday",   0, 0, nullptr);
-  const auto DEL29FEB = cdo_operator_add("del29feb", 0, 0, nullptr);
+  auto DELDAY   = cdo_operator_add("delday",   0, 0, nullptr);
+  auto DEL29FEB = cdo_operator_add("del29feb", 0, 0, nullptr);
   // clang-format on
 
-  (void) (DELDAY);  // CDO_UNUSED
+  (void) (DELDAY);  // unused
 
-  const auto operatorID = cdo_operator_id();
+  auto operatorID = cdo_operator_id();
 
   if (operatorID == DEL29FEB)
     {
@@ -50,7 +50,7 @@ Deltime(void *process)
           char smon[32];
           strncpy(smon, sarg, sizeof(smon) - 1);
           smon[sizeof(smon) - 1] = 0;
-          cstr_to_lower_case(smon);
+          cstr_to_lower(smon);
           int im;
           for (im = 0; im < 12; ++im)
             if (memcmp(smon, cmons[im + 1], 3) == 0) break;
@@ -61,17 +61,17 @@ Deltime(void *process)
 
   if (Options::cdoVerbose) cdo_print("delete day %d%s", dday, cmons[dmon]);
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   taxisDefCalendar(taxisID2, CALENDAR_365DAYS);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
   Field field;
@@ -84,10 +84,10 @@ Deltime(void *process)
   int tsID2 = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      const auto vDateTime = taxisInqVdatetime(taxisID1);
+      auto vDateTime = taxisInqVdatetime(taxisID1);
 
       int year, month, day;
       cdiDate_decode(vDateTime.date, &year, &month, &day);
@@ -110,10 +110,7 @@ Deltime(void *process)
               int varID, levelID;
               cdo_inq_record(streamID1, &varID, &levelID);
               cdo_def_record(streamID2, varID, levelID);
-              if (dataIsUnchanged)
-                {
-                  cdo_copy_record(streamID2, streamID1);
-                }
+              if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
               else
                 {
                   field.init(varList1[varID]);
