@@ -27,16 +27,16 @@ calc_full_depth(size_t gridsize, size_t nlevels, const Varray<T> &thick_c, const
 
   for (size_t k = 1; k < nlevels; ++k)
     {
-      const auto depth = &fullDepth[k * gridsize];
-      const auto depthm1 = &fullDepth[(k - 1) * gridsize];
-      const auto thickm1 = &thick_c[(k - 1) * gridsize];
+      auto depth = &fullDepth[k * gridsize];
+      auto depthm1 = &fullDepth[(k - 1) * gridsize];
+      auto thickm1 = &thick_c[(k - 1) * gridsize];
       for (size_t i = 0; i < gridsize; ++i) depth[i] = depthm1[i] + stretch_c[i] * thickm1[i];
     }
 
   for (size_t k = 0; k < nlevels; ++k)
     {
-      const auto depth = &fullDepth[k * gridsize];
-      const auto thick = &thick_c[k * gridsize];
+      auto depth = &fullDepth[k * gridsize];
+      auto thick = &thick_c[k * gridsize];
       for (size_t i = 0; i < gridsize; ++i) depth[i] += 0.5 * stretch_c[i] * thick[i] - zos[i];
     }
 }
@@ -44,9 +44,9 @@ calc_full_depth(size_t gridsize, size_t nlevels, const Varray<T> &thick_c, const
 static void
 calc_full_depth(const Field3D &thick_c, const Field3D &stretch_c, const Field3D &zos, Field3D &fullDepth)
 {
-  const auto gridsize = thick_c.gridsize;
-  const auto nlevels = thick_c.nlevels;
-  const auto memType = thick_c.memType;
+  auto gridsize = thick_c.gridsize;
+  auto nlevels = thick_c.nlevels;
+  auto memType = thick_c.memType;
   if (memType == MemType::Float)
     calc_full_depth(gridsize, nlevels, thick_c.vec_f, stretch_c.vec_f, zos.vec_f, fullDepth.vec_f);
   else
@@ -60,31 +60,29 @@ Depth(void *process)
 
   cdo_operator_add("zsdepth", 0, 0, nullptr);
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
 
   VarList varList1;
   varListInit(varList1, vlistID1);
   varListSetUniqueMemtype(varList1);
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
-  char varname[CDI_MAX_NAME];
   int thickID = -1, zosID = -1, stretchID = -1, draftaveID = -1;
   for (int varID = 0; varID < nvars; ++varID)
     {
-      strcpy(varname, varList1[varID].name);
-      cstr_to_lower_case(varname);
+      auto varname = string_to_lower(varList1[varID].name);
 
       // clang-format off
-      if      (cdo_cmpstr(varname, "prism_thick_c")) thickID = varID;
-      else if (cdo_cmpstr(varname, "stretch_c"))     stretchID = varID;
-      else if (cdo_cmpstr(varname, "zos"))           zosID = varID;
-      else if (cdo_cmpstr(varname, "draftave"))      draftaveID = varID;
+      if      (varname == "prism_thick_c") thickID = varID;
+      else if (varname == "stretch_c")     stretchID = varID;
+      else if (varname == "zos")           zosID = varID;
+      else if (varname == "draftave")      draftaveID = varID;
       // clang-format on
     }
 
@@ -105,20 +103,20 @@ Depth(void *process)
   if (-1 == zosID) cdo_abort("zos not found!");
   if (-1 == draftaveID) cdo_warning("draftave not found, set to zero!");
 
-  const auto zaxisID = varList1[thickID].zaxisID;
-  const auto nlevels = varList1[thickID].nlevels;
+  auto zaxisID = varList1[thickID].zaxisID;
+  auto nlevels = varList1[thickID].nlevels;
 
-  const auto ngrids = vlistNgrids(vlistID1);
+  auto ngrids = vlistNgrids(vlistID1);
   if (ngrids > 1) cdo_abort("Too many different grids!");
 
   int index = 0;
-  const auto gridID = vlistGrid(vlistID1, index);
+  auto gridID = vlistGrid(vlistID1, index);
 
-  const auto vlistID2 = vlistCreate();
+  auto vlistID2 = vlistCreate();
   vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto depthID = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
+  auto depthID = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
 
   cdiDefKeyString(vlistID2, depthID, CDI_KEY_NAME, "depth_c");
   cdiDefKeyString(vlistID2, depthID, CDI_KEY_STDNAME, "depth");
@@ -131,13 +129,13 @@ Depth(void *process)
   Field3D fullDepth;
   fullDepth.init(varList1[thickID]);
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
