@@ -23,9 +23,9 @@
 #include "cdo_options.h"
 
 void geopot_height_halflevel(double *gheight, const double *const ta_fl, const double *const hus_fl, const double *const p_hl,
-                             const long ngp, const long nlev);
+                             long ngp, long nlev);
 void geopot_height_fulllevel(double *gheight, const double *const ta_fl, const double *const hus_fl, const double *const p_hl,
-                             const long ngp, const long nlev);
+                             long ngp, long nlev);
 
 static void
 check_range_var2d(int stepNum, const Varray<double> &var2d, double rMin, double rMax, const char *varname)
@@ -87,7 +87,7 @@ Derivepar(void *process)
   int zaxisID_ML = -1;
   int numHybridLevels = 0, numFullLevels = 0, numHalfLevels = 0;
   auto vct = vlist_read_vct(vlistID1, zaxisID_ML, numHybridLevels, numFullLevels, numHalfLevels);
-  const int vctSize = vct.size();
+  int vctSize = vct.size();
 
   if (Options::cdoVerbose)
     for (int i = 0; i < vctSize / 2; ++i) cdo_print("vct: %5d %25.17f %25.17f", i, vct[i], vct[vctSize / 2 + i]);
