@@ -36,7 +36,6 @@ struct DistgridInfo
   int gridID;
 };
 
-
 static void
 calc_boundbox(size_t gridsize2, size_t nv, bool withBounds, const Varray<double> &xvals2, const Varray<double> &yvals2,
               const Varray<double> &xbounds2, const Varray<double> &ybounds2, double *lonBounds, double *latBounds)
@@ -93,21 +92,21 @@ static void
 gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridInfo, size_t nxvals, size_t nyvals, size_t nxblocks,
                size_t nyblocks, size_t nsplit)
 {
-  const auto gridID1 = gridInfo1.gridID;
-  const auto gridtype = gridInfo1.gridtype;
-  const auto isReg2d = gridInfo1.isReg2d;
-  const auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
-  const auto isCurvilinear = (gridtype == GRID_CURVILINEAR);
-  const auto isRegular
+  auto gridID1 = gridInfo1.gridID;
+  auto gridtype = gridInfo1.gridtype;
+  auto isReg2d = gridInfo1.isReg2d;
+  auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
+  auto isCurvilinear = (gridtype == GRID_CURVILINEAR);
+  auto isRegular
       = (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_GENERIC || gridtype == GRID_PROJECTION);
   if (!isRegular && !isCurvilinear && !isUnstructured) cdo_abort("Unsupported grid type: %s!", gridNamePtr(gridtype));
 
-  const auto nx = gridInqXsize(gridID1);
+  auto nx = gridInqXsize(gridID1);
   const size_t ny = isUnstructured ? 1 : gridInqYsize(gridID1);
 
-  const auto lxcoord = (gridInqXvals(gridID1, nullptr) > 0);
-  const auto lycoord = (gridInqYvals(gridID1, nullptr) > 0);
-  const auto withBounds = (!isRegular && gridHasBounds(gridID1));
+  auto lxcoord = (gridInqXvals(gridID1, nullptr) > 0);
+  auto lycoord = (gridInqYvals(gridID1, nullptr) > 0);
+  auto withBounds = (!isRegular && gridHasBounds(gridID1));
 
   std::vector<size_t> xlsize(nxblocks), ylsize(nyblocks);
 
@@ -121,8 +120,8 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
   if (Options::cdoVerbose)
     for (size_t iy = 0; iy < nyblocks; ++iy) cdo_print("yblock %zu: size=%zu", iy, ylsize[iy]);
 
-  const auto nxvmax = std::max(nxvals, xlsize[nxblocks - 1]);
-  const auto nyvmax = std::max(nyvals, ylsize[nyblocks - 1]);
+  auto nxvmax = std::max(nxvals, xlsize[nxblocks - 1]);
+  auto nyvmax = std::max(nyvals, ylsize[nyblocks - 1]);
 
   Varray<double> xpvals, ypvals;
   Varray<double> xvals, yvals, xbounds, ybounds;
@@ -164,7 +163,7 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
   for (size_t iy = 0; iy < nyblocks; ++iy)
     for (size_t ix = 0; ix < nxblocks; ++ix)
       {
-        const auto offset = iy * nyvals * nx + ix * nxvals;
+        auto offset = iy * nyvals * nx + ix * nxvals;
         auto gridsize2 = xlsize[ix] * ylsize[iy];
         if (!isReg2d) distgridInfo[index].cellindex.resize(gridsize2);
         auto &cellindex = distgridInfo[index].cellindex;
@@ -209,8 +208,8 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
 
         if (!isRegular && lxcoord && lycoord)
           calc_boundbox(gridsize2, nv, withBounds, xvals2, yvals2, xbounds2, ybounds2, lonBounds, latBounds);
- 
-        const auto gridID2 = gridCreate(gridtype, gridsize2);
+
+        auto gridID2 = gridCreate(gridtype, gridsize2);
         if (gridtype != GRID_UNSTRUCTURED)
           {
             gridDefXsize(gridID2, xlsize[ix]);
@@ -247,17 +246,17 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
               }
           }
 
-        const auto projID1 = gridInqProj(gridID1);
+        auto projID1 = gridInqProj(gridID1);
         if (projID1 != CDI_UNDEFID && gridInqType(projID1) == GRID_PROJECTION)
           {
-            const auto projID2 = gridCreate(GRID_PROJECTION, gridsize2);
+            auto projID2 = gridCreate(GRID_PROJECTION, gridsize2);
             gridDefXsize(projID2, xlsize[ix]);
             gridDefYsize(projID2, ylsize[iy]);
 
             grid_copy_names(projID1, projID2);
             grid_copy_mapping(projID1, projID2);
 
-            const auto lxpcoord = (gridInqXvals(projID1, nullptr) > 0);
+            auto lxpcoord = (gridInqXvals(projID1, nullptr) > 0);
             if (lxpcoord)
               {
                 if (!xpvals.size())
@@ -267,7 +266,7 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
                   }
                 gridDefXvals(projID2, &xpvals[ix * nxvals]);
               }
-            const auto lypcoord = (gridInqYvals(projID1, nullptr) > 0);
+            auto lypcoord = (gridInqYvals(projID1, nullptr) > 0);
             if (lypcoord)
               {
                 if (!ypvals.size())
@@ -288,7 +287,7 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
         if (index > nsplit) cdo_abort("Internal problem, index exceeded bounds!");
       }
 
-  const auto numBlocks = index;
+  auto numBlocks = index;
 
   for (size_t i = 0; i < numBlocks; ++i)
     {
@@ -305,13 +304,13 @@ dist_cells_reg2d(const Field &field1, Field &field2, const DistgridInfo &distgri
 {
   if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
 
-  const auto nx = distgridInfo.nx;
-  const auto ny = distgridInfo.ny;
+  auto nx = distgridInfo.nx;
+  auto ny = distgridInfo.ny;
 
   for (size_t j = 0; j < ny; ++j)
     {
-      const auto offset1 = distgridInfo.offset + j * nlon;
-      const auto offset2 = j * nx;
+      auto offset1 = distgridInfo.offset + j * nlon;
+      auto offset2 = j * nx;
 
       if (field1.memType == MemType::Float)
         for (size_t i = 0; i < nx; ++i) field2.vec_f[offset2 + i] = field1.vec_f[offset1 + i];
@@ -325,7 +324,7 @@ dist_cells(const Field &field1, Field &field2, const DistgridInfo &distgridInfo)
 {
   if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
 
-  const auto gridsize = distgridInfo.gridsize;
+  auto gridsize = distgridInfo.gridsize;
   const auto &cellidx = distgridInfo.cellindex;
 
   if (field1.memType == MemType::Float)
@@ -355,15 +354,15 @@ Distgrid(void *process)
   if (nxblocks == 0) cdo_abort("nxblocks has to be greater than 0!");
   if (nyblocks == 0) cdo_abort("nyblocks has to be greater than 0!");
 
-  const auto streamID1 = cdo_open_read(0);
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto streamID1 = cdo_open_read(0);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-  const auto ngrids = vlistNgrids(vlistID1);
+  auto ngrids = vlistNgrids(vlistID1);
 
   std::vector<GridInfo1> gridInfo1(ngrids);
   for (int index = 0; index < ngrids; ++index)
     {
-      const auto gridID = vlistGrid(vlistID1, index);
+      auto gridID = vlistGrid(vlistID1, index);
       gridInfo1[index].gridID = gridID;
       gridInfo1[index].gridtype = gridInqType(gridID);
       gridInfo1[index].gridsize = gridInqSize(gridID);
@@ -387,11 +386,11 @@ Distgrid(void *process)
       cdo_abort("No Lon/Lat, Gaussian, curvilinear or generic grid found (%s data unsupported)!", gridNamePtr(gridtype));
   }
 
-  const auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
+  auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
 
   gridID1 = vlistGrid(vlistID1, 0);
-  const auto gridsize = gridInqSize(gridID1);
-  const auto nx = gridInqXsize(gridID1);
+  auto gridsize = gridInqSize(gridID1);
+  auto nx = gridInqXsize(gridID1);
   const size_t ny = isUnstructured ? 1 : gridInqYsize(gridID1);
   for (int i = 1; i < ngrids; ++i)
     {
@@ -415,7 +414,7 @@ Distgrid(void *process)
   if (nx % xinc && nx % (xinc + 1) && nxblocks * (xinc + 1) <= nx) xinc++;
   if (ny % yinc && ny % (yinc + 1) && nyblocks * (yinc + 1) <= ny) yinc++;
 
-  const auto nsplit = nxblocks * nyblocks;
+  auto nsplit = nxblocks * nyblocks;
   if (nsplit > MaxBlocks) cdo_abort("Too many blocks (max = %d)!", MaxBlocks);
 
   cdo::set_numfiles(nsplit + 8);
@@ -471,8 +470,8 @@ Distgrid(void *process)
 
       if (Options::test && ngrids == 1 && isUnstructured)
         {
-          const auto gridsize2 = distgridInfo[0][index].gridsize;
-          const auto offset = distgridInfo[0][index].offset;
+          auto gridsize2 = distgridInfo[0][index].gridsize;
+          auto offset = distgridInfo[0][index].offset;
           const auto &lons = distgridInfo[0][index].lonBounds;
           const auto &lats = distgridInfo[0][index].latBounds;
           printf("--- # %zu\n", index + 1);
@@ -486,7 +485,7 @@ Distgrid(void *process)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       for (auto &streamID : streamIDs) cdo_def_timestep(streamID, tsID);
