@@ -31,7 +31,6 @@
 #include "param_conversion.h"
 #include <mpim_grid.h>
 #include "eigen_solution.h"
-#include "timer.h"
 #include "datetime.h"
 #include "eof_mode.h"
 
@@ -110,9 +109,8 @@ EOFs(void *process)
   int varID, levelID;
   int nts = 1;
   int grid_space = 0, time_space = 0;
-  int timer_cov = 0, timer_eig = 0;
 
-  const auto calendar = CALENDAR_STANDARD;
+  auto calendar = CALENDAR_STANDARD;
 
   struct eofdata_t
   {
@@ -123,12 +121,6 @@ EOFs(void *process)
     Varray2D<double> data;
   };
 
-  if (Options::Timer)
-    {
-      timer_cov = timer_new("Timeof cov");
-      timer_eig = timer_new("Timeof eig");
-    }
-
   cdo_initialize(process);
 
   // clang-format off
@@ -137,13 +129,13 @@ EOFs(void *process)
   cdo_operator_add("eofspatial", EOF_SPATIAL, 0, nullptr);
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
-  const auto operfunc = cdo_operator_f1(operatorID);
+  auto operatorID = cdo_operator_id();
+  auto operfunc = cdo_operator_f1(operatorID);
 
   operator_input_arg("Number of eigen functions to write out");
   auto n_eig = parameter_to_int(cdo_operator_argv(0));
 
-  const auto eigen_mode = get_eigenmode();
+  auto eigen_mode = get_eigenmode();
   auto weight_mode = get_weightmode();
 
   auto streamID1 = cdo_open_read(0);
@@ -153,11 +145,11 @@ EOFs(void *process)
   VarList varList1;
   varListInit(varList1, vlistID1);
 
-  const auto gridID1 = varList1[0].gridID;
-  const auto gridsizemax = vlistGridsizeMax(vlistID1);
-  const auto nvars = vlistNvars(vlistID1);
+  auto gridID1 = varList1[0].gridID;
+  auto gridsizemax = vlistGridsizeMax(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
-  const auto ngrids = vlistNgrids(vlistID1);
+  auto ngrids = vlistNgrids(vlistID1);
   for (int index = 1; index < ngrids; ++index)
     if (vlistGrid(vlistID1, 0) != vlistGrid(vlistID1, index)) cdo_abort("Too many different grids!");
 
@@ -239,7 +231,7 @@ EOFs(void *process)
 
   if (weight_mode == WEIGHT_ON)
     {
-      const auto wstatus = gridcell_weights(gridID1, weights);
+      auto wstatus = gridcell_weights(gridID1, weights);
       if (wstatus != 0)
         {
           weight_mode = WEIGHT_OFF;
@@ -255,12 +247,11 @@ EOFs(void *process)
 
   for (varID = 0; varID < nvars; ++varID)
     {
-      const auto nlevs = varList1[varID].nlevels;
+      auto nlevs = varList1[varID].nlevels;
       eofdata[varID].resize(nlevs);
 
       if (time_space)
-        for (levelID = 0; levelID < nlevs; ++levelID)
-          eofdata[varID][levelID].data.resize(nts);
+        for (levelID = 0; levelID < nlevs; ++levelID) eofdata[varID][levelID].data.resize(nts);
     }
 
   if (Options::cdoVerbose) cdo_print("Allocated eigenvalue/eigenvector structures with nts=%d gridsize=%zu", nts, gridsizemax);
@@ -272,7 +263,7 @@ EOFs(void *process)
   // read the data and create covariance matrices for each var & level
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       for (int recID = 0; recID < nrecs; ++recID)
@@ -280,8 +271,8 @@ EOFs(void *process)
           cdo_inq_record(streamID1, &varID, &levelID);
           cdo_read_record(streamID1, in.data(), &nmiss);
 
-          const auto gridsize = varList1[varID].gridsize;
-          const auto missval = varList1[varID].missval;
+          auto gridsize = varList1[varID].gridsize;
+          auto missval = varList1[varID].missval;
 
           if (npack == SIZE_MAX)
             {
@@ -330,7 +321,7 @@ EOFs(void *process)
               for (size_t ipack = 0; ipack < npack; ++ipack)
                 {
                   auto &covar_i = covar[ipack];
-                  const auto in_i = in[pack[ipack]];
+                  auto in_i = in[pack[ipack]];
                   for (size_t jpack = ipack; jpack < npack; ++jpack) covar_i[jpack] += in_i * in[pack[jpack]];
                 }
             }
@@ -355,15 +346,15 @@ EOFs(void *process)
   // write files with eigenvalues (ID3) and eigenvectors (ID2)
 
   // eigenvalues
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
 
-  const auto vlistID2 = vlistDuplicate(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   taxisDefRdate(taxisID2, 0);
   taxisDefRtime(taxisID2, 0);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto gridID2 = gridCreate(GRID_LONLAT, 1);
+  auto gridID2 = gridCreate(GRID_LONLAT, 1);
   gridDefXsize(gridID2, 1);
   gridDefYsize(gridID2, 1);
   double xvals = 0.0, yvals = 0.0;
@@ -372,10 +363,10 @@ EOFs(void *process)
   for (int i = 0; i < ngrids; ++i) vlistChangeGridIndex(vlistID2, i, gridID2);
 
   // eigenvectors
-  const auto streamID3 = cdo_open_write(2);
+  auto streamID3 = cdo_open_write(2);
 
-  const auto vlistID3 = vlistDuplicate(vlistID1);
-  const auto taxisID3 = taxisDuplicate(taxisID1);
+  auto vlistID3 = vlistDuplicate(vlistID1);
+  auto taxisID3 = taxisDuplicate(taxisID1);
   taxisDefRdate(taxisID3, 0);
   taxisDefRtime(taxisID3, 0);
   vlistDefTaxis(vlistID3, taxisID3);
@@ -390,7 +381,7 @@ EOFs(void *process)
 
   Varray<double> &out = in;
 
-  const int nts_out = (npack < (size_t) nts) ? npack : nts;
+  int nts_out = (npack < (size_t) nts) ? npack : nts;
 
   for (tsID = 0; tsID < nts_out; ++tsID)
     {
@@ -408,10 +399,10 @@ EOFs(void *process)
 
       for (varID = 0; varID < nvars; ++varID)
         {
-          const auto vname = varList1[varID].name;
-          const auto gridsize = varList1[varID].gridsize;
-          const auto nlevs = varList1[varID].nlevels;
-          const auto missval = varList1[varID].missval;
+          const auto &vname = varList1[varID].name;
+          auto gridsize = varList1[varID].gridsize;
+          auto nlevs = varList1[varID].nlevels;
+          auto missval = varList1[varID].missval;
 
           for (levelID = 0; levelID < nlevs; ++levelID)
             {
@@ -422,9 +413,8 @@ EOFs(void *process)
                 {
                   eofdata[varID][levelID].first_call = false;
 
-                  if (Options::cdoVerbose) cdo_print("Calculating covar matrices for %d levels of var%i (%s)", nlevs, varID + 1, vname);
-
-                  if (Options::Timer) timer_start(timer_cov);
+                  if (Options::cdoVerbose)
+                    cdo_print("Calculating covar matrices for %d levels of var%i (%s)", nlevs, varID + 1, vname);
 
                   if (Options::cdoVerbose) cdo_print("processing level %d", levelID + 1);
 
@@ -434,17 +424,14 @@ EOFs(void *process)
 
                       for (size_t ipack = 0; ipack < npack; ++ipack)
                         {
-                          const size_t i = pack[ipack];
+                          size_t i = pack[ipack];
                           for (size_t jpack = 0; jpack < npack; ++jpack)
                             {
-                              if (jpack < ipack)
-                                {
-                                  covar[ipack][jpack] = covar[jpack][ipack];
-                                }
+                              if (jpack < ipack) { covar[ipack][jpack] = covar[jpack][ipack]; }
                               else
                                 {
-                                  const auto j = pack[jpack];
-                                  covar[ipack][jpack] = covar[ipack][jpack] *                                  // covariance
+                                  auto j = pack[jpack];
+                                  covar[ipack][jpack] = covar[ipack][jpack] *                                    // covariance
                                                         std::sqrt(weights[i]) * std::sqrt(weights[j]) / sum_w /  // weights
                                                         nts;  // number of data contributing
                                 }
@@ -478,11 +465,7 @@ EOFs(void *process)
                       if (Options::cdoVerbose) cdo_print("finished calculation of covar-matrix for var %s", vname);
                     }
 
-                  if (Options::Timer) timer_stop(timer_cov);
-
                   // Solve the eigen problem
-                  if (Options::Timer) timer_start(timer_eig);
-
                   auto &eig_val = eofdata[varID][levelID].eig_val;
                   if (eigen_mode == JACOBI)
                     // TODO: use return status (>0 okay, -1 did not converge at all)
@@ -490,7 +473,6 @@ EOFs(void *process)
                   else
                     eigen_solution_of_symmetric_matrix(covar, eig_val, n, __func__);
 
-                  if (Options::Timer) timer_stop(timer_eig);
                   // NOW: covar contains the eigenvectors, eig_val the eigenvalues
 
                   for (size_t i = 0; i < gridsize; ++i) out[i] = missval;
