@@ -49,20 +49,20 @@ enum ROC_ENUM_TYPE
 };
 
 static double
-roc_curve_integrate(const Varray2D<double> &roc, const int n)
+roc_curve_integrate(const Varray2D<double> &roc, int n)
 {
   double area = 0.0;
 
   for (int i = 1; i <= n; ++i)
     {
-      const auto x1 = roc[i][FPR];
-      const auto x0 = roc[i - 1][FPR];
-      const auto y1 = roc[i][TPR];
-      const auto y0 = roc[i - 1][TPR];
-      const auto dx = x1 - x0;
-      const auto dy = y1 - y0;
+      auto x1 = roc[i][FPR];
+      auto x0 = roc[i - 1][FPR];
+      auto y1 = roc[i][TPR];
+      auto y0 = roc[i - 1][TPR];
+      auto dx = x1 - x0;
+      auto dy = y1 - y0;
 
-      const auto step_area = -0.5 * dx * dy - dx * y0;
+      auto step_area = -0.5 * dx * dy - dx * y0;
       area += step_area;
     }
 
@@ -102,9 +102,9 @@ Ensstat3(void *process)
   cdo_operator_add("ensrkhisttime",  func_rank, time_data,  nullptr);
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
-  const auto operfunc = cdo_operator_f1(operatorID);
-  const auto datafunc = cdo_operator_f2(operatorID);
+  auto operatorID = cdo_operator_id();
+  auto operfunc = cdo_operator_f1(operatorID);
+  auto datafunc = cdo_operator_f2(operatorID);
 
   int nbins = 0;
   if (operfunc == func_roc)
@@ -114,7 +114,7 @@ Ensstat3(void *process)
     }
 
   auto nfiles = cdo_stream_cnt() - 1;
-  const auto nens = nfiles - 1;
+  auto nens = nfiles - 1;
 
   if (Options::cdoVerbose) cdo_print("Ensemble over %d files.", nfiles);
 
@@ -140,7 +140,7 @@ Ensstat3(void *process)
 
   for (int fileID = 0; fileID < nfiles; ++fileID)
     {
-      const auto streamID = cdo_open_read(fileID);
+      auto streamID = cdo_open_read(fileID);
       ef[fileID].streamID = streamID;
       ef[fileID].vlistID = cdo_stream_inq_vlist(streamID);
     }
@@ -148,14 +148,14 @@ Ensstat3(void *process)
   // check for identical contents of all ensemble members
   for (int fileID = 1; fileID < nfiles; ++fileID) vlist_compare(ef[0].vlistID, ef[fileID].vlistID, CMP_ALL);
 
-  const auto vlistID1 = ef[0].vlistID;
-  const auto vlistID2 = vlistCreate();
+  auto vlistID1 = ef[0].vlistID;
+  auto vlistID2 = vlistCreate();
   vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
   std::vector<int> varIDs2(nvars);
 
-  const auto zaxisID2 = zaxisCreate(ZAXIS_GENERIC, nfiles);
+  auto zaxisID2 = zaxisCreate(ZAXIS_GENERIC, nfiles);
   {
     Varray<double> levs(nfiles, 0);
     for (int i = 0; i < nfiles; ++i) levs[i] = i;
@@ -186,8 +186,8 @@ Ensstat3(void *process)
       varIDs2[varID] = vlistDefVar(vlistID2, gridID2, zaxisID2, time_mode);
     }
 
-  const int taxisID1 = vlistInqTaxis(vlistID1);
-  const int taxisID2 = taxisDuplicate(taxisID1);
+  int taxisID1 = vlistInqTaxis(vlistID1);
+  int taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
   for (varID = 0; varID < nvars; ++varID)
@@ -247,12 +247,11 @@ Ensstat3(void *process)
     }
 
   int tsID = 0;
-  do
-    {
+  do {
       nrecs0 = cdo_stream_inq_timestep(ef[0].streamID, tsID);
       for (int fileID = 1; fileID < nfiles; ++fileID)
         {
-          const auto streamID = ef[fileID].streamID;
+          auto streamID = ef[fileID].streamID;
           nrecs = cdo_stream_inq_timestep(streamID, tsID);
           if (nrecs != nrecs0)
             {
@@ -279,14 +278,14 @@ Ensstat3(void *process)
 #endif
           for (int fileID = 0; fileID < nfiles; ++fileID)
             {
-              const auto streamID = ef[fileID].streamID;
+              auto streamID = ef[fileID].streamID;
               cdo_inq_record(streamID, &varID, &levelID);
               cdo_read_record(streamID, ef[fileID].array.data(), &nmiss);
             }
 
           gridID = vlistInqVarGrid(vlistID1, varID);
           gridsize = gridInqSize(gridID);
-          const auto missval = vlistInqVarMissval(vlistID1, varID);
+          auto missval = vlistInqVarMissval(vlistID1, varID);
 
           nmiss = 0;
           if (datafunc == TIME && operfunc == func_rank)
@@ -297,7 +296,7 @@ Ensstat3(void *process)
 #endif
           for (size_t i = 0; i < gridsize; ++i)
             {
-              const auto ompthID = cdo_omp_get_thread_num();
+              auto ompthID = cdo_omp_get_thread_num();
 
               field[ompthID].missval = missval;
               field[ompthID].nmiss = 0;
@@ -341,8 +340,8 @@ Ensstat3(void *process)
                       /* ********************************** */
                       /* RECEIVER OPERATING CHARACTERISTICS */
                       /* ********************************** */
-                      const auto dat = &field[ompthID].vec_d[1];
-                      const auto ival = (field[ompthID].vec_d[0] > 0.5) ? 1 : 0;
+                      auto dat = &field[ompthID].vec_d[1];
+                      auto ival = (field[ompthID].vec_d[0] > 0.5) ? 1 : 0;
 
                       for (binID = 0; binID < nbins; binID++) hist[binID] = 0;
 
@@ -410,10 +409,10 @@ Ensstat3(void *process)
 
                   for (binID = 0; binID <= nbins; binID++)
                     {
-                      const int p = ctg_tab[binID][TP] + ctg_tab[binID][FN];
-                      const int n = ctg_tab[binID][FP] + ctg_tab[binID][TN];
-                      const double tpr = ctg_tab[binID][TP] / (double) p;
-                      const double fpr = ctg_tab[binID][FP] / (double) n;
+                      int p = ctg_tab[binID][TP] + ctg_tab[binID][FN];
+                      int n = ctg_tab[binID][FP] + ctg_tab[binID][TN];
+                      double tpr = ctg_tab[binID][TP] / (double) p;
+                      double fpr = ctg_tab[binID][FP] / (double) n;
                       chksum += ctg_tab[binID][0] + ctg_tab[binID][1] + ctg_tab[binID][2] + ctg_tab[binID][3];
 
                       roc[binID][TPR] = tpr;
@@ -433,7 +432,7 @@ Ensstat3(void *process)
 
   if (operfunc == func_rank)
     {
-      const int osize = (datafunc == TIME) ? 1 : gridsize;
+      int osize = (datafunc == TIME) ? 1 : gridsize;
       Varray<double> tmpdoub(osize);
 
       for (binID = 0; binID < nfiles; binID++)
@@ -450,16 +449,16 @@ Ensstat3(void *process)
 
       for (int i = 0; i <= nbins; ++i)
         {
-          const int p = ctg_tab[i][TP] + ctg_tab[i][FN];
-          const int n = ctg_tab[i][FP] + ctg_tab[i][TN];
-          const double tpr = ctg_tab[i][TP] / (double) p;
-          const double fpr = ctg_tab[i][FP] / (double) n;
-          chksum += ctg_tab[i][0] + ctg_tab[i][1] + ctg_tab[i][2] + ctg_tab[i][3];
+          int p = ctg_tab[i][TP] + ctg_tab[i][FN];
+          int n = ctg_tab[i][FP] + ctg_tab[i][TN];
+          double tpr = ctg_tab[i][TP] / (double) p;
+          double fpr = ctg_tab[i][FP] / (double) n;
+          //chksum += ctg_tab[i][0] + ctg_tab[i][1] + ctg_tab[i][2] + ctg_tab[i][3];
 
           roc[i][TPR] = tpr;
           roc[i][FPR] = fpr;
 
-          const int sum = ctg_tab[i][TP] + ctg_tab[i][TN] + ctg_tab[i][FP] + ctg_tab[i][FN];
+          int sum = ctg_tab[i][TP] + ctg_tab[i][TN] + ctg_tab[i][FP] + ctg_tab[i][FN];
 
           fprintf(stdout, "%3i %10.4g: %6i %6i %6i %6i (%6i): %10.4g %10.4g\n", i, (i < nbins) ? lThresh[i] : 1, ctg_tab[i][0],
                   ctg_tab[i][1], ctg_tab[i][2], ctg_tab[i][3], sum, tpr, fpr);
