@@ -18,10 +18,10 @@
 #include <cdi.h>
 
 #include "cdo_options.h"
+#include "compare.h"
 #include "dmemory.h"
 #include "varray.h"
 #include "process_int.h"
-#include "cdo_cdi_wrapper.h"
 #include "cdo_default_values.h"
 #include <mpim_grid.h>
 
@@ -51,7 +51,7 @@ struct dset_obj_t
 
 struct datasets_t
 {
-  int nsets;
+  int numSets;
   int mergelevel;
   int lgeoloc;
   int lregion;
@@ -200,10 +200,10 @@ defLonLatGrid(int nx, int ny, double c0, double lts, double re)
 static int
 defSinusoidalGrid(int nx, int ny, double xmin, double ymax, double dx, double dy, double p1, double p2, double p3, double p4)
 {
-  (void) (p1);  // CDO_UNUSED
-  (void) (p2);  // CDO_UNUSED
-  (void) (p3);  // CDO_UNUSED
-  (void) (p4);  // CDO_UNUSED
+  (void) (p1);  // unused
+  (void) (p2);  // unused
+  (void) (p3);  // unused
+  (void) (p4);  // unused
   Varray<double> xvals(nx), yvals(ny);
 
   for (int i = 0; i < nx; ++i) xvals[i] = xmin + i * dx + dx / 2;
@@ -351,7 +351,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
   H5Tinsert(proj_tid, "Reference ellipsoid", HOFFSET(proj_t, ellipsoid), str_tid);
   H5Tinsert(proj_tid, "Projection parameter", HOFFSET(proj_t, parameter), fltarr_tid);
 
-  if (projection_name) Free(projection_name);
+  //if (projection_name) Free(projection_name); failed with: pointer being freed was not allocated
 
   grp_id = H5Gopen(loc_id, "Geolocation");
 
@@ -421,7 +421,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
   /* some CM-SAF files have incorrect entries for some metadata. */
   /* these are corrected in the following sections. */
   /* in case of questions on this, contact frank.kaspar@dwd.de */
-  if (strcmp(proj.ellipsoid, "WSG-84") == 0) strcpy(proj.ellipsoid, "WGS-84");
+  if (cdo_cmpstr(proj.ellipsoid, "WSG-84")) strcpy(proj.ellipsoid, "WGS-84");
 
   if ((int) region.xmin == -8887500 && (int) region.xmax == -8887500 && (int) region.ymin == 8887500 && (int) region.ymax == 8887500
       && (int) region.dx == 15000 && (int) region.dy == 15000)
@@ -452,7 +452,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
       if (Options::cdoVerbose) cdo_print("  Corrected size: xsize=%d  ysize=%d", xsize, ysize);
     }
 
-  if (strcmp(proj.name, "sinusoidal") != 0
+  if (!cdo_cmpstr(proj.name, "sinusoidal")
       && ((nx == xsize && ny == ysize && (int) region.xmin == -8887500 && (int) region.xmax == 8887500
            && (int) region.ymin == -8887500 && (int) region.ymax == 8887500 && (int) region.dx == 15000 && (int) region.dy == 15000)
           || (nx == xsize && ny == ysize && (int) region.xmin == -5827500 && (int) region.xmax == 5827500
@@ -484,13 +484,13 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
                   proj.parameter[3]);
     }
 
-  if (nx == xsize && ny == ysize && strcmp(proj.name, "sinusoidal") == 0 && strcmp(proj.ellipsoid, "WGS-84") == 0)
+  if (nx == xsize && ny == ysize && cdo_cmpstr(proj.name, "sinusoidal") && cdo_cmpstr(proj.ellipsoid, "WGS-84"))
     {
       gridID = defSinusoidalGrid(nx, ny, region.xmin, region.ymax, region.dx, region.dy, proj.parameter[0], proj.parameter[1],
                                  proj.parameter[2], proj.parameter[3]);
     }
   /* modification by Frank Kaspar */
-  else if (nx == xsize && ny == ysize && strcmp(proj.name, "Lambert Azimuthal Equal Area") == 0
+  else if (nx == xsize && ny == ysize && cdo_cmpstr(proj.name, "Lambert Azimuthal Equal Area")
            && memcmp(proj.ellipsoid, "Sphere", 6) == 0)
     {
       double a = (proj.parameter[4] < 0) ? 6370997.0 : proj.parameter[4];
@@ -583,7 +583,7 @@ read_region(hid_t loc_id, int nx, int ny)
   }
   */
   herr_t status = H5Dread(region_id, region_tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, &region);
-  (void) (status);  // CDO_UNUSED
+  (void) (status);  // unused
 
   if (Options::cdoVerbose)
     {
@@ -632,13 +632,13 @@ read_region(hid_t loc_id, int nx, int ny)
   double dx = (xmax - xmin) / nx;
   double dy = (ymax - ymin) / ny;
   /*
-  xsize = (int)lround((region.xmax-region.xmin)/region.dx);
-  ysize = (int)lround((region.ymax-region.ymin)/region.dy);
+  xsize = (int) std::lround((region.xmax-region.xmin)/region.dx);
+  ysize = (int) std::lround((region.ymax-region.ymin)/region.dy);
 
   if ( Options::cdoVerbose ) cdo_print("  Size: xsize=%d  ysize=%d", xsize, ysize);
   */
 
-  if (nfound == 4 && nx == region.xsize && ny == region.ysize && strcmp(proj, "laea") == 0)
+  if (nfound == 4 && nx == region.xsize && ny == region.ysize && cdo_cmpstr(proj, "laea"))
     {
       gridID = defLaeaGrid(nx, ny, xmin, ymax, dx, dy, a, lon0, lat0);
     }
@@ -682,10 +682,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
   hid_t type_id = H5Dget_type(dset_id); /* get datatype*/
 
   H5T_class_t type_class = H5Tget_class(type_id);
-  if (type_class < 0)
-    {
-      cdo_abort(" Invalid datatype for %s", varname);
-    }
+  if (type_class < 0) { cdo_abort(" Invalid datatype for %s", varname); }
   /*
   else {
     if(type_class == H5T_INTEGER)  puts("   Datatype is 'H5T_NATIVE_INTEGER'.\n");
@@ -744,7 +741,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
     }
   H5Tclose(native_type);
 
-  dataspace = H5Dget_space(dset_id); // dataspace handle
+  dataspace = H5Dget_space(dset_id);  // dataspace handle
   rank = H5Sget_simple_extent_ndims(dataspace);
   status = H5Sget_simple_extent_dims(dataspace, dims_out, nullptr);
 
@@ -781,15 +778,15 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
   gridsize = nx * ny;
 
   if (nz == 1)
-    nset = ((datasets_t *) opdata)->nsets;
+    nset = ((datasets_t *) opdata)->numSets;
   else
     {
-      for (nset = 0; nset < ((datasets_t *) opdata)->nsets; ++nset)
+      for (nset = 0; nset < ((datasets_t *) opdata)->numSets; ++nset)
         {
-          if (strcmp(varname, ((datasets_t *) opdata)->obj[nset].name) == 0) break;
+          if (cdo_cmpstr(varname, ((datasets_t *) opdata)->obj[nset].name)) break;
         }
 
-      if (nset >= ((datasets_t *) opdata)->nsets) cdo_abort("3D var %s not found!", varname);
+      if (nset >= ((datasets_t *) opdata)->numSets) cdo_abort("3D var %s not found!", varname);
     }
 
   if (nset < MAX_DSETS)
@@ -803,7 +800,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
           atype = H5Aget_type(attr);
           H5Aget_name(attr, sizeof(attname), attname);
 
-          if (strcmp(attname, "CLASS") == 0 || strcmp(attname, "IMAGE_VERSION") == 0 || strcmp(attname, "PALETTE") == 0) continue;
+          if (cdo_cmpstr(attname, "CLASS") || cdo_cmpstr(attname, "IMAGE_VERSION") || cdo_cmpstr(attname, "PALETTE")) continue;
 
           atype_mem = H5Tget_native_type(atype, H5T_DIR_ASCEND);
           atype_size = H5Tget_size(atype);
@@ -812,7 +809,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
           len = strlen(attname);
           for (int k = 0; k < len; ++k) attname[k] = tolower(attname[k]);
 
-          if (strcmp(attname, "intercept") == 0 || strcmp(attname, "offset") == 0)
+          if (cdo_cmpstr(attname, "intercept") || cdo_cmpstr(attname, "offset"))
             {
               if (atype_class == H5T_FLOAT)
                 {
@@ -851,7 +848,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
               else
                 cdo_warning("Attribute %s has unsupported data type!", attname);
             }
-          else if (strcmp(attname, "gain") == 0 || strcmp(attname, "scaling_factor") == 0)
+          else if (cdo_cmpstr(attname, "gain") || cdo_cmpstr(attname, "scaling_factor"))
             {
               if (atype_class == H5T_FLOAT)
                 {
@@ -929,25 +926,25 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
               else
                 cdo_warning("Attribute %s has unsupported data type!", attname);
             }
-          else if (strcmp(attname, "description") == 0)
+          else if (cdo_cmpstr(attname, "description"))
             {
               H5Aread(attr, atype_mem, attstring);
               if (((datasets_t *) opdata)->obj[nset].description) Free(((datasets_t *) opdata)->obj[nset].description);
               ((datasets_t *) opdata)->obj[nset].description = strdup(attstring);
             }
-          else if (strcmp(attname, "title") == 0)
+          else if (cdo_cmpstr(attname, "title"))
             {
               H5Aread(attr, atype_mem, attstring);
               if (((datasets_t *) opdata)->obj[nset].title) Free(((datasets_t *) opdata)->obj[nset].title);
               ((datasets_t *) opdata)->obj[nset].title = strdup(attstring);
             }
-          else if (strcmp(attname, "time") == 0)
+          else if (cdo_cmpstr(attname, "time"))
             {
               H5Aread(attr, atype_mem, attstring);
               if (((datasets_t *) opdata)->obj[nset].time) Free(((datasets_t *) opdata)->obj[nset].time);
               ((datasets_t *) opdata)->obj[nset].time = strdup(attstring);
             }
-          else if (strcmp(attname, "unit") == 0)
+          else if (cdo_cmpstr(attname, "unit"))
             {
               H5Aread(attr, atype_mem, attstring);
               ((datasets_t *) opdata)->obj[nset].units = strdup(attstring);
@@ -1008,13 +1005,13 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
             cdo_warning("Missing value changes over levels!");
         }
 
-      if (nz == 1) ((datasets_t *) opdata)->nsets++;
+      if (nz == 1) ((datasets_t *) opdata)->numSets++;
 
       std::vector<bool> mask(gridsize * nt, false);
 
       nmiss = 0;
 
-      const auto mm = varray_min_max(gridsize * nt, array);
+      auto mm = varray_min_max(gridsize * nt, array);
 
       if (Options::cdoVerbose)
         cdo_print("Dataset %s: missval = %g  addoffset = %g  scalefactor = %g", varname, missval, addoffset, scalefactor);
@@ -1117,19 +1114,13 @@ obj_info(hid_t loc_id, const char *name, void *opdata)
     {
     case H5G_GROUP:
       if (Options::cdoVerbose) cdo_print(" Object with name %s is a group", name);
-      if (strcmp(name, "Data") == 0)
+      if (cdo_cmpstr(name, "Data"))
         {
           ((datasets_t *) opdata)->mergelevel = true;
           H5Giterate(loc_id, name, nullptr, obj_info, opdata);
         }
-      else if (strcmp(name, "Geolocation") == 0)
-        {
-          ((datasets_t *) opdata)->lgeoloc = true;
-        }
-      else if (strcmp(name, "Metadata") == 0)
-        {
-          ((datasets_t *) opdata)->lmetadata = true;
-        }
+      else if (cdo_cmpstr(name, "Geolocation")) { ((datasets_t *) opdata)->lgeoloc = true; }
+      else if (cdo_cmpstr(name, "Metadata")) { ((datasets_t *) opdata)->lmetadata = true; }
       break;
     case H5G_DATASET:
       if (Options::cdoVerbose) cdo_print(" Object with name %s is a dataset", name);
@@ -1138,10 +1129,7 @@ obj_info(hid_t loc_id, const char *name, void *opdata)
           if (Options::cdoVerbose) cdo_print("   Skip dataset: %s", name);
         }
       /*else if ( strstr(name, "egion") ) */
-      else if (strcmp(name, "region") == 0)
-        {
-          ((datasets_t *) opdata)->lregion = true;
-        }
+      else if (cdo_cmpstr(name, "region")) { ((datasets_t *) opdata)->lregion = true; }
       else
         {
           if (Options::cdoVerbose) cdo_print("   Read dataset: %s", name);
@@ -1150,10 +1138,7 @@ obj_info(hid_t loc_id, const char *name, void *opdata)
       break;
     case H5G_TYPE:
       if (Options::cdoVerbose) cdo_print(" Object with name %s is a named datatype", name);
-      if (strcmp(name, "ProjType") == 0)
-        {
-          ((datasets_t *) opdata)->lprojtype = true;
-        }
+      if (cdo_cmpstr(name, "ProjType")) { ((datasets_t *) opdata)->lprojtype = true; }
       break;
     default: cdo_abort(" Unable to identify an object %s", name); break;
     }
@@ -1230,7 +1215,7 @@ get_vdate(int vlistID)
       cdiInqAtt(vlistID, CDI_GLOBAL, i, name, &type, &len);
       if (type == CDI_DATATYPE_TXT)
         {
-          if (strcmp(name, "DateAndTime") == 0 || strcmp(name, "Date_Time") == 0)
+          if (cdo_cmpstr(name, "DateAndTime") || cdo_cmpstr(name, "Date_Time"))
             {
               cdiInqAttTxt(vlistID, CDI_GLOBAL, name, CDI_MAX_NAME, attstr);
               if (len > 8) len = 8;
@@ -1247,7 +1232,7 @@ get_vdate(int vlistID)
 static void
 dsets_init(datasets_t *dsets)
 {
-  dsets->nsets = 0;
+  dsets->numSets = 0;
   dsets->mergelevel = 0;
   dsets->lgeoloc = 0;
   dsets->lregion = 0;
@@ -1304,7 +1289,7 @@ Importcmsaf(void *process)
 
   H5Giterate(file_id, "/", nullptr, obj_info, (void *) &dsets);
 
-  if (dsets.nsets == 0) cdo_abort("No dataset found!");
+  if (dsets.numSets == 0) cdo_abort("No dataset found!");
 
   int gridsize = dsets.obj[0].gridsize;
   int nx = dsets.obj[0].nx;
@@ -1312,7 +1297,7 @@ Importcmsaf(void *process)
   int nz = dsets.obj[0].nz;
   int nt = dsets.obj[0].nt;
 
-  for (ivar = 0; ivar < dsets.nsets; ++ivar)
+  for (ivar = 0; ivar < dsets.numSets; ++ivar)
     if (dsets.obj[ivar].nt > 1)
       {
         nt = dsets.obj[ivar].nt;
@@ -1343,23 +1328,17 @@ Importcmsaf(void *process)
     }
 
   if (Options::cdoVerbose)
-    for (ivar = 0; ivar < dsets.nsets; ++ivar)
+    for (ivar = 0; ivar < dsets.numSets; ++ivar)
       cdo_print(" Var %d %-20s %dx%d nlev = %d nts = %d", ivar, dsets.obj[ivar].name, nx, ny, nz, dsets.obj[ivar].nt);
 
-  for (ivar = 1; ivar < dsets.nsets; ++ivar)
+  for (ivar = 1; ivar < dsets.numSets; ++ivar)
     {
       if (nx != dsets.obj[0].nx || ny != dsets.obj[0].ny) cdo_abort("Gridsize must not change!");
       if (nz != dsets.obj[0].nz) cdo_abort("Number of levels must not change!");
     }
 
-  if (dsets.lgeoloc)
-    {
-      gridID = read_geolocation(file_id, nx, ny, dsets.lprojtype);
-    }
-  else if (dsets.lregion)
-    {
-      gridID = read_region(file_id, nx, ny);
-    }
+  if (dsets.lgeoloc) { gridID = read_geolocation(file_id, nx, ny, dsets.lprojtype); }
+  else if (dsets.lregion) { gridID = read_region(file_id, nx, ny); }
 
   if (gridID == -1)
     {
@@ -1378,13 +1357,13 @@ Importcmsaf(void *process)
       zaxisDefLevels(zaxisID, levels.data());
     }
 
-  const auto vlistID = vlistCreate();
+  auto vlistID = vlistCreate();
 
-  const auto taxisID = cdo_taxis_create((nt > 1) ? TAXIS_RELATIVE : TAXIS_ABSOLUTE);
+  auto taxisID = cdo_taxis_create((nt > 1) ? TAXIS_RELATIVE : TAXIS_ABSOLUTE);
   taxisDefCalendar(taxisID, CALENDAR_STANDARD);
   vlistDefTaxis(vlistID, taxisID);
 
-  for (ivar = 0; ivar < dsets.nsets; ++ivar)
+  for (ivar = 0; ivar < dsets.numSets; ++ivar)
     {
       varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
       cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, dsets.obj[ivar].name);
@@ -1404,20 +1383,20 @@ Importcmsaf(void *process)
   int vdate = get_vdate(vlistID);
   if (vdate == 0) vdate = 10101;
 
-  const auto streamID = cdo_open_write(1);
+  auto streamID = cdo_open_write(1);
 
   cdo_def_vlist(streamID, vlistID);
 
   for (tsID = 0; tsID < nt; ++tsID)
     {
       const int vtime = (vtimes.empty()) ? 0 : vtimes[tsID];
-      CdiDateTime vDateTime = { };
+      CdiDateTime vDateTime{};
       vDateTime.date = cdiDate_set(vdate);
       vDateTime.time = cdiTime_set(vtime);
       taxisDefVdatetime(taxisID, vDateTime);
       cdo_def_timestep(streamID, tsID);
 
-      for (ivar = 0; ivar < dsets.nsets; ++ivar)
+      for (ivar = 0; ivar < dsets.numSets; ++ivar)
         {
           varID = ivar;
 
@@ -1432,7 +1411,7 @@ Importcmsaf(void *process)
               if (nz == 1) offset = gridsize * tsID;
               double *array = dsets.obj[ivar].array + offset;
 
-              const auto mm = varray_min_max_mv(gridsize, array, missval);
+              auto mm = varray_min_max_mv(gridsize, array, missval);
               nmiss = gridsize - mm.n;
 
               if (Options::cdoVerbose)
@@ -1447,7 +1426,7 @@ Importcmsaf(void *process)
 
   // Close file
   status = H5Fclose(file_id);
-  (void) (status);  // CDO_UNUSED
+  (void) (status);  // unused
 
   process_def_var_num(vlistNvars(vlistID));
 
@@ -1458,7 +1437,7 @@ Importcmsaf(void *process)
   zaxisDestroy(zaxisID);
   taxisDestroy(taxisID);
 
-  for (ivar = 0; ivar < dsets.nsets; ++ivar) Free(dsets.obj[ivar].array);
+  for (ivar = 0; ivar < dsets.numSets; ++ivar) Free(dsets.obj[ivar].array);
 
   cdo_finish();
 #else
