@@ -11,7 +11,6 @@
 #include "process_int.h"
 #include "varray.h"
 #include "readline.h"
-#include "cdo_cdi_wrapper.h"
 #include <mpim_grid.h>
 #include "griddes.h"
 
@@ -103,7 +102,7 @@ Importobs(void *process)
   cdo_grid_to_degree(gridID, CDI_XAXIS, gridsize, xvals.data(), "grid center lon");
   cdo_grid_to_degree(gridID, CDI_YAXIS, gridsize, yvals.data(), "grid center lat");
 
-  auto fp = fopen(cdo_get_stream_name(0), "r");
+  auto fp = std::fopen(cdo_get_stream_name(0), "r");
   if (fp == nullptr)
     {
       perror(cdo_get_stream_name(0));
@@ -135,10 +134,10 @@ Importobs(void *process)
   int tsID = 0;
   while (cdo::readline(fp, line, MAX_LINE_LEN))
     {
-      sscanf(line, "%s %s %s %g %g %g %d %g %g %g", dummy, station, datetime, &lat, &lon, &height1, &code, &pressure, &height2,
+      std::sscanf(line, "%s %s %s %g %g %g %d %g %g %g", dummy, station, datetime, &lat, &lon, &height1, &code, &pressure, &height2,
              &value);
       long vdate_l;
-      sscanf(datetime, "%ld_%d", &vdate_l, &vtime);
+      std::sscanf(datetime, "%ld_%d", &vdate_l, &vtime);
       vdate = vdate_l;
 
       if (vdate != vdate0 || vtime != vtime0)
@@ -148,7 +147,7 @@ Importobs(void *process)
           vdate0 = vdate;
           vtime0 = vtime;
           // printf("%s %d %d %g %g %g %d %g %g %g\n", station, vdate, vtime, lat, lon, height1, code, pressure, height2, value);
-          CdiDateTime vDateTime = { };
+          CdiDateTime vDateTime{};
           vDateTime.date = cdiDate_set(vdate);
           vDateTime.time = cdiTime_set(vtime);
           taxisDefVdatetime(taxisID, vDateTime);
@@ -204,7 +203,7 @@ Importobs(void *process)
 
   cdo_stream_close(streamID);
 
-  fclose(fp);
+  std::fclose(fp);
 
   vlistDestroy(vlistID);
   gridDestroy(gridID);
