@@ -123,7 +123,7 @@ Intntime(void *process)
       for (int it = 1; it < numts; it++)
         {
           auto seconds = it * julianDate_to_seconds(julianDate_sub(julianDate2, julianDate1)) / numts;
-          auto julianDate = julianDate_add_seconds(julianDate1, lround(seconds));
+          auto julianDate = julianDate_add_seconds(julianDate1, std::lround(seconds));
           auto dt = julianDate_decode(calendar, julianDate);
 
           if (Options::cdoVerbose) cdo_print("%s %s", date_to_string(dt.date), time_to_string(dt.time));
