@@ -18,13 +18,76 @@
 
 #include <cdi.h>
 
+#include <utility>
+
 #include "process_int.h"
+#include "matrix_view.h"
+
+template <typename T>
+static void
+invert_lon_data(Varray<T> &v, size_t nlon, size_t nlat)
+{
+  if (nlat > 0 && nlon > 0)
+    {
+      Varray<T> vtmp(nlon);
+      MatrixView<T> mv(v.data(), nlat, nlon);
+
+      for (size_t ilat = 0; ilat < nlat; ilat++)
+        {
+          for (size_t ilon = 0; ilon < nlon; ilon++) vtmp[ilon] = mv[ilat][ilon];
+          for (size_t ilon = 0; ilon < nlon / 2; ilon++) std::swap(vtmp[ilon], vtmp[nlon - ilon - 1]);
+          for (size_t ilon = 0; ilon < nlon; ilon++) mv[ilat][ilon] = vtmp[ilon];
+        }
+    }
+}
 
 static void
-invertLonDes(int vlistID)
+invert_lon_data(Field &field)
+{
+  const auto nlon = gridInqXsize(field.grid);
+  const auto nlat = gridInqYsize(field.grid);
+
+  if (field.memType == MemType::Float)
+    invert_lon_data(field.vec_f, nlon, nlat);
+  else
+    invert_lon_data(field.vec_d, nlon, nlat);
+}
+
+template <typename T>
+static void
+invert_lat_data(Varray<T> &v, size_t nlon, size_t nlat)
+{
+  if (nlat > 0 && nlon > 0)
+    {
+      Varray<T> vtmp(nlon);
+      MatrixView<T> mv(v.data(), nlat, nlon);
+
+      for (size_t ilat = 0; ilat < nlat / 2; ilat++)
+        {
+          for (size_t ilon = 0; ilon < nlon; ilon++) vtmp[ilon] = mv[ilat][ilon];
+          for (size_t ilon = 0; ilon < nlon; ilon++) mv[ilat][ilon] = mv[nlat - ilat - 1][ilon];
+          for (size_t ilon = 0; ilon < nlon; ilon++) mv[nlat - ilat - 1][ilon] = vtmp[ilon];
+        }
+    }
+}
+
+static void
+invert_lat_data(Field &field)
+{
+  const auto nlon = gridInqXsize(field.grid);
+  const auto nlat = gridInqYsize(field.grid);
+
+  if (field.memType == MemType::Float)
+    invert_lat_data(field.vec_f, nlon, nlat);
+  else
+    invert_lat_data(field.vec_d, nlon, nlat);
+}
+
+static void
+invert_lon_des(int vlistID)
 {
   const auto ngrids = vlistNgrids(vlistID);
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       const auto gridID1 = vlistGrid(vlistID, index);
       const auto gridID2 = gridDuplicate(gridID1);
@@ -41,21 +104,27 @@ invertLonDes(int vlistID)
           const auto nlat = gridInqYsize(gridID1);
           const auto size = (gridtype == GRID_CURVILINEAR) ? nlon * nlat : nlon;
 
-          Varray<double> xv1(size), xv2(size);
-
-          gridInqXvals(gridID1, xv1.data());
+          Varray<double> coords(size);
 
           if (gridtype == GRID_CURVILINEAR)
             {
-              for (size_t ilat = 0; ilat < nlat; ilat++)
-                for (size_t ilon = 0; ilon < nlon; ilon++) xv2[ilat * nlon + nlon - ilon - 1] = xv1[ilat * nlon + ilon];
+              gridInqXvals(gridID1, coords.data());
+              invert_lon_data(coords, nlon, nlat);
+              gridDefXvals(gridID2, coords.data());
+
+              if (gridInqYvals(gridID1, nullptr))
+                {
+                  gridInqYvals(gridID1, coords.data());
+                  invert_lon_data(coords, nlon, nlat);
+                  gridDefYvals(gridID2, coords.data());
+                }
             }
           else
             {
-              for (size_t ilon = 0; ilon < nlon; ilon++) xv2[nlon - ilon - 1] = xv1[ilon];
+              gridInqXvals(gridID1, coords.data());
+              for (size_t ilon = 0; ilon < nlon / 2; ilon++) std::swap(coords[ilon], coords[nlon - ilon - 1]);
+              gridDefXvals(gridID2, coords.data());
             }
-
-          gridDefXvals(gridID2, xv2.data());
         }
 
       if (gridInqXbounds(gridID1, nullptr))
@@ -65,27 +134,31 @@ invertLonDes(int vlistID)
           const auto nv = gridInqNvertex(gridID1);
           const auto size = (gridtype == GRID_CURVILINEAR) ? nv * nlon * nlat : nv * nlon;
 
-          Varray<double> xb1(size), xb2(size);
-
-          gridInqXbounds(gridID1, xb1.data());
+          Varray<double> bounds(size);
 
           if (gridtype == GRID_CURVILINEAR)
             {
-              for (size_t ilat = 0; ilat < nlat; ilat++)
-                for (size_t ilon = 0; ilon < nlon; ilon++)
-                  for (int iv = 0; iv < nv; iv++)
-                    xb2[ilat * nlon * nv + (nlon - ilon - 1) * nv + iv] = xb1[ilat * nlon * nv + ilon * nv + iv];
+              gridInqXbounds(gridID1, bounds.data());
+              invert_lon_data(bounds, nlon * nv, nlat);
+              gridDefXbounds(gridID2, bounds.data());
+
+              if (gridInqYbounds(gridID1, nullptr))
+                {
+                  gridInqYbounds(gridID1, bounds.data());
+                  invert_lon_data(bounds, nlon * nv, nlat);
+                  gridDefYbounds(gridID2, bounds.data());
+                }
             }
           else
             {
-              for (size_t ilon = 0; ilon < nlon; ilon++)
+              gridInqXbounds(gridID1, bounds.data());
+              for (size_t ilon = 0; ilon < nlon / 2; ilon++)
                 {
-                  xb2[nlon * 2 - ilon * 2 - 1] = xb1[ilon * 2];
-                  xb2[nlon * 2 - ilon * 2 - 2] = xb1[ilon * 2 + 1];
+                  std::swap(bounds[nlon * 2 - ilon * 2 - 1], bounds[ilon * 2]);
+                  std::swap(bounds[nlon * 2 - ilon * 2 - 2], bounds[ilon * 2 + 1]);
                 }
+              gridDefXbounds(gridID2, bounds.data());
             }
-
-          gridDefXbounds(gridID2, xb2.data());
         }
 
       vlistChangeGrid(vlistID, gridID1, gridID2);
@@ -93,7 +166,7 @@ invertLonDes(int vlistID)
 }
 
 static void
-invertLatCoord(int gridID)
+invert_lat_coord(int gridID)
 {
   const auto gridtype = gridInqType(gridID);
 
@@ -103,31 +176,26 @@ invertLatCoord(int gridID)
       const auto nlat = gridInqYsize(gridID);
       const auto size = (gridtype == GRID_CURVILINEAR) ? nlon * nlat : nlat;
 
-      Varray<double> yv1(size), yv2(size);
+      Varray<double> coords(size);
 
       if (gridtype == GRID_CURVILINEAR)
         {
-          gridInqXvals(gridID, yv1.data());
+          if (gridInqXvals(gridID, nullptr))
+            {
+              gridInqXvals(gridID, coords.data());
+              invert_lat_data(coords, nlon, nlat);
+              gridDefXvals(gridID, coords.data());
+            }
 
-          for (size_t ilat = 0; ilat < nlat; ilat++)
-            for (size_t ilon = 0; ilon < nlon; ilon++) yv2[(nlat - ilat - 1) * nlon + ilon] = yv1[ilat * nlon + ilon];
-
-          gridDefXvals(gridID, yv2.data());
-
-          gridInqYvals(gridID, yv1.data());
-
-          for (size_t ilat = 0; ilat < nlat; ilat++)
-            for (size_t ilon = 0; ilon < nlon; ilon++) yv2[(nlat - ilat - 1) * nlon + ilon] = yv1[ilat * nlon + ilon];
-
-          gridDefYvals(gridID, yv2.data());
+          gridInqYvals(gridID, coords.data());
+          invert_lat_data(coords, nlon, nlat);
+          gridDefYvals(gridID, coords.data());
         }
       else
         {
-          gridInqYvals(gridID, yv1.data());
-
-          for (size_t ilat = 0; ilat < nlat; ilat++) yv2[nlat - ilat - 1] = yv1[ilat];
-
-          gridDefYvals(gridID, yv2.data());
+          gridInqYvals(gridID, coords.data());
+          for (size_t ilat = 0; ilat < nlat / 2; ilat++) std::swap(coords[ilat], coords[nlat - ilat - 1]);
+          gridDefYvals(gridID, coords.data());
         }
     }
 
@@ -138,35 +206,39 @@ invertLatCoord(int gridID)
       const auto nv = gridInqNvertex(gridID);
       const auto size = (gridtype == GRID_CURVILINEAR) ? nv * nlon * nlat : nv * nlat;
 
-      Varray<double> yb1(size), yb2(size);
-
-      gridInqYbounds(gridID, yb1.data());
+      Varray<double> bounds(size);
 
       if (gridtype == GRID_CURVILINEAR)
         {
-          for (size_t ilat = 0; ilat < nlat; ilat++)
-            for (size_t ilon = 0; ilon < nlon; ilon++)
-              for (int iv = 0; iv < nv; iv++)
-                yb2[(nlat - ilat - 1) * nlon * nv + ilon * nv + iv] = yb1[ilat * nlon * nv + ilon * nv + iv];
+          if (gridInqXbounds(gridID, nullptr))
+            {
+              gridInqXbounds(gridID, bounds.data());
+              invert_lat_data(bounds, nlon * nv, nlat);
+              gridDefXbounds(gridID, bounds.data());
+            }
+
+          gridInqYbounds(gridID, bounds.data());
+          invert_lat_data(bounds, nlon * nv, nlat);
+          gridDefYbounds(gridID, bounds.data());
         }
       else
         {
-          for (size_t ilat = 0; ilat < nlat; ilat++)
+          gridInqYbounds(gridID, bounds.data());
+          for (size_t ilat = 0; ilat < nlat / 2; ilat++)
             {
-              yb2[nlat * 2 - ilat * 2 - 1] = yb1[ilat * 2];
-              yb2[nlat * 2 - ilat * 2 - 2] = yb1[ilat * 2 + 1];
+              std::swap(bounds[nlat * 2 - ilat * 2 - 1], bounds[ilat * 2]);
+              std::swap(bounds[nlat * 2 - ilat * 2 - 2], bounds[ilat * 2 + 1]);
             }
+          gridDefYbounds(gridID, bounds.data());
         }
-
-      gridDefYbounds(gridID, yb2.data());
     }
 }
 
 static void
-invertLatDes(int vlistID)
+invert_lat_des(int vlistID)
 {
   const auto ngrids = vlistNgrids(vlistID);
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       const auto gridID1 = vlistGrid(vlistID, index);
       const auto gridID2 = gridDuplicate(gridID1);
@@ -177,64 +249,15 @@ invertLatDes(int vlistID)
             || gridtype == GRID_CURVILINEAR))
         cdo_abort("Unsupported gridtype: %s!", gridNamePtr(gridtype));
 
-      invertLatCoord(gridID2);
+      invert_lat_coord(gridID2);
 
       const auto projID = gridInqProj(gridID2);
-      if (projID != CDI_UNDEFID) invertLatCoord(projID);
+      if (projID != CDI_UNDEFID) invert_lat_coord(projID);
 
       vlistChangeGrid(vlistID, gridID1, gridID2);
     }
 }
 
-static void
-invertLonData(double *array1, double *array2, int gridID1)
-{
-  const auto nlon = gridInqXsize(gridID1);
-  const auto nlat = gridInqYsize(gridID1);
-
-  if (nlat > 0)
-    {
-      std::vector<double *> field1(nlat), field2(nlat);
-
-      for (size_t ilat = 0; ilat < nlat; ilat++)
-        {
-          field1[ilat] = array1 + ilat * nlon;
-          field2[ilat] = array2 + ilat * nlon;
-        }
-
-      for (size_t ilat = 0; ilat < nlat; ilat++)
-        for (size_t ilon = 0; ilon < nlon; ilon++) field2[ilat][nlon - ilon - 1] = field1[ilat][ilon];
-    }
-  else
-    {
-      array2[0] = array1[0];
-    }
-}
-
-static void
-invertLatData(double *array1, double *array2, int gridID1)
-{
-  const auto nlon = gridInqXsize(gridID1);
-  const auto nlat = gridInqYsize(gridID1);
-
-  if (nlat > 0)
-    {
-      std::vector<double *> field1(nlat), field2(nlat);
-
-      for (size_t ilat = 0; ilat < nlat; ilat++)
-        {
-          field1[ilat] = array1 + ilat * nlon;
-          field2[ilat] = array2 + ilat * nlon;
-        }
-
-      for (size_t ilat = 0; ilat < nlat; ilat++) array_copy(nlon, field1[ilat], field2[nlat - ilat - 1]);
-    }
-  else
-    {
-      array2[0] = array1[0];
-    }
-}
-
 void *
 Invert(void *process)
 {
@@ -276,17 +299,19 @@ Invert(void *process)
   if (operfunc1 == func_all || operfunc1 == func_hrd)
     {
       if (operfunc2 == func_lat)
-        invertLatDes(vlistID2);
+        invert_lat_des(vlistID2);
       else
-        invertLonDes(vlistID2);
+        invert_lon_des(vlistID2);
     }
 
   const auto streamID2 = cdo_open_write(1);
 
   cdo_def_vlist(streamID2, vlistID2);
 
-  const auto gridsizemax = vlistGridsizeMax(vlistID1);
-  Varray<double> array1(gridsizemax), array2(gridsizemax);
+  VarList varList1;
+  varListInit(varList1, vlistID1);
+
+  Field field;
 
   int tsID = 0;
   while (true)
@@ -298,31 +323,27 @@ Invert(void *process)
 
       cdo_def_timestep(streamID2, tsID);
 
-      for (int recID = 0; recID < nrecs; recID++)
+      for (int recID = 0; recID < nrecs; ++recID)
         {
           int varID, levelID;
           cdo_inq_record(streamID1, &varID, &levelID);
-          size_t nmiss;
-          cdo_read_record(streamID1, array1.data(), &nmiss);
+          field.init(varList1[varID]);
+          cdo_read_record(streamID1, field);
 
           cdo_def_record(streamID2, varID, levelID);
 
           if (operfunc1 == func_all || operfunc1 == func_fld)
             {
-              const auto gridID1 = vlistInqVarGrid(vlistID1, varID);
-
               if (operfunc2 == func_lat)
-                invertLatData(array1.data(), array2.data(), gridID1);
+                invert_lat_data(field);
               else
-                invertLonData(array1.data(), array2.data(), gridID1);
+                invert_lon_data(field);
 
-              cdo_write_record(streamID2, array2.data(), nmiss);
-            }
-          else
-            {
-              cdo_write_record(streamID2, array1.data(), nmiss);
+              cdo_write_record(streamID2, field);
             }
+          else { cdo_write_record(streamID2, field); }
         }
+
       tsID++;
     }
 
