@@ -19,14 +19,14 @@
 static void
 invertLevDes(int vlistID)
 {
-  const auto nzaxis = vlistNzaxis(vlistID);
+  auto nzaxis = vlistNzaxis(vlistID);
   for (int index = 0; index < nzaxis; ++index)
     {
-      const auto zaxisID1 = vlistZaxis(vlistID, index);
-      const auto zaxisID2 = zaxisDuplicate(zaxisID1);
-      const auto zaxistype = zaxisInqType(zaxisID1);
+      auto zaxisID1 = vlistZaxis(vlistID, index);
+      auto zaxisID2 = zaxisDuplicate(zaxisID1);
+      auto zaxistype = zaxisInqType(zaxisID1);
 
-      const auto nlev = zaxisInqSize(zaxisID1);
+      auto nlev = zaxisInqSize(zaxisID1);
       if (nlev <= 1) continue;
 
       if (zaxisInqLevels(zaxisID1, nullptr))
@@ -76,31 +76,31 @@ Invertlev(void *process)
 
   cdo_initialize(process);
 
-  const auto dataIsUnchanged = data_is_unchanged();
+  auto dataIsUnchanged = data_is_unchanged();
 
   cdo_operator_add("invertlev", 0, 0, nullptr);
 
   operator_check_argc(0);
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
   invertLevDes(vlistID2);
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
 
   cdo_def_vlist(streamID2, vlistID2);
 
-  const auto gridsizemax = vlistGridsizeMax(vlistID1);
+  auto gridsizemax = vlistGridsizeMax(vlistID1);
   Varray<double> array(gridsizemax);
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
   Varray2D<double> vardata(nvars);
   std::vector<std::vector<size_t>> varnmiss(nvars);
@@ -111,7 +111,7 @@ Invertlev(void *process)
   auto has3dVar = false;
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto nlevels = varList1[varID].nlevels;
+      auto nlevels = varList1[varID].nlevels;
       if (nlevels > 1)
         {
           has3dVar = true;
@@ -125,7 +125,7 @@ Invertlev(void *process)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -139,17 +139,14 @@ Invertlev(void *process)
 
           if (vardata[varID].size())
             {
-              const auto offset = varList1[varID].gridsize * levelID;
+              auto offset = varList1[varID].gridsize * levelID;
               cdo_read_record(streamID1, &vardata[varID][offset], &nmiss);
               varnmiss[varID][levelID] = nmiss;
             }
           else
             {
               cdo_def_record(streamID2, varID, levelID);
-              if (dataIsUnchanged)
-                {
-                  cdo_copy_record(streamID2, streamID1);
-                }
+              if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
               else
                 {
                   cdo_read_record(streamID1, array.data(), &nmiss);
@@ -162,13 +159,13 @@ Invertlev(void *process)
         {
           if (vardata[varID].size())
             {
-              const auto gridsize = varList1[varID].gridsize;
-              const auto nlevels = varList1[varID].nlevels;
+              auto gridsize = varList1[varID].gridsize;
+              auto nlevels = varList1[varID].nlevels;
               for (int levelID = 0; levelID < nlevels; ++levelID)
                 {
                   cdo_def_record(streamID2, varID, levelID);
 
-                  const auto offset = gridsize * (nlevels - levelID - 1);
+                  auto offset = gridsize * (nlevels - levelID - 1);
                   nmiss = varnmiss[varID][nlevels - levelID - 1];
 
                   cdo_write_record(streamID2, &vardata[varID][offset], nmiss);
