@@ -93,7 +93,7 @@ static void
 WriteImage2PPM(int n_xres, int n_yres, unsigned char *pImage, const char *f_name)
 {
   FILE *o_file;
-  if ((o_file = fopen(f_name, "w")) == nullptr)
+  if ((o_file = std::fopen(f_name, "w")) == nullptr)
     {
       printf("Can't open output file\n");
       return;
@@ -108,7 +108,7 @@ WriteImage2PPM(int n_xres, int n_yres, unsigned char *pImage, const char *f_name
         fprintf(o_file, "%c%c%c", unchar, unchar, unchar);
       }
 
-  fclose(o_file);
+  std::fclose(o_file);
 }
 */
 
@@ -156,7 +156,7 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
   png_bytep row = nullptr;
 
   // Open file for writing (binary mode)
-  FILE *fp = fopen(filename, "wb");
+  FILE *fp = std::fopen(filename, "wb");
   if (fp == nullptr)
     {
       fprintf(stderr, "Could not open file %s for writing\n", filename);
@@ -214,10 +214,7 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
   // Write image data
   for (int y = 0; y < height; y++)
     {
-      for (int x = 0; x < width; x++)
-        {
-          setRGBmag(&(row[x * 3]), pImage[y * width + x], mag[y * width + x]);
-        }
+      for (int x = 0; x < width; x++) { setRGBmag(&(row[x * 3]), pImage[y * width + x], mag[y * width + x]); }
       png_write_row(png_ptr, row);
     }
 
@@ -225,7 +222,7 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
   png_write_end(png_ptr, nullptr);
 
 finalise:
-  if (fp != nullptr) fclose(fp);
+  if (fp != nullptr) std::fclose(fp);
   if (info_ptr != nullptr) png_free_data(png_ptr, info_ptr, PNG_FREE_ALL, -1);
   if (png_ptr != nullptr) png_destroy_write_struct(&png_ptr, (png_infopp) nullptr);
   if (row != nullptr) free(row);
@@ -436,7 +433,7 @@ Lic(void *process)
   if (cdo_operator_argc() < 1 || cdo_operator_argc() > 2) operator_check_argc(1);
   const char *cpt_file = cdo_operator_argv(0).c_str();
   int nstart = (cdo_operator_argc() == 2) ? std::stoi(cdo_operator_argv(1)) : 0;
-  auto cpt_fp = fopen(cpt_file, "r");
+  auto cpt_fp = std::fopen(cpt_file, "r");
   if (cpt_fp == nullptr) cdo_abort("Open failed on color palette table %s", cpt_file);
 
   int status = cpt_read(cpt_fp, &cpt);
