@@ -20,10 +20,8 @@
 #include <magics_api.h>
 #include "magics_template_parser.h"
 #include "results_template_parser.h"
-#include "string_utilities.h"
 #include "util_string.h"
 
-
 #define DBG 0
 
 int VECTOR, STREAM;
@@ -39,7 +37,7 @@ int checkdevice(char *device_in);
 extern const char *DEVICE;
 
 static void
-magvector(const char *plotfile, int operatorID, const char *varname, long nlon, long nlat, Varray<double> &grid_center_lon,
+magvector(const char *plotfile, int operatorID, long nlon, long nlat, Varray<double> &grid_center_lon,
           Varray<double> &grid_center_lat, Varray<double> &uarray, Varray<double> &varray, int nparam,
           std::vector<std::string> &params, const std::string &datetimeStr)
 
@@ -49,8 +47,6 @@ magvector(const char *plotfile, int operatorID, const char *varname, long nlon,
   char plotfilename[4096];
   char *temp_str = nullptr;
 
-  (void) varname;
-
   if (uarray.empty() && varray.empty())
     {
       fprintf(stderr, " No Velocity Components in input file, cannot creaate Vector PLOT!\n");
@@ -73,7 +69,7 @@ magvector(const char *plotfile, int operatorID, const char *varname, long nlon,
 
   for (i = 0; i < nparam; ++i)
     {
-      const auto splitStrings = cstr_split_with_seperator(params[i].c_str(), "=");
+      const auto splitStrings = split_with_seperator(params[i], '=');
       const auto &key = splitStrings[0];
       const auto &value = splitStrings[1];
 
@@ -92,7 +88,7 @@ magvector(const char *plotfile, int operatorID, const char *varname, long nlon,
       if (key == "device")
         {
           temp_str = strdup(value.c_str());
-          cstr_to_upper_case(temp_str);
+          cstr_to_upper(temp_str);
           DEVICE = temp_str;
           if (DBG) fprintf(stderr, "DEVICE %s\n", DEVICE);
 
@@ -197,7 +193,7 @@ VerifyVectorParameters(int num_param, std::vector<std::string> &param_names, int
 {
 
   int i, j;
-  bool found = false, syntax = true, halt_flag = false;
+  auto halt_flag = false;
   int param_count = 0;
   const char **params = nullptr;
 
@@ -205,9 +201,9 @@ VerifyVectorParameters(int num_param, std::vector<std::string> &param_names, int
 
   for (i = 0; i < num_param; ++i)
     {
-      found = false;
-      syntax = true;
-      const auto splitStrings = cstr_split_with_seperator(param_names[i].c_str(), "=");
+      auto found = false;
+      auto syntax = true;
+      const auto splitStrings = split_with_seperator(param_names[i], '=');
 
       if (DBG) fprintf(stderr, "Verifying params!\n");
 
@@ -229,12 +225,12 @@ VerifyVectorParameters(int num_param, std::vector<std::string> &param_names, int
 
                   if (key == "thin_fac" || key == "unit_vec" || key == "step_freq")
                     {
-                      if (!cstr_is_numeric(value.c_str())) syntax = false;
+                      if (!string_is_float(value)) syntax = false;
                     }
 
                   if (key == "device")
                     {
-                      if (cstr_is_numeric(value.c_str()))
+                      if (string_is_float(value))
                         syntax = false;
                       else
                         {
@@ -253,10 +249,7 @@ VerifyVectorParameters(int num_param, std::vector<std::string> &param_names, int
                 }
             }
         }
-      else
-        {
-          syntax = false;
-        }
+      else { syntax = false; }
 
       if (!found)
         {
@@ -280,8 +273,6 @@ Magvector(void *process)
   cdo_initialize(process);
 
 #ifdef HAVE_LIBMAGICS
-  char varname[CDI_MAX_NAME];
-
   const auto nparam = cdo_operator_argc();
   auto pnames = cdo_get_oper_argv();
 
@@ -310,7 +301,7 @@ Magvector(void *process)
   if (gridInqType(gridID) == GRID_GME) cdo_abort("GME grid unsupported!");
   if (gridInqType(gridID) == GRID_UNSTRUCTURED) cdo_abort("Unstructured grid unsupported!");
 
-  if (gridInqType(gridID) != GRID_CURVILINEAR) gridID = gridToCurvilinear(gridID, 1);
+  if (gridInqType(gridID) != GRID_CURVILINEAR) gridID = gridToCurvilinear(gridID, NeedCorners::Yes);
 
   const auto gridsize = gridInqSize(gridID);
   int nlon = gridInqXsize(gridID);
@@ -366,21 +357,21 @@ Magvector(void *process)
           int varID, levelID;
           cdo_inq_record(streamID, &varID, &levelID);
 
-          vlistInqVarName(vlistID, varID, varname);
+          auto varname = cdo::inq_var_name(vlistID, varID);
 
           if (operatorID == VECTOR)
             {
-              if (cdo_cmpstr(varname, "var131") || cdo_cmpstr(varname, "u"))  // U Velocity as per GRIB is var131, as per NC 'u'
+              if (varname == "var131" || varname == "u")  // U Velocity as per GRIB is var131, as per NC 'u'
                 {
-                  if (DBG) fprintf(stderr, "Found U VEL in Varname %s\n", varname);
+                  if (DBG) fprintf(stderr, "Found U VEL in Varname %s\n", varname.c_str());
                   size_t nmiss;
                   cdo_read_record(streamID, uarray.data(), &nmiss);
                   if (nmiss) cdo_set_nan(vlistInqVarMissval(vlistID, varID), gridsize, uarray.data());
                   found++;
                 }
-              if (cdo_cmpstr(varname, "var132") || cdo_cmpstr(varname, "v"))  // V Velocity as per GRIB  is var132, as per NC 'v'
+              if (varname == "var132" || varname == "v")  // V Velocity as per GRIB  is var132, as per NC 'v'
                 {
-                  if (DBG) fprintf(stderr, "Found V VEL in Varname %s\n", varname);
+                  if (DBG) fprintf(stderr, "Found V VEL in Varname %s\n", varname.c_str());
                   size_t nmiss;
                   cdo_read_record(streamID, varray.data(), &nmiss);
                   if (nmiss) cdo_set_nan(vlistInqVarMissval(vlistID, varID), gridsize, varray.data());
@@ -399,8 +390,8 @@ Magvector(void *process)
           if (found == 2)
             {
               if (DBG) fprintf(stderr, "Found Both U & V VEL, Creating vector fields! \n");
-              magvector(cdo_get_stream_name(1), operatorID, varname, nlon, nlat, grid_center_lon, grid_center_lat, uarray, varray,
-                        nparam, pnames, datetimeStr);
+              magvector(cdo_get_stream_name(1), operatorID, nlon, nlat, grid_center_lon, grid_center_lat, uarray, varray, nparam,
+                        pnames, datetimeStr);
             }
           else if (found == 1)
             {
