@@ -12,7 +12,7 @@
 
 #include <cdi.h>
 
-#include "cdo_wtime.h"
+#include "cdo_timer.h"
 #include "process_int.h"
 #include "griddes.h"
 #include "grid_point_search.h"
@@ -22,8 +22,8 @@
 #include "verifygrid.h"
 #include "field_functions.h"
 
-//#define TESTIMPL 1
-//#define USE_YAC  1
+// #define TESTIMPL 1
+// #define USE_YAC  1
 #ifdef TESTIMPL
 #ifdef USE_YAC
 extern "C"
@@ -35,7 +35,7 @@ extern "C"
 
 constexpr double PI2 = M_PI * 2.0;
 
-double radiusDegToKm(const double radiusInDeg);
+double radiusDegToKm(double radiusInDeg);
 
 struct StatInfo
 {
@@ -76,8 +76,8 @@ read_target_cell_bounds(int gridID, Varray<double> &xbounds, Varray<double> &ybo
 {
   if (!gridHasBounds(gridID)) cdo_abort("Target cell corner coordinates missing!");
 
-  const auto nv = gridInqNvertex(gridID);
-  const auto gridsize = gridInqSize(gridID);
+  auto nv = gridInqNvertex(gridID);
+  auto gridsize = gridInqSize(gridID);
   xbounds.resize(nv * gridsize);
   ybounds.resize(nv * gridsize);
 
@@ -94,10 +94,9 @@ read_target_cell_bounds(int gridID, Varray<double> &xbounds, Varray<double> &ybo
 static void
 read_coordinates(int gridID, Varray<double> &xvals, Varray<double> &yvals)
 {
-  const auto gridID0 = gridID;
+  auto gridID0 = gridID;
 
   gridID = generate_full_point_grid(gridID);
-
   if (!gridHasCoordinates(gridID)) cdo_abort("Cell center coordinates missing!");
 
   gridInqXvals(gridID, xvals.data());
@@ -120,13 +119,10 @@ read_coordinates(int gridID, Varray<double> &xvals, Varray<double> &yvals)
 static void
 read_xbounds_reg2d(int gridID, std::vector<double> &xbounds2d)
 {
-  const auto nlon = gridInqXsize(gridID);
+  auto nlon = gridInqXsize(gridID);
   xbounds2d.resize(nlon * 2);
 
-  if (gridInqXbounds(gridID, nullptr))
-    {
-      gridInqXbounds(gridID, xbounds2d.data());
-    }
+  if (gridInqXbounds(gridID, nullptr)) { gridInqXbounds(gridID, xbounds2d.data()); }
   else
     {
       std::vector<double> xvals(nlon);
@@ -154,13 +150,10 @@ read_xbounds_reg2d(int gridID, std::vector<double> &xbounds2d)
 static void
 read_ybounds_reg2d(int gridID, std::vector<double> &ybounds2d)
 {
-  const auto nlat = gridInqYsize(gridID);
+  auto nlat = gridInqYsize(gridID);
   ybounds2d.resize(nlat * 2);
 
-  if (gridInqYbounds(gridID, nullptr))
-    {
-      gridInqYbounds(gridID, ybounds2d.data());
-    }
+  if (gridInqYbounds(gridID, nullptr)) { gridInqYbounds(gridID, ybounds2d.data()); }
   else
     {
       std::vector<double> yvals(nlat);
@@ -181,10 +174,10 @@ calc_maxdist(size_t i, size_t nv, double plon, double plat, const Varray<double>
   double maxdist = 0.0;
   for (size_t k = 0; k < nv; ++k)
     {
-      const auto lons = &xbounds[nv * i];
-      const auto lats = &ybounds[nv * i];
+      auto lons = &xbounds[nv * i];
+      auto lats = &ybounds[nv * i];
       gcLLtoXYZ(lons[k], lats[k], p2);
-      const auto sdist = squareDistance(p1, p2);
+      auto sdist = squareDistance(p1, p2);
       maxdist = std::max(maxdist, sdist);
     }
 
@@ -202,8 +195,8 @@ calc_maxdist_rec2d(size_t i, size_t nlon, double plon, double plat, const std::v
 
   constexpr int nv = 4;
   double lons[nv], lats[nv];
-  const auto iy = i / nlon;
-  const auto ix = i - iy * nlon;
+  auto iy = i / nlon;
+  auto ix = i - iy * nlon;
   lons[0] = xbounds[2 * ix];
   lons[1] = xbounds[2 * ix];
   lons[2] = xbounds[2 * ix + 1];
@@ -217,7 +210,7 @@ calc_maxdist_rec2d(size_t i, size_t nlon, double plon, double plat, const std::v
   for (size_t k = 0; k < nv; ++k)
     {
       gcLLtoXYZ(lons[k], lats[k], p2);
-      const auto sdist = squareDistance(p1, p2);
+      auto sdist = squareDistance(p1, p2);
       maxdist = std::max(maxdist, sdist);
     }
   maxdist = 1.01 * std::sqrt(maxdist);
@@ -241,12 +234,13 @@ find_points_yac(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t
   cell.edge_type = new enum yac_edge_type[ncorner];
   cell.coordinates_xyz = new double[ncorner][3];
 
-  // enum yac_edge_type lonlat_circle_type[] = { LON_CIRCLE_EDGE, LAT_CIRCLE_EDGE, LON_CIRCLE_EDGE, LAT_CIRCLE_EDGE, LON_CIRCLE_EDGE };
+  // enum yac_edge_type lonlat_circle_type[] = { LON_CIRCLE_EDGE, LAT_CIRCLE_EDGE, LON_CIRCLE_EDGE, LAT_CIRCLE_EDGE, LON_CIRCLE_EDGE
+  // };
 
   for (size_t k = 0; k < ncorner; ++k)
     {
-      const auto lon = xbounds[cell_no * ncorner + k];
-      const auto lat = ybounds[cell_no * ncorner + k];
+      auto lon = xbounds[cell_no * ncorner + k];
+      auto lat = ybounds[cell_no * ncorner + k];
       cell.edge_type[k] = GREAT_CIRCLE_EDGE;
       // cell.edge_type[k] = lonlat_circle_type[k + 1];
       gcLLtoXYZ(lon, lat, cell.coordinates_xyz[k]);
@@ -256,9 +250,9 @@ find_points_yac(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t
   size_t nvalues = 0;
   for (size_t k = 0; k < nadds; ++k)
     {
-      const auto index1 = adds[k];
-      const auto lon = xvals1[index1];
-      const auto lat = yvals1[index1];
+      auto index1 = adds[k];
+      auto lon = xvals1[index1];
+      auto lat = yvals1[index1];
 
       gcLLtoXYZ(lon, lat, centerCoordinates);
 
@@ -309,11 +303,11 @@ find_points(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t nad
 
   if (actualNumberOfCorners < 3) return 0;
 
-  const auto coordinateToIgnore = find_coordinate_to_ignore(cellCorners3D);
+  auto coordinateToIgnore = find_coordinate_to_ignore(cellCorners3D);
 
-  const auto cval = (coordinateToIgnore == 1) ? cellCorners3D[0].X
-                                              : ((coordinateToIgnore == 2) ? cellCorners3D[0].Y : cellCorners3D[0].Z);
-  const auto invertResult = (cval < 0.0);
+  auto cval
+      = (coordinateToIgnore == 1) ? cellCorners3D[0].X : ((coordinateToIgnore == 2) ? cellCorners3D[0].Y : cellCorners3D[0].Z);
+  auto invertResult = (cval < 0.0);
 
   set_cell_corners_plane_projection(coordinateToIgnore, actualNumberOfCorners, cellCorners3D, cellCornersPlaneProjection);
 
@@ -326,19 +320,18 @@ find_points(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t nad
   size_t nvalues = 0;
   for (size_t k = 0; k < nadds; ++k)
     {
-      const auto index1 = adds[k];
-      const auto lon = xvals1[index1];
-      const auto lat = yvals1[index1];
+      auto index1 = adds[k];
+      auto lon = xvals1[index1];
+      auto lat = yvals1[index1];
 
       gcLLtoXYZ(lon, lat, centerCoordinates);
       centerPoint3D.X = centerCoordinates[0];
       centerPoint3D.Y = centerCoordinates[1];
       centerPoint3D.Z = centerCoordinates[2];
 
-      const auto centerPoint2D = set_center_point_plane_projection(coordinateToIgnore, centerPoint3D);
+      auto centerPoint2D = set_center_point_plane_projection(coordinateToIgnore, centerPoint3D);
 
-      auto windingNumber
-          = winding_numbers_algorithm(cellCornersPlaneProjection, actualNumberOfCorners + 1, centerPoint2D);
+      auto windingNumber = winding_numbers_algorithm(cellCornersPlaneProjection, actualNumberOfCorners + 1, centerPoint2D);
 
       if (windingNumber != 0)
         {
@@ -359,15 +352,15 @@ find_points_rec2d(std::vector<char> &vmask, size_t i, size_t nlon2, size_t nadds
                   const Varray<double> &xvals1, const Varray<double> &yvals1, const std::vector<double> &xbounds2d,
                   const std::vector<double> &ybounds2d)
 {
-  const auto iy = i / nlon2;
-  const auto ix = i - iy * nlon2;
+  auto iy = i / nlon2;
+  auto ix = i - iy * nlon2;
 
   size_t nvalues = 0;
   for (size_t k = 0; k < nadds; ++k)
     {
-      const auto index1 = adds[k];
-      const auto x = xvals1[index1];
-      const auto y = yvals1[index1];
+      auto index1 = adds[k];
+      auto x = xvals1[index1];
+      auto y = yvals1[index1];
       if (y >= ybounds2d[2 * iy] && y < ybounds2d[2 * iy + 1])
         if ((x >= xbounds2d[2 * ix] && x < xbounds2d[2 * ix + 1])
             || ((x - PI2) >= xbounds2d[2 * ix] && (x - PI2) < xbounds2d[2 * ix + 1]))
@@ -389,7 +382,7 @@ check_vmask(std::vector<char> vmask)
 {
   constexpr int max_vals = 128;
   size_t vm[max_vals] = { 0 };
-  const auto size = vmask.size();
+  auto size = vmask.size();
   for (size_t i = 0; i < size; ++i)
     if (vmask[i] >= 0) vm[(int) vmask[i]]++;
   for (int i = 0; i < max_vals; ++i)
@@ -413,7 +406,7 @@ gen_mapdata(int gridID1, int gridID2)
   Varray<double> xvals2(gridsize2), yvals2(gridsize2);
   read_coordinates(gridID2, xvals2, yvals2);
 
-  const auto gridtype2 = gridInqType(gridID2);
+  auto gridtype2 = gridInqType(gridID2);
   auto grid2_is_reg2d = (gridtype2 == GRID_GAUSSIAN || gridtype2 == GRID_LONLAT);
 
   auto nlon2 = grid2_is_reg2d ? gridInqXsize(gridID2) : 0;
@@ -430,31 +423,23 @@ gen_mapdata(int gridID1, int gridID2)
     }
   else
     {
-      if (gridtype2 != GRID_UNSTRUCTURED && gridtype2 != GRID_CURVILINEAR) gridID2 = gridID2x = gridToCurvilinear(gridID2, 0);
-
-      if (gridtype2 == GRID_UNSTRUCTURED && !gridHasCoordinates(gridID2))
-        {
-          const auto reference = dereferenceGrid(gridID2);
-          if (reference.isValid) gridID2 = gridID2x = reference.gridID;
-          if (reference.notFound) cdo_abort("Reference to target grid not found!");
-        }
-
+      gridID2 = gridID2x = generate_full_cell_grid(gridID2);
       nv = read_target_cell_bounds(gridID2, xbounds, ybounds);
     }
 
   // for (size_t i = 0; i < nlon2; ++i) printf("%zu %g %g\n", i+1, xbounds2d[2*i], xbounds2d[2*i+1]);
   // for (size_t i = 0; i < nlat2; ++i) printf("%zu %g %g\n", i+1, ybounds2d[2*i], ybounds2d[2*i+1]);
 
-  auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  cdo::timer timer;
 
   auto xIsCyclic = false;
   size_t dims[2] = { gridsize1, 0 };
   GridPointSearch gps;
   grid_point_search_create(gps, xIsCyclic, dims, gridsize1, xvals1, yvals1);
 
-  if (Options::cdoVerbose) cdo_print("Point search created: %.2f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Point search created: %.2f seconds", timer.elapsed());
 
-  start = Options::cdoVerbose ? cdo_get_wtime() : 0;
+  timer.reset();
 
   auto ndist_max = gridsize1;
   if (gridsize1 > 1000000) ndist_max /= 4;
@@ -469,24 +454,24 @@ gen_mapdata(int gridID1, int gridID2)
 #endif
   for (size_t i = 0; i < gridsize2; ++i)
     {
-      const auto ompthID = cdo_omp_get_thread_num();
+      auto ompthID = cdo_omp_get_thread_num();
       auto &adds = adds_2D[ompthID];
       auto &dist = dist_2D[ompthID];
 
-      const auto lon2 = xvals2[i];
-      const auto lat2 = yvals2[i];
+      auto lon2 = xvals2[i];
+      auto lat2 = yvals2[i];
 
-      const auto maxdist = grid2_is_reg2d ? calc_maxdist_rec2d(i, nlon2, lon2, lat2, xbounds2d, ybounds2d)
-                                          : calc_maxdist(i, nv, lon2, lat2, xbounds, ybounds);
+      auto maxdist = grid2_is_reg2d ? calc_maxdist_rec2d(i, nlon2, lon2, lat2, xbounds2d, ybounds2d)
+                                    : calc_maxdist(i, nv, lon2, lat2, xbounds, ybounds);
 
-      const auto nadds = grid_point_search_distance_qnearest(gps, maxdist, lon2, lat2, ndist_max, adds.data(), dist.data());
+      auto nadds = grid_point_search_distance_qnearest(gps, maxdist, lon2, lat2, ndist_max, adds.data(), dist.data());
       // printf("%zu nadds %zu\n", i+1, nadds);
 
-      const auto nvalues = grid2_is_reg2d ? find_points_rec2d(vmask, i, nlon2, nadds, adds, xvals1, yvals1, xbounds2d, ybounds2d)
+      auto nvalues = grid2_is_reg2d ? find_points_rec2d(vmask, i, nlon2, nadds, adds, xvals1, yvals1, xbounds2d, ybounds2d)
 #ifdef USE_YAC
-                                          : find_points_yac(vmask, i, nv, nadds, adds, xvals1, yvals1, xbounds, ybounds);
+                                    : find_points_yac(vmask, i, nv, nadds, adds, xvals1, yvals1, xbounds, ybounds);
 #else
-                                          : find_points(vmask, i, nv, nadds, adds, xvals1, yvals1, xbounds, ybounds);
+                                    : find_points(vmask, i, nv, nadds, adds, xvals1, yvals1, xbounds, ybounds);
 #endif
 
       if (nvalues)
@@ -503,7 +488,7 @@ gen_mapdata(int gridID1, int gridID2)
 
   if (Options::cdoVerbose) check_vmask(vmask);
 
-  if (Options::cdoVerbose) cdo_print("Point search qnearest: %.2f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Point search qnearest: %.2f seconds", timer.elapsed());
 
   grid_point_search_delete(gps);
 
@@ -515,16 +500,16 @@ gen_mapdata(int gridID1, int gridID2)
 template <typename T>
 static T
 remap_kernel(int operfunc, const Varray<size_t> &adds, size_t &nmiss2, Field &field, Varray<T> &fieldvec, const Varray<T> &vec1,
-             const T missval)
+             T missval)
 {
   T value;
-  const auto nvalues = adds.size();
+  auto nvalues = adds.size();
   if (nvalues)
     {
       field.nmiss = 0;
       for (size_t k = 0; k < nvalues; ++k)
         {
-          const auto v1 = vec1[adds[k]];
+          auto v1 = vec1[adds[k]];
           fieldvec[k] = v1;
           if (DBL_IS_EQUAL(v1, missval)) field.nmiss++;
         }
@@ -549,7 +534,7 @@ remap_field(const Varray2D<size_t> &mapdata, const Field &field1, Field &field2,
   std::vector<Field> fields(Threading::ompNumThreads);
 
   auto gridsize2 = gridInqSize(field2.grid);
-  const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  cdo::timer timer;
 
   size_t nmiss2 = 0;
 #ifdef _OPENMP
@@ -558,10 +543,10 @@ remap_field(const Varray2D<size_t> &mapdata, const Field &field1, Field &field2,
   for (size_t i = 0; i < gridsize2; ++i)
     {
       const auto &adds = mapdata[i];
-      const auto nvalues = adds.size();
-      const auto missval = field1.missval;
+      auto nvalues = adds.size();
+      auto missval = field1.missval;
 
-      const auto ompthID = cdo_omp_get_thread_num();
+      auto ompthID = cdo_omp_get_thread_num();
       auto &field = fields[ompthID];
       field.memType = field1.memType;
       if (field1.memType == MemType::Float)
@@ -583,7 +568,7 @@ remap_field(const Varray2D<size_t> &mapdata, const Field &field1, Field &field2,
 
   field2.nmiss = nmiss2;
 
-  if (Options::cdoVerbose) cdo_print("Remap: %.3f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Remap: %.3f seconds", timer.elapsed());
 }
 
 static void
@@ -606,97 +591,124 @@ add_operators(void)
   // clang-format on
 }
 
+class ModuleRemapstat
+{
+  CdoStreamID streamID1;
+  CdoStreamID streamID2;
+
+  int taxisID1;
+  int taxisID2;
+
+  Field field1, field2;
+  VarList varList1, varList2;
+
+  Varray2D<size_t> mapdata;
+  int operfunc;
+
+public:
+  void
+  init(void *process)
+  {
+    cdo_initialize(process);
+
+    add_operators();
+
+    auto operatorID = cdo_operator_id();
+    operfunc = cdo_operator_f1(operatorID);
+
+    operator_input_arg("grid description file or name");
+    auto gridID2 = cdo_define_grid(cdo_operator_argv(0));
+    auto gridtype2 = gridInqType(gridID2);
+
+    {
+#ifdef TESTIMPL
+      auto hasProjParams = ((gridtype2 == GRID_PROJECTION) && grid_has_proj_params(gridID2));
+      if (!gridProjIsSupported(gridID2) && !hasProjParams && gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN
+          && gridtype2 != GRID_CURVILINEAR && gridtype2 != GRID_UNSTRUCTURED)
+#else
+      if (gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN)
+#endif
+        cdo_abort("Remapping to %s data unsupported!", gridNamePtr(gridtype2));
+    }
+
+    streamID1 = cdo_open_read(0);
+
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
+
+    taxisID1 = vlistInqTaxis(vlistID1);
+    taxisID2 = taxisDuplicate(taxisID1);
+    vlistDefTaxis(vlistID2, taxisID2);
+
+    auto ngrids = vlistNgrids(vlistID1);
+    auto gridID1 = vlistGrid(vlistID1, 0);
+    for (int index = 0; index < ngrids; ++index)
+      {
+        if (index > 0) cdo_abort("Too many different grids!");
+
+        // auto gridID1 = vlistGrid(vlistID1, index);
+        auto gridtype = gridInqType(gridID1);
+        auto hasProjParams = ((gridtype == GRID_PROJECTION) && grid_has_proj_params(gridID1));
+        if (!gridProjIsSupported(gridID1) && !hasProjParams && gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN
+            && gridtype != GRID_GME && gridtype != GRID_CURVILINEAR && gridtype != GRID_UNSTRUCTURED)
+          cdo_abort("Interpolation of %s data unsupported!", gridNamePtr(gridtype));
+
+        vlistChangeGridIndex(vlistID2, index, gridID2);
+      }
+
+    streamID2 = cdo_open_write(1);
+    cdo_def_vlist(streamID2, vlistID2);
+
+    mapdata = gen_mapdata(gridID1, gridID2);
+
+    varListInit(varList1, vlistID1);
+    varListInit(varList2, vlistID2);
+  }
+  void
+  run()
+  {
+    int tsID = 0;
+    while (true)
+      {
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
+
+        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        cdo_def_timestep(streamID2, tsID);
+
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+            field1.init(varList1[varID]);
+            cdo_read_record(streamID1, field1);
+
+            field2.init(varList2[varID]);
+
+            remap_field(mapdata, field1, field2, operfunc);
+
+            cdo_def_record(streamID2, varID, levelID);
+            cdo_write_record(streamID2, field2);
+          }
+        tsID++;
+      }
+  }
+  void
+  close()
+  {
+    cdo_stream_close(streamID2);
+    cdo_stream_close(streamID1);
+
+    cdo_finish();
+  }
+};
+
 void *
 Remapstat(void *process)
 {
-  cdo_initialize(process);
-
-  add_operators();
-
-  const auto operatorID = cdo_operator_id();
-  const auto operfunc = cdo_operator_f1(operatorID);
-
-  operator_input_arg("grid description file or name");
-  const auto gridID2 = cdo_define_grid(cdo_operator_argv(0));
-  auto gridtype2 = gridInqType(gridID2);
-
-  {
-#ifdef TESTIMPL
-    const auto hasProjParams = ((gridtype2 == GRID_PROJECTION) && grid_has_proj_params(gridID2));
-    if (!gridProjIsSupported(gridID2) && !hasProjParams && gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN
-        && gridtype2 != GRID_CURVILINEAR && gridtype2 != GRID_UNSTRUCTURED)
-#else
-    if (gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN)
-#endif
-      cdo_abort("Remapping to %s data unsupported!", gridNamePtr(gridtype2));
-  }
-
-  const auto streamID1 = cdo_open_read(0);
-
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
-
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
-  vlistDefTaxis(vlistID2, taxisID2);
-
-  const auto ngrids = vlistNgrids(vlistID1);
-  const auto gridID1 = vlistGrid(vlistID1, 0);
-  for (int index = 0; index < ngrids; ++index)
-    {
-      if (index > 0) cdo_abort("Too many different grids!");
-
-      // const auto gridID1 = vlistGrid(vlistID1, index);
-      const auto gridtype = gridInqType(gridID1);
-      const auto hasProjParams = ((gridtype == GRID_PROJECTION) && grid_has_proj_params(gridID1));
-      if (!gridProjIsSupported(gridID1) && !hasProjParams && gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN
-          && gridtype != GRID_GME && gridtype != GRID_CURVILINEAR && gridtype != GRID_UNSTRUCTURED)
-        cdo_abort("Interpolation of %s data unsupported!", gridNamePtr(gridtype));
-
-      vlistChangeGridIndex(vlistID2, index, gridID2);
-    }
-
-  const auto streamID2 = cdo_open_write(1);
-  cdo_def_vlist(streamID2, vlistID2);
-
-  Varray2D<size_t> mapdata = gen_mapdata(gridID1, gridID2);
-
-  VarList varList1, varList2;
-  varListInit(varList1, vlistID1);
-  varListInit(varList2, vlistID2);
-
-  Field field1, field2;
-
-  int tsID = 0;
-  while (true)
-    {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
-
-      cdo_taxis_copy_timestep(taxisID2, taxisID1);
-      cdo_def_timestep(streamID2, tsID);
-
-      for (int recID = 0; recID < nrecs; ++recID)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          field1.init(varList1[varID]);
-          cdo_read_record(streamID1, field1);
-
-          field2.init(varList2[varID]);
-
-          remap_field(mapdata, field1, field2, operfunc);
-
-          cdo_def_record(streamID2, varID, levelID);
-          cdo_write_record(streamID2, field2);
-        }
-      tsID++;
-    }
-
-  cdo_stream_close(streamID2);
-  cdo_stream_close(streamID1);
-
-  cdo_finish();
-
+  ModuleRemapstat remapstat;
+  remapstat.init(process);
+  remapstat.run();
+  remapstat.close();
   return nullptr;
 }
