@@ -63,24 +63,23 @@ read_cellindex(const std::string &filename)
   int pid = CDI_UNDEFID;
   // int cid = CDI_UNDEFID;
   const auto nvars = vlistNvars(vlistID);
-  char varname[CDI_MAX_NAME];
   for (int varID = 0; varID < nvars; ++varID)
     {
-      vlistInqVarName(vlistID, varID, varname);
+      auto varname = cdo::inq_var_name(vlistID, varID);
       /*
-      if (strcmp(varname, "neighbor_cell_index") == 0)
+      if (varname == "neighbor_cell_index")
         {
           nid = varID;
           break;
         }
       */
-      if (strcmp(varname, "parent_cell_index") == 0)
+      if (varname == "parent_cell_index")
         {
           pid = varID;
           break;
         }
       /*
-      if ( strcmp(varname, "child_cell_index") == 0 )
+      if (varname == "child_cell_index")
         {
           cid = varID;
           break;
@@ -116,10 +115,10 @@ read_cellindex(const std::string &filename)
         {
           streamReadRecord(streamID, data.data(), &nmiss);
           // if (varID == pid)
-            {
-              if (Options::cdoVerbose) cdo_print("Read parent_cell_index");
-              copy_data_to_index(ncells, data, cellindex->parent);
-            }
+          {
+            if (Options::cdoVerbose) cdo_print("Read parent_cell_index");
+            copy_data_to_index(ncells, data, cellindex->parent);
+          }
           // else if ( varID == nid ) copy_data_to_index(ncells, data, cellindex->neighbor+levelID*ncells);
           // else if ( varID == cid ) copy_data_to_index(ncells, data, cellindex->child+levelID*ncells);
         }
@@ -322,8 +321,8 @@ compute_child_from_bounds(CellIndex *cellindex2, long ncells2, double *grid_cent
 
       const auto coordinateToIgnore = find_coordinate_to_ignore(cellCorners3D);
 
-      const auto cval = (coordinateToIgnore == 1) ? cellCorners3D[0].X
-                                                  : ((coordinateToIgnore == 2) ? cellCorners3D[0].Y : cellCorners3D[0].Z);
+      const auto cval
+          = (coordinateToIgnore == 1) ? cellCorners3D[0].X : ((coordinateToIgnore == 2) ? cellCorners3D[0].Y : cellCorners3D[0].Z);
       const auto invertResult = (cval < 0.0);
 
       set_cell_corners_plane_projection(coordinateToIgnore, ncorner, cellCorners3D, cellCornersPlaneProjection);
@@ -349,8 +348,7 @@ compute_child_from_bounds(CellIndex *cellindex2, long ncells2, double *grid_cent
 
               const auto centerPoint2D = set_center_point_plane_projection(coordinateToIgnore, centerPoint3D);
 
-              auto winding_number
-                  = winding_numbers_algorithm(cellCornersPlaneProjection, ncorner + 1, centerPoint2D);
+              auto winding_number = winding_numbers_algorithm(cellCornersPlaneProjection, ncorner + 1, centerPoint2D);
 
               if (winding_number != 0)
                 {
@@ -435,7 +433,7 @@ samplegrid(double missval, long nci, CellIndex **cellindex, const Varray<double>
   long nx = 0;
   double x = 0.0;
 #ifdef _OPENMP
-//#pragma omp parallel for default(shared)
+// #pragma omp parallel for default(shared)
 #endif
   for (long i = 0; i < ncells2; ++i)
     {
@@ -459,115 +457,155 @@ samplegrid(double missval, long nci, CellIndex **cellindex, const Varray<double>
     }
 }
 
+class ModuleSamplegridicon
+{
+  CdoStreamID streamID1;
+  CdoStreamID streamID2;
+  CdoStreamID streamID3;
+
+  int vlistID2;
+
+  int taxisID1;
+  int taxisID2;
+  int taxisID3;
+
+  int vlistID1;
+  int gridID2;
+
+  Varray<double> array1;
+  Varray<double> array2;
+  Varray<double> array3;
+  std::vector<CellIndex *> cellindex;
+
+  int nsamplegrids;
+  size_t gridsize2;
+
+public:
+  void
+  init(void *process)
+  {
+    cdo_initialize(process);
+
+    cdo_operator_add("samplegridicon", 0, 0, "sample grids");
+
+    nsamplegrids = cdo_operator_argc();
+    if (nsamplegrids < 2) cdo_abort("Parameter missing!");
+
+    cellindex = std::vector<CellIndex *>(nsamplegrids);
+
+    for (int i = 0; i < nsamplegrids; ++i)
+      {
+        cellindex[i] = read_cellindex(cdo_operator_argv(i));
+        cellindex[i]->filename = cdo_operator_argv(i).c_str();
+        if (Options::cdoVerbose) cdo_print("Found %ld grid cells in %s", cellindex[i]->ncells, cellindex[i]->filename);
+      }
+
+    for (int i = 0; i < nsamplegrids - 1; ++i) compute_child(cellindex[i], cellindex[i + 1]);
+
+    gridID2 = read_grid(cdo_operator_argv(nsamplegrids - 1).c_str());
+
+    streamID1 = cdo_open_read(0);
+    vlistID1 = cdo_stream_inq_vlist(streamID1);
+
+    long gridsize = vlistGridsizeMax(vlistID1);
+    if (Options::cdoVerbose) cdo_print("Source gridsize = %zu", gridsize);
+    if (gridsize != cellindex[0]->ncells)
+      cdo_abort("Gridsize (%ld) of input stream and first grid (%ld) differ!", gridsize, cellindex[0]->ncells);
+    if (vlistNumber(vlistID1) != CDI_REAL) gridsize *= 2;
+    array1 = Varray<double>(gridsize);
+
+    vlistID2 = vlistDuplicate(vlistID1);
+    const auto vlistID3 = vlistDuplicate(vlistID1);
+
+    taxisID1 = vlistInqTaxis(vlistID1);
+    taxisID2 = taxisDuplicate(taxisID1);
+    taxisID3 = taxisDuplicate(taxisID1);
+    vlistDefTaxis(vlistID2, taxisID2);
+    vlistDefTaxis(vlistID3, taxisID3);
+
+    const auto ngrids = vlistNgrids(vlistID1);
+    for (int index = 0; index < ngrids; ++index)
+      {
+        const auto gridID = vlistGrid(vlistID1, index);
+        const auto gridtype = gridInqType(gridID);
+        if (!(gridtype == GRID_UNSTRUCTURED && gridInqNvertex(gridID) == 3))
+          cdo_abort("Unsupported gridtype: %s with %d corners", gridNamePtr(gridtype), gridInqNvertex(gridID));
+
+        vlistChangeGridIndex(vlistID2, index, gridID2);
+        vlistChangeGridIndex(vlistID3, index, gridID2);
+      }
+
+    streamID2 = cdo_open_write(1);
+    cdo_def_vlist(streamID2, vlistID2);
+
+    streamID3 = cdo_open_write(2);
+    cdo_def_vlist(streamID3, vlistID3);
+
+    gridsize2 = gridInqSize(gridID2);
+    if (Options::cdoVerbose) cdo_print("Target gridsize = %ld", gridsize2);
+    if (vlistNumber(vlistID2) != CDI_REAL) gridsize2 *= 2;
+    array2 = Varray<double>(gridsize2);
+    array3 = Varray<double>(gridsize2);
+  }
+  void
+  run()
+  {
+    int tsID = 0;
+    while (true)
+      {
+        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
+
+        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        cdo_taxis_copy_timestep(taxisID3, taxisID1);
+        cdo_def_timestep(streamID2, tsID);
+        cdo_def_timestep(streamID3, tsID);
+
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+            size_t nmiss;
+            cdo_read_record(streamID1, array1.data(), &nmiss);
+
+            const auto missval = vlistInqVarMissval(vlistID1, varID);
+
+            samplegrid(missval, nsamplegrids, &cellindex[0], array1, array2, array3);
+
+            nmiss = varray_num_mv(gridsize2, array2, missval);
+            cdo_def_record(streamID2, varID, levelID);
+            cdo_write_record(streamID2, array2.data(), nmiss);
+
+            nmiss = varray_num_mv(gridsize2, array3, missval);
+            cdo_def_record(streamID3, varID, levelID);
+            cdo_write_record(streamID3, array3.data(), nmiss);
+          }
+
+        tsID++;
+      }
+  }
+  void
+  close()
+  {
+    cdo_stream_close(streamID3);
+    cdo_stream_close(streamID2);
+    cdo_stream_close(streamID1);
+
+    vlistDestroy(vlistID2);
+    gridDestroy(gridID2);
+
+    for (int i = 0; i < nsamplegrids; ++i) free_cellindex(cellindex[i]);
+
+    cdo_finish();
+  }
+};
+
 void *
 Samplegridicon(void *process)
 {
-  cdo_initialize(process);
-
-  cdo_operator_add("samplegridicon", 0, 0, "sample grids");
-
-  const auto nsamplegrids = cdo_operator_argc();
-  if (nsamplegrids < 2) cdo_abort("Parameter missing!");
-
-  std::vector<CellIndex *> cellindex(nsamplegrids);
-
-  for (int i = 0; i < nsamplegrids; ++i)
-    {
-      cellindex[i] = read_cellindex(cdo_operator_argv(i));
-      cellindex[i]->filename = cdo_operator_argv(i).c_str();
-      if (Options::cdoVerbose) cdo_print("Found %ld grid cells in %s", cellindex[i]->ncells, cellindex[i]->filename);
-    }
-
-  for (int i = 0; i < nsamplegrids - 1; ++i) compute_child(cellindex[i], cellindex[i + 1]);
-
-  const auto gridID2 = read_grid(cdo_operator_argv(nsamplegrids - 1).c_str());
-
-  const auto streamID1 = cdo_open_read(0);
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-
-  long gridsize = vlistGridsizeMax(vlistID1);
-  if (Options::cdoVerbose) cdo_print("Source gridsize = %zu", gridsize);
-  if (gridsize != cellindex[0]->ncells)
-    cdo_abort("Gridsize (%ld) of input stream and first grid (%ld) differ!", gridsize, cellindex[0]->ncells);
-  if (vlistNumber(vlistID1) != CDI_REAL) gridsize *= 2;
-  Varray<double> array1(gridsize);
-
-  const auto vlistID2 = vlistDuplicate(vlistID1);
-  const auto vlistID3 = vlistDuplicate(vlistID1);
-
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
-  const auto taxisID3 = taxisDuplicate(taxisID1);
-  vlistDefTaxis(vlistID2, taxisID2);
-  vlistDefTaxis(vlistID3, taxisID3);
-
-  const auto ngrids = vlistNgrids(vlistID1);
-  for (int index = 0; index < ngrids; ++index)
-    {
-      const auto gridID = vlistGrid(vlistID1, index);
-      const auto gridtype = gridInqType(gridID);
-      if (!(gridtype == GRID_UNSTRUCTURED && gridInqNvertex(gridID) == 3))
-        cdo_abort("Unsupported gridtype: %s with %d corners", gridNamePtr(gridtype), gridInqNvertex(gridID));
-
-      vlistChangeGridIndex(vlistID2, index, gridID2);
-      vlistChangeGridIndex(vlistID3, index, gridID2);
-    }
-
-  const auto streamID2 = cdo_open_write(1);
-  cdo_def_vlist(streamID2, vlistID2);
-
-  const auto streamID3 = cdo_open_write(2);
-  cdo_def_vlist(streamID3, vlistID3);
-
-  auto gridsize2 = gridInqSize(gridID2);
-  if (Options::cdoVerbose) cdo_print("Target gridsize = %ld", gridsize2);
-  if (vlistNumber(vlistID2) != CDI_REAL) gridsize2 *= 2;
-  Varray<double> array2(gridsize2), array3(gridsize2);
-
-  int tsID = 0;
-  while (true)
-    {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
-
-      cdo_taxis_copy_timestep(taxisID2, taxisID1);
-      cdo_taxis_copy_timestep(taxisID3, taxisID1);
-      cdo_def_timestep(streamID2, tsID);
-      cdo_def_timestep(streamID3, tsID);
-
-      for (int recID = 0; recID < nrecs; ++recID)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          size_t nmiss;
-          cdo_read_record(streamID1, array1.data(), &nmiss);
-
-          const auto missval = vlistInqVarMissval(vlistID1, varID);
-
-          samplegrid(missval, nsamplegrids, &cellindex[0], array1, array2, array3);
-
-          nmiss = varray_num_mv(gridsize2, array2, missval);
-          cdo_def_record(streamID2, varID, levelID);
-          cdo_write_record(streamID2, array2.data(), nmiss);
-
-          nmiss = varray_num_mv(gridsize2, array3, missval);
-          cdo_def_record(streamID3, varID, levelID);
-          cdo_write_record(streamID3, array3.data(), nmiss);
-        }
-
-      tsID++;
-    }
-
-  cdo_stream_close(streamID3);
-  cdo_stream_close(streamID2);
-  cdo_stream_close(streamID1);
-
-  vlistDestroy(vlistID2);
-  gridDestroy(gridID2);
-
-  for (int i = 0; i < nsamplegrids; ++i) free_cellindex(cellindex[i]);
-
-  cdo_finish();
-
+  ModuleSamplegridicon samplegridicon;
+  samplegridicon.init(process);
+  samplegridicon.run();
+  samplegridicon.close();
   return nullptr;
 }
