@@ -149,350 +149,387 @@ int getNumberOfDeleteSelectionTuples();
 
 int multiSelectionParser(const char *filenameOrString);
 
+class ModuleSelMulti
+{
+  CdoStreamID streamID1;
+  CdoStreamID streamID2;
+
+  int taxisID1;
+  int taxisID2;
+
+  int vlistID1;
+  int vlistID2;
+
+  int operatorID;
+  int nvars;
+  size_t gridsizemax;
+
+  bool lcopy = false;
+
+  VarList varList1;
+  Varray<double> array;
+
+  int SELMULTI, DELMULTI, CHANGEMULTI;
+
+public:
+  void
+  init(void *process)
+  {
+
+    cdo_initialize(process);
+
+    // clang-format off
+   SELMULTI    = cdo_operator_add("selmulti",    0, 0, "filename/string with selection specification");
+   DELMULTI    = cdo_operator_add("delmulti",    0, 0, "filename/string with selection specification");
+   CHANGEMULTI = cdo_operator_add("changemulti", 0, 0, "filename/string with selection specification");
+    // clang-format on
+
+    operatorID = cdo_operator_id();
+
+    operator_input_arg(cdo_operator_enter(operatorID));
+
+    // operator_check_argc(1);
+    const char *filenameOrString = cdo_operator_argv(0).c_str();
+    if (cdoDebugExt)
+      {
+        printf("Given operator arguments (nr=%d): \n", cdo_operator_argc());
+        for (int i = 0; i < cdo_operator_argc(); ++i) printf("%s", cdo_operator_argv(i).c_str());
+        printf("\n");
+      }
+    if (!multiSelectionParser(filenameOrString))
+      cdo_warning("Error processing file with selection description!\n%s", filenameOrString);
+
+    if (operatorID == SELMULTI)
+      if (getNumberOfSelectionTuples() == 0)
+        cdo_abort("Error! You must provide at lease ONE selection tuple!\n"
+                  "Notations: 'SELECT,  .. or sel(/;;) or (/;;)'\nCheck the file: %s",
+                  filenameOrString);
+
+    if (operatorID == DELMULTI)
+      if (getNumberOfDeleteSelectionTuples() == 0)
+        cdo_abort("Error! You must provide at lease ONE selection tuple!\n"
+                  "Notations: 'DELETE,  .. or del(/;;) or (/;;)'\nCheck the file: %s",
+                  filenameOrString);
+
+    if (operatorID == CHANGEMULTI)
+      if (getNumberOfSelectionTuples() == 0)
+        cdo_abort("Error! You must provide at lease ONE selection tuple!\n"
+                  "Notations: 'CHANGE,  .. or (/;;|;;;)'\nCheck the file: %s",
+                  filenameOrString);
+
+    streamID1 = cdo_open_read(0);
+
+    vlistID1 = cdo_stream_inq_vlist(streamID1);
+
+    varListInit(varList1, vlistID1);
+
+    vlistClearFlag(vlistID1);
+    nvars = vlistNvars(vlistID1);
+
+    Debug(cdoDebugExt, " Total number of variables: %d", nvars);
+
+    for (int varID = 0; varID < nvars; ++varID)
+      {
+        const auto &var = varList1[varID];
+        const auto ltype = zaxis_to_ltype(var.zaxisID);
+
+        for (int levelID = 0; levelID < var.nlevels; ++levelID)
+          {
+            auto level = zaxisInqLevel(var.zaxisID, levelID);
+
+            if (operatorID == DELMULTI)
+              vlistDefFlag(vlistID1, varID, levelID, true);  // set initially, override bellow if in selection
+            if (operatorID == CHANGEMULTI)
+              {
+                vlistDefFlag(vlistID1, varID, levelID, true);  // change operation copies all fields
+                continue;
+              }
+
+            for (int ii = 0; ii < NUMTUPLES; ++ii)
+              {
+                TUPLEREC *tuplerec = getSelTuple(ii);
+                // if ( cdoDebugExt ) cdo_print(" Processing: (code %d,
+                // ltype %d, level %d);  nvars=%d, varID=%d", code, ltype,
+                // (int)level, nvars, varID);
+                // Note: When the list is Empty then function
+                // checkListContainsInt() also returns true !
+                const auto selcode = checkListContainsInt(var.code, tuplerec->codeLST, tuplerec->ncodes);
+                const auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
+                const auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
+                if (selcode && selltype && sellevel)
+                  {
+                    if (operatorID == SELMULTI)
+                      {
+                        switch (tuplerec->sel_or_del_or_change)
+                          {
+                          case 0:  // operator decides ...
+                            vlistDefFlag(vlistID1, varID, levelID, true);
+                            if (cdoDebugExt)
+                              {
+                                if (!tuplerec->simpleMath)
+                                  cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", var.code,
+                                            ltype, (int) (level), varID, levelID);
+                                else
+                                  cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; SCALE=%f; "
+                                            "OFFSET=%f",
+                                            var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
+                              }
+                            break;
+                          case 1:
+                            vlistDefFlag(vlistID1, varID, levelID, true);
+                            if (cdoDebugExt)
+                              {
+                                if (!tuplerec->simpleMath)
+                                  cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", var.code,
+                                            ltype, (int) (level), varID, levelID);
+                                else
+                                  cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; SCALE=%f; "
+                                            "OFFSET=%f",
+                                            var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
+                              }
+                            break;
+                          case 2:
+                            vlistDefFlag(vlistID1, varID, levelID, false);
+                            if (cdoDebugExt)
+                              {
+                                if (!tuplerec->simpleMath)
+                                  cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]",
+                                            var.code, ltype, (int) (level), varID, levelID);
+                                else
+                                  cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   "
+                                            "[varID(%d),levelID(%d)]; SCALE=%f; OFFSET=%f",
+                                            var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
+                              }
+                            break;
+                          }
+                      }
+                    else if (operatorID == DELMULTI)
+                      {
+                        switch (tuplerec->sel_or_del_or_change)
+                          {
+                          case 0:  // operator decides ...
+                            vlistDefFlag(vlistID1, varID, levelID, false);
+                            if (cdoDebugExt)
+                              {
+                                if (!tuplerec->simpleMath)
+                                  cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]",
+                                            var.code, ltype, (int) (level), varID, levelID);
+                                else
+                                  cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   "
+                                            "[varID(%d),levelID(%d)]; SCALE=%f; OFFSET=%f",
+                                            var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
+                              }
+                            break;
+                          case 1:
+                            vlistDefFlag(vlistID1, varID, levelID, true);
+                            if (cdoDebugExt)
+                              {
+                                if (!tuplerec->simpleMath)
+                                  cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", var.code,
+                                            ltype, (int) (level), varID, levelID);
+                                else
+                                  cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; SCALE=%f; "
+                                            "OFFSET=%f",
+                                            var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
+                              }
+                            break;
+                          case 2:
+                            vlistDefFlag(vlistID1, varID, levelID, false);
+                            if (cdoDebugExt)
+                              {
+                                if (!tuplerec->simpleMath)
+                                  cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]",
+                                            var.code, ltype, (int) (level), varID, levelID);
+                                else
+                                  cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   "
+                                            "[varID(%d),levelID(%d)]; SCALE=%f; OFFSET=%f",
+                                            var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
+                              }
+                            break;
+                          }
+                      }
+                    break;
+                  }
+              }  // end for ( .. NUMTUPLES
+          }      // end for ( levelID
+      }          // end for ( varID
+
+    Debug(cdoDebugExt, " Writing the selected fields ...");
+
+    vlistID2 = vlistCreate();
+    cdo_vlist_copy_flag(vlistID2, vlistID1);
+    vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
+
+    {
+      nvars = vlistNvars(vlistID2);
+      int varID;
+      for (varID = 0; varID < nvars; ++varID)
+        if (vlistInqVarTimetype(vlistID2, varID) != TIME_CONSTANT) break;
+      if (varID == nvars) vlistDefNtsteps(vlistID2, 0);
+    }
+
+    taxisID1 = vlistInqTaxis(vlistID1);
+    taxisID2 = taxisDuplicate(taxisID1);
+    vlistDefTaxis(vlistID2, taxisID2);
+
+    streamID2 = cdo_open_write(1);
+    cdo_def_vlist(streamID2, vlistID2);
+
+    gridsizemax = vlistGridsizeMax(vlistID1);
+    if (vlistNumber(vlistID1) != CDI_REAL) gridsizemax *= 2;
+    array = Varray<double>(gridsizemax);
+  }
+  void
+  run()
+  {
+    int tsID = 0;
+    while (true)
+      {
+        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
+
+        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        cdo_def_timestep(streamID2, tsID);
+
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+            const auto &var = varList1[varID];
+
+            if (vlistInqFlag(vlistID1, varID, levelID) == true)
+              {
+                int simpleMath = 0;  // 1:  simple array arithmetics ( *,+), 0: do nothing
+                double scale = 1.0;
+                double offset = 0.0;
+                const auto code = var.code;
+                const auto level = zaxisInqLevel(var.zaxisID, levelID);
+                const auto ltype = zaxis_to_ltype(var.zaxisID);
+                for (int ii = 0; ii < NUMTUPLES; ++ii)
+                  {
+                    TUPLEREC *tuplerec = getSelTuple(ii);
+                    // Note: When the list is Empty then function
+                    // checkListContainsInt() also returns true !
+                    const auto selcode = checkListContainsInt(code, tuplerec->codeLST, tuplerec->ncodes);
+                    const auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
+                    const auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
+                    lcopy = true;
+                    if (selcode && selltype && sellevel)
+                      {
+                        if (operatorID == CHANGEMULTI)
+                          {
+                            if (cdoDebugExt)
+                              cdo_print(" Processing: (code %d, ltype %d, level %d);  nvars=%d, varID=%d => (selcode %d, selltype "
+                                        "%d, sellevel %d) => change (%d,%d,%d)",
+                                        code, ltype, (int) level, nvars, varID, selcode, selltype, sellevel, tuplerec->changedCode,
+                                        tuplerec->changedLevelType, tuplerec->changedLevel);
+                            if ((tuplerec->changedCode == -1) && (tuplerec->changedLevelType == -1)
+                                && (tuplerec->changedLevel == -1))
+                              cdo_print(" WARNING: Cannot CHANGE identification!");
+                            else
+                              streamGrbChangeParameterIdentification(tuplerec->changedCode, tuplerec->changedLevelType,
+                                                                     tuplerec->changedLevel);
+                            // Calling PROXY function
+                            // streamGrbChangeParameterIdentification() which
+                            // results in later calling func.
+                            // gribapiChangeParameterIdentification(); see
+                            // stream_gribapi.c The change happens during the last
+                            // step of writing a grib-record into a file.
+                          }
+                        else
+                          {
+                            if (cdoDebugExt)
+                              cdo_print(" Processing: (code %d, ltype %d, level %d);  nvars=%d, varID=%d => (selcode %d, "
+                                        "selltype %d, sellevel %d)",
+                                        code, ltype, (int) level, nvars, varID, selcode, selltype, sellevel);
+                          }
+                        simpleMath = tuplerec->simpleMath;  // 1:  simple array arithmetics ( *,+),
+                                                            // 0: do nothing
+                        if (simpleMath)
+                          {
+                            scale = tuplerec->scale;
+                            offset = tuplerec->offset;
+                            lcopy = false;
+                          }
+                        break;  // get out of this for loop
+                      }
+                  }  // end of for (ii=0; ii<NUMTUPLES ..
+
+                const auto varID2 = vlistFindVar(vlistID2, varID);
+                const auto levelID2 = vlistFindLevel(vlistID2, varID, levelID);
+
+                // tijdelijk PATCH M.K.
+                if ((varID2 == -1) || (levelID2 == -1))
+                  {
+                    cdo_print(" Warning: Missing varID or levelID with (code %3i, "
+                              "ltype %3i, level %3i)   [varID(%d),levelID(%d)] .. #2[varID(%d),levelID(%d)]",
+                              code, ltype, (int) (level), varID, levelID, varID2, levelID2);
+                    continue;
+                  }
+                cdo_def_record(streamID2, varID2, levelID2);
+
+                if (lcopy)
+                  {
+                    if (cdoDebugExt)
+                      cdo_print(" Copying record [%4d] with (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", recID,
+                                code, ltype, (int) (level), varID, levelID);
+                    cdo_copy_record(streamID2, streamID1);
+                  }
+                else
+                  {
+                    size_t nmiss;
+                    cdo_read_record(streamID1, array.data(), &nmiss);
+
+                    if (!simpleMath)
+                      {
+                        if (cdoDebugExt)
+                          cdo_print(" Writing record [%4d] with (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", recID,
+                                    code, ltype, (int) (level), varID, levelID);
+                      }
+                    else  // 1:  simple array arithmetics ( *,+)
+                      {
+                        if (cdoDebugExt)
+                          cdo_print(" Writing record [%4d] with (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; "
+                                    "SCALE=%f; OFFSET=%f",
+                                    recID, code, ltype, (int) (level), varID, levelID, scale, offset);
+                        for (size_t li = 0; li < gridsizemax; ++li)
+                          if (!DBL_IS_EQUAL(array[li], var.missval))
+                            {
+                              array[li] = scale * (array[li] - offset);
+                              // If SCALE and/or OFFSET are defined, then the data
+                              // values are scaled as SCALE*(VALUE-OFFSET).
+                            }
+                      }
+
+                    cdo_write_record(streamID2, array.data(), nmiss);
+                  }  // end of else ( lcopy )
+              }      // end if ( vlistInqFlag(vlistID1, varID, levelID) == true )
+          }          // end for ( recID ..
+
+        tsID++;
+      }  // end while
+  }
+  void
+  close()
+  {
+    cdo_stream_close(streamID1);
+    cdo_stream_close(streamID2);
+
+    vlistDestroy(vlistID2);
+
+    cdo_finish();
+
+    cdoDebugExt = 0;
+  }
+};
+
 void *
 Selmulti(void *process)
 {
-  auto lcopy = false;
-
-  cdo_initialize(process);
-
-  // clang-format off
-  const auto SELMULTI    = cdo_operator_add("selmulti",    0, 0, "filename/string with selection specification");
-  const auto DELMULTI    = cdo_operator_add("delmulti",    0, 0, "filename/string with selection specification");
-  const auto CHANGEMULTI = cdo_operator_add("changemulti", 0, 0, "filename/string with selection specification");
-  // clang-format on
-
-  const auto operatorID = cdo_operator_id();
-
-  operator_input_arg(cdo_operator_enter(operatorID));
-
-  // operator_check_argc(1);
-  const char *filenameOrString = cdo_operator_argv(0).c_str();
-  if (cdoDebugExt)
-    {
-      printf("Given operator arguments (nr=%d): \n", cdo_operator_argc());
-      for (int i = 0; i < cdo_operator_argc(); ++i) printf("%s", cdo_operator_argv(i).c_str());
-      printf("\n");
-    }
-  if (!multiSelectionParser(filenameOrString))
-    cdo_warning("Error processing file with selection description!\n%s", filenameOrString);
-
-  if (operatorID == SELMULTI)
-    if (getNumberOfSelectionTuples() == 0)
-      cdo_abort("Error! You must provide at lease ONE selection tuple!\n"
-                "Notations: 'SELECT,  .. or sel(/;;) or (/;;)'\nCheck the file: %s",
-                filenameOrString);
-
-  if (operatorID == DELMULTI)
-    if (getNumberOfDeleteSelectionTuples() == 0)
-      cdo_abort("Error! You must provide at lease ONE selection tuple!\n"
-                "Notations: 'DELETE,  .. or del(/;;) or (/;;)'\nCheck the file: %s",
-                filenameOrString);
-
-  if (operatorID == CHANGEMULTI)
-    if (getNumberOfSelectionTuples() == 0)
-      cdo_abort("Error! You must provide at lease ONE selection tuple!\n"
-                "Notations: 'CHANGE,  .. or (/;;|;;;)'\nCheck the file: %s",
-                filenameOrString);
-
-  const auto streamID1 = cdo_open_read(0);
-
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-
-  VarList varList1;
-  varListInit(varList1, vlistID1);
-
-  vlistClearFlag(vlistID1);
-  auto nvars = vlistNvars(vlistID1);
-
-  Debug(cdoDebugExt, " Total number of variables: %d", nvars);
-
-  for (int varID = 0; varID < nvars; ++varID)
-    {
-      const auto &var = varList1[varID];
-      const auto ltype = zaxis_to_ltype(var.zaxisID);
-
-      for (int levelID = 0; levelID < var.nlevels; ++levelID)
-        {
-          auto level = zaxisInqLevel(var.zaxisID, levelID);
-
-          if (operatorID == DELMULTI)
-            vlistDefFlag(vlistID1, varID, levelID, true);  // set initially, override bellow if in selection
-          if (operatorID == CHANGEMULTI)
-            {
-              vlistDefFlag(vlistID1, varID, levelID, true);  // change operation copies all fields
-              continue;
-            }
-
-          for (int ii = 0; ii < NUMTUPLES; ++ii)
-            {
-              TUPLEREC *tuplerec = getSelTuple(ii);
-              // if ( cdoDebugExt ) cdo_print(" Processing: (code %d,
-              // ltype %d, level %d);  nvars=%d, varID=%d", code, ltype,
-              // (int)level, nvars, varID);
-              // Note: When the list is Empty then function
-              // checkListContainsInt() also returns true !
-              const auto selcode = checkListContainsInt(var.code, tuplerec->codeLST, tuplerec->ncodes);
-              const auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
-              const auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
-              if (selcode && selltype && sellevel)
-                {
-                  if (operatorID == SELMULTI)
-                    {
-                      switch (tuplerec->sel_or_del_or_change)
-                        {
-                        case 0:  // operator decides ...
-                          vlistDefFlag(vlistID1, varID, levelID, true);
-                          if (cdoDebugExt)
-                            {
-                              if (!tuplerec->simpleMath)
-                                cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", var.code, ltype,
-                                          (int) (level), varID, levelID);
-                              else
-                                cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; SCALE=%f; "
-                                          "OFFSET=%f",
-                                          var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
-                            }
-                          break;
-                        case 1:
-                          vlistDefFlag(vlistID1, varID, levelID, true);
-                          if (cdoDebugExt)
-                            {
-                              if (!tuplerec->simpleMath)
-                                cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", var.code, ltype,
-                                          (int) (level), varID, levelID);
-                              else
-                                cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; SCALE=%f; "
-                                          "OFFSET=%f",
-                                          var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
-                            }
-                          break;
-                        case 2:
-                          vlistDefFlag(vlistID1, varID, levelID, false);
-                          if (cdoDebugExt)
-                            {
-                              if (!tuplerec->simpleMath)
-                                cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]",
-                                          var.code, ltype, (int) (level), varID, levelID);
-                              else
-                                cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   "
-                                          "[varID(%d),levelID(%d)]; SCALE=%f; OFFSET=%f",
-                                          var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
-                            }
-                          break;
-                        }
-                    }
-                  else if (operatorID == DELMULTI)
-                    {
-                      switch (tuplerec->sel_or_del_or_change)
-                        {
-                        case 0:  // operator decides ...
-                          vlistDefFlag(vlistID1, varID, levelID, false);
-                          if (cdoDebugExt)
-                            {
-                              if (!tuplerec->simpleMath)
-                                cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]",
-                                          var.code, ltype, (int) (level), varID, levelID);
-                              else
-                                cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   "
-                                          "[varID(%d),levelID(%d)]; SCALE=%f; OFFSET=%f",
-                                          var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
-                            }
-                          break;
-                        case 1:
-                          vlistDefFlag(vlistID1, varID, levelID, true);
-                          if (cdoDebugExt)
-                            {
-                              if (!tuplerec->simpleMath)
-                                cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", var.code, ltype,
-                                          (int) (level), varID, levelID);
-                              else
-                                cdo_print(" Selecting : (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; SCALE=%f; "
-                                          "OFFSET=%f",
-                                          var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
-                            }
-                          break;
-                        case 2:
-                          vlistDefFlag(vlistID1, varID, levelID, false);
-                          if (cdoDebugExt)
-                            {
-                              if (!tuplerec->simpleMath)
-                                cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]",
-                                          var.code, ltype, (int) (level), varID, levelID);
-                              else
-                                cdo_print(" Selecting for removal: (code %3i, ltype %3i, level %3i)   "
-                                          "[varID(%d),levelID(%d)]; SCALE=%f; OFFSET=%f",
-                                          var.code, ltype, (int) (level), varID, levelID, tuplerec->scale, tuplerec->offset);
-                            }
-                          break;
-                        }
-                    }
-                  break;
-                }
-            }  // end for ( .. NUMTUPLES
-        }      // end for ( levelID
-    }          // end for ( varID
-
-  Debug(cdoDebugExt, " Writing the selected fields ...");
-
-  auto vlistID2 = vlistCreate();
-  cdo_vlist_copy_flag(vlistID2, vlistID1);
-  vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
-
-  {
-    nvars = vlistNvars(vlistID2);
-    int varID;
-    for (varID = 0; varID < nvars; ++varID)
-      if (vlistInqVarTimetype(vlistID2, varID) != TIME_CONSTANT) break;
-    if (varID == nvars) vlistDefNtsteps(vlistID2, 0);
-  }
-
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
-  vlistDefTaxis(vlistID2, taxisID2);
-
-  const auto streamID2 = cdo_open_write(1);
-  cdo_def_vlist(streamID2, vlistID2);
-
-  auto gridsizemax = vlistGridsizeMax(vlistID1);
-  if (vlistNumber(vlistID1) != CDI_REAL) gridsizemax *= 2;
-  Varray<double> array(gridsizemax);
-
-  int tsID = 0;
-  while (true)
-    {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
-
-      cdo_taxis_copy_timestep(taxisID2, taxisID1);
-      cdo_def_timestep(streamID2, tsID);
-
-      for (int recID = 0; recID < nrecs; ++recID)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          const auto &var = varList1[varID];
-
-          if (vlistInqFlag(vlistID1, varID, levelID) == true)
-            {
-              int simpleMath = 0;  // 1:  simple array arithmetics ( *,+), 0: do nothing
-              double scale = 1.0;
-              double offset = 0.0;
-              const auto code = var.code;
-              const auto level = zaxisInqLevel(var.zaxisID, levelID);
-              const auto ltype = zaxis_to_ltype(var.zaxisID);
-              for (int ii = 0; ii < NUMTUPLES; ++ii)
-                {
-                  TUPLEREC *tuplerec = getSelTuple(ii);
-                  // Note: When the list is Empty then function
-                  // checkListContainsInt() also returns true !
-                  const auto selcode = checkListContainsInt(code, tuplerec->codeLST, tuplerec->ncodes);
-                  const auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
-                  const auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
-                  lcopy = true;
-                  if (selcode && selltype && sellevel)
-                    {
-                      if (operatorID == CHANGEMULTI)
-                        {
-                          if (cdoDebugExt)
-                            cdo_print(" Processing: (code %d, ltype %d, level %d);  nvars=%d, varID=%d => (selcode %d, selltype "
-                                      "%d, sellevel %d) => change (%d,%d,%d)",
-                                      code, ltype, (int) level, nvars, varID, selcode, selltype, sellevel, tuplerec->changedCode,
-                                      tuplerec->changedLevelType, tuplerec->changedLevel);
-                          if ((tuplerec->changedCode == -1) && (tuplerec->changedLevelType == -1) && (tuplerec->changedLevel == -1))
-                            cdo_print(" WARNING: Cannot CHANGE identification!");
-                          else
-                            streamGrbChangeParameterIdentification(tuplerec->changedCode, tuplerec->changedLevelType,
-                                                                   tuplerec->changedLevel);
-                          // Calling PROXY function
-                          // streamGrbChangeParameterIdentification() which
-                          // results in later calling func.
-                          // gribapiChangeParameterIdentification(); see
-                          // stream_gribapi.c The change happens during the last
-                          // step of writing a grib-record into a file.
-                        }
-                      else
-                        {
-                          if (cdoDebugExt)
-                            cdo_print(" Processing: (code %d, ltype %d, level %d);  nvars=%d, varID=%d => (selcode %d, "
-                                      "selltype %d, sellevel %d)",
-                                      code, ltype, (int) level, nvars, varID, selcode, selltype, sellevel);
-                        }
-                      simpleMath = tuplerec->simpleMath;  // 1:  simple array arithmetics ( *,+),
-                                                          // 0: do nothing
-                      if (simpleMath)
-                        {
-                          scale = tuplerec->scale;
-                          offset = tuplerec->offset;
-                          lcopy = false;
-                        }
-                      break;  // get out of this for loop
-                    }
-                }  // end of for (ii=0; ii<NUMTUPLES ..
-
-              const auto varID2 = vlistFindVar(vlistID2, varID);
-              const auto levelID2 = vlistFindLevel(vlistID2, varID, levelID);
-
-              // tijdelijk PATCH M.K.
-              if ((varID2 == -1) || (levelID2 == -1))
-                {
-                  cdo_print(" Warning: Missing varID or levelID with (code %3i, "
-                            "ltype %3i, level %3i)   [varID(%d),levelID(%d)] .. #2[varID(%d),levelID(%d)]",
-                            code, ltype, (int) (level), varID, levelID, varID2, levelID2);
-                  continue;
-                }
-              cdo_def_record(streamID2, varID2, levelID2);
-
-              if (lcopy)
-                {
-                  if (cdoDebugExt)
-                    cdo_print(" Copying record [%4d] with (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", recID, code,
-                              ltype, (int) (level), varID, levelID);
-                  cdo_copy_record(streamID2, streamID1);
-                }
-              else
-                {
-                  size_t nmiss;
-                  cdo_read_record(streamID1, array.data(), &nmiss);
-
-                  if (!simpleMath)
-                    {
-                      if (cdoDebugExt)
-                        cdo_print(" Writing record [%4d] with (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]", recID,
-                                  code, ltype, (int) (level), varID, levelID);
-                    }
-                  else  // 1:  simple array arithmetics ( *,+)
-                    {
-                      if (cdoDebugExt)
-                        cdo_print(" Writing record [%4d] with (code %3i, ltype %3i, level %3i)   [varID(%d),levelID(%d)]; "
-                                  "SCALE=%f; OFFSET=%f",
-                                  recID, code, ltype, (int) (level), varID, levelID, scale, offset);
-                      for (size_t li = 0; li < gridsizemax; ++li)
-                        if (!DBL_IS_EQUAL(array[li], var.missval))
-                          {
-                            array[li] = scale * (array[li] - offset);
-                            // If SCALE and/or OFFSET are defined, then the data
-                            // values are scaled as SCALE*(VALUE-OFFSET).
-                          }
-                    }
-
-                  cdo_write_record(streamID2, array.data(), nmiss);
-                }  // end of else ( lcopy )
-            }      // end if ( vlistInqFlag(vlistID1, varID, levelID) == true )
-        }          // end for ( recID ..
-
-      tsID++;
-    }  // end while
-
-  cdo_stream_close(streamID1);
-  cdo_stream_close(streamID2);
-
-  vlistDestroy(vlistID2);
-
-  cdo_finish();
-
-  cdoDebugExt = 0;
-
+  ModuleSelMulti selmulti;
+  selmulti.init(process);
+  selmulti.run();
+  selmulti.close();
   return nullptr;
 }
 
