@@ -43,9 +43,9 @@ print_newline_if_missing(int nout, int maxOut)
 static void
 show_year(CdoStreamID streamID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto taxisID = vlistInqTaxis(vlistID);
-  const auto ntsteps = vlistNtsteps(vlistID);
+  auto vlistID = cdo_stream_inq_vlist(streamID);
+  auto taxisID = vlistInqTaxis(vlistID);
+  auto ntsteps = vlistNtsteps(vlistID);
   if (ntsteps == 0) return;
 
   constexpr int maxOut = 20;
@@ -55,10 +55,10 @@ show_year(CdoStreamID streamID)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
       if (nrecs == 0) break;
 
-      const auto vDateTime = taxisInqVdatetime(taxisID);
+      auto vDateTime = taxisInqVdatetime(taxisID);
       const int year = vDateTime.date.year;
 
       if (tsID == 0 || year0 != year)
@@ -77,9 +77,9 @@ show_year(CdoStreamID streamID)
 static void
 show_mon(CdoStreamID streamID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto taxisID = vlistInqTaxis(vlistID);
-  const auto ntsteps = vlistNtsteps(vlistID);
+  auto vlistID = cdo_stream_inq_vlist(streamID);
+  auto taxisID = vlistInqTaxis(vlistID);
+  auto ntsteps = vlistNtsteps(vlistID);
   if (ntsteps == 0) return;
 
   constexpr int maxOut = 36;
@@ -89,10 +89,10 @@ show_mon(CdoStreamID streamID)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
       if (nrecs == 0) break;
 
-      const auto vDateTime = taxisInqVdatetime(taxisID);
+      auto vDateTime = taxisInqVdatetime(taxisID);
       const int month = vDateTime.date.month;
 
       if (tsID == 0 || month0 != month)
@@ -111,9 +111,9 @@ show_mon(CdoStreamID streamID)
 static void
 show_date(CdoStreamID streamID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto taxisID = vlistInqTaxis(vlistID);
-  const auto ntsteps = vlistNtsteps(vlistID);
+  auto vlistID = cdo_stream_inq_vlist(streamID);
+  auto taxisID = vlistInqTaxis(vlistID);
+  auto ntsteps = vlistNtsteps(vlistID);
   if (ntsteps == 0) return;
 
   constexpr int maxOut = 12;
@@ -123,11 +123,11 @@ show_date(CdoStreamID streamID)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
       if (nrecs == 0) break;
 
-      const auto vDateTime = taxisInqVdatetime(taxisID);
-      const auto vdate = cdiDate_get(vDateTime.date);
+      auto vDateTime = taxisInqVdatetime(taxisID);
+      auto vdate = cdiDate_get(vDateTime.date);
 
       if (tsID == 0 || date0 != vdate)
         {
@@ -145,9 +145,9 @@ show_date(CdoStreamID streamID)
 static void
 show_time(CdoStreamID streamID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto taxisID = vlistInqTaxis(vlistID);
-  const auto ntsteps = vlistNtsteps(vlistID);
+  auto vlistID = cdo_stream_inq_vlist(streamID);
+  auto taxisID = vlistInqTaxis(vlistID);
+  auto ntsteps = vlistNtsteps(vlistID);
   if (ntsteps == 0) return;
 
   constexpr int maxOut = 12;
@@ -156,10 +156,10 @@ show_time(CdoStreamID streamID)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
       if (nrecs == 0) break;
 
-      const auto vDateTime = taxisInqVdatetime(taxisID);
+      auto vDateTime = taxisInqVdatetime(taxisID);
       nout++;
       fprintf(stdout, " %s", time_to_string(vDateTime.time).c_str());
       print_newline(nout, maxOut);
@@ -172,9 +172,9 @@ show_time(CdoStreamID streamID)
 static void
 show_timestamp(CdoStreamID streamID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto taxisID = vlistInqTaxis(vlistID);
-  const auto ntsteps = vlistNtsteps(vlistID);
+  auto vlistID = cdo_stream_inq_vlist(streamID);
+  auto taxisID = vlistInqTaxis(vlistID);
+  auto ntsteps = vlistNtsteps(vlistID);
   if (ntsteps == 0) return;
 
   constexpr int maxOut = 4;
@@ -183,7 +183,7 @@ show_timestamp(CdoStreamID streamID)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
       if (nrecs == 0) break;
 
       nout++;
@@ -196,34 +196,32 @@ show_timestamp(CdoStreamID streamID)
 }
 
 static void
-show_code(CdoStreamID streamID)
+show_code(const VarList &varList)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto nvars = vlistNvars(vlistID);
-
   constexpr int maxOut = 25;
   int nout = 0;
 
+  int nvars = varList.size();
   for (int varID = 0; varID < nvars; ++varID)
     {
       nout++;
-      fprintf(stdout, " %d", vlistInqVarCode(vlistID, varID));
+      const auto &var = varList[varID];
+      fprintf(stdout, " %d", var.code);
       print_newline(nout, maxOut);
     }
   if (Options::silentMode || (nout % maxOut)) fprintf(stdout, "\n");
 }
 
 static void
-show_grid(CdoStreamID streamID)
+show_grid(int vlistID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto nvars = vlistNvars(vlistID);
+  auto nvars = vlistNvars(vlistID);
 
   fprintf(stdout, "# param nr | grid nr | z-axis nr:   /* Use in combination with operatores: griddes and zaxisdes */\n");
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto gridID = vlistInqVarGrid(vlistID, varID);
-      const auto zaxisID = vlistInqVarZaxis(vlistID, varID);
+      auto gridID = vlistInqVarGrid(vlistID, varID);
+      auto zaxisID = vlistInqVarZaxis(vlistID, varID);
 
       fprintf(stdout, "      %3d     %3d      %3d\n", vlistInqVarCode(vlistID, varID), vlistGridIndex(vlistID, gridID) + 1,
               vlistZaxisIndex(vlistID, zaxisID) + 1);
@@ -231,41 +229,35 @@ show_grid(CdoStreamID streamID)
 }
 
 static void
-show_unit(CdoStreamID streamID)
+show_unit(const VarList &varList)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto nvars = vlistNvars(vlistID);
-
   constexpr int maxOut = 10;
   int nout = 0;
 
-  char varunits[CDI_MAX_NAME];
+  int nvars = varList.size();
   for (int varID = 0; varID < nvars; ++varID)
     {
       nout++;
-      varunits[0] = 0;
-      vlistInqVarUnits(vlistID, varID, varunits);
-      if (strlen(varunits)) fprintf(stdout, " %s", varunits);
+      const auto &var = varList[varID];
+      if (var.units.size()) fprintf(stdout, " %s", var.units.c_str());
       print_newline(nout, maxOut);
     }
   print_newline_if_missing(nout, maxOut);
 }
 
 static void
-show_param(CdoStreamID streamID)
+show_param(const VarList &varList)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto nvars = vlistNvars(vlistID);
-
   constexpr int maxOut = 10;
   int nout = 0;
 
   char paramstr[32];
+  int nvars = varList.size();
   for (int varID = 0; varID < nvars; ++varID)
     {
       nout++;
-      const auto param = vlistInqVarParam(vlistID, varID);
-      cdiParamToString(param, paramstr, sizeof(paramstr));
+      const auto &var = varList[varID];
+      cdiParamToString(var.param, paramstr, sizeof(paramstr));
 
       fprintf(stdout, " %s", paramstr);
       print_newline(nout, maxOut);
@@ -274,71 +266,60 @@ show_param(CdoStreamID streamID)
 }
 
 static void
-show_name(CdoStreamID streamID)
+show_name(const VarList &varList)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto nvars = vlistNvars(vlistID);
-
   constexpr int maxOut = 10;
   int nout = 0;
 
-  char varname[CDI_MAX_NAME];
+  int nvars = varList.size();
   for (int varID = 0; varID < nvars; ++varID)
     {
       nout++;
-      vlistInqVarName(vlistID, varID, varname);
-      fprintf(stdout, " %s", varname);
+      const auto &var = varList[varID];
+      fprintf(stdout, " %s", var.name.c_str());
       print_newline(nout, maxOut);
     }
   print_newline_if_missing(nout, maxOut);
 }
 
 static void
-show_stdname(CdoStreamID streamID)
+show_stdname(int vlistID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto nvars = vlistNvars(vlistID);
+  auto nvars = vlistNvars(vlistID);
 
   constexpr int maxOut = 1;
   int nout = 0;
 
-  char stdname[CDI_MAX_NAME];
   for (int varID = 0; varID < nvars; ++varID)
     {
       nout++;
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(vlistID, varID, CDI_KEY_STDNAME, stdname, &length);
-      fprintf(stdout, " %s", (stdname[0] != 0) ? stdname : "unknown");
+      auto stdname = cdo::inq_key_string(vlistID, varID, CDI_KEY_STDNAME);
+      fprintf(stdout, " %s", stdname.size() ? stdname.c_str() : "unknown");
       print_newline(nout, maxOut);
     }
   print_newline_if_missing(nout, maxOut);
 }
 
 static void
-show_level(CdoStreamID streamID)
+show_level(const VarList &varList)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-  const auto nvars = vlistNvars(vlistID);
-
+  int nvars = varList.size();
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto zaxisID = vlistInqVarZaxis(vlistID, varID);
-      const auto nlevs = zaxisInqSize(zaxisID);
-      for (int levelID = 0; levelID < nlevs; ++levelID) fprintf(stdout, " %.9g", cdo_zaxis_inq_level(zaxisID, levelID));
+      const auto &var = varList[varID];
+      for (int levelID = 0; levelID < var.nlevels; ++levelID) fprintf(stdout, " %.9g", cdo_zaxis_inq_level(var.zaxisID, levelID));
       fprintf(stdout, "\n");
     }
 }
 
 static void
-show_ltype(CdoStreamID streamID)
+show_ltype(int vlistID)
 {
-  const auto vlistID = cdo_stream_inq_vlist(streamID);
-
-  const auto nzaxis = vlistNzaxis(vlistID);
+  auto nzaxis = vlistNzaxis(vlistID);
   for (int index = 0; index < nzaxis; ++index)
     {
-      const auto zaxisID = vlistZaxis(vlistID, index);
-      const auto ltype = zaxis_to_ltype(zaxisID);
+      auto zaxisID = vlistZaxis(vlistID, index);
+      auto ltype = zaxis_to_ltype(zaxisID);
 
       if (ltype != -1) fprintf(stdout, " %d", ltype);
     }
@@ -346,84 +327,102 @@ show_ltype(CdoStreamID streamID)
 }
 
 static void
-show_atts(int vlistID)
+show_atts(int vlistID, const VarList &varList)
 {
-  const auto nvars = vlistNvars(vlistID);
+  auto nvars = vlistNvars(vlistID);
 
-  char varname[CDI_MAX_NAME];
   for (int varID = 0; varID < nvars; ++varID)
     {
-      vlistInqVarName(vlistID, varID, varname);
-      fprintf(stdout, "%s:\n", varname);
+      const auto &var = varList[varID];
+      fprintf(stdout, "%s:\n", var.name.c_str());
 
       int nattsvar;
       cdiInqNatts(vlistID, varID, &nattsvar);
-      print_atts(vlistID, varID, nattsvar, nullptr);
+      print_attributes(varList, vlistID, varID, nattsvar, nullptr);
     }
 }
-
-void *
-Showinfo(void *process)
+class ModuleShowinfo
 {
-  cdo_initialize(process);
+  int SHOWYEAR, SHOWMON, SHOWDATE, SHOWTIME, SHOWTIMESTAMP, SHOWCODE, SHOWUNIT, SHOWPARAM, SHOWNAME, SHOWSTDNAME, SHOWLEVEL,
+      SHOWLTYPE, SHOWFORMAT, SHOWGRID, SHOWATTS, SHOWATTSGLOB;
+  int operatorID;
+  CdoStreamID streamID;
+  int vlistID;
+  VarList varList;
 
-  // clang-format off
-  const auto SHOWYEAR      = cdo_operator_add("showyear",      0, 0, nullptr);
-  const auto SHOWMON       = cdo_operator_add("showmon",       0, 0, nullptr);
-  const auto SHOWDATE      = cdo_operator_add("showdate",      0, 0, nullptr);
-  const auto SHOWTIME      = cdo_operator_add("showtime",      0, 0, nullptr);
-  const auto SHOWTIMESTAMP = cdo_operator_add("showtimestamp", 0, 0, nullptr);
-  const auto SHOWCODE      = cdo_operator_add("showcode",      0, 0, nullptr);
-  const auto SHOWUNIT      = cdo_operator_add("showunit",      0, 0, nullptr);
-  const auto SHOWPARAM     = cdo_operator_add("showparam",     0, 0, nullptr);
-  const auto SHOWNAME      = cdo_operator_add("showname",      0, 0, nullptr);
-  const auto SHOWSTDNAME   = cdo_operator_add("showstdname",   0, 0, nullptr);
-  const auto SHOWLEVEL     = cdo_operator_add("showlevel",     0, 0, nullptr);
-  const auto SHOWLTYPE     = cdo_operator_add("showltype",     0, 0, nullptr);
-  const auto SHOWFORMAT    = cdo_operator_add("showformat",    0, 0, nullptr);
-  const auto SHOWGRID      = cdo_operator_add("showgrid",      0, 0, nullptr); 
-  const auto SHOWATTS      = cdo_operator_add("showatts",      0, 0, nullptr);
-  const auto SHOWATTSGLOB  = cdo_operator_add("showattsglob",  0, 0, nullptr);
+public:
+  void
+  init(void *process)
+  {
+    cdo_initialize(process);
 
-  const auto operatorID = cdo_operator_id();
+    // clang-format off
+  SHOWYEAR      = cdo_operator_add("showyear",      0, 0, nullptr);
+  SHOWMON       = cdo_operator_add("showmon",       0, 0, nullptr);
+  SHOWDATE      = cdo_operator_add("showdate",      0, 0, nullptr);
+  SHOWTIME      = cdo_operator_add("showtime",      0, 0, nullptr);
+  SHOWTIMESTAMP = cdo_operator_add("showtimestamp", 0, 0, nullptr);
+  SHOWCODE      = cdo_operator_add("showcode",      0, 0, nullptr);
+  SHOWUNIT      = cdo_operator_add("showunit",      0, 0, nullptr);
+  SHOWPARAM     = cdo_operator_add("showparam",     0, 0, nullptr);
+  SHOWNAME      = cdo_operator_add("showname",      0, 0, nullptr);
+  SHOWSTDNAME   = cdo_operator_add("showstdname",   0, 0, nullptr);
+  SHOWLEVEL     = cdo_operator_add("showlevel",     0, 0, nullptr);
+  SHOWLTYPE     = cdo_operator_add("showltype",     0, 0, nullptr);
+  SHOWFORMAT    = cdo_operator_add("showformat",    0, 0, nullptr);
+  SHOWGRID      = cdo_operator_add("showgrid",      0, 0, nullptr);
+  SHOWATTS      = cdo_operator_add("showatts",      0, 0, nullptr);
+  SHOWATTSGLOB  = cdo_operator_add("showattsglob",  0, 0, nullptr);
+  operatorID = cdo_operator_id();
 
   operator_check_argc(0);
 
-  const auto streamID = cdo_open_read(0);
+   streamID = cdo_open_read(0);
+  vlistID = cdo_stream_inq_vlist(streamID);
+  varListInit(varList, vlistID);}
+  void run(){
 
   if      (operatorID == SHOWYEAR)      show_year(streamID);
   else if (operatorID == SHOWMON)       show_mon(streamID);
   else if (operatorID == SHOWDATE)      show_date(streamID);
   else if (operatorID == SHOWTIME)      show_time(streamID);
   else if (operatorID == SHOWTIMESTAMP) show_timestamp(streamID);
-  else if (operatorID == SHOWCODE)      show_code(streamID);
-  else if (operatorID == SHOWGRID)      show_grid(streamID);
-  else if (operatorID == SHOWUNIT)      show_unit(streamID);
-  else if (operatorID == SHOWPARAM)     show_param(streamID);
-  else if (operatorID == SHOWNAME)      show_name(streamID);
-  else if (operatorID == SHOWSTDNAME)   show_stdname(streamID);
-  else if (operatorID == SHOWLEVEL)     show_level(streamID);
-  else if (operatorID == SHOWLTYPE)     show_ltype(streamID);
+  else if (operatorID == SHOWCODE)      show_code(varList);
+  else if (operatorID == SHOWGRID)      show_grid(vlistID);
+  else if (operatorID == SHOWUNIT)      show_unit(varList);
+  else if (operatorID == SHOWPARAM)     show_param(varList);
+  else if (operatorID == SHOWNAME)      show_name(varList);
+  else if (operatorID == SHOWSTDNAME)   show_stdname(vlistID);
+  else if (operatorID == SHOWLEVEL)     show_level(varList);
+  else if (operatorID == SHOWLTYPE)     show_ltype(vlistID);
   else if (operatorID == SHOWFORMAT)
     {
-      const auto vlistID = cdo_stream_inq_vlist(streamID);
       print_filetype(streamID, vlistID);
     }
   else if (operatorID == SHOWATTS || operatorID == SHOWATTSGLOB)
     {
-      const auto vlistID = cdo_stream_inq_vlist(streamID);
-      if (operatorID == SHOWATTS) show_atts(vlistID);
+      if (operatorID == SHOWATTS) show_atts(vlistID, varList);
 
       fprintf(stdout, "Global:\n");
       int natts;
       cdiInqNatts(vlistID, CDI_GLOBAL, &natts);
-      print_atts(vlistID, CDI_GLOBAL, natts, nullptr);
-    }
+      print_attributes(varList, vlistID, CDI_GLOBAL, natts, nullptr);
+    }}
   // clang-format on
+  void
+  close()
+  {
+    cdo_stream_close(streamID);
 
-  cdo_stream_close(streamID);
-
-  cdo_finish();
-
+    cdo_finish();
+  }
+};
+void *
+Showinfo(void *process)
+{
+  ModuleShowinfo showinfo;
+  showinfo.init(process);
+  showinfo.run();
+  showinfo.close();
   return nullptr;
 }
