@@ -24,7 +24,7 @@
 #include "datetime.h"
 #include "cdo_default_values.h"
 
-const char *get_steptype_name(const int tsteptype);
+const char *get_steptype_name(int tsteptype);
 
 enum
 {
@@ -381,7 +381,7 @@ print_time_info_xs(int ntsteps, int taxisID, CdoStreamID streamID)
 }
 
 static void
-addOperators(void)
+add_operators(void)
 {
   // clang-format off
   cdo_operator_add("sinfo",   func_generic, 0, nullptr);
@@ -412,7 +412,7 @@ public:
   {
     cdo_initialize(process);
 
-    addOperators();
+    add_operators();
 
     auto operatorID = cdo_operator_id();
 
@@ -455,7 +455,7 @@ public:
         int numRecordsConst = 0;
         int numRecordsVar = 0;
         int numValues = 0;
-        size_t memorySize = 0;
+        // size_t memorySize = 0;
         size_t inputSize = 0;
         size_t outputSize = 0;
         if (Options::test && xsInfo)
@@ -474,8 +474,8 @@ public:
                 auto size = var.nlevels * var.gridsize * var.nwpv;
                 numValues += size;
 
-                auto numBytes = (var.memType == MemType::Double) ? 8 : 4;
-                memorySize += size * numBytes;
+                // auto numBytes = (var.memType == MemType::Double) ? 8 : 4;
+                // memorySize += size * numBytes;
 
                 auto numBits = get_num_input_bits(var.datatype);
                 inputSize += (size * numBits) / 8;
