@@ -19,7 +19,7 @@
 
 #include "process_int.h"
 #include "param_conversion.h"
-#include "cdo_wtime.h"
+#include "cdo_timer.h"
 #include <mpim_grid.h>
 #include "constants.h"  // planet radius
 #include "pmlist.h"
@@ -72,7 +72,7 @@ smooth(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2, const
   std::vector<knnWeightsType> knnWeights;
   for (int i = 0; i < Threading::ompNumThreads; ++i) knnWeights.push_back(knnWeightsType(numNeighbors));
 
-  auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  cdo::timer timer;
 
   bool xIsCyclic = false;
   size_t dims[2] = { gridsize, 0 };
@@ -84,11 +84,11 @@ smooth(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2, const
   else
     grid_point_search_set_chord_radius(gps, spoint.radius);
 
-  if (Options::cdoVerbose) cdo_print("Point search created: %.2f seconds (%zu points)", cdo_get_wtime() - start, gridsize);
+  if (Options::cdoVerbose) cdo_print("Point search created: %.2f seconds (%zu points)", timer.elapsed(), gridsize);
 
   if (Options::cdoVerbose) progress::init();
 
-  start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  timer.reset();
 
   size_t naddsMin = gridsize, naddsMax = 0;
   std::atomic<size_t> atomicCount{ 0 }, atomicSum{ 0 }, atomicNumMiss{ 0 };
@@ -98,7 +98,7 @@ smooth(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2, const
 #endif
   for (size_t i = 0; i < gridsize; ++i)
     {
-      const auto ompthID = cdo_omp_get_thread_num();
+      auto ompthID = cdo_omp_get_thread_num();
 
       atomicCount++;
       if (Options::cdoVerbose && cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / gridsize);
@@ -106,7 +106,7 @@ smooth(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2, const
       grid_search_point_smooth(gps, xvals[i], yvals[i], knnWeights[ompthID]);
 
       // Compute weights based on inverse distance if mask is false, eliminate those points
-      const auto nadds = knnWeights[ompthID].computeWeights(mask, spoint.radius, spoint.weight0, spoint.weightR);
+      auto nadds = knnWeights[ompthID].computeWeights(mask, spoint.radius, spoint.weight0, spoint.weightR);
       naddsMin = std::min(naddsMin, nadds);
       naddsMax = std::max(naddsMax, nadds);
 
@@ -120,7 +120,7 @@ smooth(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2, const
   size_t nmissx = atomicNumMiss;
   size_t numPoints = atomicSum;
 
-  if (Options::cdoVerbose) cdo_print("Point search nearest: %.2f seconds (%zu points)", cdo_get_wtime() - start, numPoints);
+  if (Options::cdoVerbose) cdo_print("Point search nearest: %.2f seconds (%zu points)", timer.elapsed(), numPoints);
   if (Options::cdoVerbose) cdo_print("Min/Max points found: %zu/%zu", naddsMin, naddsMax);
 
   grid_point_search_delete(gps);
@@ -156,10 +156,10 @@ template <typename T>
 static size_t
 smooth9(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2)
 {
-  const auto gridsize = gridInqSize(gridID);
-  const auto nlon = gridInqXsize(gridID);
-  const auto nlat = gridInqYsize(gridID);
-  const auto gridIsCyclic = gridIsCircular(gridID);
+  auto gridsize = gridInqSize(gridID);
+  auto nlon = gridInqXsize(gridID);
+  auto nlat = gridInqYsize(gridID);
+  auto gridIsCyclic = gridIsCircular(gridID);
 
   std::vector<uint8_t> mask(gridsize);
 
@@ -174,7 +174,7 @@ smooth9(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2)
 
           if ((i == 0) || (j == 0) || (i == (nlat - 1)) || (j == (nlon - 1)))
             {
-              const auto ij = j + nlon * i;
+              auto ij = j + nlon * i;
               if (mask[ij])
                 {
                   avg += array1[ij];
@@ -261,7 +261,7 @@ smooth9(const Field &field1, Field &field2)
 }
 
 double
-radiusDegToKm(const double radiusInDeg)
+radiusDegToKm(double radiusInDeg)
 {
   return radiusInDeg * (2.0 * PlanetRadius * M_PI) / (360.0 * 1000.0);
 }
@@ -318,9 +318,6 @@ print_parameter(int xnsmooth, const SmoothPoint &sp)
 {
   std::stringstream outbuffer;
 
-  outbuffer << "nsmooth=" << xnsmooth;
-  outbuffer << ", maxpoints=" << sp.maxpoints;
-
   if (sp.arc_radius > 0.0)
     outbuffer << ", arc_radius=" << sp.arc_radius << "deg(" << radiusDegToKm(sp.arc_radius) << "km)";
   else
@@ -338,109 +335,142 @@ check_radius_range(double radius, const char *name)
   if (radius < 0.0 || radius > 180.0) cdo_abort("%s=%g out of bounds (0-180 deg)!", name, radius);
 }
 
+class ModuleSmooth
+{
+  int nvars;
+  VarList varList1;
+  Field field1, field2;
+  std::vector<bool> varIDs;
+
+  CdoStreamID streamID1;
+  CdoStreamID streamID2;
+
+  int taxisID1;
+  int taxisID2;
+
+  int vlistID2;
+
+  int xnsmooth = 1;
+  int operatorID;
+
+  SmoothPoint spoint;
+
+  int SMOOTH, SMOOTH9;
+
+public:
+  void
+  init(void *process)
+  {
+
+    cdo_initialize(process);
+
+    // clang-format off
+   SMOOTH  = cdo_operator_add("smooth",   0,   0, nullptr);
+   SMOOTH9 = cdo_operator_add("smooth9",  0,   0, nullptr);
+    // clang-format on
+
+    operatorID = cdo_operator_id();
+
+    if (operatorID == SMOOTH) get_parameter(xnsmooth, spoint);
+
+    check_radius_range(spoint.radius, "radius");
+    check_radius_range(spoint.arc_radius, "arc_radius");
+
+    streamID1 = cdo_open_read(0);
+
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    vlistID2 = vlistDuplicate(vlistID1);
+
+    taxisID1 = vlistInqTaxis(vlistID1);
+    taxisID2 = taxisDuplicate(taxisID1);
+    vlistDefTaxis(vlistID2, taxisID2);
+
+    varListInit(varList1, vlistID1);
+
+    nvars = vlistNvars(vlistID1);
+    varIDs = std::vector<bool>(nvars, false);
+
+    for (int varID = 0; varID < nvars; ++varID)
+      {
+        const auto &var = varList1[varID];
+        auto gridID = var.gridID;
+        auto gridtype = gridInqType(gridID);
+        if (gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || gridtype == GRID_CURVILINEAR || gridtype == GRID_PROJECTION
+            || (operatorID == SMOOTH9 && gridtype == GRID_GENERIC && gridInqXsize(gridID) > 0 && gridInqYsize(gridID) > 0))
+          {
+            varIDs[varID] = true;
+          }
+        else if (operatorID == SMOOTH && gridtype == GRID_UNSTRUCTURED) { varIDs[varID] = true; }
+        else { cdo_warning("Unsupported grid for variable %s", var.name); }
+      }
+
+    auto gridsizemax = vlistGridsizeMax(vlistID1);
+    if (gridsizemax < spoint.maxpoints) spoint.maxpoints = gridsizemax;
+    if (Options::cdoVerbose && operatorID == SMOOTH) print_parameter(xnsmooth, spoint);
+
+    spoint.radius *= DEG2RAD;
+    spoint.arc_radius *= DEG2RAD;
+
+    streamID2 = cdo_open_write(1);
+  }
+  void
+  run()
+  {
+    cdo_def_vlist(streamID2, vlistID2);
+
+    int tsID = 0;
+    while (true)
+      {
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
+
+        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        cdo_def_timestep(streamID2, tsID);
+
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+            const auto &var = varList1[varID];
+            field1.init(var);
+            field2.init(var);
+            cdo_read_record(streamID1, field1);
+
+            if (varIDs[varID])
+              {
+                for (int i = 0; i < xnsmooth; ++i)
+                  {
+                    if (operatorID == SMOOTH)
+                      smooth(field1, field2, spoint);
+                    else if (operatorID == SMOOTH9)
+                      smooth9(field1, field2);
+
+                    field_copy(field2, field1);
+                  }
+              }
+
+            cdo_def_record(streamID2, varID, levelID);
+            cdo_write_record(streamID2, field1);
+          }
+
+        tsID++;
+      }
+  }
+  void
+  close()
+  {
+    cdo_stream_close(streamID2);
+    cdo_stream_close(streamID1);
+
+    cdo_finish();
+  }
+};
 void *
 Smooth(void *process)
 {
-  int xnsmooth = 1;
-
-  cdo_initialize(process);
-
-  // clang-format off
-  const auto SMOOTH  = cdo_operator_add("smooth",   0,   0, nullptr);
-  const auto SMOOTH9 = cdo_operator_add("smooth9",  0,   0, nullptr);
-  // clang-format on
-
-  const auto operatorID = cdo_operator_id();
-
-  SmoothPoint spoint;
-  if (operatorID == SMOOTH) get_parameter(xnsmooth, spoint);
-
-  check_radius_range(spoint.radius, "radius");
-  check_radius_range(spoint.arc_radius, "arc_radius");
-
-  const auto streamID1 = cdo_open_read(0);
-
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
-
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
-  vlistDefTaxis(vlistID2, taxisID2);
-
-  VarList varList1;
-  varListInit(varList1, vlistID1);
-
-  const auto nvars = vlistNvars(vlistID1);
-  std::vector<bool> varIDs(nvars, false);
-
-  for (int varID = 0; varID < nvars; ++varID)
-    {
-      const auto &var = varList1[varID];
-      const auto gridID = var.gridID;
-      const auto gridtype = gridInqType(gridID);
-      if (gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || gridtype == GRID_CURVILINEAR || gridtype == GRID_PROJECTION
-          || (operatorID == SMOOTH9 && gridtype == GRID_GENERIC && gridInqXsize(gridID) > 0 && gridInqYsize(gridID) > 0))
-        {
-          varIDs[varID] = true;
-        }
-      else if (operatorID == SMOOTH && gridtype == GRID_UNSTRUCTURED) { varIDs[varID] = true; }
-      else { cdo_warning("Unsupported grid for variable %s", var.name); }
-    }
-
-  const auto gridsizemax = vlistGridsizeMax(vlistID1);
-  if (gridsizemax < spoint.maxpoints) spoint.maxpoints = gridsizemax;
-  if (Options::cdoVerbose && operatorID == SMOOTH) print_parameter(xnsmooth, spoint);
-
-  spoint.radius *= DEG2RAD;
-  spoint.arc_radius *= DEG2RAD;
-
-  Field field1, field2;
-
-  const auto streamID2 = cdo_open_write(1);
-  cdo_def_vlist(streamID2, vlistID2);
-
-  int tsID = 0;
-  while (true)
-    {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
-
-      cdo_taxis_copy_timestep(taxisID2, taxisID1);
-      cdo_def_timestep(streamID2, tsID);
-
-      for (int recID = 0; recID < nrecs; ++recID)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          const auto &var = varList1[varID];
-          field1.init(var);
-          field2.init(var);
-          cdo_read_record(streamID1, field1);
-
-          if (varIDs[varID])
-            {
-              for (int i = 0; i < xnsmooth; ++i)
-                {
-                  if (operatorID == SMOOTH)
-                    smooth(field1, field2, spoint);
-                  else if (operatorID == SMOOTH9)
-                    smooth9(field1, field2);
-
-                  field_copy(field2, field1);
-                }
-            }
-
-          cdo_def_record(streamID2, varID, levelID);
-          cdo_write_record(streamID2, field1);
-        }
-
-      tsID++;
-    }
-
-  cdo_stream_close(streamID2);
-  cdo_stream_close(streamID1);
-
-  cdo_finish();
-
+  ModuleSmooth smooth;
+  smooth.init(process);
+  smooth.run();
+  smooth.close();
   return nullptr;
 }
