@@ -27,8 +27,8 @@
 void *
 Timcount(void *process)
 {
-  CdiDateTime vDateTime0 = { };
-  CdiDateTime vDateTimeN = { };
+  CdiDateTime vDateTime0{};
+  CdiDateTime vDateTimeN{};
 
   cdo_initialize(process);
 
@@ -40,29 +40,29 @@ Timcount(void *process)
   cdo_operator_add("hourcount", 0, CMP_HOUR, nullptr);
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
-  const auto compareDate = cdo_operator_f2(operatorID);
+  auto operatorID = cdo_operator_id();
+  auto compareDate = cdo_operator_f2(operatorID);
 
   operator_check_argc(0);
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
   for (int varID = 0; varID < nvars; ++varID) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, "No.");
 
   vlistDefNtsteps(vlistID2, (compareDate == CMP_DATE) ? 1 : -1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
-  const auto maxrecs = vlistNrecs(vlistID1);
+  auto maxrecs = vlistNrecs(vlistID1);
   std::vector<RecordInfo> recList(maxrecs);
 
   VarList varList1;
@@ -78,15 +78,15 @@ Timcount(void *process)
   while (true)
     {
       int nrecs = 0;
-      int nsets = 0;
+      int numSets = 0;
       while (true)
         {
           nrecs = cdo_stream_inq_timestep(streamID1, tsID);
           if (nrecs == 0) break;
 
-          const auto vDateTime = taxisInqVdatetime(taxisID1);
+          auto vDateTime = taxisInqVdatetime(taxisID1);
 
-          if (nsets == 0) vDateTime0 = vDateTime;
+          if (numSets == 0) vDateTime0 = vDateTime;
 
           if (date_is_neq(vDateTime, vDateTime0, compareDate))
             {
@@ -99,16 +99,11 @@ Timcount(void *process)
               int varID, levelID;
               cdo_inq_record(streamID1, &varID, &levelID);
 
-              if (tsID == 0)
-                {
-                  recList[recID].varID = varID;
-                  recList[recID].levelID = levelID;
-                  recList[recID].lconst = (vlistInqVarTimetype(vlistID1, varID) == TIME_CONSTANT);
-                }
+              if (tsID == 0) recList[recID].set(varID, levelID);
 
               const size_t fieldsize = vars1[varID][levelID].size;
 
-              if (nsets == 0)
+              if (numSets == 0)
                 {
                   for (size_t i = 0; i < fieldsize; ++i) vars1[varID][levelID].vec_d[i] = vars1[varID][levelID].missval;
                   vars1[varID][levelID].nmiss = fieldsize;
@@ -121,21 +116,20 @@ Timcount(void *process)
             }
 
           vDateTimeN = vDateTime;
-          nsets++;
+          numSets++;
           tsID++;
         }
 
-      if (nrecs == 0 && nsets == 0) break;
+      if (nrecs == 0 && numSets == 0) break;
 
       taxisDefVdatetime(taxisID2, vDateTimeN);
       cdo_def_timestep(streamID2, otsID);
 
       for (int recID = 0; recID < maxrecs; ++recID)
         {
-          if (otsID && recList[recID].lconst) continue;
+          auto [varID, levelID] = recList[recID].get();
+          if (otsID && varList1[varID].isConstant) continue;
 
-          const auto varID = recList[recID].varID;
-          const auto levelID = recList[recID].levelID;
           cdo_def_record(streamID2, varID, levelID);
           cdo_write_record(streamID2, vars1[varID][levelID].vec_d.data(), vars1[varID][levelID].nmiss);
         }
