@@ -27,59 +27,59 @@
 void *
 Timselpctl(void *process)
 {
-  const auto timestat_date = TimeStat::MEAN;
+  constexpr auto timestatDate{ TimeStat::MEAN };
 
   cdo_initialize(process);
 
   cdo_operator_add("timselpctl", FieldFunc_Pctl, 0, nullptr);
 
-  operator_input_arg("percentile number, nsets <,noffset <,nskip>>");
+  operator_input_arg("percentile number, numSets <,noffset <,nskip>>");
 
-  const auto nargc = cdo_operator_argc();
+  auto nargc = cdo_operator_argc();
   if (nargc < 2) cdo_abort("Too few arguments! Need %d found %d.", 2, nargc);
 
-  const auto pn = parameter_to_double(cdo_operator_argv(0));
-  const auto ndates = parameter_to_int(cdo_operator_argv(1));
+  auto pn = parameter_to_double(cdo_operator_argv(0));
+  auto ndates = parameter_to_int(cdo_operator_argv(1));
   int noffset = 0, nskip = 0;
   if (nargc > 2) noffset = parameter_to_int(cdo_operator_argv(2));
   if (nargc > 3) nskip = parameter_to_int(cdo_operator_argv(3));
 
-  if (Options::cdoVerbose) cdo_print("nsets = %d, noffset = %d, nskip = %d", ndates, noffset, nskip);
+  if (Options::cdoVerbose) cdo_print("numSets = %d, noffset = %d, nskip = %d", ndates, noffset, nskip);
 
-  const auto streamID1 = cdo_open_read(0);
-  const auto streamID2 = cdo_open_read(1);
-  const auto streamID3 = cdo_open_read(2);
+  auto streamID1 = cdo_open_read(0);
+  auto streamID2 = cdo_open_read(1);
+  auto streamID3 = cdo_open_read(2);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = cdo_stream_inq_vlist(streamID2);
-  const auto vlistID3 = cdo_stream_inq_vlist(streamID3);
-  const auto vlistID4 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = cdo_stream_inq_vlist(streamID2);
+  auto vlistID3 = cdo_stream_inq_vlist(streamID3);
+  auto vlistID4 = vlistDuplicate(vlistID1);
 
   vlist_compare(vlistID1, vlistID2, CMP_ALL);
   vlist_compare(vlistID1, vlistID3, CMP_ALL);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = vlistInqTaxis(vlistID2);
-  const auto taxisID3 = vlistInqTaxis(vlistID3);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = vlistInqTaxis(vlistID2);
+  auto taxisID3 = vlistInqTaxis(vlistID3);
   // TODO - check that time axes 2 and 3 are equal
 
-  const auto taxisID4 = taxisDuplicate(taxisID1);
+  auto taxisID4 = taxisDuplicate(taxisID1);
   taxisWithBounds(taxisID4);
   vlistDefTaxis(vlistID4, taxisID4);
 
-  const auto streamID4 = cdo_open_write(3);
+  auto streamID4 = cdo_open_write(3);
   cdo_def_vlist(streamID4, vlistID4);
 
-  const auto ntsteps = vlistNtsteps(vlistID1);
-  const auto nvars = vlistNvars(vlistID1);
+  auto ntsteps = vlistNtsteps(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
-  const auto maxrecs = vlistNrecs(vlistID1);
+  auto maxrecs = vlistNrecs(vlistID1);
   std::vector<RecordInfo> recList(maxrecs);
 
   FieldVector constFields(maxrecs);
 
   DateTimeList dtlist;
-  dtlist.set_stat(timestat_date);
+  dtlist.set_stat(timestatDate);
   dtlist.set_calendar(taxisInqCalendar(taxisID1));
 
   Field field1, field2;
@@ -94,7 +94,7 @@ Timselpctl(void *process)
   int tsID;
   for (tsID = 0; tsID < noffset; ++tsID)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       for (int recID = 0; recID < nrecs; ++recID)
@@ -102,12 +102,7 @@ Timselpctl(void *process)
           int varID, levelID;
           cdo_inq_record(streamID1, &varID, &levelID);
 
-          if (tsID == 0)
-            {
-              recList[recID].varID = varID;
-              recList[recID].levelID = levelID;
-              recList[recID].lconst = (varList1[varID].timetype == TIME_CONSTANT);
-            }
+          if (tsID == 0) recList[recID].set(varID, levelID);
         }
     }
 
@@ -125,8 +120,8 @@ Timselpctl(void *process)
         cdo_abort("Number of records at time step %d of %s and %s differ!", otsID + 1, cdo_get_stream_name(1),
                   cdo_get_stream_name(2));
 
-      const auto vDateTime2 = taxisInqVdatetime(taxisID2);
-      const auto vDateTime3 = taxisInqVdatetime(taxisID3);
+      auto vDateTime2 = taxisInqVdatetime(taxisID2);
+      auto vDateTime3 = taxisInqVdatetime(taxisID3);
       if (cdiDateTime_isNE(vDateTime2, vDateTime3))
         cdo_abort("Verification dates at time step %d of %s and %s differ!", otsID + 1, cdo_get_stream_name(1),
                   cdo_get_stream_name(2));
@@ -145,28 +140,23 @@ Timselpctl(void *process)
           hset.defVarLevelBounds(varID, levelID, field1, field2);
         }
 
-      int nsets = 0;
+      int numSets = 0;
       if (nrecs)
-        for (nsets = 0; nsets < ndates; nsets++)
+        for (numSets = 0; numSets < ndates; numSets++)
           {
             nrecs = cdo_stream_inq_timestep(streamID1, tsID);
             if (nrecs == 0) break;
 
-            dtlist.taxis_inq_timestep(taxisID1, nsets);
+            dtlist.taxis_inq_timestep(taxisID1, numSets);
 
             for (int recID = 0; recID < nrecs; ++recID)
               {
                 int varID, levelID;
                 cdo_inq_record(streamID1, &varID, &levelID);
 
-                if (tsID == 0)
-                  {
-                    recList[recID].varID = varID;
-                    recList[recID].levelID = levelID;
-                    recList[recID].lconst = (varList1[varID].timetype == TIME_CONSTANT);
-                  }
+                if (tsID == 0) recList[recID].set(varID, levelID);
 
-                if (tsID == 0 && recList[recID].lconst)
+                if (tsID == 0 && varList1[varID].isConstant)
                   {
                     constFields[recID].init(varList1[varID]);
                     cdo_read_record(streamID1, constFields[recID]);
@@ -183,23 +173,19 @@ Timselpctl(void *process)
             tsID++;
           }
 
-      if (nrecs == 0 && nsets == 0) break;
+      if (nrecs == 0 && numSets == 0) break;
 
-      dtlist.stat_taxis_def_timestep(taxisID4, nsets);
+      dtlist.stat_taxis_def_timestep(taxisID4, numSets);
       cdo_def_timestep(streamID4, otsID);
 
       for (int recID = 0; recID < maxrecs; ++recID)
         {
-          if (otsID && recList[recID].lconst) continue;
+          auto [varID, levelID] = recList[recID].get();
+          if (otsID && varList1[varID].isConstant) continue;
 
-          const auto varID = recList[recID].varID;
-          const auto levelID = recList[recID].levelID;
           cdo_def_record(streamID4, varID, levelID);
 
-          if (recList[recID].lconst)
-            {
-              cdo_write_record(streamID4, constFields[recID]);
-            }
+          if (varList1[varID].isConstant) { cdo_write_record(streamID4, constFields[recID]); }
           else
             {
               field1.init(varList1[varID]);
