@@ -15,19 +15,19 @@ Tocomplex(void *process)
 {
   cdo_initialize(process);
 
-  const auto RETOCOMPLEX = cdo_operator_add("retocomplex", 0, 0, nullptr);
-  const auto IMTOCOMPLEX = cdo_operator_add("imtocomplex", 0, 0, nullptr);
+  auto RETOCOMPLEX = cdo_operator_add("retocomplex", 0, 0, nullptr);
+  auto IMTOCOMPLEX = cdo_operator_add("imtocomplex", 0, 0, nullptr);
 
-  const auto operatorID = cdo_operator_id();
+  auto operatorID = cdo_operator_id();
 
   operator_check_argc(0);
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto nvars = vlistNvars(vlistID2);
+  auto nvars = vlistNvars(vlistID2);
   for (int varID = 0; varID < nvars; ++varID)
     {
       auto datatype = vlistInqVarDatatype(vlistID2, varID);
@@ -35,15 +35,15 @@ Tocomplex(void *process)
       vlistDefVarDatatype(vlistID2, varID, datatype);
     }
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
   // if (CdoDefault::FileType != CDI_FILETYPE_EXT) cdo_abort("Complex numbers need EXTRA format; used CDO option -f ext!");
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
-  const auto gridsizemax = vlistGridsizeMax(vlistID1);
+  auto gridsizemax = vlistGridsizeMax(vlistID1);
   Varray<double> array1(gridsizemax), array2(2 * gridsizemax);
 
   VarList varList1;
@@ -53,7 +53,7 @@ Tocomplex(void *process)
   int tsID2 = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -68,7 +68,7 @@ Tocomplex(void *process)
 
           cdo_read_record(streamID1, array1.data(), &nmiss);
 
-          const auto gridsize = varList1[varID].gridsize;
+          auto gridsize = varList1[varID].gridsize;
           if (operatorID == RETOCOMPLEX)
             {
               for (size_t i = 0; i < gridsize; ++i)
