@@ -25,10 +25,9 @@ template <typename T>
 static void
 add_trend(double zj, const Varray<T> &v1, const Varray<double> &v2, const Varray<double> &v3, Varray<T> &v4, size_t n, double mv)
 {
-  const auto missval1 = mv;
-  const auto missval2 = mv;
-  for (size_t i = 0; i < n; ++i)
-    v4[i] = ADDMN(v1[i], ADDMN(v2[i], MULMN(v3[i], zj)));
+  auto missval1 = mv;
+  auto missval2 = mv;
+  for (size_t i = 0; i < n; ++i) v4[i] = ADDMN(v1[i], ADDMN(v2[i], MULMN(v3[i], zj)));
 }
 
 static void
@@ -46,10 +45,9 @@ template <typename T>
 static void
 sub_trend(double zj, const Varray<T> &v1, const Varray<double> &v2, const Varray<double> &v3, Varray<T> &v4, size_t n, double mv)
 {
-  const auto missval1 = mv;
-  const auto missval2 = mv;
-  for (size_t i = 0; i < n; ++i)
-    v4[i] = SUBMN(v1[i], ADDMN(v2[i], MULMN(v3[i], zj)));
+  auto missval1 = mv;
+  auto missval2 = mv;
+  for (size_t i = 0; i < n; ++i) v4[i] = SUBMN(v1[i], ADDMN(v2[i], MULMN(v3[i], zj)));
 }
 
 static void
@@ -66,13 +64,13 @@ sub_trend(double zj, const Field &field1, const Field &field2, const Field &fiel
 static void
 trendarithGetParameter(bool &tstepIsEqual)
 {
-  const auto pargc = cdo_operator_argc();
+  auto pargc = cdo_operator_argc();
   if (pargc)
     {
       const auto &pargv = cdo_get_oper_argv();
 
       KVList kvlist;
-      kvlist.name = "TREND";
+      kvlist.name = cdo_module_name();
       if (kvlist.parse_arguments(pargc, pargv) != 0) cdo_abort("Parse error!");
       if (Options::cdoVerbose) kvlist.print();
 
@@ -99,26 +97,26 @@ Trendarith(void *process)
   cdo_operator_add("addtrend", FieldFunc_Add, 0, nullptr);
   cdo_operator_add("subtrend", FieldFunc_Sub, 0, nullptr);
 
-  const auto operatorID = cdo_operator_id();
-  const auto operfunc = cdo_operator_f1(operatorID);
+  auto operatorID = cdo_operator_id();
+  auto operfunc = cdo_operator_f1(operatorID);
 
   auto tstepIsEqual = true;
   trendarithGetParameter(tstepIsEqual);
 
-  const auto streamID1 = cdo_open_read(0);
-  const auto streamID2 = cdo_open_read(1);
-  const auto streamID3 = cdo_open_read(2);
+  auto streamID1 = cdo_open_read(0);
+  auto streamID2 = cdo_open_read(1);
+  auto streamID3 = cdo_open_read(2);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = cdo_stream_inq_vlist(streamID2);
-  const auto vlistID3 = cdo_stream_inq_vlist(streamID3);
-  const auto vlistID4 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = cdo_stream_inq_vlist(streamID2);
+  auto vlistID3 = cdo_stream_inq_vlist(streamID3);
+  auto vlistID4 = vlistDuplicate(vlistID1);
 
   vlist_compare(vlistID1, vlistID2, CMP_DIM);
   vlist_compare(vlistID1, vlistID3, CMP_DIM);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID4 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID4 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID4, taxisID4);
 
   VarList varList;
@@ -126,7 +124,7 @@ Trendarith(void *process)
 
   Field field1, field4;
 
-  const auto streamID4 = cdo_open_write(3);
+  auto streamID4 = cdo_open_write(3);
   cdo_def_vlist(streamID4, vlistID4);
 
   FieldVector2D vars2, vars3;
@@ -134,7 +132,7 @@ Trendarith(void *process)
   fields_from_vlist(vlistID1, vars3, FIELD_VEC);
 
   {
-    const auto nrecs = cdo_stream_inq_timestep(streamID2, 0);
+    auto nrecs = cdo_stream_inq_timestep(streamID2, 0);
     for (int recID = 0; recID < nrecs; ++recID)
       {
         int varID, levelID;
@@ -144,7 +142,7 @@ Trendarith(void *process)
   }
 
   {
-    const auto nrecs = cdo_stream_inq_timestep(streamID3, 0);
+    auto nrecs = cdo_stream_inq_timestep(streamID3, 0);
     for (int recID = 0; recID < nrecs; ++recID)
       {
         int varID, levelID;
@@ -153,7 +151,7 @@ Trendarith(void *process)
       }
   }
 
-  const auto calendar = taxisInqCalendar(taxisID1);
+  auto calendar = taxisInqCalendar(taxisID1);
 
   CheckTimeIncr checkTimeIncr;
   JulianDate julianDate0;
@@ -161,13 +159,13 @@ Trendarith(void *process)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      const auto vDateTime = taxisInqVdatetime(taxisID1);
+      auto vDateTime = taxisInqVdatetime(taxisID1);
 
       if (tstepIsEqual) check_time_increment(tsID, calendar, vDateTime, checkTimeIncr);
-      const auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
+      auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
 
       cdo_taxis_copy_timestep(taxisID4, taxisID1);
       cdo_def_timestep(streamID4, tsID);
