@@ -39,7 +39,7 @@ tstepcount(long nts, T missval, const Varray<T> &v, T refval)
 void *
 Tstepcount(void *process)
 {
-  CdiDateTime vDateTime = { };
+  CdiDateTime vDateTime{};
 
   cdo_initialize(process);
 
