@@ -22,8 +22,8 @@
 static void
 add_vars_mv(size_t gridsize, double missval, const Varray<double> &var1, const Varray<double> &var2, Varray<double> &var3)
 {
-  const auto missval1 = missval;
-  const auto missval2 = missval;
+  auto missval1 = missval;
+  auto missval2 = missval;
   // for ( size_t i = 0; i < gridsize; ++i ) var3[i] = ADDMN(var2[i], var1[i]);
   for (size_t i = 0; i < gridsize; ++i)
     {
@@ -50,14 +50,14 @@ Vertcum(void *process)
   int VERTCUMHL = cdo_operator_add("vertcumhl",  0,  0, nullptr);
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
+  auto operatorID = cdo_operator_id();
 
   operator_check_argc(0);
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
   int zaxisIDhl = -1;
 
@@ -65,11 +65,11 @@ Vertcum(void *process)
     {
       std::vector<double> vct;
       bool lhybrid = false;
-      const auto nzaxis = vlistNzaxis(vlistID1);
+      auto nzaxis = vlistNzaxis(vlistID1);
       for (int i = 0; i < nzaxis; ++i)
         {
-          const auto zaxisID = vlistZaxis(vlistID1, i);
-          const auto nlevs = zaxisInqSize(zaxisID);
+          auto zaxisID = vlistZaxis(vlistID1, i);
+          auto nlevs = zaxisInqSize(zaxisID);
 
           if (zaxisInqType(zaxisID) == ZAXIS_HYBRID && nlevs > 1)
             {
@@ -105,15 +105,15 @@ Vertcum(void *process)
   varListInit(varList1, vlistID1);
   varListInit(varList2, vlistID2);
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
   std::vector<std::vector<size_t>> varnmiss(nvars);
   Varray3D<double> vardata1(nvars), vardata2(nvars);
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto gridsize = varList1[varID].gridsize;
-      const auto nlevs = varList1[varID].nlevels;
-      const auto nlevs2 = varList2[varID].nlevels;
+      auto gridsize = varList1[varID].gridsize;
+      auto nlevs = varList1[varID].nlevels;
+      auto nlevs2 = varList2[varID].nlevels;
 
       varnmiss[varID].resize(nlevs);
       vardata1[varID].resize(nlevs);
@@ -122,17 +122,17 @@ Vertcum(void *process)
       for (int levelID = 0; levelID < nlevs2; ++levelID) vardata2[varID][levelID].resize(gridsize);
     }
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -147,9 +147,9 @@ Vertcum(void *process)
 
       for (int varID = 0; varID < nvars; ++varID)
         {
-          const auto missval = varList2[varID].missval;
-          const auto gridsize = varList2[varID].gridsize;
-          const auto nlevs2 = varList2[varID].nlevels;
+          auto missval = varList2[varID].missval;
+          auto gridsize = varList2[varID].gridsize;
+          auto nlevs2 = varList2[varID].nlevels;
 
           if (operatorID == VERTCUMHL && nlevs2 == nlevshl)
             {
@@ -188,13 +188,13 @@ Vertcum(void *process)
 
       for (int varID = 0; varID < nvars; ++varID)
         {
-          const auto missval = varList2[varID].missval;
-          const auto gridsize = varList2[varID].gridsize;
-          const auto nlevs2 = varList2[varID].nlevels;
+          auto missval = varList2[varID].missval;
+          auto gridsize = varList2[varID].gridsize;
+          auto nlevs2 = varList2[varID].nlevels;
           for (int levelID = 0; levelID < nlevs2; ++levelID)
             {
               auto &single = vardata2[varID][levelID];
-              const auto nmiss = varray_num_mv(gridsize, single, missval);
+              auto nmiss = varray_num_mv(gridsize, single, missval);
               cdo_def_record(streamID2, varID, levelID);
               cdo_write_record(streamID2, single.data(), nmiss);
             }
