@@ -22,11 +22,10 @@
 #include "param_conversion.h"
 #include "vertint_util.h"
 
-
 static void
 check_range_ps(int stepNum, const Field &psProg)
 {
-  const auto mm = field_min_max(psProg);
+  auto mm = field_min_max(psProg);
   if (mm.min < MIN_PS || mm.max > MAX_PS)
     cdo_warning("Surface pressure out of range (min=%g max=%g) [timestep:%d]!", mm.min, mm.max, stepNum);
 }
@@ -37,13 +36,10 @@ is_height_axis(int zaxisID)
   auto isHeight = false;
   if (zaxisInqType(zaxisID) == ZAXIS_REFERENCE)
     {
-      char units[CDI_MAX_NAME], stdname[CDI_MAX_NAME];
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS, units, &length);
-      length = CDI_MAX_NAME;
-      cdiInqKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_STDNAME, stdname, &length);
-      //if (cdo_cmpstr(stdname, "height") && *units == 0) isHeight = true;
-      if (cdo_cmpstr(stdname, "height")) isHeight = true;
+      // auto units = cdo::inq_key_string(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS);
+      auto stdname = cdo::inq_key_string(zaxisID, CDI_GLOBAL, CDI_KEY_STDNAME);
+      // if (stdname == "height" && units.empty()) isHeight = true;
+      if (stdname == "height") isHeight = true;
     }
   return isHeight;
 }
@@ -51,11 +47,11 @@ is_height_axis(int zaxisID)
 static void
 change_height_zaxis(int nhlev, int vlistID1, int vlistID2, int zaxisID2)
 {
-  const auto nzaxis = vlistNzaxis(vlistID1);
+  auto nzaxis = vlistNzaxis(vlistID1);
   for (int iz = 0; iz < nzaxis; ++iz)
     {
-      const auto zaxisID = vlistZaxis(vlistID1, iz);
-      const auto nlevel = zaxisInqSize(zaxisID);
+      auto zaxisID = vlistZaxis(vlistID1, iz);
+      auto nlevel = zaxisInqSize(zaxisID);
       if ((nlevel == nhlev || nlevel == (nhlev + 1)) && is_height_axis(zaxisID)) vlistChangeZaxisIndex(vlistID2, iz, zaxisID2);
     }
 }
@@ -70,8 +66,8 @@ calc_half_press(size_t gridsize, size_t nhlevf, const Varray<T> &fullPress, size
 #endif
   for (size_t k = 1; k < nhlevf; ++k)
     {
-      const auto fullPress_km1 = &fullPress[(k - 1) * gridsize];
-      const auto fullPress_k = &fullPress[k * gridsize];
+      auto fullPress_km1 = &fullPress[(k - 1) * gridsize];
+      auto fullPress_k = &fullPress[k * gridsize];
       auto halfPress_k = &halfPress[k * gridsize];
       for (size_t i = 0; i < gridsize; ++i) halfPress_k[i] = 0.5 * (fullPress_km1[i] + fullPress_k[i]);
     }
@@ -98,19 +94,18 @@ Vertintap(void *process)
   int nhlev = 0, nhlevf = 0, nhlevh = 0;
   int apressID = -1, dpressID = -1;
   int psID = -1;
-  char stdname[CDI_MAX_NAME];
 
   cdo_initialize(process);
 
   // clang-format off
-                         cdo_operator_add("ap2pl",     func_pl, 0, "pressure levels in pascal");
-  const auto AP2PLX    = cdo_operator_add("ap2plx",    func_pl, 0, "pressure levels in pascal");
-                         cdo_operator_add("ap2hl",     func_hl, 0, "height levels in meter");
-  const auto AP2HLX    = cdo_operator_add("ap2hlx",    func_hl, 0, "height levels in meter");
+                   cdo_operator_add("ap2pl",     func_pl, 0, "pressure levels in pascal");
+  auto AP2PLX    = cdo_operator_add("ap2plx",    func_pl, 0, "pressure levels in pascal");
+                   cdo_operator_add("ap2hl",     func_hl, 0, "height levels in meter");
+  auto AP2HLX    = cdo_operator_add("ap2hlx",    func_hl, 0, "height levels in meter");
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
-  const auto useHeightLevel = (cdo_operator_f1(operatorID) == func_hl);
+  auto operatorID = cdo_operator_id();
+  auto useHeightLevel = (cdo_operator_f1(operatorID) == func_hl);
 
   auto extrapolate = (operatorID == AP2PLX || operatorID == AP2HLX);
   if (extrapolate == false) extrapolate = getenv_extrapolate();
@@ -126,45 +121,40 @@ Vertintap(void *process)
         plev
             = { 100000, 92500, 85000, 70000, 60000, 50000, 40000, 30000, 25000, 20000, 15000, 10000, 7000, 5000, 3000, 2000, 1000 };
     }
-  else
-    {
-      plev = cdo_argv_to_flt(cdo_get_oper_argv());
-    }
+  else { plev = cdo_argv_to_flt(cdo_get_oper_argv()); }
 
   int nplev = plev.size();
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto gridsize = vlist_check_gridsize(vlistID1);
+  auto gridsize = vlist_check_gridsize(vlistID1);
 
-  const auto zaxistype = useHeightLevel ? ZAXIS_HEIGHT : ZAXIS_PRESSURE;
-  const auto zaxisIDp = zaxisCreate(zaxistype, nplev);
+  auto zaxistype = useHeightLevel ? ZAXIS_HEIGHT : ZAXIS_PRESSURE;
+  auto zaxisIDp = zaxisCreate(zaxistype, nplev);
   zaxisDefLevels(zaxisIDp, plev.data());
 
   VarList varList1;
   varListInit(varList1, vlistID1);
   varListSetUniqueMemtype(varList1);
-  const auto memtype = varList1[0].memType;
+  auto memtype = varList1[0].memType;
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(vlistID1, varID, CDI_KEY_STDNAME, stdname, &length);
-      cstr_to_lower_case(stdname);
+      auto stdname = string_to_lower(cdo::inq_key_string(vlistID1, varID, CDI_KEY_STDNAME));
 
       // clang-format off
-      if      (cdo_cmpstr(stdname, var_stdname(surface_air_pressure))) psID = varID;
-      else if (cdo_cmpstr(stdname, var_stdname(air_pressure)))         apressID = varID;
-      else if (cdo_cmpstr(stdname, var_stdname(pressure_thickness)))   dpressID = varID;
+      if      (stdname == var_stdname(surface_air_pressure)) psID = varID;
+      else if (stdname == var_stdname(air_pressure))         apressID = varID;
+      else if (stdname == var_stdname(pressure_thickness))   dpressID = varID;
       // clang-format on
     }
 
@@ -181,14 +171,14 @@ Vertintap(void *process)
   if (apressID == -1) cdo_abort("%s not found!", var_stdname(air_pressure));
 
   int zaxisIDh = -1;
-  const auto nzaxis = vlistNzaxis(vlistID1);
+  auto nzaxis = vlistNzaxis(vlistID1);
   for (int i = 0; i < nzaxis; ++i)
     {
-      const auto zaxisID = vlistZaxis(vlistID1, i);
+      auto zaxisID = vlistZaxis(vlistID1, i);
       if (zaxisID == varList1[apressID].zaxisID)
         {
           auto mono_level = true;
-          const auto nlevels = zaxisInqSize(zaxisID);
+          auto nlevels = zaxisInqSize(zaxisID);
 
           if (nlevels > 1 && is_height_axis(zaxisID))
             {
@@ -220,11 +210,11 @@ Vertintap(void *process)
   varListInit(varList2, vlistID2);
   varListSetMemtype(varList2, memtype);
 
-  std::vector<bool> vars(nvars), varinterp(nvars);
+  std::vector<bool> processVars(nvars), interpVars(nvars);
   Varray2D<size_t> varnmiss(nvars);
   Field3DVector vardata1(nvars), vardata2(nvars);
 
-  const auto maxlev = (nhlevh > nplev) ? nhlevh : nplev;
+  auto maxlev = (nhlevh > nplev) ? nhlevh : nplev;
 
   Varray<size_t> pnmiss;
   if (!extrapolate) pnmiss.resize(nplev);
@@ -232,7 +222,7 @@ Vertintap(void *process)
   // check levels
   if (zaxisIDh != -1)
     {
-      const auto nlev = zaxisInqSize(zaxisIDh);
+      auto nlev = zaxisInqSize(zaxisIDh);
       if (nlev != nhlev) cdo_abort("Internal error, wrong number of height level!");
     }
 
@@ -257,7 +247,8 @@ Vertintap(void *process)
   else
     {
       cdo_warning("No 3D variable with generalized height levels found!");
-      cdo_print("Generalized height levels are defined by the attributes: standard_name=\"height\" and long_name=\"generalized height\"");
+      cdo_print(
+          "Generalized height levels are defined by the attributes: standard_name=\"height\" and long_name=\"generalized height\"");
     }
 
   if (useHeightLevel)
@@ -273,29 +264,28 @@ Vertintap(void *process)
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto gridID = varList1[varID].gridID;
-      const auto zaxisID = varList1[varID].zaxisID;
-      const auto nlevels = varList1[varID].nlevels;
+      const auto &var = varList1[varID];
+      auto isHeightAxis = is_height_axis(var.zaxisID);
 
-      if (gridInqType(gridID) == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
+      if (gridInqType(var.gridID) == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
 
-      vardata1[varID].init(varList1[varID]);
+      vardata1[varID].init(var);
 
-      varinterp[varID]
-          = (zaxisID == zaxisIDh || (is_height_axis(zaxisID) && zaxisIDh != -1 && (nlevels == nhlevh || nlevels == nhlevf)));
+      interpVars[varID]
+          = (var.zaxisID == zaxisIDh || (isHeightAxis && zaxisIDh != -1 && (var.nlevels == nhlevh || var.nlevels == nhlevf)));
 
-      if (varinterp[varID])
+      if (interpVars[varID])
         {
           varnmiss[varID].resize(maxlev, 0);
           vardata2[varID].init(varList2[varID]);
         }
       else
         {
-          if (is_height_axis(zaxisID) && zaxisIDh != -1 && nlevels > 1)
-            cdo_warning("Parameter %d has wrong number of levels, skipped! (name=%s nlevel=%d)", varID + 1, varList1[varID].name,
-                        nlevels);
+          if (isHeightAxis && zaxisIDh != -1 && var.nlevels > 1)
+            cdo_warning("Parameter %d has wrong number of levels, skipped! (name=%s nlevel=%d)", varID + 1, var.name,
+                        var.nlevels);
 
-          varnmiss[varID].resize(nlevels);
+          varnmiss[varID].resize(var.nlevels);
         }
     }
 
@@ -309,24 +299,24 @@ Vertintap(void *process)
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      if (varinterp[varID] && varList1[varID].timetype == TIME_CONSTANT) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
+      if (interpVars[varID] && varList1[varID].isConstant) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
     }
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
 
   cdo_def_vlist(streamID2, vlistID2);
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       for (int varID = 0; varID < nvars; ++varID)
         {
-          vars[varID] = false;
-          const auto nlevels = varList1[varID].nlevels;
-          for (int levelID = 0; levelID < nlevels; ++levelID) varnmiss[varID][levelID] = 0;
+          processVars[varID] = false;
+          const auto &var = varList1[varID];
+          for (int levelID = 0; levelID < var.nlevels; ++levelID) varnmiss[varID][levelID] = 0;
         }
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -337,11 +327,11 @@ Vertintap(void *process)
           int varID, levelID;
           cdo_inq_record(streamID1, &varID, &levelID);
           cdo_read_record(streamID1, vardata1[varID], levelID, &varnmiss[varID][levelID]);
-          vars[varID] = true;
+          processVars[varID] = true;
         }
 
       for (int varID = 0; varID < nvars; ++varID)
-        if (varinterp[varID]) vars[varID] = true;
+        if (interpVars[varID]) processVars[varID] = true;
 
       if (zaxisIDh != -1)
         {
@@ -378,22 +368,23 @@ Vertintap(void *process)
 
       for (int varID = 0; varID < nvars; ++varID)
         {
-          if (vars[varID])
+          if (processVars[varID])
             {
-              if (tsID > 0 && !varinterp[varID] && varList1[varID].timetype == TIME_CONSTANT) continue;
+              const auto &var = varList1[varID];
 
-              if (varinterp[varID])
+              if (tsID > 0 && !interpVars[varID] && var.isConstant) continue;
+
+              if (interpVars[varID])
                 {
-                  const auto nlevels = varList1[varID].nlevels;
-                  if (nlevels != nhlevf && nlevels != nhlevh)
-                    cdo_abort("Number of generalized height level differ from full/half level (param=%s)!", varList1[varID].name);
+                  if (var.nlevels != nhlevf && var.nlevels != nhlevh)
+                    cdo_abort("Number of generalized height level differ from full/half level (param=%s)!", var.name);
 
-                  for (int levelID = 0; levelID < nlevels; ++levelID)
+                  for (int levelID = 0; levelID < var.nlevels; ++levelID)
                     {
                       if (varnmiss[varID][levelID]) cdo_abort("Missing values unsupported for this operator!");
                     }
 
-                  const auto &levels3D = (nlevels == nhlevf) ? fullPress : halfPress;
+                  const auto &levels3D = (var.nlevels == nhlevf) ? fullPress : halfPress;
                   // vertIndex on half levels missing; do we need halfPress???
                   vertical_interp_X(levels3D, vardata1[varID], vardata2[varID], vertIndex, plev, gridsize);
 
@@ -403,7 +394,7 @@ Vertintap(void *process)
               for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
                 {
                   cdo_def_record(streamID2, varID, levelID);
-                  cdo_write_record(streamID2, varinterp[varID] ? vardata2[varID] : vardata1[varID], levelID,
+                  cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
                                    varnmiss[varID][levelID]);
                 }
             }
