@@ -25,20 +25,18 @@
 #include "param_conversion.h"
 #include "vertint_util.h"
 
-
 static void
 field_copy_div_2d_to_3d(MemType memType, size_t gridsize, int nlevels, const Field &field2d, Field3D &field3d)
 {
   if (memType == MemType::Float)
-    for (size_t i = 0; i < gridsize; ++i)
-      field3d.vec_f[gridsize * nlevels + i] = field2d.vec_f[i] / PlanetGrav;
+    for (size_t i = 0; i < gridsize; ++i) field3d.vec_f[gridsize * nlevels + i] = field2d.vec_f[i] / PlanetGrav;
   else
-    for (size_t i = 0; i < gridsize; ++i)
-      field3d.vec_d[gridsize * nlevels + i] = field2d.vec_d[i] / PlanetGrav;
+    for (size_t i = 0; i < gridsize; ++i) field3d.vec_d[gridsize * nlevels + i] = field2d.vec_d[i] / PlanetGrav;
 }
 
 static void
-vct_to_hybrid_pressure(MemType memType, Field3D &pressure_FL, Field3D &pressure_HL, const double *vct, const Field &ps, long numHybridLevels, long ngp)
+vct_to_hybrid_pressure(MemType memType, Field3D &pressure_FL, Field3D &pressure_HL, const double *vct, const Field &ps,
+                       long numHybridLevels, long ngp)
 {
   if (memType == MemType::Float)
     vct_to_hybrid_pressure(pressure_FL.vec_f.data(), pressure_HL.vec_f.data(), vct, ps.vec_f.data(), numHybridLevels, ngp);
@@ -50,7 +48,7 @@ static void
 invert_vct(Varray<double> &vct)
 {
   Varray<double> vctbuf = vct;
-  const auto vctSize = vct.size();
+  auto vctSize = vct.size();
   for (size_t i = 0; i < vctSize / 2; ++i)
     {
       vct[vctSize / 2 - 1 - i] = vctbuf[i];
@@ -61,14 +59,14 @@ invert_vct(Varray<double> &vct)
 static void
 check_vct(const Varray<double> &vct, int numHalfLevels)
 {
-  const auto sum = varray_sum(2 * numHalfLevels, vct);
+  auto sum = varray_sum(2 * numHalfLevels, vct);
   if (!(sum > 0.0)) cdo_warning("VCT is empty!");
 }
 
 static void
 check_range_ps(int stepNum, const Field &psProg)
 {
-  const auto mm = field_min_max(psProg);
+  auto mm = field_min_max(psProg);
   if (mm.min < MIN_PS || mm.max > MAX_PS)
     cdo_warning("Surface pressure out of range (min=%g max=%g) [timestep:%d]!", mm.min, mm.max, stepNum);
 }
@@ -76,7 +74,7 @@ check_range_ps(int stepNum, const Field &psProg)
 static void
 check_range_sgeopot(int stepNum, const Field &sgeopot)
 {
-  const auto mm = field_min_max(sgeopot);
+  auto mm = field_min_max(sgeopot);
   if (mm.min < MIN_FIS || mm.max > MAX_FIS)
     cdo_warning("Surface geopotential out of range (min=%g max=%g) [timestep:%d]!", mm.min, mm.max, stepNum);
   if (sgeopot.gridsize > 1 && mm.min >= 0.0 && mm.max <= 9000.0 && IS_NOT_EQUAL(mm.min, mm.max))
@@ -84,7 +82,7 @@ check_range_sgeopot(int stepNum, const Field &sgeopot)
 }
 
 static bool
-zaxis_is_hybrid(const int zaxistype)
+zaxis_is_hybrid(int zaxistype)
 {
   return (zaxistype == ZAXIS_HYBRID || zaxistype == ZAXIS_HYBRID_HALF);
 }
@@ -92,16 +90,16 @@ zaxis_is_hybrid(const int zaxistype)
 static void
 change_hybrid_zaxis(int vlistID1, int vlistID2, int vctSize, double *vct, int zaxisID2, int numFullLevels, int numHalfLevels)
 {
-  const auto nzaxis = vlistNzaxis(vlistID1);
+  auto nzaxis = vlistNzaxis(vlistID1);
   for (int iz = 0; iz < nzaxis; ++iz)
     {
-      const auto zaxisID = vlistZaxis(vlistID1, iz);
-      const auto nlevels = zaxisInqSize(zaxisID);
-      const auto zaxistype = zaxisInqType(zaxisID);
+      auto zaxisID = vlistZaxis(vlistID1, iz);
+      auto nlevels = zaxisInqSize(zaxisID);
+      auto zaxistype = zaxisInqType(zaxisID);
 
       if (zaxis_is_hybrid(zaxistype) && (nlevels == numHalfLevels || nlevels == numFullLevels))
         {
-          const auto vctSize2 = zaxisInqVctSize(zaxisID);
+          auto vctSize2 = zaxisInqVctSize(zaxisID);
           if (vctSize2 == vctSize && memcmp(vct, zaxisInqVctPtr(zaxisID), vctSize * sizeof(double)) == 0)
             vlistChangeZaxisIndex(vlistID2, iz, zaxisID2);
         }
@@ -113,24 +111,24 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
 {
   int numPL = pressureLevels.size();
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto gridsize = vlist_check_gridsize(vlistID1);
+  auto gridsize = vlist_check_gridsize(vlistID1);
 
-  const auto zaxisID_PL = zaxisCreate(useHeightLevel ? ZAXIS_HEIGHT : ZAXIS_PRESSURE, numPL);
+  auto zaxisID_PL = zaxisCreate(useHeightLevel ? ZAXIS_ALTITUDE : ZAXIS_PRESSURE, numPL);
   zaxisDefLevels(zaxisID_PL, pressureLevels.data());
 
   int zaxisID_ML = -1;
   int numHybridLevels = 0, numFullLevels = 0, numHalfLevels = 0;
   auto vct = vlist_read_vct(vlistID1, zaxisID_ML, numHybridLevels, numFullLevels, numHalfLevels);
-  const int vctSize = vct.size();
+  int vctSize = vct.size();
 
   // check VCT
   if (zaxisID_ML != -1) check_vct(vct, numHalfLevels);
@@ -156,19 +154,19 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
   VarList varList1;
   varListInit(varList1, vlistID1);
   varListSetUniqueMemtype(varList1);
-  const auto memType = varList1[0].memType;
+  auto memType = varList1[0].memType;
 
   VarList varList2;
   varListInit(varList2, vlistID2);
   varListSetMemtype(varList2, memType);
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
-  std::vector<bool> vars(nvars), varinterp(nvars);
+  std::vector<bool> processVars(nvars), interpVars(nvars);
   Varray2D<size_t> varnmiss(nvars);
   Field3DVector vardata1(nvars), vardata2(nvars);
 
-  const auto maxLevels = std::max(numHalfLevels, numPL);
+  auto maxLevels = std::max(numHalfLevels, numPL);
 
   Varray<size_t> pnmiss;
   if (!extrapolate) pnmiss.resize(numPL);
@@ -176,7 +174,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
   // check levels
   if (zaxisID_ML != -1)
     {
-      const auto nlev = zaxisInqSize(zaxisID_ML);
+      auto nlev = zaxisInqSize(zaxisID_ML);
       if (nlev != numHybridLevels) cdo_abort("Internal error, wrong number of hybrid level!");
     }
 
@@ -229,25 +227,27 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto gridID = varList1[varID].gridID;
-      const auto zaxisID = varList1[varID].zaxisID;
-      const auto zaxistype = zaxisInqType(zaxisID);
-      const auto nlevels = varList1[varID].nlevels;
+      auto &var1 = varList1[varID];
+      auto gridID = var1.gridID;
+      auto zaxisID = var1.zaxisID;
+      auto zaxistype = zaxisInqType(zaxisID);
+      auto nlevels = var1.nlevels;
 
       if (gridInqType(gridID) == GRID_SPECTRAL && zaxis_is_hybrid(zaxistype))
         cdo_abort("Spectral data on model level unsupported!");
 
       if (gridInqType(gridID) == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
 
-      if (varID == varIDs.gheightID) varList1[varID].nlevels = nlevels + 1;
-      vardata1[varID].init(varList1[varID]);
-      if (varID == varIDs.gheightID) varList1[varID].nlevels = nlevels;
+      if (varID == varIDs.gheightID) var1.nlevels = nlevels + 1;
+      vardata1[varID].init(var1);
+      if (varID == varIDs.gheightID) var1.nlevels = nlevels;
 
-      // varinterp[varID] = (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && nlevels == numHybridLevels);
-      varinterp[varID]
-          = (zaxisID == zaxisID_ML || (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && (nlevels == numHalfLevels || nlevels == numFullLevels)));
+      // interpVars[varID] = (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && nlevels == numHybridLevels);
+      interpVars[varID]
+          = (zaxisID == zaxisID_ML
+             || (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && (nlevels == numHalfLevels || nlevels == numFullLevels)));
 
-      if (varinterp[varID])
+      if (interpVars[varID])
         {
           varnmiss[varID].resize(maxLevels, 0);
           vardata2[varID].init(varList2[varID]);
@@ -256,8 +256,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
         {
           varnmiss[varID].resize(nlevels);
           if (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && nlevels > 1)
-            cdo_warning("Parameter %d has wrong number of levels, skipped! (param=%s nlevel=%d)", varID + 1, varList1[varID].name,
-                        nlevels);
+            cdo_warning("Parameter %d has wrong number of levels, skipped! (param=%s nlevel=%d)", varID + 1, var1.name, nlevels);
         }
     }
 
@@ -273,7 +272,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
       presID = varIDs.psID;
     }
 
-  if (Options::cdoVerbose)
+  if (Options::cdoVerbose && presID != -1)
     {
       if (presID == varIDs.lnpsID)
         cdo_print("Using LOG(%s) from %s", var_stdname(surface_air_pressure), varList1[presID].name);
@@ -282,9 +281,9 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
     }
 
   Field psProg;
-  psProg.init(varList1[presID]);
+  if (zaxisID_ML != -1 && presID != -1) psProg.init(varList1[presID]);
 
-  const auto sgeopotNeeded = (varIDs.tempID != -1 || varIDs.gheightID != -1);
+  auto sgeopotNeeded = (varIDs.tempID != -1 || varIDs.gheightID != -1);
 
   Field sgeopot;
   if (zaxisID_ML != -1 && sgeopotNeeded)
@@ -303,16 +302,16 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
         }
     }
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      for (int varID = 0; varID < nvars; ++varID) vars[varID] = false;
+      for (int varID = 0; varID < nvars; ++varID) processVars[varID] = false;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
@@ -321,14 +320,13 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
         {
           int varID, levelID;
           cdo_inq_record(streamID1, &varID, &levelID);
+          const auto &var = varList1[varID];
 
-          const auto zaxisID = varList1[varID].zaxisID;
-          const auto nlevels = varList1[varID].nlevels;
-          if (vctIsInverted && zaxisID_ML != -1 && zaxisID == zaxisID_ML) levelID = nlevels - 1 - levelID;
+          if (vctIsInverted && zaxisID_ML != -1 && var.zaxisID == zaxisID_ML) levelID = var.nlevels - 1 - levelID;
 
           cdo_read_record(streamID1, vardata1[varID], levelID, &varnmiss[varID][levelID]);
 
-          vars[varID] = true;
+          processVars[varID] = true;
         }
 
       if (zaxisID_ML != -1)
@@ -361,15 +359,17 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
 
       for (int varID = 0; varID < nvars; ++varID)
         {
-          if (vars[varID])
+          if (processVars[varID])
             {
-              if (tsID > 0 && varList1[varID].timetype == TIME_CONSTANT) continue;
+              const auto &var = varList1[varID];
 
-              if (varinterp[varID])
+              if (tsID > 0 && var.isConstant) continue;
+
+              if (interpVars[varID])
                 {
-                  const auto nlevels = varList1[varID].nlevels;
+                  auto nlevels = var.nlevels;
                   if (nlevels != numFullLevels && nlevels != numHalfLevels)
-                    cdo_abort("Number of hybrid level differ from full/half level (param=%s)!", varList1[varID].name);
+                    cdo_abort("Number of hybrid level differ from full/half level (param=%s)!", var.name);
 
                   for (int levelID = 0; levelID < nlevels; ++levelID)
                     {
@@ -380,15 +380,15 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
                     {
                       if (nlevels == numHalfLevels) cdo_abort("Temperature on half level unsupported!");
 
-                      vertical_interp_T(nlevels, pressure_FL, pressure_HL, vardata1[varID], vardata2[varID], sgeopot, vertIndex, pressureLevels,
-                                        gridsize);
+                      vertical_interp_T(nlevels, pressure_FL, pressure_HL, vardata1[varID], vardata2[varID], sgeopot, vertIndex,
+                                        pressureLevels, gridsize);
                     }
                   else if (varID == varIDs.gheightID)
                     {
                       field_copy_div_2d_to_3d(memType, gridsize, nlevels, sgeopot, vardata1[varID]);
 
-                      vertical_interp_Z(nlevels, pressure_FL, pressure_HL, vardata1[varID], vardata2[varID], vardata1[varIDs.tempID], sgeopot,
-                                        vertIndex, pressureLevels, gridsize);
+                      vertical_interp_Z(nlevels, pressure_FL, pressure_HL, vardata1[varID], vardata2[varID],
+                                        vardata1[varIDs.tempID], sgeopot, vertIndex, pressureLevels, gridsize);
                     }
                   else
                     {
@@ -402,7 +402,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
               for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
                 {
                   cdo_def_record(streamID2, varID, levelID);
-                  cdo_write_record(streamID2, varinterp[varID] ? vardata2[varID] : vardata1[varID], levelID,
+                  cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
                                    varnmiss[varID][levelID]);
                 }
             }
@@ -420,35 +420,34 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
 {
   int numHL = heightLevels.size();
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  const auto vlistID2 = vlistDuplicate(vlistID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto gridsize = vlist_check_gridsize(vlistID1);
+  auto gridsize = vlist_check_gridsize(vlistID1);
 
-  const auto zaxisID_HL = zaxisCreate(ZAXIS_HEIGHT, numHL);
+  auto zaxisID_HL = zaxisCreate(ZAXIS_HEIGHT, numHL);
   zaxisDefLevels(zaxisID_HL, heightLevels.data());
 
   int zaxisID_ML = -1;
   int numHybridLevels = 0, numFullLevels = 0, numHalfLevels = 0;
   auto vct = vlist_read_vct(vlistID1, zaxisID_ML, numHybridLevels, numFullLevels, numHalfLevels);
-  const int vctSize = vct.size();
+  int vctSize = vct.size();
 
   // check VCT
   if (zaxisID_ML != -1) check_vct(vct, numHalfLevels);
 
   change_hybrid_zaxis(vlistID1, vlistID2, vctSize, vct.data(), zaxisID_HL, numFullLevels, numHalfLevels);
 
-  int psvarID = -1;
   auto vctIsInverted = false;
   if (vctSize && vctSize % 2 == 0)
     {
-      psvarID = vlist_get_psvarid(vlistID1, zaxisID_ML);
+      (void) vlist_get_psvarid(vlistID1, zaxisID_ML);
 
       int i;
       for (i = vctSize / 2 + 1; i < vctSize; ++i)
@@ -463,19 +462,19 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
   VarList varList1;
   varListInit(varList1, vlistID1);
   varListSetUniqueMemtype(varList1);
-  const auto memType = varList1[0].memType;
+  auto memType = varList1[0].memType;
 
   VarList varList2;
   varListInit(varList2, vlistID2);
   varListSetMemtype(varList2, memType);
 
-  const auto nvars = vlistNvars(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
 
-  std::vector<bool> vars(nvars), varinterp(nvars);
+  std::vector<bool> processVars(nvars), interpVars(nvars);
   Varray2D<size_t> varnmiss(nvars);
   Field3DVector vardata1(nvars), vardata2(nvars);
 
-  const auto maxLevels = std::max(numHalfLevels, numHL);
+  auto maxLevels = std::max(numHalfLevels, numHL);
 
   Varray<size_t> pnmiss;
   if (!extrapolate) pnmiss.resize(numHL);
@@ -483,7 +482,7 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
   // check levels
   if (zaxisID_ML != -1)
     {
-      const auto nlev = zaxisInqSize(zaxisID_ML);
+      auto nlev = zaxisInqSize(zaxisID_ML);
       if (nlev != numHybridLevels) cdo_abort("Internal error, wrong number of hybrid level!");
     }
 
@@ -525,23 +524,25 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto gridID = varList1[varID].gridID;
-      const auto zaxisID = varList1[varID].zaxisID;
-      const auto zaxistype = zaxisInqType(zaxisID);
-      const auto nlevels = varList1[varID].nlevels;
+      auto &var1 = varList1[varID];
+      auto gridID = var1.gridID;
+      auto zaxisID = var1.zaxisID;
+      auto zaxistype = zaxisInqType(zaxisID);
+      auto nlevels = var1.nlevels;
 
       if (gridInqType(gridID) == GRID_SPECTRAL && zaxis_is_hybrid(zaxistype))
         cdo_abort("Spectral data on model level unsupported!");
 
       if (gridInqType(gridID) == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
 
-      vardata1[varID].init(varList1[varID]);
+      vardata1[varID].init(var1);
 
-      // varinterp[varID] = (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && nlevels == numHybridLevels);
-      varinterp[varID]
-          = (zaxisID == zaxisID_ML || (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && (nlevels == numHalfLevels || nlevels == numFullLevels)));
+      // interpVars[varID] = (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && nlevels == numHybridLevels);
+      interpVars[varID]
+          = (zaxisID == zaxisID_ML
+             || (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && (nlevels == numHalfLevels || nlevels == numFullLevels)));
 
-      if (varinterp[varID])
+      if (interpVars[varID])
         {
           varnmiss[varID].resize(maxLevels, 0);
           vardata2[varID].init(varList2[varID]);
@@ -550,15 +551,13 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
         {
           varnmiss[varID].resize(nlevels);
           if (zaxis_is_hybrid(zaxistype) && zaxisID_ML != -1 && nlevels > 1)
-            cdo_warning("Parameter %d has wrong number of levels, skipped! (param=%s nlevel=%d)", varID + 1, varList1[varID].name,
-                        nlevels);
+            cdo_warning("Parameter %d has wrong number of levels, skipped! (param=%s nlevel=%d)", varID + 1, var1.name, nlevels);
         }
     }
 
-  if (zaxisID_ML != -1 && varIDs.gheightID == -1)
-    cdo_abort("%s not found!", var_stdname(geopotential_height));
+  if (zaxisID_ML != -1 && varIDs.gheightID == -1) cdo_abort("%s not found!", var_stdname(geopotential_height));
 
-  const auto sgeopotNeeded = (!extrapolate && varIDs.gheightID != -1);
+  auto sgeopotNeeded = (!extrapolate && varIDs.gheightID != -1);
 
   Field sgeopot;
   if (zaxisID_ML != -1 && sgeopotNeeded)
@@ -573,24 +572,21 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
 
           if (extrapolate) cdo_warning("%s not found - set to zero!", var_stdname(surface_geopotential));
         }
-      else
-        {
-          sgeopot.init(varList1[varIDs.sgeopotID]);
-        }
+      else { sgeopot.init(varList1[varIDs.sgeopotID]); }
 
       field_fill(sgeopot, 0.0);
     }
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      for (int varID = 0; varID < nvars; ++varID) vars[varID] = false;
+      for (int varID = 0; varID < nvars; ++varID) processVars[varID] = false;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
@@ -600,35 +596,31 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
           int varID, levelID;
           cdo_inq_record(streamID1, &varID, &levelID);
 
-          //const auto zaxisID = varList1[varID].zaxisID;
-          //const auto nlevels = varList1[varID].nlevels;
-          //if (vctIsInverted && zaxisID_ML != -1 && zaxisID == zaxisID_ML) levelID = nlevels - 1 - levelID;
-
           cdo_read_record(streamID1, vardata1[varID], levelID, &varnmiss[varID][levelID]);
 
-          vars[varID] = true;
+          processVars[varID] = true;
         }
 
       if (zaxisID_ML != -1)
         {
           gen_vert_index(vertIndex, heightLevels, vardata1[varIDs.gheightID], gridsize);
 
-          //if (!extrapolate) gen_vert_index_mv(vertIndex, heightLevels, gridsize, psProg, pnmiss);
+          // if (!extrapolate) gen_vert_index_mv(vertIndex, heightLevels, gridsize, psProg, pnmiss);
         }
 
       for (int varID = 0; varID < nvars; ++varID)
         {
-          if (vars[varID])
+          if (processVars[varID])
             {
-              if (tsID > 0 && varList1[varID].timetype == TIME_CONSTANT) continue;
+              const auto &var = varList1[varID];
+              if (tsID > 0 && var.isConstant) continue;
 
-              if (varinterp[varID])
+              if (interpVars[varID])
                 {
-                  const auto nlevels = varList1[varID].nlevels;
-                  if (nlevels != numFullLevels && nlevels != numHalfLevels)
-                    cdo_abort("Number of hybrid level differ from full/half level (param=%s)!", varList1[varID].name);
+                  if (var.nlevels != numFullLevels && var.nlevels != numHalfLevels)
+                    cdo_abort("Number of hybrid level differ from full/half level (param=%s)!", var.name);
 
-                  for (int levelID = 0; levelID < nlevels; ++levelID)
+                  for (int levelID = 0; levelID < var.nlevels; ++levelID)
                     {
                       if (varnmiss[varID][levelID]) cdo_abort("Missing values unsupported for this operator!");
                     }
@@ -643,7 +635,7 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
               for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
                 {
                   cdo_def_record(streamID2, varID, levelID);
-                  cdo_write_record(streamID2, varinterp[varID] ? vardata2[varID] : vardata1[varID], levelID,
+                  cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
                                    varnmiss[varID][levelID]);
                 }
             }
@@ -668,17 +660,17 @@ Vertintml(void *process)
   cdo_initialize(process);
 
   // clang-format off
-                          cdo_operator_add("ml2pl",      func_pl, 0, "pressure levels in pascal");
-  const auto ML2PLX     = cdo_operator_add("ml2plx",     func_pl, 0, "pressure levels in pascal");
-                          cdo_operator_add("ml2hl",      func_hl, 0, "height levels in meter");
-  const auto ML2HLX     = cdo_operator_add("ml2hlx",     func_hl, 0, "height levels in meter");
-                          cdo_operator_add("ml2height",  func_hl, 1, "height levels in meter");
-  const auto ML2HEIGHTX = cdo_operator_add("ml2heightx", func_hl, 1, "height levels in meter");
+                    cdo_operator_add("ml2pl",      func_pl, 0, "pressure levels in pascal");
+  auto ML2PLX     = cdo_operator_add("ml2plx",     func_pl, 0, "pressure levels in pascal");
+                    cdo_operator_add("ml2hl",      func_hl, 0, "height levels in meter");
+  auto ML2HLX     = cdo_operator_add("ml2hlx",     func_hl, 0, "height levels in meter");
+                    cdo_operator_add("ml2height",  func_hl, 1, "height levels in meter");
+  auto ML2HEIGHTX = cdo_operator_add("ml2heightx", func_hl, 1, "height levels in meter");
   // clang-format on
 
-  const auto operatorID = cdo_operator_id();
-  const auto useHeightLevel = (cdo_operator_f1(operatorID) == func_hl);
-  const auto doPressureInterpolation = (cdo_operator_f2(operatorID) == 0);
+  auto operatorID = cdo_operator_id();
+  auto useHeightLevel = (cdo_operator_f1(operatorID) == func_hl);
+  auto doPressureInterpolation = (cdo_operator_f2(operatorID) == 0);
 
   auto extrapolate = (operatorID == ML2PLX || operatorID == ML2HLX || operatorID == ML2HEIGHTX);
   if (extrapolate == false) extrapolate = getenv_extrapolate();
@@ -694,17 +686,13 @@ Vertintml(void *process)
         levels
             = { 100000, 92500, 85000, 70000, 60000, 50000, 40000, 30000, 25000, 20000, 15000, 10000, 7000, 5000, 3000, 2000, 1000 };
     }
-  else
-    {
-      levels = cdo_argv_to_flt(cdo_get_oper_argv());
-    }
+  else { levels = cdo_argv_to_flt(cdo_get_oper_argv()); }
 
   if (doPressureInterpolation)
     pressure_level_interpolation(levels, useHeightLevel, extrapolate);
   else
     height_level_interpolation(levels, extrapolate);
 
-
   cdo_finish();
 
   return nullptr;
