@@ -33,31 +33,31 @@ int PROJUVLATLON;
 // NOTE: Variable with codes (3[3,4],105,10) will get from CDO typically a name:
 // "10u", resp. "10v" Mostly u & v at level type 105 is not staggered, but test it to be sure..
 
-#define CheckVarIsU(varID, varname, code)                                      \
-  {                                                                            \
-    VarIsU = 0;                                                                \
-    if (lvar)                                                                  \
-      {                                                                        \
-        if (strcmp((char *) (varname), (char *) (chvars)[0]) == 0) VarIsU = 1; \
-      }                                                                        \
-    else if (code == chcodes[0])                                               \
-      VarIsU = 1;                                                              \
+#define CheckVarIsU(varID, varname, code)     \
+  {                                           \
+    VarIsU = 0;                               \
+    if (lvar)                                 \
+      {                                       \
+        if (varname == chvars[0]) VarIsU = 1; \
+      }                                       \
+    else if (code == chcodes[0])              \
+      VarIsU = 1;                             \
   }
-#define CheckVarIsV(varID, varname, code)                                      \
-  {                                                                            \
-    VarIsV = 0;                                                                \
-    if (lvar)                                                                  \
-      {                                                                        \
-        if (strcmp((char *) (varname), (char *) (chvars)[1]) == 0) VarIsV = 1; \
-      }                                                                        \
-    else if (code == chcodes[1])                                               \
-      VarIsV = 1;                                                              \
+#define CheckVarIsV(varID, varname, code)     \
+  {                                           \
+    VarIsV = 0;                               \
+    if (lvar)                                 \
+      {                                       \
+        if (varname == chvars[1]) VarIsV = 1; \
+      }                                       \
+    else if (code == chcodes[1])              \
+      VarIsV = 1;                             \
   }
 #define CheckUVisStaggered(varID1, varID2, zaxisID1, zaxisID2) \
   {                                                            \
     VarsUVareStaggered = 1;                                    \
-    auto gridID1tmp = vlistInqVarGrid(vlistID1, varID1);        \
-    auto gridID2tmp = vlistInqVarGrid(vlistID1, varID2);        \
+    auto gridID1tmp = varList1[varID1].gridID;                 \
+    auto gridID2tmp = varList1[varID2].gridID;                 \
     if (zaxisID1 != zaxisID2)                                  \
       VarsUVareStaggered = 0;                                  \
     else if (gridID1tmp == gridID2tmp)                         \
@@ -188,7 +188,6 @@ DestaggerUV()
   int chcodes[MAXARG];
   const char *chvars[MAXARG];
   double destagGridOffsets[MAXARG];
-  char varname[CDI_MAX_NAME];
   int gridID1 = CDI_UNDEFID, gridID2 = CDI_UNDEFID;
   int gridID0 = CDI_UNDEFID;
   int gridID;
@@ -239,15 +238,18 @@ DestaggerUV()
 
   Debug(cdoDebugExt, "destagGridOffsets = (%01.1f,%01.1f)", destagGridOffsets[0], destagGridOffsets[1]);
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
   auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
+  VarList varList1;
+  varListInit(varList1, vlistID1);
+
   // Find the first occurance of staggered U and V variables (for example codes 33,34). We assume that one (grib-)file
   // contains only 1 sort of horizontal grids and at most 2 staggered grids.
   /*
@@ -293,22 +295,22 @@ DestaggerUV()
   int nvars = vlistNvars(vlistID1);
   for (varID = 0; varID < nvars; ++varID)
     {
-      auto param = vlistInqVarParam(vlistID1, varID);
+      const auto &var = varList1[varID];
+
       int pnum, pcat, pdis;
-      cdiDecodeParam(param, &pnum, &pcat, &pdis);
+      cdiDecodeParam(var.param, &pnum, &pcat, &pdis);
       auto code = pnum;
-      auto zaxisID = vlistInqVarZaxis(vlistID1, varID);
+      auto zaxisID = var.zaxisID;
       auto ltype = zaxis_to_ltype(zaxisID);
       auto nlevs = zaxisInqSize(zaxisID);
-      vlistInqVarName(vlistID1, varID, varname);
-      auto gridIDx = vlistInqVarGrid(vlistID1, varID);
+      auto gridIDx = var.gridID;
       if (cdoDebugExt >= 20)
         cdo_print("Var.id [%4d] with grib code:%3d and has name: %6s; level "
                   "type: %3d; number of levels: %3d; gridID: %d; zaxisID: %d",
-                  varID, code, varname, ltype, nlevs, gridIDx, zaxisID);
+                  varID, code, var.name, ltype, nlevs, gridIDx, zaxisID);
 
-      CheckVarIsU(varID, varname, code);
-      CheckVarIsV(varID, varname, code);
+      CheckVarIsU(varID, var.name, code);
+      CheckVarIsV(varID, var.name, code);
       if (VarIsU)
         {
           varID1 = varID;
@@ -325,8 +327,8 @@ DestaggerUV()
           CheckUVisStaggered(varID1, varID2, zaxisID1, zaxisID2);
           if (VarsUVareStaggered)
             {
-              gridID1 = vlistInqVarGrid(vlistID1, varID1);
-              gridID2 = vlistInqVarGrid(vlistID1, varID2);
+              gridID1 = varList1[varID1].gridID;
+              gridID2 = varList1[varID2].gridID;
               if (cdoDebugExt)
                 cdo_print("Found STAGGERED U & V: varID1=%d (gridID1=%d), varID2=%d (gridID2=%d)", varID1, gridID2, varID2,
                           gridID1);
@@ -347,11 +349,11 @@ DestaggerUV()
       // de-staggered uv If there will be no temperature field we will define grid the grid
       if (lvar)  // We have a list of variables
         {
-          if (strcmp(varname, "t") == 0) gridID0 = vlistInqVarGrid(vlistID1, varID);
+          if (var.name == "t") gridID0 = var.gridID;
         }
       else
         {
-          if (code == 11) gridID0 = vlistInqVarGrid(vlistID1, varID);
+          if (code == 11) gridID0 = var.gridID;
         }
     }  // end of for ( varID = 0; varID < nvars; ..
 
@@ -381,8 +383,8 @@ DestaggerUV()
       xincV = gridInqXinc(gridID2);
       yincV = gridInqXinc(gridID2);
 
-      const auto gridtype1 = gridInqType(gridID1);
-      const auto gridtype2 = gridInqType(gridID2);
+      auto gridtype1 = gridInqType(gridID1);
+      auto gridtype2 = gridInqType(gridID2);
 
       if (!(gridtype1 == GRID_PROJECTION && gridInqProjType(gridID1) == CDI_PROJ_RLL && gridtype2 == GRID_PROJECTION
             && gridInqProjType(gridID2) == CDI_PROJ_RLL))
@@ -451,12 +453,14 @@ DestaggerUV()
           Debug(cdoDebugExt, "Last trial to find a reference grid for destaggered wind.");
           for (varID = 0; varID < nvars; ++varID)
             {
-              gridID = vlistInqVarGrid(vlistID1, varID);
+              const auto &var = varList1[varID];
+
+              gridID = var.gridID;
               Debug(cdoDebugExt, "Var.id %d has grid nr:%d", varID, gridID);
               if ((varID != varID1stg) && (varID != varID2stg))
                 {
                   // this will the new (horizontal) grid for de-staggered
-                  gridID0 = vlistInqVarGrid(vlistID1, varID);
+                  gridID0 = var.gridID;
                 }
             }
         }
@@ -478,7 +482,7 @@ DestaggerUV()
       ovar.resize(gridsize);
     }  // end of  if (!lcopy)
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
 
   if (varID1stg != CDI_UNDEFID && varID2stg != CDI_UNDEFID)
     {
@@ -493,7 +497,7 @@ DestaggerUV()
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -508,11 +512,13 @@ DestaggerUV()
       for (int recID = 0; recID < nrecs; ++recID)
         {
           cdo_inq_record(streamID1, &varID, &levelID);
-          auto param = vlistInqVarParam(vlistID1, varID);
+
+          const auto &var = varList1[varID];
+
           int pnum, pcat, pdis;
-          cdiDecodeParam(param, &pnum, &pcat, &pdis);
+          cdiDecodeParam(var.param, &pnum, &pcat, &pdis);
           auto code = pnum;
-          auto zaxisID = vlistInqVarZaxis(vlistID1, varID);
+          auto zaxisID = var.zaxisID;
           auto ltype = zaxis_to_ltype(zaxisID);
           auto level = (int) zaxisInqLevel(zaxisID, levelID);
 
@@ -522,9 +528,8 @@ DestaggerUV()
               //       You cannot use this way of U/V variable detection!
               // VarIsU = (varID == varID1stg); ** DON'T USE
               // VarIsV = (varID == varID2stg); ** DON'T USE
-              vlistInqVarName(vlistID1, varID, varname);
-              CheckVarIsU(varID, varname, code);
-              CheckVarIsV(varID, varname, code);
+              CheckVarIsU(varID, var.name, code);
+              CheckVarIsV(varID, var.name, code);
 
               UorV = -1;  // -1: not U, neither V
               if (VarIsU)
@@ -534,7 +539,7 @@ DestaggerUV()
 
               if (UorV >= 0)
                 {
-                  gridID = vlistInqVarGrid(vlistID1, varID);
+                  gridID = var.gridID;
                   if (UorV == 0)
                     {
                       if (gridID == gridID1)  // Has this variable the staggered grid?
@@ -542,7 +547,7 @@ DestaggerUV()
                           if (cdoDebugExt >= 10)
                             cdo_print("Destaggering U-wind record: %05d (timestep:%d); Var.id [%4d]; (code=%3d; "
                                       "ltype=%3d; level=%4d; levelID=%3d); GridID %d => %d  *** <===",
-                                      recID, tsID, varID, code, ltype, level, levelID, vlistInqVarGrid(vlistID1, varID),
+                                      recID, tsID, varID, code, ltype, level, levelID, var.gridID,
                                       vlistInqVarGrid(vlistID2, varID));
                         }
                       else
@@ -555,7 +560,7 @@ DestaggerUV()
                           if (cdoDebugExt >= 10)
                             cdo_print("Destaggering V-wind record: %05d (timestep:%d); Var.id [%4d]; (code=%3d; "
                                       "ltype=%3d; level=%4d; levelID=%3d); GridID %d => %d  *** <===",
-                                      recID, tsID, varID, code, ltype, level, levelID, vlistInqVarGrid(vlistID1, varID),
+                                      recID, tsID, varID, code, ltype, level, levelID, var.gridID,
                                       vlistInqVarGrid(vlistID2, varID));
                         }
                       else
@@ -593,8 +598,7 @@ DestaggerUV()
                   //                          (xfirst_V = -30.20; yfirst_V = -30.75);
                   // cdo uvDestag: Grid info: (dxU; dyU) = (0.00; 0.05); (dxV; dyV) = (0.05; 0.00)
                   if (cdoDebugExt >= 20)
-                    cdo_print("Setting GRID id from: %d => to: %d", vlistInqVarGrid(vlistID1, varID),
-                              vlistInqVarGrid(vlistID2, varID));
+                    cdo_print("Setting GRID id from: %d => to: %d", var.gridID, vlistInqVarGrid(vlistID2, varID));
 
                   cdo_def_record(streamID2, varID, levelID);
                   cdo_write_record(streamID2, ovar.data(), nmiss);
@@ -687,8 +691,8 @@ rot_uv_north(int gridID, double *us, double *vs)
         iDirectionIncrementInDegrees = 0.1;
   */
 
-  const auto nx = gridInqXsize(gridID);
-  const auto ny = gridInqYsize(gridID);
+  auto nx = gridInqXsize(gridID);
+  auto ny = gridInqYsize(gridID);
 
   Varray<double> xvals(nx * ny), yvals(nx * ny);
   gridInqXvals(gridID, xvals.data());
@@ -744,7 +748,7 @@ rot_uv_north(int gridID, double *us, double *vs)
       for (j = 0; j < ny; ++j)
         for (i = 0; i < nx; ++i)
           {
-            const auto idx = j * nx + i;
+            auto idx = j * nx + i;
             lon_pnt0 = xvals[idx];
             lat_pnt0 = yvals[idx];
 #ifndef OPTrotuvNorth
@@ -869,10 +873,10 @@ rot_uv_north(int gridID, double *us, double *vs)
             // zpntNorthSph = 0; zpntEastSph = 0;  // not needed in 2D
 
             // 1) Build the rotation matrix and put the axes-base vectors into the matrix
-            const auto VJaa = xpntEastSph;
-            const auto VJab = xpntNorthSph;
-            const auto VJba = ypntEastSph;
-            const auto VJbb = ypntNorthSph;
+            auto VJaa = xpntEastSph;
+            auto VJab = xpntNorthSph;
+            auto VJba = ypntEastSph;
+            auto VJbb = ypntNorthSph;
 
             auto idx4 = 4 * idx;
             // Caching the rotation matrix for later usage ..
@@ -913,28 +917,28 @@ rot_uv_north(int gridID, double *us, double *vs)
   for (j = 0; j < ny; ++j)
     for (i = 0; i < nx; ++i)
       {
-        const auto idx = (j * nx + i);
+        auto idx = (j * nx + i);
         auto idx4 = 4 * idx;
-        const auto VJaa = rotationMatrixArray[idx4++];
-        const auto VJab = rotationMatrixArray[idx4++];
-        const auto VJba = rotationMatrixArray[idx4++];
-        const auto VJbb = rotationMatrixArray[idx4++];
+        auto VJaa = rotationMatrixArray[idx4++];
+        auto VJab = rotationMatrixArray[idx4++];
+        auto VJba = rotationMatrixArray[idx4++];
+        auto VJbb = rotationMatrixArray[idx4++];
 
         // 2) Transform the UV vector with jacobian matrix
-        const auto u = us[idx];
-        const auto v = vs[idx];
+        auto u = us[idx];
+        auto v = vs[idx];
         // u = 6.0;  v = 0.0; // test: 6 m/s along the easting direction of the grid
-        const auto magnitude = hypot(u, v);  // old vector magnitude in the model space
+        auto magnitude = hypot(u, v);  // old vector magnitude in the model space
         //(uu) =   (VJaa VJab) * ( u )
         //(vv)     (VJba VJbb)   ( v )
-        const auto uu = VJaa * u + VJab * v;
-        const auto vv = VJba * u + VJbb * v;
+        auto uu = VJaa * u + VJab * v;
+        auto vv = VJba * u + VJbb * v;
         //(uu) =   (VJaa VJab VJac) * ( u )
         //(vv)     (VJba VJbb VJbc)   ( v )
         //(ww)     (VJba VJbb VJcc)   ( w )
 
         // 3) Apply scaling of the vector so that the vector keeps the original length (model space)
-        const auto newMagnitude = hypot(uu, vv);
+        auto newMagnitude = hypot(uu, vv);
         us[idx] = uu * magnitude / newMagnitude;
         vs[idx] = vv * magnitude / newMagnitude;
       }
@@ -967,8 +971,8 @@ rot_uv_back_mode64(int gridID, double *us, double *vs)
   if (gridInqType(gridID) == GRID_PROJECTION && gridInqProjType(gridID) == CDI_PROJ_RLL)
     gridInqParamRLL(gridID, &xpole, &ypole, &angle);
 
-  const auto nlon = gridInqXsize(gridID);
-  const auto nlat = gridInqYsize(gridID);
+  auto nlon = gridInqXsize(gridID);
+  auto nlat = gridInqYsize(gridID);
 
   Varray<double> xvals(nlon), yvals(nlat);
   gridInqXvals(gridID, xvals.data());
@@ -984,10 +988,10 @@ rot_uv_back_mode64(int gridID, double *us, double *vs)
   for (size_t ilat = 0; ilat < nlat; ilat++)
     for (size_t ilon = 0; ilon < nlon; ilon++)
       {
-        const auto i = ilat * nlon + ilon;
+        auto i = ilat * nlon + ilon;
 
-        const auto xval = lamrot_to_lam(yvals[ilat], xvals[ilon], ypole, xpole, angle);
-        const auto yval = phirot_to_phi(yvals[ilat], xvals[ilon], ypole, angle);
+        auto xval = lamrot_to_lam(yvals[ilat], xvals[ilon], ypole, xpole, angle);
+        auto yval = phirot_to_phi(yvals[ilat], xvals[ilon], ypole, angle);
 
         usvs_to_uv(us[i], vs[i], yval, xval, ypole, xpole, &u, &v);
 
@@ -1015,8 +1019,8 @@ project_uv_latlon(int gridID, double *us, double *vs)
     cdo_abort("%s(gridname=%s) transformation grid must be GRID_CURVILINEAR!", __func__, gridNamePtr(gridInqType(gridID)));
   // this should never happen
 
-  const auto nx = gridInqXsize(gridID);
-  const auto ny = gridInqYsize(gridID);
+  auto nx = gridInqXsize(gridID);
+  auto ny = gridInqYsize(gridID);
 
   Varray<double> xvals(nx * ny), yvals(nx * ny);
   gridInqXvals(gridID, xvals.data());
@@ -1034,9 +1038,9 @@ project_uv_latlon(int gridID, double *us, double *vs)
   for (size_t j = 0; j < ny; ++j)
     for (size_t i = 0; i < nx; ++i)
       {
-        const auto idx = j * nx + i;
-        const auto xpnt0 = xvals[idx];
-        const auto ypnt0 = yvals[idx];
+        auto idx = j * nx + i;
+        auto xpnt0 = xvals[idx];
+        auto ypnt0 = yvals[idx];
         double xpntEast, ypntEast;
         double xpntNorth, ypntNorth;
         if ((i + 1) < nx)
@@ -1081,26 +1085,26 @@ project_uv_latlon(int gridID, double *us, double *vs)
         ///  Basically transforms grid-relative UV into north pole relative UV
         ///  (~ lat-lon space) u,v : grid relative (u,v) not staggered get(u); get(v)
         // 1) Build the jacobian matrix
-        const auto distLon = hypot(xpntEast - xpnt0, ypntEast - ypnt0);
-        const auto distLat = hypot(xpntNorth - xpnt0, ypntNorth - ypnt0);
-        const auto VJaa = signLon * (xpntEast - xpnt0) / distLon;
-        const auto VJab = signLon * (xpntNorth - xpnt0) / distLat;
-        const auto VJba = signLat * (ypntEast - ypnt0) / distLon;
-        const auto VJbb = signLat * (ypntNorth - ypnt0) / distLat;
+        auto distLon = hypot(xpntEast - xpnt0, ypntEast - ypnt0);
+        auto distLat = hypot(xpntNorth - xpnt0, ypntNorth - ypnt0);
+        auto VJaa = signLon * (xpntEast - xpnt0) / distLon;
+        auto VJab = signLon * (xpntNorth - xpnt0) / distLat;
+        auto VJba = signLat * (ypntEast - ypnt0) / distLon;
+        auto VJbb = signLat * (ypntNorth - ypnt0) / distLat;
         if (cdoDebugExt >= 20)
           if (((i < 3) && (j < 3)) || ((i > (nx - 3)) && (j > (ny - 3))))
             cdo_print("Jacobian for grid point [%zu,%zu] with latlon[%3.6f,%3.6f]: (VJaa, VJab, VJba, VJbb) = "
                       "(%3.6f,%3.6f,%3.6f,%3.6f)",
                       i, j, xpnt0, ypnt0, VJaa, VJab, VJba, VJbb);
         // 2) Transform the UV vector with jacobian matrix
-        const auto u = us[idx];
-        const auto v = vs[idx];
+        auto u = us[idx];
+        auto v = vs[idx];
         // u = 6.0;  v = 0.0; // test: 6 m/s along the easting direction of the grid
-        const auto magnitude = hypot(u, v);  // old vector magnitude in the model space
-        const auto uu = VJaa * u + VJab * v;
-        const auto vv = VJba * u + VJbb * v;
+        auto magnitude = hypot(u, v);  // old vector magnitude in the model space
+        auto uu = VJaa * u + VJab * v;
+        auto vv = VJba * u + VJbb * v;
         // 3) Apply scaling of the vector so that the vector keeps the original length (model space)
-        const auto newMagnitude = hypot(uu, vv);
+        auto newMagnitude = hypot(uu, vv);
         us[idx] = uu * magnitude / newMagnitude;
         vs[idx] = vv * magnitude / newMagnitude;
       }
@@ -1115,11 +1119,10 @@ TransformUV(int operatorID)
   int varID1, varID2, nlevel1, nlevel2;
   size_t gridsize = 0;
   int code, gridID;
-  int param, ltype, level, nlevs, zaxisID;
+  int ltype, level, nlevs, zaxisID;
   int pnum, pcat, pdis;
   int chcodes[MAXARG];
   const char *chvars[MAXARG];
-  char varname[CDI_MAX_NAME];
   int gridIDcurvl = -1;
   int gridIDlastused = -1;
 
@@ -1150,13 +1153,13 @@ TransformUV(int operatorID)
       for (int i = 0; i < nch; ++i) chcodes[i] = parameter_to_int(cdo_operator_argv(i));
     }
 
-  const auto streamID1 = cdo_open_read(0);
+  auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
   auto vlistID2 = vlistDuplicate(vlistID1);
 
-  const auto nvars = vlistNvars(vlistID1);
-  const auto num_recs = vlistNrecs(vlistID1);
+  auto nvars = vlistNvars(vlistID1);
+  auto num_recs = vlistNrecs(vlistID1);
 
   std::vector<RecordInfo> recList(num_recs);
 
@@ -1166,6 +1169,10 @@ TransformUV(int operatorID)
   // U & V are NOT grid relative
   for (varID = 0; varID < nvars; ++varID) cdiDefKeyInt(vlistID2, varID, CDI_KEY_UVRELATIVETOGRID, 0);
 
+  VarList varList1, varList2;
+  varListInit(varList1, vlistID1);
+  varListInit(varList2, vlistID2);
+
   bool lfound[MAXARG];
   for (int i = 0; i < nch; ++i) lfound[i] = false;
 
@@ -1173,9 +1180,8 @@ TransformUV(int operatorID)
     {
       for (varID = 0; varID < nvars; ++varID)
         {
-          vlistInqVarName(vlistID2, varID, varname);
           for (int i = 0; i < nch; ++i)
-            if (strcmp(varname, chvars[i]) == 0) lfound[i] = true;
+            if (varList2[varID].name == chvars[i]) lfound[i] = true;
         }
       for (int i = 0; i < nch; ++i)
         if (!lfound[i]) cdo_abort("Variable %s not found!", chvars[i]);
@@ -1184,9 +1190,8 @@ TransformUV(int operatorID)
     {
       for (varID = 0; varID < nvars; ++varID)
         {
-          code = vlistInqVarCode(vlistID2, varID);
           for (int i = 0; i < nch; ++i)
-            if (code == chcodes[i]) lfound[i] = true;
+            if (varList2[varID].code == chcodes[i]) lfound[i] = true;
         }
       for (int i = 0; i < nch; ++i)
         if (!lfound[i]) cdo_abort("Code %d not found!", chcodes[i]);
@@ -1198,34 +1203,31 @@ TransformUV(int operatorID)
 
   for (varID = 0; varID < nvars; ++varID)
     {
-      param = vlistInqVarParam(vlistID1,
-                               varID); /*  vlistInqVarParam(int vlistID, int varID): Get the parameter number of a Variable */
-      cdiDecodeParam(param, &pnum, &pcat, &pdis);
+      const auto &var = varList1[varID];
+
+      cdiDecodeParam(var.param, &pnum, &pcat, &pdis);
       code = pnum;
-      zaxisID = vlistInqVarZaxis(vlistID1, varID);
+      zaxisID = var.zaxisID;
       ltype = zaxis_to_ltype(zaxisID);
       nlevs = zaxisInqSize(zaxisID);
-      vlistInqVarName(vlistID1, varID,
-                      varname); /* vlistInqVarName(int vlistID, int varID, char *name): Get the name of a Variable */
 
-      gridID = vlistInqVarGrid(vlistID1, varID);
+      gridID = var.gridID;
       if (cdoDebugExt >= 20)
         cdo_print(
             "Var.id [%4d] with grib code:%3d and has name: %6s; level type: %3d; number of levels: %3d; gridID: %d; zaxisID: %d",
-            varID, code, varname, ltype, nlevs, gridID, zaxisID);
+            varID, code, var.name, ltype, nlevs, gridID, zaxisID);
 
       if (!(gridInqType(gridID) == GRID_PROJECTION && gridInqProjType(gridID) == CDI_PROJ_RLL))
         cdo_abort("Only rotated lon/lat grids supported!");
 
-      CheckVarIsU(varID, varname, code);
-      CheckVarIsV(varID, varname, code);
+      CheckVarIsU(varID, var.name, code);
+      CheckVarIsV(varID, var.name, code);
       if (VarIsU || VarIsV)
         {
           gridsize = gridInqSize(gridID);
           if (cdoDebugExt)
             cdo_print("Allocating memory for variableID %4d (code=%3d): gridsize(%zu)*nlevels(%d) = %zu [%4.3f MB]", varID,
-                      vlistInqVarCode(vlistID2, varID), gridsize, nlevs, gridsize * nlevs,
-                      gridsize * nlevs * sizeof(double) / (1024.0 * 1024));
+                      varList2[varID].code, gridsize, nlevs, gridsize * nlevs, gridsize * nlevs * sizeof(double) / (1024.0 * 1024));
           varnmiss[varID].resize(nlevs);
           vardata[varID].resize(nlevs);
           for (levelID = 0; levelID < nlevs; ++levelID) vardata[varID][levelID].resize(gridsize);
@@ -1234,11 +1236,11 @@ TransformUV(int operatorID)
 
   Debug(cdoDebugExt, "Neccessary memory has been allocated.");
 
-  const auto taxisID1 = vlistInqTaxis(vlistID1);
-  const auto taxisID2 = taxisDuplicate(taxisID1);
+  auto taxisID1 = vlistInqTaxis(vlistID1);
+  auto taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  const auto streamID2 = cdo_open_write(1);
+  auto streamID2 = cdo_open_write(1);
 
   cdo_def_vlist(streamID2, vlistID2);          // from this point the stream is using a different vlistID !!!!!
   vlistID2 = cdo_stream_inq_vlist(streamID2);  // refresh it
@@ -1246,7 +1248,7 @@ TransformUV(int operatorID)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -1257,8 +1259,8 @@ TransformUV(int operatorID)
       for (int recID = 0; recID < nrecs; ++recID)
         {
           cdo_inq_record(streamID1, &varID, &levelID);
-          code = vlistInqVarCode(vlistID1, varID);
-          zaxisID = vlistInqVarZaxis(vlistID1, varID);
+          code = varList1[varID].code;
+          zaxisID = varList1[varID].zaxisID;
           ltype = zaxis_to_ltype(zaxisID);
           level = zaxisInqLevel(zaxisID, levelID);
 
@@ -1302,24 +1304,23 @@ TransformUV(int operatorID)
           }
         else  // This means that it is U or V.
           {
-            code1 = vlistInqVarCode(vlistID2, varID1);
-            zaxisID1 = vlistInqVarZaxis(vlistID2, varID1);
+            code1 = varList2[varID1].code;
+            zaxisID1 = varList2[varID1].zaxisID;
             ltype1 = zaxis_to_ltype(zaxisID1);
             nlevel1 = zaxisInqSize(zaxisID1);
-            vlistInqVarName(vlistID2, varID1, varname);
-            CheckVarIsV(varID1, varname, code1);
+            CheckVarIsV(varID1, varList2[varID1].name, code1);
             if (VarIsV) continue;
             if (cdoDebugExt >= 20)
               cdo_print("Checking U-wind: Var.id [%4d] with grib code:%3d; name: %6s; level type: %3d; number of levels: %3d; "
                         "zaxisID: %d",
-                        varID1, code1, varname, ltype1, nlevel1, zaxisID1);
-            CheckVarIsU(varID1, varname, code1);
+                        varID1, code1, varList2[varID1].name, ltype1, nlevel1, zaxisID1);
+            CheckVarIsU(varID1, varList2[varID1].name, code1);
             if (!VarIsU) continue;
             if (cdoDebugExt >= 10)
               cdo_print("** FOUND U-wind; Var.id [%4d] with grib code:%3d; name: %6s; level type: %3d; number of levels: %3d; "
                         "zaxisID: %d",
-                        varID1, code1, varname, ltype1, nlevel1, zaxisID1);
-            const auto usvarID = varID1;
+                        varID1, code1, varList2[varID1].name, ltype1, nlevel1, zaxisID1);
+            auto usvarID = varID1;
             // find corresponding v-variable to u-variable:
             for (varID2 = 0; varID2 < nvars; ++varID2)
               if (vardata[varID2].empty())
@@ -1328,29 +1329,28 @@ TransformUV(int operatorID)
                 }
               else  // This means that it is U or V.
                 {
-                  code2 = vlistInqVarCode(vlistID2, varID2);
-                  zaxisID2 = vlistInqVarZaxis(vlistID2, varID2);
+                  code2 = varList2[varID2].code;
+                  zaxisID2 = varList2[varID2].zaxisID;
                   ltype2 = zaxis_to_ltype(zaxisID2);
                   nlevel2 = zaxisInqSize(zaxisID2);
-                  vlistInqVarName(vlistID2, varID2, varname);
-                  CheckVarIsU(varID2, varname, code2);
+                  CheckVarIsU(varID2, varList2[varID2].name, code2);
                   if (VarIsU) continue;
                   if (cdoDebugExt >= 20)
                     cdo_print("Checking V-wind: Var.id [%4d] with grib code:%3d; name: %6s; level type: %3d; number of "
                               "levels: %3d; zaxisID: %d",
-                              varID2, code2, varname, ltype2, nlevel2, zaxisID2);
-                  CheckVarIsV(varID2, varname, code2);
+                              varID2, code2, varList2[varID2].name, ltype2, nlevel2, zaxisID2);
+                  CheckVarIsV(varID2, varList2[varID2].name, code2);
                   if (!VarIsV) continue;
                   if (!((ltype1 == ltype2) && (nlevel1 == nlevel2) && (zaxisID1 == zaxisID2))) continue;
                   if (cdoDebugExt >= 10)
                     cdo_print("** FOUND V-wind; Var.id [%4d] with grib code:%3d; name: %6s; level type: %3d; number of "
                               "levels: %3d; zaxisID: %d",
-                              varID2, code2, varname, ltype1, nlevel2, zaxisID2);
-                  const auto vsvarID = varID2;
+                              varID2, code2, varList2[varID2].name, ltype1, nlevel2, zaxisID2);
+                  auto vsvarID = varID2;
                   if (cdoDebugExt >= 20)
-                    cdo_print("Using code %d [%d](u) and code %d [%d](v)", vlistInqVarCode(vlistID1, varID1), code1,
-                              vlistInqVarCode(vlistID1, varID2), code2);
-                  gridID = vlistInqVarGrid(vlistID1, varID1);
+                    cdo_print("Using code %d [%d](u) and code %d [%d](v)", varList1[varID1].code, code1, varList1[varID2].code,
+                              code2);
+                  gridID = varList1[varID1].gridID;
                   if (operatorID != ROTUVN)  // ROTUVN operator does not need creation of gridIDcurvl ...
                     {
                       if ((gridIDcurvl != -1) && (gridIDlastused != gridID))
@@ -1364,7 +1364,7 @@ TransformUV(int operatorID)
                           gridIDlastused = gridID;
                           // Compute 2D array with latlons only once. We expect that all horizontal grids for UV are same.
                           // NOTE: At this stage U and V cannot be staggered!
-                          gridIDcurvl = gridToCurvilinear(gridID, 1);
+                          gridIDcurvl = gridToCurvilinear(gridID, NeedCorners::Yes);
                           if (cdoDebugExt)
                             cdo_print("Transformed rotated-latLon grid (id:%d) to curvilinear (id:%d) with true lat-lon "
                                       "coordinates.",
@@ -1463,8 +1463,8 @@ TransformUV(int operatorID)
           levelID = recList[recID].levelID;
           if (varID != -1)
             {
-              code = vlistInqVarCode(vlistID1, varID);
-              zaxisID = vlistInqVarZaxis(vlistID1, varID);
+              code = varList1[varID].code;
+              zaxisID = varList1[varID].zaxisID;
               ltype = zaxis_to_ltype(zaxisID);
               level = zaxisInqLevel(zaxisID, levelID);
               if (cdoDebugExt >= 10)
@@ -1502,7 +1502,7 @@ WindTrans(void *process)
   PROJUVLATLON = cdo_operator_add("projuvLatLon", 0, 0, nullptr);  // Cylindrical Equidistant projection
   // clang-format on
 
-  const int operatorID = cdo_operator_id();
+  int operatorID = cdo_operator_id();
 
   // will be calling: rot_uv_north(int gridID, double *us, double *vs);
   if (operatorID == ROTUVNORTH) return TransformUV(operatorID);
