@@ -63,7 +63,6 @@
 #include "cdo_vlist.h"
 #include "process_int.h"
 #include "cdo_task.h"
-#include "timer.h"
 #include "datetime.h"
 #include "printinfo.h"
 #include "util_date.h"
@@ -99,8 +98,6 @@ cdoReadTimestep(void *rarg)
   int tsIDnext = readarg->tsIDnext;
   int nrecs = readarg->nrecs;
 
-  // timer_start(timer_read);
-
   for (int recID = 0; recID < nrecs; ++recID)
     {
       int varID, levelID;
@@ -132,8 +129,6 @@ cdoReadTimestep(void *rarg)
       input_vars[varID][levelID].nmiss = nmiss;
     }
 
-    // timer_stop(timer_read);
-
 #ifdef USE_CDI_STREAM
   num_recs = streamInqTimestep(streamID, tsIDnext);
 #else
@@ -192,7 +187,7 @@ addOperators(void)
 void *
 XTimstat(void *process)
 {
-  TimeStat timestat_date = TimeStat::MEAN;
+  constexpr auto timestatDate{ TimeStat::MEAN };
   CdiDateTime vDateTime0{};
   CdiDateTime vDateTimeN{};
   CdoStreamID streamID3 = CDO_STREAM_UNDEF;
@@ -285,7 +280,7 @@ XTimstat(void *process)
     }
 
   DateTimeList dtlist;
-  dtlist.set_stat(timestat_date);
+  dtlist.set_stat(timestatDate);
   dtlist.set_calendar(taxisInqCalendar(taxisID1));
 
   int FIELD_MEMTYPE = 0;
