@@ -17,7 +17,6 @@
 #include "varray.h"
 #include "gaussian_latitudes.h"
 
-
 static void
 jspleg1(double *pleg, double plat, long ktrunc, double *work)
 {
@@ -164,7 +163,7 @@ phcs(bool needHnm, double *pnm, double *hnm, long waves, double pmu, double *zte
         {
           jnmjk = jn - jk;
           zcosfak *= (jk - 1.0) * (jn + jnmjk + 2.0) / (jk * (jn + jnmjk + 1.0));
-          zsinfak = zcosfak * zsqp * (double)jnmjk;
+          zsinfak = zcosfak * zsqp * (double) jnmjk;
           zcospar += zcosfak * std::cos(lat * jnmjk);
           zsinpar += zsinfak * std::sin(lat * jnmjk);
         }
@@ -197,7 +196,7 @@ phcs(bool needHnm, double *pnm, double *hnm, long waves, double pmu, double *zte
 
       for (long jn = 1; jn < waves; jn++)
         hnm[jn] = (jn + 1) * pmu * ztemp2[jn]
-          - std::sqrt(((jn + jn + 3.0) * ((jn + 1) * (jn + 1) - 1.0)) / (jn + jn + 1.0)) * ztemp2[jn - 1];
+                  - std::sqrt(((jn + jn + 3.0) * ((jn + 1) * (jn + 1) - 1.0)) / (jn + jn + 1.0)) * ztemp2[jn - 1];
 
       hnm += waves;
     }
@@ -253,7 +252,8 @@ after_legini_full(long ntr, long nlat, double *restrict poli, double *restrict p
   Varray2D<double> ztemp1_2(Threading::ompNumThreads);
   Varray2D<double> ztemp2_2(Threading::ompNumThreads);
   for (long i = 0; i < Threading::ompNumThreads; ++i) pnm_2[i].resize(dimsp);
-  if (needHnm) for (long i = 0; i < Threading::ompNumThreads; ++i) hnm_2[i].resize(dimsp);
+  if (needHnm)
+    for (long i = 0; i < Threading::ompNumThreads; ++i) hnm_2[i].resize(dimsp);
   for (long i = 0; i < Threading::ompNumThreads; ++i) ztemp1_2[i].resize(twowaves);
   for (long i = 0; i < Threading::ompNumThreads; ++i) ztemp2_2[i].resize(twowaves);
 #else
@@ -392,10 +392,7 @@ sp2fc(const double *sa, double *fa, const double *poli, long nlev, long nlat, lo
               auto salt = sal + cumindex[jmm] * 2;
               auto far = fal + jmm * 2 * nlat;
               auto fai = far + nlat;
-              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++)
-                {
-                  sp2fc_kernel(nlat, polt + jfc * nlat, salt + jfc * 2, far, fai);
-                }
+              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++) { sp2fc_kernel(nlat, polt + jfc * nlat, salt + jfc * 2, far, fai); }
             }
         }
     }
@@ -416,10 +413,7 @@ sp2fc(const double *sa, double *fa, const double *poli, long nlev, long nlat, lo
               auto salt = sal + cumindex[jmm] * 2;
               auto far = fal + jmm * 2 * nlat;
               auto fai = far + nlat;
-              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++)
-                {
-                  sp2fc_kernel(nlat, polt + jfc * nlat, salt + jfc * 2, far, fai);
-                }
+              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++) { sp2fc_kernel(nlat, polt + jfc * nlat, salt + jfc * 2, far, fai); }
             }
         }
     }
@@ -468,10 +462,7 @@ fc2sp(const double *fa, double *sa, const double *poli, long nlev, long nlat, lo
               auto salt = sal + cumindex[jmm] * 2;
               auto far = fal + jmm * 2 * nlat;
               auto fai = far + nlat;
-              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++)
-                {
-                  fc2sp_kernel(nlat, polt + jfc * nlat, far, fai, salt + jfc * 2);
-                }
+              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++) { fc2sp_kernel(nlat, polt + jfc * nlat, far, fai, salt + jfc * 2); }
             }
         }
     }
@@ -491,10 +482,7 @@ fc2sp(const double *fa, double *sa, const double *poli, long nlev, long nlat, lo
               auto salt = sal + cumindex[jmm] * 2;
               auto far = fal + jmm * 2 * nlat;
               auto fai = far + nlat;
-              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++)
-                {
-                  fc2sp_kernel(nlat, polt + jfc * nlat, far, fai, salt + jfc * 2);
-                }
+              for (long jfc = 0; jfc < (ntp1 - jmm); jfc++) { fc2sp_kernel(nlat, polt + jfc * nlat, far, fai, salt + jfc * 2); }
             }
         }
     }
