@@ -16,6 +16,7 @@
 #include <iostream>
 #include <algorithm>
 #include <vector>
+#include <limits>
 
 #ifdef HAVE_EXECINFO_H
 #include <execinfo.h>
@@ -74,10 +75,6 @@ cdo_exit()
   exit(EXIT_FAILURE);
 }
 
-// static int Debug = 0;
-// static int DebugLevel = 0;
-// static int Version = 0;
-static int Help = 0;
 static int CDO_numThreads = 0;
 static int timer_total;
 static int CDO_netcdf_hdr_pad = 0;
@@ -118,20 +115,20 @@ static int
 cdo_feenableexcept(int excepts)
 {
   static fenv_t fenv;
-  if (fegetenv(&fenv)) return -1;
+  if (std::fegetenv(&fenv)) return -1;
 
   (void) excepts;
-  int old_excepts = -1;  // previous masks
-#if defined(HAVE_FENV_T___CONTROL) && defined(HAVE_FENV_T___MXCSR)
-  unsigned new_excepts = ((unsigned) excepts) & FE_ALL_EXCEPT;
-  old_excepts = (int) (fenv.__control & FE_ALL_EXCEPT);
+  int oldExcepts = -1;  // previous masks
+#if defined HAVE_FENV_T___CONTROL && defined HAVE_FENV_T___MXCSR
+  unsigned newExcepts = ((unsigned) excepts) & FE_ALL_EXCEPT;
+  oldExcepts = (int) (fenv.__control & FE_ALL_EXCEPT);
 
   // unmask
-  fenv.__control &= ~new_excepts;
-  fenv.__mxcsr &= ~(new_excepts << 7);
+  fenv.__control &= ~newExcepts;
+  fenv.__mxcsr &= ~(newExcepts << 7);
 #endif
 
-  return (fesetenv(&fenv) ? -1 : old_excepts);
+  return (std::fesetenv(&fenv) ? -1 : oldExcepts);
 }
 #endif
 
@@ -166,9 +163,8 @@ cdo_set_digits(const char *const arg)
 static void
 cdo_version()
 {
-  int filetypes[] = { CDI_FILETYPE_SRV, CDI_FILETYPE_EXT, CDI_FILETYPE_IEG, CDI_FILETYPE_GRB,  CDI_FILETYPE_GRB2,
-                      CDI_FILETYPE_NC,  CDI_FILETYPE_NC2, CDI_FILETYPE_NC4, CDI_FILETYPE_NC4C, CDI_FILETYPE_NC5,
-                                CDI_FILETYPE_NCZARR };
+  int filetypes[] = { CDI_FILETYPE_SRV, CDI_FILETYPE_EXT, CDI_FILETYPE_IEG,  CDI_FILETYPE_GRB, CDI_FILETYPE_GRB2,  CDI_FILETYPE_NC,
+                      CDI_FILETYPE_NC2, CDI_FILETYPE_NC4, CDI_FILETYPE_NC4C, CDI_FILETYPE_NC5, CDI_FILETYPE_NCZARR };
   const char *typenames[] = { "srv", "ext", "ieg", "grb1", "grb2", "nc1", "nc2", "nc4", "nc4c", "nc5", "nczarr" };
 
   auto fp = stdout;
@@ -195,10 +191,10 @@ cdo_version()
 #endif
 #endif
 
-  cdo_print_features();
-  cdo_print_libraries();
+  CdoFeatures::cdo_print_features();
+  CdoFeatures::cdo_print_libraries();
 
-#if defined(CDI_SIZE_TYPE)
+#ifdef CDI_SIZE_TYPE
 #define CDO_STRINGIFY(x) #x
 #define CDO_TOSTRING(x) CDO_STRINGIFY(x)
   fprintf(fp, "CDI data types: SizeType=%s\n", CDO_TOSTRING(CDI_SIZE_TYPE));
@@ -215,19 +211,79 @@ cdo_version()
 }
 
 static void
-cdo_variableInputs()
+cdo_display_syntax_help(const std::string &help, FILE *p_target)
 {
-  set_text_color(stderr, BRIGHT, BLUE);
-  fprintf(stderr, "#==============================================================================#\n");
-  reset_text_color(stderr);
-  fprintf(stderr, "    For operators with variable number of inputs:\n");
-  fprintf(stderr, "    Brackets can be used for grouping input to the right operator.\n");
-  reset_text_color(stderr);
-  fprintf(stderr, "    example:\n");
-  fprintf(stderr, "       -add -select,x=0 [ file1 -add -topo -file2 ] -merge [ file3 file4 ] out\n");
-  set_text_color(stderr, BRIGHT, BLUE);
-  fprintf(stderr, "#==============================================================================#\n");
-  reset_text_color(stderr);
+  set_text_color(p_target, BRIGHT, BLUE);
+  std::string pad = CLIOptions::pad_size_terminal('=');
+  fprintf(p_target, "%s", pad.c_str());
+  reset_text_color(p_target);
+  fprintf(p_target, "%s", help.c_str());
+  set_text_color(p_target, BRIGHT, BLUE);
+  pad = CLIOptions::pad_size_terminal('=');
+  fprintf(p_target, "%s", pad.c_str());
+  reset_text_color(p_target);
+}
+static void
+print_category(const std::string p_category, FILE *p_target)
+{
+  std::string options = CLIOptions::print_options_help(p_category).c_str();
+  if (!options.empty())
+    {
+      const std::string pad = CLIOptions::pad_size_terminal('=', p_category);
+      fprintf(p_target, "%s", pad.c_str());
+      set_text_color(p_target, BLUE);
+      fprintf(p_target, "%s", options.c_str());
+      reset_text_color(p_target);
+    }
+}
+
+static void
+cdo_usage()
+{
+
+  FILE *target = stderr;
+  std::string pad = CLIOptions::pad_size_terminal('-');
+  fprintf(target, "%s", pad.c_str());
+  fprintf(target, "  Usage : cdo  [Options]  Operator1  [-Operator2  [-OperatorN]]\n");
+  pad = CLIOptions::pad_size_terminal('-');
+  fprintf(target, "%s\n", pad.c_str());
+
+  print_category("Info", target);
+  print_category("Output", target);
+  print_category("Multi Threading", target);
+  print_category("Search Methods", target);
+  print_category("Format Specific", target);
+  print_category("CGRIBEX", target);
+  print_category("Numeric", target);
+  print_category("History", target);
+  print_category("Compression", target);
+  print_category("Hirlam Extensions", target);
+  print_category("Options", target);
+  print_category("Help", target);
+
+  pad = CLIOptions::pad_size_terminal('=', "Environment Variables");
+  fprintf(target, "%s\n", pad.c_str());
+  set_text_color(target, BLUE);
+  fprintf(target, "%s", CLIOptions::print_envvar_help().c_str());
+  reset_text_color(target);
+  fprintf(target, "\n");
+  /*
+  pad = CLIOptions::pad_size_terminal('=', "Syntax Features");
+  fprintf(target, "%s", pad.c_str());
+  fprintf(target, "%s\n", "    Apply");
+  fprintf(target, "%s\n", Parser::apply_help.c_str());
+  pad = CLIOptions::pad_size_terminal('-');
+  fprintf(target, "%s", pad.c_str());
+  fprintf(target, "%s\n", "    Subgroups");
+  fprintf(target, "%s\n", Parser::subgroup_help.c_str());
+  */
+  pad = CLIOptions::pad_size_terminal('=');
+  fprintf(target, "%s\n", pad.c_str());
+  fprintf(target, "    CDO version %s, Copyright (C) 2002-2023 MPI für Meteorologie\n", VERSION);
+  fprintf(target, "    This is free software and comes with ABSOLUTELY NO WARRANTY\n");
+  fprintf(target, "    Report bugs to <https://mpimet.mpg.de/cdo>\n\n");
+  pad = CLIOptions::pad_size_terminal('=');
+  fprintf(target, "%s", pad.c_str());
 }
 
 static void
@@ -274,10 +330,7 @@ cdo_print_help(const char **help)
                   else
                     fprintf(stdout, "%s\n", help[i]);
                 }
-              else
-                {
-                  fprintf(stdout, "%s\n", help[i]);
-                }
+              else { fprintf(stdout, "%s\n", help[i]); }
             }
         }
     }
@@ -315,8 +368,8 @@ set_default_datatype(const char *datatypestr)
   if (isdigit((int) *datatypestr))
     {
       auto nbits = atoi(datatypestr);
-      datatypestr += 1;
-      if (nbits >= 10) datatypestr += 1;
+      datatypestr++;
+      if (nbits >= 10) datatypestr++;
 
       if (dtype == -1)
         {
@@ -372,18 +425,18 @@ set_default_datatype(const char *datatypestr)
       if (*datatypestr == 'l' || *datatypestr == 'L')
         {
           if (IsBigendian()) CdoDefault::Byteorder = CDI_LITTLEENDIAN;
-          datatypestr++;
         }
       else if (*datatypestr == 'b' || *datatypestr == 'B')
         {
           if (!IsBigendian()) CdoDefault::Byteorder = CDI_BIGENDIAN;
-          datatypestr++;
-        }
-      else
-        {
-          cdo_abort("Unsupported character in number of bytes: >%s< !", datatypestr);
         }
+      else { cdo_abort("Unsupported character in number of bytes: >%s< !", datatypestr); }
+
+      datatypestr++;
+      if (*datatypestr != 0)  { cdo_abort("Unsupported character in number of bytes: >%s< !", datatypestr); }
     }
+
+  if (CdoDefault::DataType == -1) { cdo_abort("Number of bits undefined!"); }
 }
 
 static void
@@ -392,23 +445,22 @@ set_default_filetype(const std::string &filetypeString)
 
   if (filetypeString.size() > 0)
     {
-      const char *filetypestr = filetypeString.c_str();
       size_t len = 0;
 
       // clang-format off
-      if      (cdo_cmpstrLenRhs(filetypestr, "grb2",   len)) CdoDefault::FileType = CDI_FILETYPE_GRB2;
-      else if (cdo_cmpstrLenRhs(filetypestr, "grb1",   len)) CdoDefault::FileType = CDI_FILETYPE_GRB;
-      else if (cdo_cmpstrLenRhs(filetypestr, "grb",    len)) CdoDefault::FileType = CDI_FILETYPE_GRB;
-      else if (cdo_cmpstrLenRhs(filetypestr, "nc2",    len)) CdoDefault::FileType = CDI_FILETYPE_NC2;
-      else if (cdo_cmpstrLenRhs(filetypestr, "nc4c",   len)) CdoDefault::FileType = CDI_FILETYPE_NC4C;
-      else if (cdo_cmpstrLenRhs(filetypestr, "nc4",    len)) CdoDefault::FileType = CDI_FILETYPE_NC4;
-      else if (cdo_cmpstrLenRhs(filetypestr, "nc5",    len)) CdoDefault::FileType = CDI_FILETYPE_NC5;
-      else if (cdo_cmpstrLenRhs(filetypestr, "nc1",    len)) CdoDefault::FileType = CDI_FILETYPE_NC;
-      else if (cdo_cmpstrLenRhs(filetypestr, "nczarr", len)) CdoDefault::FileType = CDI_FILETYPE_NCZARR;
-      else if (cdo_cmpstrLenRhs(filetypestr, "nc",     len)) CdoDefault::FileType = CDI_FILETYPE_NC2;
-      else if (cdo_cmpstrLenRhs(filetypestr, "srv",    len)) CdoDefault::FileType = CDI_FILETYPE_SRV;
-      else if (cdo_cmpstrLenRhs(filetypestr, "ext",    len)) CdoDefault::FileType = CDI_FILETYPE_EXT;
-      else if (cdo_cmpstrLenRhs(filetypestr, "ieg",    len)) CdoDefault::FileType = CDI_FILETYPE_IEG;
+      if      (cdo_cmpstrLenRhs(filetypeString, "grb2",   len)) CdoDefault::FileType = CDI_FILETYPE_GRB2;
+      else if (cdo_cmpstrLenRhs(filetypeString, "grb1",   len)) CdoDefault::FileType = CDI_FILETYPE_GRB;
+      else if (cdo_cmpstrLenRhs(filetypeString, "grb",    len)) CdoDefault::FileType = CDI_FILETYPE_GRB;
+      else if (cdo_cmpstrLenRhs(filetypeString, "nc2",    len)) CdoDefault::FileType = CDI_FILETYPE_NC2;
+      else if (cdo_cmpstrLenRhs(filetypeString, "nc4c",   len)) CdoDefault::FileType = CDI_FILETYPE_NC4C;
+      else if (cdo_cmpstrLenRhs(filetypeString, "nc4",    len)) CdoDefault::FileType = CDI_FILETYPE_NC4;
+      else if (cdo_cmpstrLenRhs(filetypeString, "nc5",    len)) CdoDefault::FileType = CDI_FILETYPE_NC5;
+      else if (cdo_cmpstrLenRhs(filetypeString, "nc1",    len)) CdoDefault::FileType = CDI_FILETYPE_NC;
+      else if (cdo_cmpstrLenRhs(filetypeString, "nczarr", len)) CdoDefault::FileType = CDI_FILETYPE_NCZARR;
+      else if (cdo_cmpstrLenRhs(filetypeString, "nc",     len)) CdoDefault::FileType = CDI_FILETYPE_NC2;
+      else if (cdo_cmpstrLenRhs(filetypeString, "srv",    len)) CdoDefault::FileType = CDI_FILETYPE_SRV;
+      else if (cdo_cmpstrLenRhs(filetypeString, "ext",    len)) CdoDefault::FileType = CDI_FILETYPE_EXT;
+      else if (cdo_cmpstrLenRhs(filetypeString, "ieg",    len)) CdoDefault::FileType = CDI_FILETYPE_IEG;
       else
         {
           cdo_warning("Unsupported filetype %s!", filetypeString);
@@ -417,14 +469,11 @@ set_default_filetype(const std::string &filetypeString)
         }
       // clang-format on
 
-      const char *ftstr = filetypestr + len;
+      const char *ftstr = filetypeString.c_str() + len;
 
       if (CdoDefault::FileType != CDI_UNDEFID && *ftstr != 0)
         {
-          if (*ftstr == '_')
-            {
-              set_default_datatype(++ftstr);
-            }
+          if (*ftstr == '_') { set_default_datatype(++ftstr); }
           else
             {
               cdo_warning("Unexpected character >%c< in file type >%s<!", *ftstr, filetypeString);
@@ -481,23 +530,41 @@ alignof_vector_data(const std::vector<int> &tsize) -> int
   return align;
 }
 
+static void
+define_filter(const std::string &argString)
+{
+  if (argString.size() > 0)
+    {
+      if (Options::filterId != 0) { cdo_abort("Filter already defined! Only one filter is allowed."); }
+
+      auto filterArgs = split_with_seperator(argString, ',');
+      Options::filterId = parameter_to_int(filterArgs[0]);
+      if (Options::filterId <= 0) { cdo_abort("Undefined filter id: %d", Options::filterId); }
+      for (size_t i = 1; i < filterArgs.size(); ++i)
+        {
+          if (filterArgs[i].size() > 0) Options::filterParams.push_back(parameter_to_int(filterArgs[i]));
+        }
+    }
+  else { cdo_abort("Filter id missing!"); }
+}
+
 static void
 define_compress(const std::string &argString)
 {
   const char *arg = argString.c_str();
-  size_t len = strlen(arg);
+  size_t len = argString.size();
 
-  if (strncmp(arg, "szip", len) == 0)
+  if (argString == "szip")
     {
       Options::cdoCompType = CDI_COMPRESS_SZIP;
       Options::cdoCompLevel = 0;
     }
-  else if (strncmp(arg, "aec", len) == 0 || strncmp(arg, "ccsds", len) == 0)
+  else if (argString == "aec" || argString == "ccsds")
     {
       Options::cdoCompType = CDI_COMPRESS_AEC;
       Options::cdoCompLevel = 0;
     }
-  else if (strncmp(arg, "jpeg", len) == 0)
+  else if (argString == "jpeg")
     {
       Options::cdoCompType = CDI_COMPRESS_JPEG;
       Options::cdoCompLevel = 0;
@@ -507,10 +574,14 @@ define_compress(const std::string &argString)
       Options::cdoCompType = CDI_COMPRESS_ZIP;
       Options::cdoCompLevel = (len == 5 && arg[3] == '_' && isdigit(arg[4])) ? atoi(&arg[4]) : 1;
     }
-  else
+  else if (strncmp(arg, "zstd", 4) == 0)
     {
-      cdo_abort("Compression type '%s' unsupported!", arg);
+      if (Options::filterId != 0) { cdo_abort("Filter already defined! Only one filter is allowed."); }
+      Options::filterId = 32015;
+      int zstdLevel = (len >= 6 && len <= 7 && arg[4] == '_' && isdigit(arg[5])) ? atoi(&arg[5]) : 1;
+      Options::filterParams.push_back(zstdLevel);
     }
+  else { cdo_abort("Compression type '%s' unsupported!", arg); }
 }
 
 static void
@@ -579,7 +650,7 @@ get_env_vars()
           }
       })
       ->describe_argument("true|false")
-      ->add_help("MISSING HELP");
+      ->add_help("'true' disables history attribute.");
 
   CLIOptions::envvar("CDO_RESET_HISTORY")
       ->add_effect([&](const std::string &envstr) { Options::CDO_Reset_History = parameter_to_bool(envstr); })
@@ -602,10 +673,10 @@ get_env_vars()
   CLIOptions::envvar("CDO_DISABLE_FILESUFFIX")
       ->add_effect([&]() { strcat(cdo::File_Suffix, "nullptr"); })
       ->describe_argument("true|false")
-      ->add_help("MISSING HELP");
+      ->add_help("'true' disables file suffix.");
 
   CLIOptions::envvar("CDO_VERSION_INFO")
-      ->add_effect([&](const std::string &envstr) { Options::VersionInfo = parameter_to_bool(envstr);})
+      ->add_effect([&](const std::string &envstr) { Options::VersionInfo = parameter_to_bool(envstr); })
       ->describe_argument("true|false")
       ->add_default("true")
       ->add_help("'false' disables the global NetCDF attribute CDO [default: true].");
@@ -758,36 +829,6 @@ cdo_set_options()
   if (CDO_netcdf_hdr_pad > 0) cdiDefGlobal("NETCDF_HDR_PAD", CDO_netcdf_hdr_pad);
 }
 
-static long
-stringToNumBytes(const std::string &intstring)
-{
-  long intval = -1;
-
-  auto len = (int) intstring.size();
-  if (len)
-    {
-      long fact = 1;
-      for (int loop = 0; loop < len; loop++)
-        {
-          if (!isdigit((int) intstring[loop]))
-            {
-              switch (tolower((int) intstring[loop]))
-                {
-                case 'k': fact = 1024; break;
-                case 'm': fact = 1048576; break;
-                case 'g': fact = 1073741824; break;
-                default: fact = 0; break;
-                }
-              break;
-            }
-        }
-
-      if (fact) intval = fact * atol(intstring.c_str());
-    }
-
-  return intval;
-}
-
 void
 evaluate_color_options(const std::string &arg)
 {
@@ -795,7 +836,7 @@ evaluate_color_options(const std::string &arg)
   if      ("all"  == arg) mpmo_color_set(All);
   else if ("auto" == arg) mpmo_color_set(Auto);
   else if ("no"   == arg) mpmo_color_set(No);
-  else cdo_abort("Color option <%s> unknown. Known options: auto, all, no", Yellow(arg.c_str()));
+  else cdo_abort("Color option <%s> unknown. Known options: auto, all, no", Yellow(arg));
   // clang-format on
 }
 
@@ -817,7 +858,7 @@ evaluate_except_options(const std::string &arg)
 static void
 cdo_rusage(void)
 {
-#if defined(HAVE_SYS_RESOURCE_H) && defined(RUSAGE_SELF)
+#if defined HAVE_SYS_RESOURCE_H && defined RUSAGE_SELF
   struct rusage ru;
   auto status = getrusage(RUSAGE_SELF, &ru);
   if (status == 0)
@@ -884,27 +925,22 @@ get_progname(char *string)
   char *progname = strrchr(string, '/');
 #endif
 
-  if (progname == nullptr)
-    progname = string;
-  else
-    progname++;
-
-  return progname;
+  return (progname == nullptr) ? string : ++progname;
 }
 
-#ifdef HAVE_NC4HDF5
+#ifdef HAVE_H5DONT_ATEXIT
 extern "C" void H5dont_atexit(void);
 #endif
 
-void
-print_oper_attribs_rename_this_later(std::string argument)
+static void
+print_operator_attributes(const std::string &argument)
 {
   ModListOptions local_modListOpt;
   local_modListOpt.parse_request(argument);
   operator_print_list(local_modListOpt);
 }
 
-void
+static void
 setup_openMP()
 {
 #ifdef _OPENMP
@@ -936,7 +972,7 @@ setup_openMP()
 #endif
 }
 
-void
+static void
 cdo_print_debug_info()
 {
   fprintf(stderr, "stdinIsTerminal:   %d\n", cdo::stdinIsTerminal);
@@ -946,7 +982,7 @@ cdo_print_debug_info()
   print_pthread_info();
 }
 
-std::string
+static std::string
 predefined_tables(int p_padding)
 {
   const char *name;
@@ -963,78 +999,97 @@ predefined_tables(int p_padding)
   return tables;
 }
 
-void
+static void
 create_options_from_envvars()
 {
-  CLIOptions::option_from_envvar("CDO_DISABLE_FILESUFFIX");
-  CLIOptions::option_from_envvar("CDO_DISABLE_HISTORY");
-  CLIOptions::option_from_envvar("CDO_DOWNLOAD_PATH");
-  CLIOptions::option_from_envvar("CDO_FILE_SUFFIX");
-  CLIOptions::option_from_envvar("CDO_HISTORY_INFO");
-  CLIOptions::option_from_envvar("CDO_ICON_GRIDS");
-  CLIOptions::option_from_envvar("CDO_RESET_HISTORY");
-  CLIOptions::option_from_envvar("CDO_TEST");
   CLIOptions::option_from_envvar("CDO_VERSION_INFO");
+
+  CLIOptions::option_from_envvar("CDO_DISABLE_FILESUFFIX");
+  CLIOptions::option_from_envvar("CDO_FILE_SUFFIX");
+
+  CLIOptions::option_from_envvar("CDO_DISABLE_HISTORY")->set_category("History");
+  CLIOptions::option_from_envvar("CDO_HISTORY_INFO")->set_category("History");
+  CLIOptions::option_from_envvar("CDO_RESET_HISTORY")->set_category("History");
+
+  CLIOptions::option_from_envvar("CDO_DOWNLOAD_PATH");
+
+  CLIOptions::option_from_envvar("CDO_ICON_GRIDS");
+
+  CLIOptions::option_from_envvar("CDO_TEST");
 }
 
-void
+static void
 setup_cli_options()
 {
   CLIOptions::option("envvars")
       ->add_effect([&]() { CLIOptions::print_envvars = true; })
       ->aborts_program(true)
+      ->set_category("Info")
       ->add_help("Prints the environment variables of CDO.");
 
   CLIOptions::option("settings")
       ->add_effect([&]() { CLIOptions::print_settings = true; })
       ->aborts_program(true)
+      ->set_category("Info")
       ->add_help("Prints the settings of CDO.");
 
-  CLIOptions::option("debug", "d")->add_effect([&]() {
-    cdo::set_debug(1);
-    cdo_version();
-  });
+  CLIOptions::option("debug", "d")
+      ->add_effect([&]() {
+        unsigned cdoDebugLevel = 0;
+        unsigned cdiDebugLevel = 0;
+        cdo::parse_debug_arguments({ "1" }, cdoDebugLevel, cdiDebugLevel);
+
+        cdiDebug(cdiDebugLevel);
+        cdo::set_debug(cdoDebugLevel);
+        cdo_version();
+      })
+      ->set_category("Output")
+      ->add_help("Pring all available debug messages");
 
   CLIOptions::option("scoped_debug", "D")
-      ->describe_argument("debug_scope")
-      ->set_argument_optional(true)
-      ->add_effect([&](const std::string &argument) {
-        if (argument.empty())
-          {
-            std::cout << "No debug level given please choose: " << std::endl;
-            print_debug_options();
-            exit(EXIT_SUCCESS);
-          }
-        else
-          {
-            auto debugLevel = parameter_to_int(argument);
-            if (debugLevel > 1) cdiDebug(debugLevel);
-            cdo::set_debug(debugLevel);
-            cdo_version();
-          }
+      ->describe_argument("comma seperated scopes")
+      ->set_category("Output")
+      ->on_empty_argument([]() {
+        std::cerr << "No debug level given please choose: " << std::endl;
+        print_debug_options();
+        exit(EXIT_SUCCESS);
       })
-      ->add_help("DebugLevels:", "Cdi: 0:off, 1:on, 2:cdi, 3:memory, 4:file, 5:format",
-                 "Cdo: 6:cdo, 7:pipeStream, 8:fileStream, 9:pipe,", "     10:pthread, 11:process, 12:processmanager");
+      ->add_effect([&](const std::string &argument) {
+        auto [success, tokens] = tokenize_comma_seperated_int_list(argument);
+
+        unsigned cdoDebugLevel = 0;
+        unsigned cdiDebugLevel = 0;
+        cdo::parse_debug_arguments(tokens, cdoDebugLevel, cdiDebugLevel);
+
+        cdiDebug(cdiDebugLevel);
+        cdo::set_debug(cdoDebugLevel);
+
+        cdo_version();
+      })
+      ->add_help("Multiple scopes simultaneously possible. Use this option without arguments to get a list of possible scopes");
 
   CLIOptions::option("worker")
       ->describe_argument("num")
       ->add_effect([&](const std::string &argument) { Options::numStreamWorker = parameter_to_int(argument); })
+      ->set_category("Multi Threading")
       ->add_help("Number of worker to decode/decompress GRIB records.");
 
   CLIOptions::option("precision")
       ->describe_argument("float_digits[,double_digits]")
       ->add_effect([&](const std::string &argument) { cdo_set_digits(argument.c_str()); })
+      ->set_category("Numeric")
       ->add_help("Precision to use in displaying floating-point data (default: 7,15).");
 
   CLIOptions::option("percentile")
       ->describe_argument("method")
+      ->set_category("Numeric")
       ->add_effect([&](const std::string &argument) { percentile_set_method(argument); })
       ->add_help("Methods: nrank, nist, rtype8, <NumPy method (linear|lower|higher|nearest|...)>");
 
   CLIOptions::option("netcdf_hdr_pad")
       ->describe_argument("nbr")
       ->add_effect([&](const std::string &argument) {
-        int netcdf_hdr_pad = stringToNumBytes(argument);
+        int netcdf_hdr_pad = parameter_to_bytes(argument);
         if (netcdf_hdr_pad >= 0) CDO_netcdf_hdr_pad = netcdf_hdr_pad;
       })
       ->add_help("Pad NetCDF output header with nbr bytes.");
@@ -1044,30 +1099,34 @@ setup_cli_options()
       ->add_effect([&](const std::string &argument) { Options::Use_FFTW = (int) parameter_to_bool(argument); })
       ->add_help("Sets fftw usage.");
 
-  CLIOptions::option("cellsearchmethod")
-      ->describe_argument("spherepart|latbins")
-      ->add_effect([&](const std::string &argument) { set_cell_search_method(argument.c_str()); })
-      ->add_help("Sets the cell search method.");
-
   CLIOptions::option("config")
       ->describe_argument("all|all-json|<specific_feature_name>")
-      ->add_effect([&](const std::string &argument) { cdo_print_config(argument); })
+      ->add_effect([&](const std::string &argument) { CdoFeatures::cdo_print_config(argument); })
+      ->on_empty_argument([&]() { CdoFeatures::print_argument_options(); })
       ->aborts_program(true)
+      ->set_category("Info")
       ->add_help("Prints all features and the enabled status.", "Use option <all> to see explicit feature names.");
 
+  CLIOptions::option("cellsearchmethod")
+      ->describe_argument("spherepart|latbins")
+      ->set_category("Search Methods")
+      ->add_effect([&](const std::string &argument) { set_cell_search_method(argument); })
+      ->add_help("Sets the cell search method.");
+
   CLIOptions::option("pointsearchmethod")
       ->set_internal(true)
       ->describe_argument("<full|kdtree|nanoflann|spherepart|latbins>")
+      ->set_category("Search Methods")
       ->add_effect([&](const std::string &argument) { set_point_search_method(argument); })
       ->add_help("Sets the point search method.");
 
   CLIOptions::option("gridsearchradius")
       ->describe_argument("degrees[0..180]")
+      ->set_category("Search Methods")
       ->add_effect([&](const std::string &argument) {
-        extern double pointSearchRadius;
-        auto fval = radius_str_to_deg(argument.c_str());
+        auto fval = radius_str_to_deg(argument);
         if (fval < 0 || fval > 180) cdo_abort("%s=%g out of bounds (0-180 deg)!", "gridsearchradius", fval);
-        pointSearchRadius = fval;
+        cdo_set_search_radius(fval);
       })
       ->add_help("Sets the grid search radius (0-180 deg).");
 
@@ -1086,6 +1145,7 @@ setup_cli_options()
 
   CLIOptions::option("enableexcept")
       ->describe_argument("except")
+      ->set_category("Numeric")
       ->add_effect([&](const std::string &argument) {
         auto except = evaluate_except_options(argument);
         if (except < 0) cdo_abort("option --%s: unsupported argument: %s", "enableexcept", argument);
@@ -1119,33 +1179,63 @@ setup_cli_options()
 
   CLIOptions::option("float")
       ->add_effect([&]() { Options::CDO_Memtype = MemType::Float; })
+      ->set_category("Numeric")
       ->add_help("Using single precision floats for data in memory.");
 
   CLIOptions::option("single")
       ->add_effect([&]() { Options::CDO_Memtype = MemType::Float; })
+      ->set_category("Numeric")
       ->add_help("Using single precision floats for data in memory.");
 
   CLIOptions::option("double")
       ->add_effect([&]() { Options::CDO_Memtype = MemType::Double; })
+      ->set_category("Numeric")
       ->add_help("Using double precision floats for data in memory.");
 
-  CLIOptions::option("rusage")->add_effect([&]() { CDO_Rusage = 1; })->add_help("Print information about resource utilization.");
+  CLIOptions::option("rusage")
+      ->add_effect([&]() { CDO_Rusage = 1; })
+      ->add_help("Print information about resource utilization.")
+      ->set_category("Info");
 
   CLIOptions::option("attribs")
       ->describe_argument("arbitrary|filesOnly|onlyFirst|noOutput|obase")
       ->aborts_program(true)
-      ->add_effect([&](const std::string &argument) { print_oper_attribs_rename_this_later(argument); })
+      ->set_category("Info")
+      ->add_effect([&](const std::string &argument) { print_operator_attributes(argument); })
       ->add_help("Lists all operators with choosen features or the attributes of given operator(s)",
                  "operator name or a combination of [arbitrary,filesOnly,onlyFirst,noOutput,obase].");
 
   CLIOptions::option("operators")
       ->aborts_program(true)
-      ->add_effect([&]() { print_oper_attribs_rename_this_later(std::string()); })
+      ->add_effect([&]() { print_operator_attributes(std::string()); })
+      ->set_category("Info")
+      ->add_help("Prints list of operators.");
+
+  CLIOptions::option("module_info")
+      ->aborts_program(true)
+      ->describe_argument("module name")
+      ->set_category("Info")
+      ->add_effect([&](const std::string &argument) {
+        auto names = get_module_operator_names(argument);
+        if (names.empty())
+          {
+            std::string errstr = "Module " + argument + " not found\n";
+            std::cerr << errstr;
+          }
+        else
+          {
+
+            std::string info_string = "\n" + argument + ":\n";
+            for (const auto &name : names) { info_string += std::string(4, ' ') + name + "\n"; }
+            std::cerr << info_string + "\n";
+          }
+      })
       ->add_help("Prints list of operators.");
 
   CLIOptions::option("operators_no_output")
       ->aborts_program(true)
-      ->add_effect([&]() { print_oper_attribs_rename_this_later("noOutput"); })
+      ->add_effect([&]() { print_operator_attributes("noOutput"); })
+      ->set_category("Info")
       ->add_help("Prints all operators which produce no output.");
 
   CLIOptions::option("pedantic")->add_effect([&]() { MpMO::enable_pedantic(true); })->add_help("Warnings count as errors.");
@@ -1153,10 +1243,12 @@ setup_cli_options()
   CLIOptions::option("color", "C")
       ->describe_argument("auto|no|all")
       ->add_effect([&](const std::string &argument) { evaluate_color_options(argument); })
+      ->set_category("Output")
       ->add_help("Set behaviour of colorized output messages.");
 
   CLIOptions::option("eccodes")
       ->add_effect([&]() { cdiDefGlobal("ECCODES_GRIB1", true); })
+      ->set_category("Format Specific")
       ->add_help("Use ecCodes to decode/encode GRIB1 messages.");
 
   CLIOptions::option("format", "f")
@@ -1166,27 +1258,26 @@ setup_cli_options()
 
   CLIOptions::option("help", "h")
       ->describe_argument("operator")
-      ->set_argument_optional(true)
-      ->add_effect([&](const std::string &argument) {
-        if (argument.empty())
-          CLIOptions::usage();
-        else
-          cdo_print_help(operator_help(argument));
-      })
+      ->add_effect([&](const std::string &argument) { cdo_print_help(operator_help(argument)); })
+      ->on_empty_argument([]() { cdo_usage(); })
       ->aborts_program(true)
+      ->set_category("Help")
       ->add_help("Shows either help information for the given operator or the usage of CDO.");
 
   CLIOptions::option("history")
       ->add_effect([&]() { Options::CDO_Append_History = 1; })
+      ->set_category("History")
       ->add_help("Do append to NetCDF \"history\" global attribute.");
 
   CLIOptions::option("no_history")
       ->add_effect([&]() { Options::CDO_Append_History = 0; })
+      ->set_category("History")
       ->add_help("Do not append to NetCDF \"history\" global attribute.");
 
   CLIOptions::option("version", "V")
       ->add_effect([&]() { cdo_version(); })
       ->aborts_program(true)
+      ->set_category("Info")
       ->add_help("Print the version number.");
 
   CLIOptions::option("dryrun", "A")->add_effect([&]() { applyDryRun = true; })->add_help("Dry run that shows processed CDO call.");
@@ -1202,6 +1293,7 @@ setup_cli_options()
   // clang-format off
   CLIOptions::option("default_datatype", "b")
       ->describe_argument("nbits")
+      ->set_category("Numeric")
       ->add_effect([&](const std::string &argument) { set_default_datatype(argument.c_str()); })
       ->add_help("Set the number of bits for the output precision",
                  "    I8|I16|I32|F32|F64     for nc1,nc2,nc4,nc4c,nc5,nczarr;",
@@ -1227,13 +1319,16 @@ setup_cli_options()
 
   CLIOptions::option("chunktype", "k")
       ->describe_argument("auto|grid|lines")
+
+      ->set_category("Format Specific")
       ->add_effect([&](const std::string &argument) { define_chunktype(argument); })
       ->add_help("NetCDF4 chunk type: auto, grid or lines.");
 
   CLIOptions::option("chunksize")
       ->describe_argument("size")
+      ->set_category("Format Specific")
       ->add_effect([&](const std::string &argument) {
-        int chunkSize = stringToNumBytes(argument);
+        int chunkSize = parameter_to_bytes(argument);
         if (chunkSize >= 0) Options::cdoChunkSize = chunkSize;
       })
       ->add_help("NetCDF4 chunk size.");
@@ -1267,6 +1362,7 @@ setup_cli_options()
   CLIOptions::option("num_threads", "P")
       ->describe_argument("nthreads")
       ->add_effect([&](const std::string &argument) { CDO_numThreads = parameter_to_int(argument); })
+      ->set_category("Multi Threading")
       ->add_help("Set number of OpenMP threads.");
 
   CLIOptions::option("parrallel_read", "p")
@@ -1275,14 +1371,17 @@ setup_cli_options()
         Options::CDO_Parallel_Read = true;
         Options::CDO_task = true;
       })
+      ->set_category("Multi Threading")
       ->add_help("Enables parallel read.");
 
   CLIOptions::option("sortname", "Q")
       ->add_effect([&]() { cdiDefGlobal("SORTNAME", true); })
+      ->set_category("Format Specific")
       ->add_help("Alphanumeric sorting of NetCDF parameter names.");
 
   CLIOptions::option("seed")
       ->describe_argument("seed")
+      ->set_category("Numeric")
       ->add_effect([&](const std::string &argument) {
         int intarg = parameter_to_int(argument);
         if (intarg < 0) cdo_abort("Unsupported value for option --seed %d [>=0]", intarg);
@@ -1295,6 +1394,7 @@ setup_cli_options()
         Options::cdoRegulargrid = true;
         cdiDefGlobal("REGULARGRID", true);
       })
+      ->set_category("CGRIBEX")
       ->add_help("Convert GRIB1 data from global reduced to regular Gaussian grid (cgribex only).");
 
   CLIOptions::option("relative_taxis", "r")
@@ -1316,13 +1416,15 @@ setup_cli_options()
         MpMO::enable_silent_mode(Options::silentMode);
         progress::silentMode = true;
       })
+      ->set_category("Output")
       ->add_help("Silent mode.");
 
   CLIOptions::option("timer", "T")->add_effect([&]() { Options::Timer = true; })->add_help("Enable timer.");
 
   CLIOptions::option("table", "t")
       ->describe_argument("codetab")
-      ->add_effect([&](const std::string &argument) { CdoDefault::TableID = define_table(argument.c_str()); })
+      ->set_category("CGRIBEX")
+      ->add_effect([&](const std::string &argument) { CdoDefault::TableID = cdo::define_table(argument); })
       ->add_help("Set GRIB1 default parameter code table name or file (cgribex only).", predefined_tables(CLIOptions::padding));
 
   CLIOptions::option("interactive", "u")
@@ -1344,6 +1446,7 @@ setup_cli_options()
         extern int _Verbose;  // CDI Warnings
         _Verbose = 0;
       })
+      ->set_category("Output")
       ->add_help("Disable warning messages.");
 
   CLIOptions::option("par_io", "X")
@@ -1351,36 +1454,57 @@ setup_cli_options()
       ->add_effect([&]() {
         Options::cdoParIO = true;  // multi threaded I/O
       })
-      ->add_help("Enables multithreaded I/O.");
+      ->add_help("Enables multithreaded I/O.")
+      ->set_category("Multi Threading");
 
   CLIOptions::option("compress", "Z")
       ->add_effect([&]() { Options::cdoCompress = true; })
+      ->set_category("Compression")
       ->add_help("Enables compression. Default = SZIP");
 
+  CLIOptions::option("filter", "F")
+      ->describe_argument("filterId,params")
+      ->add_effect([&](const std::string &argument) { define_filter(argument); })
+      ->set_category("Fromat Specific")
+      ->add_help("NetCDF4/HDF5 filter description.");
+
   CLIOptions::option("compression_type", "z")
-      ->describe_argument("aec|jpeg|zip[_1-9]")
+      ->describe_argument("aec|jpeg|zip[_1-9]|zstd[1-19]")
+      ->set_category("Compression")
       ->add_effect([&](const std::string &argument) { define_compress(argument); })
-      ->add_help("SZIP compression of GRIB1 records.", "aec        AEC compression of GRIB2 records",
-                 "jpeg       JPEG compression of GRIB2 records", "zip[_1-9]  Deflate compression of NetCDF4 variables");
+      ->add_help("aec         AEC compression of GRIB2 records", "jpeg        JPEG compression of GRIB2 records",
+                 "zip[_1-9]   Deflate compression of NetCDF4 variables", "zstd[_1-19] Zstandard compression of NetCDF4 variables");
 
   CLIOptions::option("nsb")
       ->set_internal(true)
       ->describe_argument("1-23")
       ->add_effect([&](const std::string &argument) { Options::nsb = parameter_to_int(argument); })
+      ->set_category("Numeric")
       ->add_help("Number of significant bits used for bit-rounding.");
 
   CLIOptions::option("show_available_options")
       ->set_internal(true)
       ->aborts_program(true)
+      ->set_category("Info")
       ->add_effect([&]() { CLIOptions::print_available_options(); })
       ->add_help("Shows all available optins and prints all shortforms, only internal use for testing.");
 
-  CLIOptions::option("argument_groups")->aborts_program(true)->add_effect([&]() { cdo_variableInputs(); });
+  CLIOptions::option("argument_groups")
+      ->aborts_program(true)
+      ->add_help("Explanation and Examples for subgrouping operators with [ ] syntax")
+      ->add_effect([&]() { cdo_display_syntax_help(Parser::subgroup_help, stderr); })
+      ->set_category("Help");
+  CLIOptions::option("apply")
+      ->aborts_program(true)
+      ->add_help("Explanation and Examples for -apply syntax")
+      ->add_effect([&]() { cdo_display_syntax_help(Parser::apply_help, stderr); })
+      ->set_category("Help");
   CLIOptions::option("sortparam")->add_effect([]() { cdiDefGlobal("SORTPARAM", true); });
 
 #ifdef HIRLAM_EXTENSIONS
   CLIOptions::option("Dkext")
       ->describe_argument("debLev")
+      ->set_category("Hirlam Extension")
       ->add_effect([&](const std::string &argument) {
         auto extDebugVal = parameter_to_int(argument);
         if (extDebugVal > 0)
@@ -1394,6 +1518,7 @@ setup_cli_options()
 
   CLIOptions::option("outputGribDataScanningMode")
       ->describe_argument("mode")
+      ->set_category("Hirlam Extension")
       ->add_effect([&](const std::string &argument) {
         auto scanningModeValue = parameter_to_int(argument);
         if (cdoDebugExt) printf("scanningModeValue=%d\n", scanningModeValue);
@@ -1416,8 +1541,6 @@ setup_cli_options()
 int
 main(int argc, char *argv[])
 {
-  int status = 0;
-
   cdo::set_exit_function(cdo_exit);
   cdo::set_context_function(process_inq_prompt);
   progress::set_context_function(process_inq_prompt);
@@ -1442,15 +1565,17 @@ main(int argc, char *argv[])
 
   setup_cli_options();
 
-  int CDO_optind = CLIOptions::parse(std::vector<std::string>(argv, argv + argc));
+  auto CDO_optind = CLIOptions::parse(std::vector<std::string>(argv, argv + argc));
 
-  if (CDO_optind == CLIOptions::ABORT_REQUESTED) exit(EXIT_FAILURE);
-  else if (CDO_optind == CLIOptions::EXIT_REQUESTED) exit(EXIT_SUCCESS);
+  if (CDO_optind == CLIOptions::ABORT_REQUESTED)
+    exit(EXIT_FAILURE);
+  else if (CDO_optind == CLIOptions::EXIT_REQUESTED)
+    exit(EXIT_SUCCESS);
 
-  if (CDO_optind >= argc && !Help)
+  if (CDO_optind >= argc)
     {
       fprintf(stderr, "\nNo operator given!\n\n");
-      CLIOptions::usage();
+      cdo_usage();
       exit(EXIT_FAILURE);
     }
   else
@@ -1463,20 +1588,9 @@ main(int argc, char *argv[])
 
       if (cdo::dbg()) cdo_print_debug_info();
 
-      if (Help)
-        {
-          CLIOptions::usage();
-          return status;
-        }
-
       std::vector<std::string> new_argv(&argv[CDO_optind], argv + argc);
 
       new_argv = expand_wild_cards(new_argv);
-      if (applyDryRun == true)
-        {
-          std::cerr << argv_to_string(new_argv) << std::endl;
-          exit(applyDryRun ? 0 : -1);
-        }
 
       if (CdoDefault::TableID != CDI_UNDEFID) cdo_def_table_id(CdoDefault::TableID);
 
@@ -1484,15 +1598,20 @@ main(int argc, char *argv[])
       timer_read = timer_new("read");
       timer_write = timer_new("write");
 
-#ifdef HAVE_NC4HDF5
-      H5dont_atexit(); // don't call H5close on exit
+#ifdef HAVE_H5DONT_ATEXIT
+      H5dont_atexit();  // don't call H5close on exit
 #endif
 #ifdef CUSTOM_MODULES
       load_custom_modules("custom_modules");
       close_library_handles();
 #endif
 
-      auto processStructure = Parser::parse(new_argv);
+      auto processStructure = Parser::parse(new_argv, process_inq_prompt);
+      if (applyDryRun == true)
+        {
+          std::cerr << processStructure[0]->to_string() << std::endl;
+          exit(applyDryRun ? 0 : -1);
+        }
       g_processManager.buildProcessTree(processStructure);
       timer_start(timer_total);
       g_processManager.run_processes();
@@ -1504,7 +1623,5 @@ main(int argc, char *argv[])
 
   if (CDO_Rusage) cdo_rusage();
 
-  if (!status) status = Options::cdoExitStatus;
-
-  return status;
+  return Options::cdoExitStatus;
 }
