@@ -15,6 +15,18 @@
 
 #include "cdo_output.h"
 
+static std::string DEFAULT_CATEGORY = "Options";
+
+struct cdo_option_argument
+{
+  std::string description = std::string();
+  bool is_optional = false;
+  std::string errmsg = std::string();
+  std::string default_value = "";
+  std::string value = std::string();
+  std::function<void(std::string argument)> on_empty_argument = [](std::string s = "") { cdo_abort("missing argument for %s", s); };
+};
+
 struct cdo_option_2
 {
 
@@ -24,15 +36,35 @@ struct cdo_option_2
   };
   bool hasArgument = false;
   bool abortOnExecute = false;
-  std::string argument = std::string();
+  cdo_option_argument argument = cdo_option_argument();
   std::vector<std::string> description = std::vector<std::string>();
-  std::string argumentDescription = std::string();
   std::string name = std::string();
   std::string shortName = std::string();
   bool isInternal = false;
-  bool argumentIsOptional = false;
   std::string linkedEnvironmentVariable = std::string();
-  std::string default_value = "";
+  std::string category = DEFAULT_CATEGORY;
+
+  cdo_option_2 *
+  set_category(std::string p_category)
+  {
+    category = p_category;
+    return this;
+  }
+
+  cdo_option_2 *
+  on_empty_argument(const std::function<void(std::string p_argument)> p_on_empty_argument)
+  {
+    argument.on_empty_argument = p_on_empty_argument;
+    return this;
+  }
+
+  cdo_option_2 *
+  on_empty_argument(const std::function<void()> p_on_empty_argument)
+  {
+    argument.on_empty_argument = [p_on_empty_argument](std::string){p_on_empty_argument();};
+    return this;
+  }
+
 
   cdo_option_2 *
   add_effect(const std::function<void(std::string argument)> p_effect)
@@ -41,19 +73,6 @@ struct cdo_option_2
     effect = p_effect;
     return this;
   }
-  cdo_option_2 *
-  set_internal(bool p_is_internal)
-  {
-    isInternal = p_is_internal;
-    return this;
-  }
-
-  cdo_option_2 *
-  add_default(const std::string &p_default_value)
-  {
-    default_value = p_default_value;
-    return this;
-  }
 
   cdo_option_2 *
   add_effect(const std::function<void(void)> p_effect)
@@ -62,17 +81,32 @@ struct cdo_option_2
     return this;
   }
 
+  cdo_option_2 *
+  set_internal(bool p_is_internal)
+  {
+    isInternal = p_is_internal;
+    return this;
+  }
+
+  cdo_option_2 *
+  add_default(const std::string &p_default_value)
+  {
+    argument.default_value = p_default_value;
+    return this;
+  }
+
+
   cdo_option_2 *
   describe_argument(const std::string &desc)
   {
     hasArgument = true;
-    argumentDescription = desc;
+    argument.description = desc;
     return this;
   }
   cdo_option_2 *
   set_argument_optional(bool p_isOptional)
   {
-    argumentIsOptional = p_isOptional;
+    argument.is_optional = p_isOptional;
     return this;
   }
 
@@ -96,15 +130,12 @@ struct cdo_option_2
   std::string
   get_arg()
   {
-    return argument;
+    return argument.value;
   }
   void
   execute()
   {
-    if (effect == nullptr)
-      {
-        cdo_abort("effect not set");
-      }
+    if (effect == nullptr) { cdo_abort("effect not set"); }
     effect(get_arg());
   }
 
@@ -130,16 +161,10 @@ struct cdo_option_2
       {
         if (hasArgument)
           {
-            if (*env_var == '\0')
-              {
-                cdo_abort("Error: %s defined but has no value", linkedEnvironmentVariable);
-              }
+            if (*env_var == '\0') { cdo_abort("Error: %s defined but has no value", linkedEnvironmentVariable); }
             effect(std::string(env_var));
           }
-        else
-          {
-            effect(std::string());
-          }
+        else { effect(std::string()); }
       }
   }
 };
@@ -154,6 +179,7 @@ private:
   static std::map<std::string, std::shared_ptr<cdo_option_2>> envvarMap;
 
 public:
+  static std::string pad_size_terminal(char padWith, const std::string &sourround = std::string());
   const static int EXIT_REQUESTED;
   const static int ABORT_REQUESTED;
   const static int padding;
@@ -164,11 +190,11 @@ public:
   static void get_env_vars();
   static std::shared_ptr<cdo_option_2> &option(const std::string &p_name, const std::string &p_short_form = std::string());
   static std::shared_ptr<cdo_option_2> &envvar(const std::string &p_name);
-  static void usage();
+  static cdo_option_2 *option_from_envvar(const std::string &p_envvarName);
+
   static void print_available_options();
-  static void print_options_help();
-  static void print_envvar_help();
+  static std::string print_options_help(std::string p_category = DEFAULT_CATEGORY);
+  static std::string print_envvar_help();
   static void print_registry(const std::vector<std::shared_ptr<cdo_option_2>> &p_registry);
-  static void option_from_envvar(const std::string &p_envvarName);
 };
 #endif /* _CDO_GETOPT_H */
