@@ -14,6 +14,8 @@
 #include <cdi.h>
 #include <pthread.h>
 #include <string>
+#include <limits>
+#include <bitset>
 
 #include "cdo_output.h"
 
@@ -21,61 +23,144 @@
 int cdoDebug = 0;
 int cdoDebugExt = 0;  //  Debug level for the KNMI extensions
                       // Subsystem Debug Switches
-int PSTREAM = 0;
-int PROCESS = 0;
-int PIPE = 0;
-int PIPE_STREAM = 0;
-int FILE_STREAM = 0;
-int PTHREAD = 0;
-int PROCESS_MANAGER = 0;
-int CDO_NODE = 0;
+unsigned PROCESS = 0;
+unsigned PIPE = 0;
+unsigned PIPE_STREAM = 0;
+unsigned FILE_STREAM = 0;
+unsigned PTHREAD = 0;
+unsigned PROCESS_MANAGER = 0;
+unsigned CDO_NODE = 0;
+unsigned PARSER = 0;
+unsigned PROCESS_INT = 0;
+
+std::string debug_option_string = "DebugLevels:\n"
+                                  "     0: off \n"
+                                  "     1: all debugs messages enabled\n"
+                                  "  Cdi:\n"
+                                  "     2: cdi\n"
+                                  "     3: memory\n"
+                                  "     4: file\n"
+                                  "     5: format\n"
+                                  "  Cdo:\n"
+                                  "     6: CDO\n"
+                                  "     7: PipeStream\n"
+                                  "     8: FileStream\n"
+                                  "     9: Pipe\n"
+                                  "    10: Pthread\n"
+                                  "    11: Process\n"
+                                  "    12: Process manager\n"
+                                  "    13: CDO nodes\n"
+                                  "    14: Parser\n"
+                                  "    15: Process interface\n";
 
 void
 print_debug_options()
 {
-  std::cout << "DebugLevels:" << std::endl
-            << "  Cdi:" << std::endl
-            << "     0: off " << std::endl
-            << "     1: on : std debug: 2 cdi,32 cdo, 512 processes, 1024 process manager" << std::endl
-            << "     2: cdi" << std::endl
-            << "     3: memory" << std::endl
-            << "     4: file" << std::endl
-            << "     5: format" << std::endl
-            << "  Cdo:" << std::endl
-            << "     6: cdo" << std::endl
-            << "     7: pipeStream" << std::endl
-            << "     8: fileStream" << std::endl
-            << "     9: pipe" << std::endl
-            << "    10: pthread" << std::endl
-            << "    11: process" << std::endl
-            << "    12: process manager" << std::endl
-            << "    13: cdo nodes" << std::endl;
+  std::cout << debug_option_string;
 }
 
 namespace cdo
 {
 void
-set_debug(int p_debug_level)
+parse_debug_arguments(const std::vector<std::string> &tokens, unsigned &cdoDebugLevel, unsigned &cdiDebugLevel)
 {
-  MpMO::DebugLevel = p_debug_level;
-  if (p_debug_level == 1 || (p_debug_level & 1 << 5)) cdoDebug = 1;
-  if (p_debug_level == 1 || (p_debug_level & 1 << 6)) FILE_STREAM = 1;
-  if (p_debug_level == 1 || (p_debug_level & 1 << 7)) PIPE_STREAM = 1;
+
+  for (std::string t : tokens)
+    {
+      if (t.substr(0, 4).compare("ext=") == 0)
+        {
+          cdoDebugExt = std::stoul(t.substr(5));
+          continue;
+        }
+      unsigned int_token = std::stoul(t);
+      switch (int_token)
+        {
+        case 0:
+          cdoDebugLevel = 0;
+          cdiDebugLevel = 0;
+          break;
+        case 1:
+          cdoDebugLevel = std::numeric_limits<unsigned>::max();
+          cdiDebugLevel = std::numeric_limits<unsigned>::max();
+          break;
+        case 2: cdiDebugLevel = std::numeric_limits<unsigned>::max(); break;
+        case 6: cdoDebugLevel = std::numeric_limits<unsigned>::max(); break;
+
+        default:
+          if (int_token > 6) { cdoDebugLevel = (cdoDebugLevel | (1 << (int_token))); }
+          else
+            {
+              cdiDebugLevel = (cdiDebugLevel | (1 << (int_token - 1)));
+            }
+        }
+    }
+}
+
+// unused, only for debug reasons
+void
+print_debug_levels(const unsigned cdoDebugLevel, const unsigned cdiDebugLevel)
+{
+  // clang-format off
+  std::string deb_level = "CDO Debug Levels:\n";
+  deb_level   +="PIPE_STREAM:     "  + std::string(PIPE_STREAM ? "ON" : "OFF")     + "\n"
+              + "FILE_STREAM:     "  + std::string(FILE_STREAM ? "ON" : "OFF")     + "\n"
+              + "PIPE:            "  + std::string(PIPE ? "ON" : "OFF")            + "\n"
+              + "PTHREAD:         "  + std::string(PTHREAD ? "ON" : "OFF")         + "\n"
+              + "PROCESS:         "  + std::string(PROCESS ? "ON" : "OFF")         + "\n"
+              + "PROCESS_MANAGER: "  + std::string(PROCESS_MANAGER ? "ON" : "OFF") + "\n"
+              + "CDO_NODE:        "  + std::string(CDO_NODE ? "ON" : "OFF")        + "\n"
+              + "PARSER:          "  + std::string(PARSER ? "ON" : "OFF")          + "\n"
+              + "PROCESS_INT:     "  + std::string(PROCESS_INT ? "ON" : "OFF")     + "\n";
+  std::cout << deb_level << std::endl;
+
+  if (cdoDebugLevel  == 1)
+    {
+      std::bitset<32> cdo_dbg(cdoDebugLevel);
+      std::cout << "CDO BITSET: " << cdo_dbg << '\n';
+      std::bitset<32> cdi_dbg(cdiDebugLevel);
+      std::cout << "CDI BITSET: " << cdi_dbg << '\n';
+    }
+  // clang-format on
+}
+void
+set_debug(unsigned p_debug_level)
+{
+  // cdi dbg = 1 << 1
+  // cdi mem = 1 << 2
+  // cdi mem = 1 << 3
+  // cdi format = 1 << 4
+  if (p_debug_level & (1u << 6)) p_debug_level = (std::numeric_limits<unsigned>::max());
+  if (p_debug_level & (1u << 7)) PIPE_STREAM = 1;
+  if (p_debug_level & (1u << 8)) FILE_STREAM = 1;
 #ifdef HAVE_LIBPTHREAD
-  if ((p_debug_level & 1 << 8)) PIPE = 1;
-  if ((p_debug_level & 1 << 9)) PTHREAD = 1;
+  if (p_debug_level & (1u << 9)) PIPE = 1;
+  if (p_debug_level & (1u << 10)) PTHREAD = 1;
 #endif
-  if (p_debug_level == 1 || (p_debug_level & 1 << 10)) PROCESS = 1;
-  if (p_debug_level == 1 || (p_debug_level & 1 << 11)) PROCESS_MANAGER = 1;
-  if (p_debug_level == 1 || (p_debug_level & 1 << 12)) CDO_NODE = 1;
+  if (p_debug_level & (1u << 11)) PROCESS = 1;
+  if (p_debug_level & (1u << 12)) PROCESS_MANAGER = 1;
+  if (p_debug_level & (1u << 13)) CDO_NODE = 1;
+  if (p_debug_level & (1u << 14)) PARSER = 1;
+  if (p_debug_level & (1u << 15)) PROCESS_INT = 1;
+  MpMO::DebugLevel = p_debug_level;
+  cdoDebug = (p_debug_level > 0);
 }
 
-bool dbg(){
-    return cdoDebug > 0;
+bool
+dbg()
+{
+  return (cdoDebug > 0);
 }
 
-void default_exit(){exit(EXIT_FAILURE);}
-const char* default_context(){return "cdo init";}
+void
+default_exit()
+{
+  exit(EXIT_FAILURE);
+}
+const char *
+default_context()
+{
+  return "cdo init";
+}
 void (*exitProgram)(void) = default_exit;
 const char *(*getContext)(void) = default_context;
 
@@ -96,7 +181,7 @@ char *
 getGRB2ErrStr(const char *progname)
 {
   const char *format = "To create a %s application with GRIB2 support use: ./configure --with-eccodes=<ECCODES root directory> ...";
-  const size_t finalSize = snprintf(nullptr, 0, format, progname);
+  const size_t finalSize = std::snprintf(nullptr, 0, format, progname);
   char *errStr = (char *) malloc(finalSize + 1);
   sprintf(errStr, format, progname);
 
@@ -111,13 +196,13 @@ getNCErrString(int filetype, const char *progname)
                         : ((filetype == CDI_FILETYPE_NC2) ? "2" : ((filetype == CDI_FILETYPE_NC5) ? "5" : ""));
 #ifdef HAVE_LIBNETCDF
   const char *format = "%s was build with a NetCDF version which doesn't support NetCDF%s data!";
-  const size_t finalSize = snprintf(nullptr, 0, format, progname, ncv);
+  const size_t finalSize = std::snprintf(nullptr, 0, format, progname, ncv);
   char *errStr = (char *) malloc(finalSize + 1);
   sprintf(errStr, format, progname, ncv);
 #else
   const char *format
       = "To create a %s application with NetCDF%s support use: ./configure --with-netcdf=<NetCDF%s root directory> ...";
-  const size_t finalSize = snprintf(nullptr, 0, format, progname, ncv, ncv);
+  const size_t finalSize = std::snprintf(nullptr, 0, format, progname, ncv, ncv);
   char *errStr = (char *) malloc(finalSize + 1);
   sprintf(errStr, format, progname, ncv, ncv);
 #endif
@@ -146,6 +231,7 @@ checkForMissingLib(int filetype, const char *progname)
     case CDI_FILETYPE_NC4:
     case CDI_FILETYPE_NC4C:
     case CDI_FILETYPE_NC5:
+    case CDI_FILETYPE_NCZARR:
       {
         errStr = getNCErrString(filetype, progname);
         break;
@@ -164,7 +250,7 @@ cdi_open_error(int cdiErrno, const std::string &format, const char *path)
   if (cdiErrno == CDI_ELIBNAVAIL)
     {
       int byteorder;
-      const auto filetype = cdiGetFiletype(path, &byteorder);
+      auto filetype = cdiGetFiletype(path, &byteorder);
       char *errStr = checkForMissingLib(filetype, "CDO");
       if (errStr)
         {
@@ -205,7 +291,7 @@ query_user_exit(const char *argument)
       (void) fflush(stdout);
       if (fgets(usr_rpl, USR_RPL_MAX_LNG, stdin) == nullptr) continue;
 
-      /* Ensure last character in input string is \n and replace that with \0 */
+      // Ensure last character in input string is \n and replace that with \0
       usr_rpl_lng = strlen(usr_rpl);
       if (usr_rpl_lng >= 1)
         if (usr_rpl[usr_rpl_lng - 1] == '\n')
@@ -215,7 +301,7 @@ query_user_exit(const char *argument)
           }
     }
 
-  /* Ensure one case statement for each exit condition in preceding while loop */
+  // Ensure one case statement for each exit condition in preceding while loop
   usr_rpl_int = (int) usr_rpl[0];
   switch (usr_rpl_int)
     {
@@ -224,16 +310,13 @@ query_user_exit(const char *argument)
     case 'O':
     case 'o': break;
     default: exit(EXIT_FAILURE); break;
-    } /* end switch */
+    }
 }
 
 std::string
 cdo_argv_to_string(const std::vector<std::string> &argv)
 {
   std::string s_argv = "";
-  for (const auto &x : argv)
-    {
-      s_argv += x + " ";
-    }
+  for (const auto &x : argv) { s_argv += x + " "; }
   return s_argv;
 }
