@@ -1,6 +1,7 @@
 #ifndef CDO_VARLIST_H
 #define CDO_VARLIST_H
 
+#include <string>
 #include <vector>
 
 #include <cdi.h>
@@ -10,7 +11,9 @@
 
 struct CdoVar
 {
-  char name[CDI_MAX_NAME] = { 0 };
+  std::string name;
+  std::string longname;
+  std::string units;
   MemType memType = MemType::Native;
   int gridID = -1;
   int zaxisID = -1;
@@ -23,12 +26,15 @@ struct CdoVar
   int code = 0;
   int param = 0;
   int nwpv = 1;  // number of words per value; real:1  complex:2
+  bool isConstant = false;
 };
 
 using VarList = std::vector<CdoVar>;
-void varListInit(VarList &vl, int vlistID);
-void varListSetUniqueMemtype(VarList &vl);
-void varListSetMemtype(VarList &vl, MemType memType);
+void varListInit(VarList &varList, int vlistID);
+void varListSetUniqueMemtype(VarList &varList);
+void varListSetMemtype(VarList &varList, MemType memType);
+int varList_numConstVars(const VarList &varList);
+int varList_numVaryingVars(const VarList &varList);
 
 struct VarIDs
 {
