@@ -1,6 +1,7 @@
 #ifndef CDO_VLIST_H
 #define CDO_VLIST_H
 
+#include <string>
 #include <map>
 
 #include <cdi.h>
@@ -39,6 +40,6 @@ int vlist_get_first_gaussian_grid(int vlistID);
 int vlist_get_first_spectral_grid(int vlistID);
 int vlist_get_first_fourier_grid(int vlistID);
 
-void cdo_check_missval(double missval, const char *varname);
+void cdo_check_missval(double missval, const std::string &varname);
 
 #endif
