@@ -22,35 +22,22 @@
 
 #define MAX_LINE_LEN 65536
 
-struct zaxis_t
+struct ZaxisDesciption
 {
   Varray<double> vals;
   Varray<double> lbounds;
   Varray<double> ubounds;
   Varray<double> vct;
   size_t vctsize;
-  int type;
-  int datatype;
-  size_t size;
-  bool scalar;
-  char name[CDI_MAX_NAME];
-  char longname[CDI_MAX_NAME];
-  char units[CDI_MAX_NAME];
+  int type = CDI_UNDEFID;
+  int datatype = CDI_UNDEFID;
+  size_t size = 0;
+  bool scalar = false;
+  std::string name;
+  std::string longname;
+  std::string units;
 };
 
-void
-zaxisInit(zaxis_t &zaxis)
-{
-  zaxis.type = CDI_UNDEFID;
-  zaxis.datatype = CDI_UNDEFID;
-  zaxis.vctsize = 0;
-  zaxis.size = 0;
-  zaxis.scalar = false;
-  zaxis.name[0] = 0;
-  zaxis.longname[0] = 0;
-  zaxis.units[0] = 0;
-}
-
 static int
 getoptname(char *optname, const char *optstring, int nopt)
 {
@@ -69,7 +56,7 @@ getoptname(char *optname, const char *optstring, int nopt)
   if (pend)
     {
       pend = strchr(pname, ',');
-      const auto namelen = (pend == nullptr) ? strlen(pname) : (size_t)(pend - pname);
+      auto namelen = (pend == nullptr) ? strlen(pname) : (size_t) (pend - pname);
       memcpy(optname, pname, namelen);
       optname[namelen] = '\0';
     }
@@ -80,12 +67,12 @@ getoptname(char *optname, const char *optstring, int nopt)
 }
 
 int
-zaxisDefine(zaxis_t zaxis)
+zaxisDefine(ZaxisDesciption zaxis)
 {
   if (zaxis.type == CDI_UNDEFID) cdo_abort("zaxistype undefined!");
   if (zaxis.size == 0) cdo_abort("zaxis size undefined!");
 
-  const auto zaxisID = zaxisCreate(zaxis.type, (int) zaxis.size);
+  auto zaxisID = zaxisCreate(zaxis.type, (int) zaxis.size);
 
   if (zaxis.size == 1 && zaxis.scalar) zaxisDefScalar(zaxisID);
 
@@ -95,9 +82,9 @@ zaxisDefine(zaxis_t zaxis)
   if (zaxis.lbounds.size()) zaxisDefLbounds(zaxisID, zaxis.lbounds.data());
   if (zaxis.ubounds.size()) zaxisDefUbounds(zaxisID, zaxis.ubounds.data());
 
-  if (zaxis.name[0]) cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_NAME, zaxis.name);
-  if (zaxis.longname[0]) cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_LONGNAME, zaxis.longname);
-  if (zaxis.units[0]) cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS, zaxis.units);
+  if (zaxis.name.size()) cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_NAME, zaxis.name.c_str());
+  if (zaxis.longname.size()) cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_LONGNAME, zaxis.longname.c_str());
+  if (zaxis.units.size()) cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS, zaxis.units.c_str());
 
   if (zaxis.type == ZAXIS_HYBRID || zaxis.type == ZAXIS_HYBRID_HALF)
     {
@@ -117,7 +104,7 @@ struct KVMap
 };
 
 static void
-zaxis_read_data(size_t nkv, KVMap *kvmap, zaxis_t *zaxis, size_t &natts, const char *dname)
+zaxis_read_data(size_t nkv, KVMap *kvmap, ZaxisDesciption &zaxis, size_t &natts, const char *dname)
 {
   // char uuidStr[256];
 
@@ -137,60 +124,60 @@ zaxis_read_data(size_t nkv, KVMap *kvmap, zaxis_t *zaxis, size_t &natts, const c
         {
           auto zaxistype = parameter_to_word(value);
 
-          if      (zaxistype == "pressure") zaxis->type = ZAXIS_PRESSURE;
-          else if (zaxistype == "hybrid_half") zaxis->type = ZAXIS_HYBRID_HALF;
-          else if (zaxistype == "hybrid") zaxis->type = ZAXIS_HYBRID;
-          else if (zaxistype == "height") zaxis->type = ZAXIS_HEIGHT;
-          else if (zaxistype == "depth_below_sea") zaxis->type = ZAXIS_DEPTH_BELOW_SEA;
-          else if (zaxistype == "depth_below_land") zaxis->type = ZAXIS_DEPTH_BELOW_LAND;
-          else if (zaxistype == "isentropic") zaxis->type = ZAXIS_ISENTROPIC;
-          else if (zaxistype == "surface") zaxis->type = ZAXIS_SURFACE;
-          else if (zaxistype == "generic") zaxis->type = ZAXIS_GENERIC;
+          if      (zaxistype == "pressure") zaxis.type = ZAXIS_PRESSURE;
+          else if (zaxistype == "hybrid_half") zaxis.type = ZAXIS_HYBRID_HALF;
+          else if (zaxistype == "hybrid") zaxis.type = ZAXIS_HYBRID;
+          else if (zaxistype == "height") zaxis.type = ZAXIS_HEIGHT;
+          else if (zaxistype == "depth_below_sea") zaxis.type = ZAXIS_DEPTH_BELOW_SEA;
+          else if (zaxistype == "depth_below_land") zaxis.type = ZAXIS_DEPTH_BELOW_LAND;
+          else if (zaxistype == "isentropic") zaxis.type = ZAXIS_ISENTROPIC;
+          else if (zaxistype == "surface") zaxis.type = ZAXIS_SURFACE;
+          else if (zaxistype == "generic") zaxis.type = ZAXIS_GENERIC;
           else cdo_abort("Invalid zaxis type: %s (zaxis description file: %s)", zaxistype, dname);
         }
       else if (key == "datatype")
         {
           auto datatype = parameter_to_word(value);
 
-          if      (datatype == "double") zaxis->datatype = CDI_DATATYPE_FLT64;
-          else if (datatype == "float")  zaxis->datatype = CDI_DATATYPE_FLT32;
-          else if (datatype == "int")    zaxis->datatype = CDI_DATATYPE_INT32;
-          else if (datatype == "short")  zaxis->datatype = CDI_DATATYPE_INT16;
+          if      (datatype == "double") zaxis.datatype = CDI_DATATYPE_FLT64;
+          else if (datatype == "float")  zaxis.datatype = CDI_DATATYPE_FLT32;
+          else if (datatype == "int")    zaxis.datatype = CDI_DATATYPE_INT32;
+          else if (datatype == "short")  zaxis.datatype = CDI_DATATYPE_INT16;
           else cdo_abort("Invalid datatype: %s (zaxis description file: %s)", datatype, dname);
         }
-      else if (key == "size")     zaxis->size = parameter_to_int(value);
-      else if (key == "scalar")   zaxis->scalar = parameter_to_bool(value);
-      else if (key == "vctsize")  zaxis->vctsize = parameter_to_int(value);
-      else if (key == "name")     strcpy(zaxis->name, parameter_to_word(value.c_str()));
-      else if (key == "units")    strcpy(zaxis->units, parameter_to_word(value.c_str()));
-      else if (key == "longname") strcpy(zaxis->longname, value.c_str());
+      else if (key == "size")     zaxis.size = parameter_to_int(value);
+      else if (key == "scalar")   zaxis.scalar = parameter_to_bool(value);
+      else if (key == "vctsize")  zaxis.vctsize = parameter_to_int(value);
+      else if (key == "name")     zaxis.name = parameter_to_word(value);
+      else if (key == "units")    zaxis.units = parameter_to_word(value);
+      else if (key == "longname") zaxis.longname = value;
       else if (key == "levels")
         {
-          if (zaxis->size == 0) cdo_abort("size undefined (zaxis description file: %s)!", dname);
-          if (zaxis->size != nvalues) cdo_abort("size=%zu and number of levels=%zu differ!", zaxis->size, nvalues);
-          zaxis->vals.resize(zaxis->size);
-          for (size_t i = 0; i < zaxis->size; ++i) zaxis->vals[i] = parameter_to_double(values[i]);
+          if (zaxis.size == 0) cdo_abort("size undefined (zaxis description file: %s)!", dname);
+          if (zaxis.size != nvalues) cdo_abort("size=%zu and number of levels=%zu differ!", zaxis.size, nvalues);
+          zaxis.vals.resize(zaxis.size);
+          for (size_t i = 0; i < zaxis.size; ++i) zaxis.vals[i] = parameter_to_double(values[i]);
         }
       else if (key == "lbounds")
         {
-          if (zaxis->size == 0) cdo_abort("size undefined (zaxis description file: %s)!", dname);
-          if (zaxis->size != nvalues) cdo_abort("size=%zu and number of lbounds=%zu differ!", zaxis->size, nvalues);
-          zaxis->lbounds.resize(zaxis->size);
-          for (size_t i = 0; i < zaxis->size; ++i) zaxis->lbounds[i] = parameter_to_double(values[i]);
+          if (zaxis.size == 0) cdo_abort("size undefined (zaxis description file: %s)!", dname);
+          if (zaxis.size != nvalues) cdo_abort("size=%zu and number of lbounds=%zu differ!", zaxis.size, nvalues);
+          zaxis.lbounds.resize(zaxis.size);
+          for (size_t i = 0; i < zaxis.size; ++i) zaxis.lbounds[i] = parameter_to_double(values[i]);
         }
       else if (key == "ubounds")
         {
-          if (zaxis->size == 0) cdo_abort("size undefined (zaxis description file: %s)!", dname);
-          if (zaxis->size != nvalues) cdo_abort("size=%zu and number of ubounds=%zu differ!", zaxis->size, nvalues);
-          zaxis->ubounds.resize(zaxis->size);
-          for (size_t i = 0; i < zaxis->size; ++i) zaxis->ubounds[i] = parameter_to_double(values[i]);
+          if (zaxis.size == 0) cdo_abort("size undefined (zaxis description file: %s)!", dname);
+          if (zaxis.size != nvalues) cdo_abort("size=%zu and number of ubounds=%zu differ!", zaxis.size, nvalues);
+          zaxis.ubounds.resize(zaxis.size);
+          for (size_t i = 0; i < zaxis.size; ++i) zaxis.ubounds[i] = parameter_to_double(values[i]);
         }
       else if (key == "vct")
         {
-          if (zaxis->vctsize == 0) cdo_abort("vctsize undefined (zaxis description file: %s)!", dname);
-          if (zaxis->vctsize != nvalues) cdo_abort("vctsize=%zu and size of vct=%zu differ!", zaxis->vctsize, nvalues);
-          zaxis->vct.resize(zaxis->vctsize);
-          for (size_t i = 0; i < zaxis->vctsize; ++i) zaxis->vct[i] = parameter_to_double(values[i]);
+          if (zaxis.vctsize == 0) cdo_abort("vctsize undefined (zaxis description file: %s)!", dname);
+          if (zaxis.vctsize != nvalues) cdo_abort("vctsize=%zu and size of vct=%zu differ!", zaxis.vctsize, nvalues);
+          zaxis.vct.resize(zaxis.vctsize);
+          for (size_t i = 0; i < zaxis.vctsize; ++i) zaxis.vct[i] = parameter_to_double(values[i]);
         }
       else
         {
@@ -229,7 +216,7 @@ zaxis_read_attributes(size_t natts, size_t nkv, KVMap *kvmap, int zaxisID)
               cdo_abort("Found reserved keyword >%s< in attribute names! Check name or position of >%s<.", key, attkey0);
         }
 
-      const auto dtype = literals_find_datatype(nvalues, values);
+      auto dtype = literals_find_datatype(nvalues, values);
 
       if (dtype == CDI_DATATYPE_INT8 || dtype == CDI_DATATYPE_INT16 || dtype == CDI_DATATYPE_INT32)
         {
@@ -245,7 +232,7 @@ zaxis_read_attributes(size_t natts, size_t nkv, KVMap *kvmap, int zaxisID)
         }
       else
         {
-          const auto len = (int) value.size();
+          auto len = (int) value.size();
           cdiDefAttTxt(zaxisID, CDI_GLOBAL, key.c_str(), len, value.c_str());
         }
     }
@@ -259,7 +246,7 @@ zaxis_from_file(FILE *zfp, const char *filename)
   if (pmlist.size() == 0) return -1;
   KVList &kvlist = pmlist.front();
 
-  const auto nkv = kvlist.size();
+  auto nkv = kvlist.size();
   if (nkv == 0) return -1;
 
   std::vector<KVMap> kvmap(nkv);
@@ -269,13 +256,9 @@ zaxis_from_file(FILE *zfp, const char *filename)
   const char *firstKey = "zaxistype";
   for (auto &kv : kvlist)
     {
-      if (ik == 0 && kv.key != firstKey)
-        cdo_abort("First zaxis description keyword must be >%s< (found: %s)!", firstKey, kv.key);
+      if (ik == 0 && kv.key != firstKey) cdo_abort("First zaxis description keyword must be >%s< (found: %s)!", firstKey, kv.key);
 
-      if (kv.nvalues == 0)
-        {
-          cdo_warning("Z-axis description keyword %s has no values, skipped!", kv.key);
-        }
+      if (kv.nvalues == 0) { cdo_warning("Z-axis description keyword %s has no values, skipped!", kv.key); }
       else
         {
           kvmap[ik].isValid = true;
@@ -284,11 +267,10 @@ zaxis_from_file(FILE *zfp, const char *filename)
       ik++;
     }
 
-  zaxis_t zaxis;
-  zaxisInit(zaxis);
+  ZaxisDesciption zaxis;
 
   size_t natts = 0;
-  zaxis_read_data(nkv, kvmap.data(), &zaxis, natts, filename);
+  zaxis_read_data(nkv, kvmap.data(), zaxis, natts, filename);
 
   int zaxisID = (zaxis.type == CDI_UNDEFID) ? CDI_UNDEFID : zaxisDefine(zaxis);
   if (zaxisID != CDI_UNDEFID && natts > 0) zaxis_read_attributes(natts, nkv, kvmap.data(), zaxisID);
@@ -297,11 +279,11 @@ zaxis_from_file(FILE *zfp, const char *filename)
 }
 
 static void
-gen_zaxis_height(zaxis_t *zaxis, const char *pline)
+gen_zaxis_height(ZaxisDesciption &zaxis, const char *pline)
 {
   int zaxistype = ZAXIS_HEIGHT;
 
-  if (Options::CMOR_Mode) zaxis->scalar = true;
+  if (Options::CMOR_Mode) zaxis.scalar = true;
 
   if (*pline != 0)
     {
@@ -315,27 +297,27 @@ gen_zaxis_height(zaxis_t *zaxis, const char *pline)
       if (!isdigit((int) *pline) && !ispunct((int) *pline)) return;
 
       auto endptr = (char *) pline;
-      const auto value = strtod(pline, &endptr);
+      auto value = strtod(pline, &endptr);
       if (*endptr != 0)
         {
           pline = endptr;
           if (*pline == '_') pline++;
 
           if (*pline == 0) return;
-          const char *units = pline;
+          std::string units = pline;
 
-          zaxis->type = zaxistype;
-          zaxis->size = 1;
-          // zaxis->scalar = true;
-          zaxis->vals.resize(1);
-          zaxis->vals[0] = value;
-          strcpy(zaxis->units, units);
+          zaxis.type = zaxistype;
+          zaxis.size = 1;
+          // zaxis.scalar = true;
+          zaxis.vals.resize(1);
+          zaxis.vals[0] = value;
+          zaxis.units = units;
 
-          const auto len = strlen(units);
+          auto len = units.size();
           if (len > 2 && units[len - 2] == '_' && units[len - 1] == 's')
             {
-              zaxis->units[len - 2] = 0;
-              zaxis->scalar = true;
+              zaxis.units.resize(len - 2);
+              zaxis.scalar = true;
             }
         }
     }
@@ -348,10 +330,9 @@ zaxis_from_name(const char *zaxisnameptr)
   size_t len;
 
   auto zaxisname = strdup(zaxisnameptr);
-  cstr_to_lower_case(zaxisname);
+  cstr_to_lower(zaxisname);
 
-  zaxis_t zaxis;
-  zaxisInit(zaxis);
+  ZaxisDesciption zaxis;
 
   auto pline = zaxisname;
   if (cdo_cmpstrLenRhs(pline, "surface"))  // surface
@@ -364,7 +345,7 @@ zaxis_from_name(const char *zaxisnameptr)
   else if (cdo_cmpstrLenRhs(zaxisname, "height", len))
     {
       pline = &zaxisname[len];
-      gen_zaxis_height(&zaxis, pline);
+      gen_zaxis_height(zaxis, pline);
     }
 
   if (zaxis.type != CDI_UNDEFID) zaxisID = zaxisDefine(zaxis);
@@ -379,11 +360,11 @@ cdo_define_zaxis(const char *zaxisfile)
 {
   int zaxisID = CDI_UNDEFID;
 
-  auto zfp = fopen(zaxisfile, "r");
+  auto zfp = std::fopen(zaxisfile, "r");
   if (zfp)
     {
       zaxisID = zaxis_from_file(zfp, zaxisfile);
-      fclose(zfp);
+      std::fclose(zfp);
     }
   else
     {
@@ -408,10 +389,7 @@ define_zaxis(const char *zaxisarg)
   char zaxisfile[4096];
   int nfile = 0;
 
-  while (getoptname(zaxisfile, zaxisarg, nfile++) == 0)
-    {
-      (void) cdo_define_zaxis(zaxisfile);
-    }
+  while (getoptname(zaxisfile, zaxisarg, nfile++) == 0) { (void) cdo_define_zaxis(zaxisfile); }
 }
 
 static int
@@ -439,7 +417,6 @@ int
 zaxis_to_ltype(int zaxisID)
 {
   int ltype = 0;
-
   cdiInqKeyInt(zaxisID, CDI_GLOBAL, CDI_KEY_TYPEOFFIRSTFIXEDSURFACE, &ltype);
   if (ltype <= 0) ltype = ztype2ltype(zaxisInqType(zaxisID));
 
@@ -460,7 +437,7 @@ gen_layer_bounds(int nlev, const Varray<double> &levels, Varray<double> &lbounds
       ubounds[nlev - 1] = levels[nlev - 1];
       for (int i = 0; i < nlev - 1; ++i)
         {
-          const auto bound = 0.5 * (levels[i] + levels[i + 1]);
+          auto bound = 0.5 * (levels[i] + levels[i + 1]);
           lbounds[i + 1] = bound;
           ubounds[i] = bound;
         }
@@ -468,7 +445,8 @@ gen_layer_bounds(int nlev, const Varray<double> &levels, Varray<double> &lbounds
 }
 
 int
-get_layer_thickness(bool useWeights, bool genBounds, int index, int zaxisID, int nlev, Varray<double> &thickness, Varray<double> &weights)
+get_layer_thickness(bool useWeights, bool genBounds, int index, int zaxisID, int nlev, Varray<double> &thickness,
+                    Varray<double> &weights)
 {
   int status = 0;
   Varray<double> levels(nlev), lbounds(nlev, 0.0), ubounds(nlev, 1.0);
@@ -488,10 +466,10 @@ get_layer_thickness(bool useWeights, bool genBounds, int index, int zaxisID, int
 
   for (int i = 0; i < nlev; ++i) thickness[i] = std::fabs(ubounds[i] - lbounds[i]);
 
-  const auto layerSum = varray_sum(nlev, thickness);
-  varray_copy(nlev, thickness,  weights);
+  auto layerSum = varray_sum(nlev, thickness);
+  varray_copy(nlev, thickness, weights);
   varray_divc(nlev, weights, (layerSum / nlev));
-  const auto weightSum = varray_sum(nlev, weights);
+  auto weightSum = varray_sum(nlev, weights);
 
   if (Options::cdoVerbose)
     {
