@@ -15,7 +15,6 @@
 
 #include "dmemory.h"
 #include "process_int.h"
-#include "cdo_cdi_wrapper.h"
 
 #define TO_KELVIN(x) ((x) + 273.15)
 #define MISSVAL -9.0E33
@@ -117,7 +116,7 @@ writeNcFile(const char path[], const double array[], int length)
     {
       int vdate = (tsID < 6) ? (20060625 + tsID) : (20060701 + tsID - 6);
       int vtime = 235900;
-      CdiDateTime vDateTime = { };
+      CdiDateTime vDateTime{};
       vDateTime.date = cdiDate_set(vdate);
       vDateTime.time = cdiTime_set(vtime);
       taxisDefVdatetime(taxisID, vDateTime);
