@@ -20,7 +20,7 @@ bool CDO_Ignore_Time_Bounds = false;
 bool CDO_Use_Time_Bounds = false;
 static bool dateTimeInit = false;
 
-const char*
+const char *
 time_units_cstr(TimeUnits timeUnit)
 {
   // clang-format off
@@ -60,7 +60,7 @@ get_timestat_date(TimeStat *tstat_date)
   if (envstr)
     {
       TimeStat env_date = TimeStat::UNDEF;
-      const auto envstrl = string_to_lower(envstr);
+      auto envstrl = string_to_lower(envstr);
 
       // clang-format off
       if      (envstrl == "first")   env_date = TimeStat::FIRST;
@@ -85,7 +85,7 @@ DateTimeList::init()
 }
 
 CdiDateTime
-DateTimeList::get_vDateTime(const int tsID)
+DateTimeList::get_vDateTime(int tsID)
 {
   if (tsID < 0 || (size_t) tsID >= this->size) cdo_abort("Internal error; tsID out of bounds!");
 
@@ -99,7 +99,7 @@ DateTimeList::shift()
 }
 
 void
-DateTimeList::taxis_inq_timestep(const int taxisID, const int tsID)
+DateTimeList::taxis_inq_timestep(int taxisID, int tsID)
 {
   constexpr size_t NALLOC = 128;
 
@@ -124,15 +124,15 @@ DateTimeList::taxis_inq_timestep(const int taxisID, const int tsID)
     {
       taxisInqVdatetimeBounds(taxisID, &(this->dtInfo[tsID].b[0]), &(this->dtInfo[tsID].b[1]));
 
-      const auto time = cdiTime_get(this->dtInfo[tsID].b[1].time);
+      auto time = cdiTime_get(this->dtInfo[tsID].b[1].time);
       if (CDO_Use_Time_Bounds && time == 0 && cdiDateTime_isEQ(this->dtInfo[tsID].v, this->dtInfo[tsID].b[1]))
         {
-          const auto julianDate1 = julianDate_encode(this->calendar, this->dtInfo[tsID].b[0]);
-          const auto julianDate2 = julianDate_encode(this->calendar, this->dtInfo[tsID].b[1]);
+          auto julianDate1 = julianDate_encode(this->calendar, this->dtInfo[tsID].b[0]);
+          auto julianDate2 = julianDate_encode(this->calendar, this->dtInfo[tsID].b[1]);
 
           if (julianDate_to_seconds(julianDate1) < julianDate_to_seconds(julianDate2))
             {
-              const auto julianDate = julianDate_add_seconds(julianDate2, -1);
+              auto julianDate = julianDate_add_seconds(julianDate2, -1);
               this->dtInfo[tsID].c = julianDate_decode(this->calendar, julianDate);
             }
         }
@@ -145,14 +145,14 @@ DateTimeList::taxis_inq_timestep(const int taxisID, const int tsID)
 }
 
 void
-DateTimeList::taxis_set_next_timestep(const int taxisID)
+DateTimeList::taxis_set_next_timestep(int taxisID)
 {
-  const int tsID = this->size;
+  int tsID = this->size;
   this->taxis_inq_timestep(taxisID, tsID);
 }
 
 void
-DateTimeList::taxis_def_timestep(const int taxisID, const int tsID)
+DateTimeList::taxis_def_timestep(int taxisID, int tsID)
 {
   if (tsID < 0 || (size_t) tsID >= this->size) cdo_abort("Internal error; tsID out of bounds!");
 
@@ -161,28 +161,28 @@ DateTimeList::taxis_def_timestep(const int taxisID, const int tsID)
 }
 
 void
-DateTimeList::mean(const int nsteps)
+DateTimeList::mean(int nsteps)
 {
   if (nsteps % 2 == 0)
     {
 #ifdef TEST_DTLIST_MEAN
-      const auto julianDate0 = julianDate_encode(this->calendar, this->dtInfo[0].v);
+      auto julianDate0 = julianDate_encode(this->calendar, this->dtInfo[0].v);
 
       double seconds = 0.0;
       for (int i = 1; i < nsteps; ++i)
         {
-          const auto julianDate = julianDate_encode(this->calendar, this->dtInfo[i].v);
+          auto julianDate = julianDate_encode(this->calendar, this->dtInfo[i].v);
           seconds += julianDate_to_seconds(julianDate_sub(julianDate, julianDate0));
         }
 
-      const auto julianDate = julianDate_add_seconds(julianDate0, lround(seconds / nsteps));
+      auto julianDate = julianDate_add_seconds(julianDate0, std::lround(seconds / nsteps));
       this->timestat.v = julianDate_decode(this->calendar, julianDate);
 #else
-      const auto julianDate1 = julianDate_encode(this->calendar, this->dtInfo[nsteps / 2 - 1].v);
-      const auto julianDate2 = julianDate_encode(this->calendar, this->dtInfo[nsteps / 2].v);
+      auto julianDate1 = julianDate_encode(this->calendar, this->dtInfo[nsteps / 2 - 1].v);
+      auto julianDate2 = julianDate_encode(this->calendar, this->dtInfo[nsteps / 2].v);
 
-      const auto seconds = julianDate_to_seconds(julianDate_sub(julianDate2, julianDate1)) / 2;
-      const auto julianDatem = julianDate_add_seconds(julianDate1, lround(seconds));
+      auto seconds = julianDate_to_seconds(julianDate_sub(julianDate2, julianDate1)) / 2;
+      auto julianDatem = julianDate_add_seconds(julianDate1, std::lround(seconds));
       this->timestat.v = julianDate_decode(this->calendar, julianDatem);
 #endif
     }
@@ -193,13 +193,13 @@ DateTimeList::mean(const int nsteps)
 }
 
 void
-DateTimeList::midhigh(const int nsteps)
+DateTimeList::midhigh(int nsteps)
 {
   this->timestat.v = this->dtInfo[nsteps / 2].v;
 }
 
 void
-DateTimeList::stat_taxis_def_timestep(const int taxisID, const int nsteps)
+DateTimeList::stat_taxis_def_timestep(int taxisID, int nsteps)
 {
   if ((size_t) nsteps > this->size) cdo_abort("Internal error; unexpected nsteps=%d (limit=%ld)!", nsteps, this->size);
 
@@ -232,22 +232,22 @@ DateTimeList::stat_taxis_def_timestep(const int taxisID, const int nsteps)
 }
 
 void
-DateTimeList::stat_taxis_def_timestep(const int taxisID)
+DateTimeList::stat_taxis_def_timestep(int taxisID)
 {
-  const int nsteps = this->size;
+  int nsteps = this->size;
   this->stat_taxis_def_timestep(taxisID, nsteps);
 }
 
 CdiDateTime
-datetime_avg(const int calendar, const int ndates, const std::vector<CdiDateTime> &cdiDateTimes)
+datetime_avg(int calendar, int ndates, const std::vector<CdiDateTime> &cdiDateTimes)
 {
   if (ndates % 2 == 0)
     {
-      const auto julianDate1 = julianDate_encode(calendar, cdiDateTimes[ndates / 2 - 1]);
-      const auto julianDate2 = julianDate_encode(calendar, cdiDateTimes[ndates / 2]);
+      auto julianDate1 = julianDate_encode(calendar, cdiDateTimes[ndates / 2 - 1]);
+      auto julianDate2 = julianDate_encode(calendar, cdiDateTimes[ndates / 2]);
 
-      const auto seconds = julianDate_to_seconds(julianDate_sub(julianDate2, julianDate1)) / 2;
-      const auto julianDatem = julianDate_add_seconds(julianDate1, lround(seconds));
+      auto seconds = julianDate_to_seconds(julianDate_sub(julianDate2, julianDate1)) / 2;
+      auto julianDatem = julianDate_add_seconds(julianDate1, std::lround(seconds));
       return julianDate_decode(calendar, julianDatem);
     }
   else
@@ -266,19 +266,16 @@ adjust_month_and_year(int &month, int &year)
 }
 
 double
-delta_time_step_0(const int tsID, const int calendar, const CdiDateTime &vDateTime, JulianDate &julianDate0, double &deltat1)
+delta_time_step_0(int tsID, int calendar, const CdiDateTime &vDateTime, JulianDate &julianDate0, double &deltat1)
 {
   double zj = 0.0;
 
-  const auto julianDate = julianDate_encode(calendar, vDateTime);
+  auto julianDate = julianDate_encode(calendar, vDateTime);
 
-  if (tsID == 0)
-    {
-      julianDate0 = julianDate;
-    }
+  if (tsID == 0) { julianDate0 = julianDate; }
   else
     {
-      const auto deltat = julianDate_to_seconds(julianDate_sub(julianDate, julianDate0));
+      auto deltat = julianDate_to_seconds(julianDate_sub(julianDate, julianDate0));
       if (tsID == 1) deltat1 = deltat;
       zj = deltat / deltat1;
     }
@@ -287,15 +284,15 @@ delta_time_step_0(const int tsID, const int calendar, const CdiDateTime &vDateTi
 }
 
 TimeIncrement
-get_time_increment(const double jdelta, CdiDate vDate0, CdiDate vDate1)
+get_time_increment(double jdelta, CdiDate vDate0, CdiDate vDate1)
 {
-  int64_t lperiod = (jdelta < 0) ? (int64_t)(jdelta - 0.5) : (int64_t)(jdelta + 0.5);
+  int64_t seconds = (jdelta < 0.0) ? (int64_t) (jdelta - 0.5) : (int64_t) (jdelta + 0.5);
 
   int sign = 1;
-  if (lperiod < 0)
+  if (seconds < 0)
     {
       std::swap(vDate0, vDate1);
-      lperiod = -lperiod;
+      seconds = -seconds;
       sign = -1;
     }
 
@@ -310,30 +307,30 @@ get_time_increment(const double jdelta, CdiDate vDate0, CdiDate vDate1)
   if (deltam == 0) deltam = 1;
 
   TimeIncrement timeIncr;
-  if (lperiod / 60 >= 1 && lperiod / 60 < 60)
-    {
-      timeIncr = { lperiod / 60, TimeUnits::MINUTES };
-    }
-  else if (lperiod / 3600 >= 1 && lperiod / 3600 < 24)
-    {
-      timeIncr = { lperiod / 3600, TimeUnits::HOURS };
-    }
-  else if (lperiod / (3600 * 24) >= 1 && lperiod / (3600 * 24) < 32)
-    {
-      timeIncr = { lperiod / (3600 * 24), TimeUnits::DAYS };
-      if (timeIncr.period >= 27 && deltam == 1) timeIncr = { 1, TimeUnits::MONTHS };
-    }
-  else if (lperiod / (3600 * 24 * 30) >= 1 && lperiod / (3600 * 24 * 30) < 12)
-    {
-      timeIncr = { deltam, TimeUnits::MONTHS };
-    }
-  else if (lperiod / (3600 * 24 * 30 * 12) >= 1)
+  if (seconds >= (3600 * 24 * 30 * 12))
     {
       timeIncr = { deltay, TimeUnits::YEARS };
     }
+  else if (seconds >= (3600 * 24 * 30) && seconds / (3600 * 24 * 30) < 12)
+    {
+      timeIncr = { deltam, TimeUnits::MONTHS };
+    }
+  else if (seconds >= (3600 * 24) && seconds / (3600 * 24) < 32)
+    {
+      timeIncr = { seconds / (3600 * 24), TimeUnits::DAYS };
+      if (timeIncr.period >= 27 && deltam == 1) timeIncr = { 1, TimeUnits::MONTHS };
+    }
+  else if (seconds >= 3600 && seconds % 3600 == 0)
+    {
+      timeIncr = { seconds / 3600, TimeUnits::HOURS };
+    }
+  else if (seconds >= 60 && seconds % 60 == 0)
+    {
+      timeIncr = { seconds / 60, TimeUnits::MINUTES };
+    }
   else
     {
-      timeIncr = { lperiod, TimeUnits::SECONDS };
+      timeIncr = { seconds, TimeUnits::SECONDS };
     }
 
   timeIncr.period *= sign;
@@ -342,18 +339,19 @@ get_time_increment(const double jdelta, CdiDate vDate0, CdiDate vDate1)
 }
 
 void
-check_time_increment(const int tsID, const int calendar, const CdiDateTime &vDateTime, CheckTimeIncr &checkTimeIncr)
+check_time_increment(int tsID, int calendar, const CdiDateTime &vDateTime, CheckTimeIncr &checkTimeIncr)
 {
-  const auto julianDate = julianDate_encode(calendar, vDateTime);
+  auto julianDate = julianDate_encode(calendar, vDateTime);
 
   if (tsID)
     {
-      const auto jdeltat = julianDate_to_seconds(julianDate_sub(julianDate, checkTimeIncr.julianDate0));
-      const auto timeIncr = get_time_increment(jdeltat, checkTimeIncr.vDate0, vDateTime.date);
+      auto jdeltat = julianDate_to_seconds(julianDate_sub(julianDate, checkTimeIncr.julianDate0));
+      auto timeIncr = get_time_increment(jdeltat, checkTimeIncr.vDate0, vDateTime.date);
 
       if (tsID == 1) checkTimeIncr.timeIncr = timeIncr;
 
-      if (checkTimeIncr.printWarning && (timeIncr.period != checkTimeIncr.timeIncr.period || timeIncr.units != checkTimeIncr.timeIncr.units))
+      if (checkTimeIncr.printWarning
+          && (timeIncr.period != checkTimeIncr.timeIncr.period || timeIncr.units != checkTimeIncr.timeIncr.units))
         {
           checkTimeIncr.printWarning = false;
           cdo_warning("Time increment in step %d (%lld%s) differs from step 1 (%lld%s)!"
@@ -382,16 +380,20 @@ decode_month(const CdiDate &date)
 int
 decode_month_and_day(const CdiDate &date)
 {
-  const int month = date.month, day = date.day;
+  int month = date.month, day = date.day;
   return (month * 100 + day);
 }
 
 int
 decode_day_of_year(const CdiDate &date)
 {
-  int year, month, day;
-  cdiDate_decode(date, &year, &month, &day);
-  return (month >= 1 && month <= 12) ? ((month - 1) * 31 + day) : 0;
+  int year, mon, day;
+  cdiDate_decode(date, &year, &mon, &day);
+
+  if (day < 1 || day > 31) { return 0; }
+  if (mon < 1 || mon > 12) { return 0; }
+
+  return (mon - 1) * 31 + day;
 }
 
 int
@@ -434,7 +436,7 @@ set_date_time(CdiDateTime &datetime1, CdiDateTime datetime2)
 static int
 get_timeunits(const char *unitsStr, int &incrPeriod, int &incrUnits, int &timeUnits)
 {
-  const auto len = strlen(unitsStr);
+  auto len = strlen(unitsStr);
 
   // clang-format off
   if      (memcmp(unitsStr, "seconds", len) == 0) { incrUnits = 1;     timeUnits = TUNIT_SECOND; }
@@ -465,7 +467,7 @@ decode_datestring(const std::string &dateString)
   if (strchr(dateString.c_str() + 1, '-'))
     {
       int year = 1, month = 1, day = 1;
-      sscanf(dateString.c_str(), "%d-%d-%d", &year, &month, &day);
+      std::sscanf(dateString.c_str(), "%d-%d-%d", &year, &month, &day);
       return cdiDate_encode(year, month, day);
     }
   else
@@ -481,7 +483,7 @@ decode_timestring(const std::string &timeString)
     {
       int hour = 0, minute = 0, second = 0, ms = 0;
       double fseconds = 0.0;
-      sscanf(timeString.c_str(), "%d:%d:%lf", &hour, &minute, &fseconds);
+      std::sscanf(timeString.c_str(), "%d:%d:%lf", &hour, &minute, &fseconds);
       second = (int) fseconds;
       ms = (fseconds - second) * 1000;
       return cdiTime_encode(hour, minute, second, ms);
@@ -500,8 +502,8 @@ decode_timeunits(const std::string &timeUnitsString, int &incrPeriod, int &incrU
   timeUnits = 0;
 
   char *pUnits = nullptr;
-  const auto fperiod = strtod(timeUnitsString.c_str(), &pUnits);
-  if (pUnits != timeUnitsString.c_str()) incrPeriod = lround(fperiod);
+  auto fperiod = strtod(timeUnitsString.c_str(), &pUnits);
+  if (pUnits != timeUnitsString.c_str()) incrPeriod = std::lround(fperiod);
 
   if (pUnits) get_timeunits(pUnits, incrPeriod, incrUnits, timeUnits);
 }
