@@ -35,9 +35,9 @@ enum class TimeStat
 
 struct DateTimeInfo
 {
-  CdiDateTime c;     // corrected verification time
-  CdiDateTime v;     // verification time
-  CdiDateTime b[2];  // time bounds
+  CdiDateTime c{};     // corrected verification time
+  CdiDateTime v{};     // verification time
+  CdiDateTime b[2]{};  // time bounds
 };
 
 class TimeIncrement
@@ -48,27 +48,41 @@ public:
 
   TimeIncrement() {}
   TimeIncrement(int64_t _period, TimeUnits _units) : period(_period), units(_units) {}
+
+  bool
+  operator==(const TimeIncrement &timeIncr) const
+  {
+    return (period == timeIncr.period && units == timeIncr.units);
+  }
+
+  bool
+  operator!=(const TimeIncrement &timeIncr) const
+  {
+    return (period != timeIncr.period || units != timeIncr.units);
+  }
 };
 
 struct CheckTimeIncr
 {
   JulianDate julianDate0;
   TimeIncrement timeIncr;
-  CdiDate vDate0 = { };
+  CdiDate vDate0{};
   bool printWarning = true;
 };
 
-class // DateTimeList
+// clang-format off
+class  // DateTimeList
 #ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 DateTimeList
+// clang-format on
 {
 public:
   DateTimeList() { init(); }
   // clang-format off
-  void set_stat(const TimeStat _stat) { this->stat = _stat; }
-  void set_calendar(const int _calendar) { this->calendar = _calendar; }
+  void set_stat(TimeStat _stat) { this->stat = _stat; }
+  void set_calendar(int _calendar) { this->calendar = _calendar; }
   // clang-format on
   CdiDateTime get_vDateTime(int tsID);
   void shift();
