@@ -12,7 +12,6 @@
 #include "expr_fun.h"
 #include "expr_yacc.hh"
 
-
 // clang-format off
 auto expr_func_con_var = [](auto hasMV, auto n, auto mv, const auto cVal, const auto &vIn, auto &vOut, auto binray_operator)
 {
@@ -153,15 +152,15 @@ auto expr_div_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, const auto &v
 // clang-format on
 
 nodeType *
-expr_con_con(const int oper, const nodeType *p1, const nodeType *p2)
+expr_con_con(int oper, const nodeType *p1, const nodeType *p2)
 {
   auto p = (nodeType *) calloc(1, sizeof(nodeType));
 
   p->type = NodeEnum::typeCon;
   p->isTmpObj = true;
 
-  auto cval1 = p1->u.con.value;
-  const auto cval2 = p2->u.con.value;
+  auto cval1 = p1->con().value;
+  const auto cval2 = p2->con().value;
 
   // clang-format off
   switch (oper)
@@ -184,14 +183,13 @@ expr_con_con(const int oper, const nodeType *p1, const nodeType *p2)
     }
   // clang-format on
 
-  p->u.con.value = cval1;
+  p->v = conNodeType(cval1);
 
   return p;
 }
 
 void
-oper_expr_con_var(const int oper, const bool hasMV, const size_t n, const double mv, double *odat,
-                  const double cval, const double *idat)
+oper_expr_con_var(int oper, bool hasMV, size_t n, double mv, double *odat, double cval, const double *idat)
 {
   // clang-format off
   switch (oper)
@@ -216,8 +214,7 @@ oper_expr_con_var(const int oper, const bool hasMV, const size_t n, const double
 }
 
 void
-oper_expr_var_con(const int oper, const bool hasMV, const size_t n, const double mv,
-                  double *odat, const double *idat, const double cval)
+oper_expr_var_con(int oper, bool hasMV, size_t n, double mv, double *odat, const double *idat, double cval)
 {
   // clang-format off
   switch (oper)
@@ -242,8 +239,7 @@ oper_expr_var_con(const int oper, const bool hasMV, const size_t n, const double
 }
 
 void
-oper_expr_var_var(const int oper, const bool hasMV, const size_t n, const double mv1, const double mv2,
-                  double *odat, const double *idat1, const double *idat2)
+oper_expr_var_var(int oper, bool hasMV, size_t n, double mv1, double mv2, double *odat, const double *idat1, double *idat2)
 {
   // clang-format off
   switch (oper)
