@@ -8,6 +8,7 @@
 #define FIELD_H
 
 #include <cstdio>
+#include <utility>
 #include "varray.h"
 #include "cdo_options.h"
 #include "cdo_vlist.h"
@@ -22,21 +23,23 @@ const auto memtype_is_double_double = [](auto a, auto b) noexcept { return (a ==
 
 enum field_flag
 {
-  FIELD_VEC = 2,  // allocated memory
-  FIELD_FLT = 4,  // 32-bit float
-  FIELD_DBL = 8,  // 64-bit float
-  FIELD_NAT = 16, // native: 32-bit float for 32-bit float data, otherweise 64-bit float
+  FIELD_VEC = 2,   // allocated memory
+  FIELD_FLT = 4,   // 32-bit float
+  FIELD_DBL = 8,   // 64-bit float
+  FIELD_NAT = 16,  // native: 32-bit float for 32-bit float data, otherweise 64-bit float
 };
 
-class // Field
+// clang-format off
+class  // Field
 #ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 Field
+// clang-format on
 {
 public:
   int fpeRaised = 0;
-  int nwpv = 1;         // number of words per value; real:1  complex:2
+  int nwpv = 1;  // number of words per value; real:1  complex:2
   int grid = -1;
   MemType memType = MemType::Native;  // MemType::Float or MemType::Double
 
@@ -60,7 +63,8 @@ public:
   bool empty() const;
   void check_gridsize() const;
 
-  bool hasData() const
+  bool
+  hasData() const
   {
     return (memType == MemType::Float) ? !vec_f.empty() : !vec_d.empty();
   }
@@ -69,11 +73,13 @@ private:
   size_t m_count = 0;
 };
 
-class // Field3D
+// clang-format off
+class  // Field3D
 #ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 Field3D : public Field
+// clang-format on
 {
 public:
   size_t nlevels = 0;
@@ -86,7 +92,8 @@ struct RecordInfo
 {
   int varID = 0;
   int levelID = 0;
-  bool lconst = false;
+  void set(int _varID, int _levelID) { this->varID = _varID; this->levelID = _levelID; }
+  std::pair<int, int> get() const { return std::make_pair(varID, levelID); }
 };
 
 using FieldVector = std::vector<Field>;
@@ -106,7 +113,8 @@ size_t field_num_mv(Field &field);
 MinMax field_min_max(const Field &field);
 
 template <class UnaryOperation>
-void field_transform(const Field &fieldIn, Field &fieldOut, UnaryOperation unary_op)
+void
+field_transform(const Field &fieldIn, Field &fieldOut, UnaryOperation unary_op)
 {
   if (fieldIn.memType == MemType::Float && fieldOut.memType == MemType::Float)
     varray_transform(fieldIn.vec_f, fieldOut.vec_f, unary_op);
