@@ -62,10 +62,7 @@ varray2_div(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const double
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < len; ++i)
-    {
-      v1[i] = is_equal(v2[i], 0.0) ? missval1 : arith_div(v1[i], v2[i]);
-    }
+  for (size_t i = 0; i < len; ++i) { v1[i] = is_equal(v2[i], 0.0) ? missval1 : arith_div(v1[i], v2[i]); }
 }
 
 template <typename T1, typename T2, typename FUNC>
@@ -81,10 +78,7 @@ varray2_arith(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, FUNC func)
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < len; ++i)
-    {
-      v1[i] = func(v1[i], v2[i]);
-    }
+  for (size_t i = 0; i < len; ++i) { v1[i] = func(v1[i], v2[i]); }
 }
 
 template <typename T1, typename T2, typename FUNC>
@@ -643,10 +637,7 @@ field2_minidx(size_t nmiss3, size_t len, double missval3, Field &field1, Field &
             {
               if (DBL_IS_EQUAL(v2[i], missval2)) v1[i] = missval1;
             }
-          else if (v3[i] < v2[i] || DBL_IS_EQUAL(v2[i], missval2))
-            {
-              field2_set_index(v1[i], v2[i], v3[i], idx);
-            }
+          else if (v3[i] < v2[i] || DBL_IS_EQUAL(v2[i], missval2)) { field2_set_index(v1[i], v2[i], v3[i], idx); }
         }
 
       field_num_mv(field1);
@@ -690,10 +681,7 @@ field2_maxidx(size_t nmiss3, size_t len, double missval3, Field &field1, Field &
             {
               if (DBL_IS_EQUAL(v2[i], missval2)) v1[i] = missval1;
             }
-          else if (v3[i] > v2[i] || DBL_IS_EQUAL(v2[i], missval2))
-            {
-              field2_set_index(v1[i], v2[i], v3[i], idx);
-            }
+          else if (v3[i] > v2[i] || DBL_IS_EQUAL(v2[i], missval2)) { field2_set_index(v1[i], v2[i], v3[i], idx); }
         }
 
       field_num_mv(field1);
@@ -799,17 +787,14 @@ field2_std(Field &field1, const Field &field2, const Field &field3, const int di
         array1[i] = missval1;
         nmiss++;
       }
-    else
-      {
-        array1[i] = IS_NOT_EQUAL(array1[i], 0) ? std::sqrt(array1[i]) : 0;
-      }
+    else { array1[i] = IS_NOT_EQUAL(array1[i], 0) ? std::sqrt(array1[i]) : 0; }
   field1.nmiss = nmiss;
 }
 
 void
-fieldc_var(Field &field1, const Field &field2, const int nsets, const int divisor)
+fieldc_var(Field &field1, const Field &field2, const int numSets, const int divisor)
 {
-  const auto nsetx = nsets - divisor;
+  const auto nsetx = numSets - divisor;
   const auto missval1 = field1.missval;
   const auto missval2 = field2.missval;
   auto &array1 = field1.vec_d;
@@ -826,7 +811,7 @@ fieldc_var(Field &field1, const Field &field2, const int nsets, const int diviso
     {
       for (size_t i = 0; i < len; ++i)
         {
-          const auto temp = MULMN(array1[i], array1[i]) / nsets;
+          const auto temp = MULMN(array1[i], array1[i]) / numSets;
           array1[i] = SUBMN(array2[i], temp) / nsetx;
           if (array1[i] < 0 && array1[i] > -1.e-5) array1[i] = 0;
         }
@@ -835,7 +820,7 @@ fieldc_var(Field &field1, const Field &field2, const int nsets, const int diviso
     {
       for (size_t i = 0; i < len; ++i)
         {
-          const auto temp = MUL(array1[i], array1[i]) / nsets;
+          const auto temp = MUL(array1[i], array1[i]) / numSets;
           array1[i] = SUB(array2[i], temp) / nsetx;
           if (array1[i] < 0 && array1[i] > -1.e-5) array1[i] = 0;
         }
@@ -845,7 +830,7 @@ fieldc_var(Field &field1, const Field &field2, const int nsets, const int diviso
 }
 
 void
-fieldc_std(Field &field1, const Field &field2, const int nsets, const int divisor)
+fieldc_std(Field &field1, const Field &field2, const int numSets, const int divisor)
 {
   const auto missval1 = field1.missval;
   auto &array1 = field1.vec_d;
@@ -853,7 +838,7 @@ fieldc_std(Field &field1, const Field &field2, const int nsets, const int diviso
   const auto len = field1.size;
   if (len != field2.size) cdo_abort("Fields have different size (%s)", __func__);
 
-  fieldc_var(field1, field2, nsets, divisor);
+  fieldc_var(field1, field2, numSets, divisor);
 
   size_t nmiss = 0;
   for (size_t i = 0; i < len; ++i)
@@ -862,10 +847,7 @@ fieldc_std(Field &field1, const Field &field2, const int nsets, const int diviso
         array1[i] = missval1;
         nmiss++;
       }
-    else
-      {
-        array1[i] = IS_NOT_EQUAL(array1[i], 0) ? std::sqrt(array1[i]) : 0;
-      }
+    else { array1[i] = IS_NOT_EQUAL(array1[i], 0) ? std::sqrt(array1[i]) : 0; }
 
   field1.nmiss = nmiss;
 }
@@ -962,7 +944,7 @@ varray2_count(const size_t len, Varray<T> &v)
 {
   assert(len > 0);
 
-  for (size_t i = 0; i < len; ++i)  v[i] += 1.0;
+  for (size_t i = 0; i < len; ++i) v[i] += 1.0;
 }
 
 void
@@ -990,7 +972,6 @@ field2_count(Field &field1, const Field &field2)
       else
         varray2_count(field1.size, field1.vec_d);
     }
-
 }
 
 void
