@@ -14,20 +14,20 @@
 static void
 fields_from_vlist_kernel(const int vlistID, FieldVector2D &field2D, int ptype, bool lfill, double fillValue)
 {
-  const auto allocateData = (ptype & FIELD_VEC);
-  const auto nvars = vlistNvars(vlistID);
+  auto allocateData = (ptype & FIELD_VEC);
+  auto nvars = vlistNvars(vlistID);
   field2D.resize(nvars);
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      const auto gridID = vlistInqVarGrid(vlistID, varID);
-      const auto gridsize = gridInqSize(gridID);
-      const size_t nwpv = vlist_inq_nwpv(vlistID, varID);  // number of words per value; real:1  complex:2
-      const auto size = gridsize * nwpv;
-      const auto zaxisID = vlistInqVarZaxis(vlistID, varID);
-      const auto nlevels = zaxisInqSize(zaxisID);
-      const auto missval = vlistInqVarMissval(vlistID, varID);
-      const auto datatype = vlistInqVarDatatype(vlistID, varID);
+      auto gridID = vlistInqVarGrid(vlistID, varID);
+      auto gridsize = gridInqSize(gridID);
+      size_t nwpv = vlist_inq_nwpv(vlistID, varID);  // number of words per value; real:1  complex:2
+      auto size = gridsize * nwpv;
+      auto zaxisID = vlistInqVarZaxis(vlistID, varID);
+      auto nlevels = zaxisInqSize(zaxisID);
+      auto missval = vlistInqVarMissval(vlistID, varID);
+      auto datatype = vlistInqVarDatatype(vlistID, varID);
       auto memType = (ptype & FIELD_FLT) ? MemType::Float : MemType::Double;
       if (ptype & FIELD_NAT)
         {
