@@ -264,10 +264,7 @@ meridional_pctl(const Field &field1, Field &field2, const double pn)
                 if (!DBL_IS_EQUAL(field1.vec_d[j * nx + i], missval)) v[k++] = field1.vec_d[j * nx + i];
             }
 
-          if (k > 0)
-            {
-              field2.vec_d[i] = percentile(v.data(), k, pn);
-            }
+          if (k > 0) { field2.vec_d[i] = percentile(v.data(), k, pn); }
           else
             {
               field2.vec_d[i] = missval;
