@@ -154,13 +154,10 @@ template <typename T>
 static void
 fieldc_mod(size_t len, size_t nmiss, Varray<T> &v, const T missval, const double divisor)
 {
-  (void)nmiss;
+  (void) nmiss;
   const auto missval1 = missval;
 
-  for (size_t i = 0; i < len; ++i)
-    {
-      v[i] = DBL_IS_EQUAL(v[i], missval1) ? missval1 : std::fmod((double) v[i], divisor);
-    }
+  for (size_t i = 0; i < len; ++i) { v[i] = DBL_IS_EQUAL(v[i], missval1) ? missval1 : std::fmod((double) v[i], divisor); }
 }
 
 void
