@@ -31,10 +31,10 @@ PointSearchMethod pointSearchMethod(PointSearchMethod::undefined);
 
 struct gpsFull
 {
-  size_t n;
-  const double *plons;
-  const double *plats;
-  double **pts;
+  size_t n = 0;
+  const double *plons = nullptr;
+  const double *plats = nullptr;
+  double (*pts)[3] = nullptr;
 };
 
 template <typename T>
@@ -59,14 +59,13 @@ struct PointCloud
   // value, the
   //  "if/else's" are actually solved at compile time.
   inline T
-  kdtree_get_pt(const size_t idx, int dim) const
+  kdtree_get_pt(size_t idx, int dim) const
   {
-    if (dim == 0)
-      return pts[idx].x;
-    else if (dim == 1)
-      return pts[idx].y;
-    else
-      return pts[idx].z;
+    // clang-format off
+    if      (dim == 0) return pts[idx].x;
+    else if (dim == 1) return pts[idx].y;
+    else               return pts[idx].z;
+    // clang-format on
   }
 
   // Optional bounding-box computation: return false to default to a standard
@@ -88,16 +87,11 @@ struct PointCloud
 using nfTree_t
     = nanoflann::KDTreeSingleIndexAdaptor<nanoflann::L2_Simple_Adaptor<double, PointCloud<double>>, PointCloud<double>, 3>;
 
+// get point search radius in radians
 static double
-cdoDefaultRadius(void)
+cdo_get_search_radius_inRadians(void)
 {
-  extern double pointSearchRadius;
-
-  auto searchRadius = pointSearchRadius;
-  searchRadius = std::min(std::max(searchRadius, 0.), 180.);
-  searchRadius *= DEG2RAD;
-
-  return searchRadius;
+  return cdo_get_search_radius() * DEG2RAD;
 }
 
 void
@@ -122,7 +116,7 @@ arc_to_chord_length(double arcLength)
 static double
 chord_to_arc_length(double chordLength)
 {
-  return 2.0 * std::asin(std::min(std::max(chordLength / 2.0, -1.0), 1.0));
+  return 2.0 * std::asin(std::clamp(chordLength / 2.0, -1.0, 1.0));
 }
 
 void
@@ -145,18 +139,31 @@ grid_point_search_extrapolate(GridPointSearch &gps)
   gps.extrapolate = true;
 }
 
+void
+grid_point_search_create_healpix(GridPointSearch &gps, size_t size, int nside, HpOrder order)
+{
+  gps.isCyclic = true;
+  gps.dims[0] = size;
+  gps.nside = nside;
+  gps.order = order;
+
+  gps.searchRadius = cdo_get_search_radius_inRadians();
+
+  gps.in_use = true;
+}
+
 void
 grid_point_search_create_reg_2d(GridPointSearch &gps, bool xIsCyclic, size_t dims[2], const Varray<double> &lons,
                                 const Varray<double> &lats)
 {
-  gps.is_cyclic = xIsCyclic;
+  gps.isCyclic = xIsCyclic;
   gps.is_reg2d = true;
   gps.dims[0] = dims[0];
   gps.dims[1] = dims[1];
-  const auto nx = dims[0];
-  const auto ny = dims[1];
+  auto nx = dims[0];
+  auto ny = dims[1];
 
-  const auto nxm = xIsCyclic ? nx + 1 : nx;
+  auto nxm = xIsCyclic ? nx + 1 : nx;
 
   gps.reg2d_center_lon.resize(nxm);
   gps.reg2d_center_lat.resize(ny);
@@ -189,7 +196,7 @@ grid_point_search_create_reg_2d(GridPointSearch &gps, bool xIsCyclic, size_t dim
       sinlat[n] = std::sin(lats[n]);
     }
 
-  gps.searchRadius = cdoDefaultRadius();
+  gps.searchRadius = cdo_get_search_radius_inRadians();
 
   gps.in_use = true;
 }
@@ -261,13 +268,13 @@ static void *
 gps_create_nanoflann(size_t n, const Varray<double> &lons, const Varray<double> &lats, GridPointSearch &gps,
                      bool useBoundBox = false)
 {
-  PointCloud<double> *pointcloud = new PointCloud<double>();
+  PointCloud<double> *pointCloud = new PointCloud<double>();
 
   double min[3] = { 1.e9, 1.e9, 1.e9 };
   double max[3] = { -1.e9, -1.e9, -1.e9 };
 
   // Generating Point Cloud
-  pointcloud->pts.resize(n);
+  pointCloud->pts.resize(n);
 #ifdef HAVE_OPENMP45
 #pragma omp parallel for schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
 #endif
@@ -275,14 +282,14 @@ gps_create_nanoflann(size_t n, const Varray<double> &lons, const Varray<double>
     {
       double point[3];
       gcLLtoXYZ(lons[i], lats[i], point);
-      pointcloud->pts[i].x = point[0];
-      pointcloud->pts[i].y = point[1];
-      pointcloud->pts[i].z = point[2];
+      pointCloud->pts[i].x = point[0];
+      pointCloud->pts[i].y = point[1];
+      pointCloud->pts[i].z = point[2];
       min_point(min, point);
       max_point(max, point);
     }
 
-  gps.pointcloud = (void *) pointcloud;
+  gps.pointCloud = (void *) pointCloud;
 
   if (!useBoundBox) min[0] = min[1] = min[2] = -1;
   if (!useBoundBox) max[0] = max[1] = max[2] = 1;
@@ -294,11 +301,11 @@ gps_create_nanoflann(size_t n, const Varray<double> &lons, const Varray<double>
 
   if (Options::cdoVerbose) cdo_print("BBOX: min=%g/%g/%g  max=%g/%g/%g", min[0], min[1], min[2], max[0], max[1], max[2]);
 
-  for (int i = 0; i < 3; ++i) pointcloud->min[i] = min[i];
-  for (int i = 0; i < 3; ++i) pointcloud->max[i] = max[i];
+  for (int i = 0; i < 3; ++i) pointCloud->min[i] = min[i];
+  for (int i = 0; i < 3; ++i) pointCloud->max[i] = max[i];
 
   // construct a kd-tree index:
-  nfTree_t *nft = new nfTree_t(3 /*dim*/, *pointcloud, nanoflann::KDTreeSingleIndexAdaptorParams(50 /* max leaf */));
+  nfTree_t *nft = new nfTree_t(3 /*dim*/, *pointCloud, nanoflann::KDTreeSingleIndexAdaptorParams(50 /* max leaf */));
   nft->buildIndex();
 
   return (void *) nft;
@@ -308,9 +315,7 @@ static void *
 gps_create_spherepart(size_t n, const Varray<double> &lons, const Varray<double> &lats, GridPointSearch &gps,
                       bool useBoundBox = false)
 {
-  double(*coordinates_xyz)[3];
-  coordinates_xyz = (double(*)[3]) malloc(n * sizeof(*coordinates_xyz));
-  gps.coordinates_xyz = coordinates_xyz;
+  gps.coordinates_xyz = new double[n][3];
 
   double min[3] = { 1.e9, 1.e9, 1.e9 };
   double max[3] = { -1.e9, -1.e9, -1.e9 };
@@ -320,7 +325,7 @@ gps_create_spherepart(size_t n, const Varray<double> &lons, const Varray<double>
 #endif
   for (size_t i = 0; i < n; ++i)
     {
-      double *point = coordinates_xyz[i];
+      double *point = gps.coordinates_xyz[i];
       gcLLtoXYZ(lons[i], lats[i], point);
       min_point(min, point);
       max_point(max, point);
@@ -336,11 +341,11 @@ gps_create_spherepart(size_t n, const Varray<double> &lons, const Varray<double>
 
   if (Options::cdoVerbose) cdo_print("BBOX: min=%g/%g/%g  max=%g/%g/%g", min[0], min[1], min[2], max[0], max[1], max[2]);
 
-  size_t *global_ids = (size_t *) malloc(n * sizeof(*global_ids));
+  size_t *global_ids = new size_t[n];
   for (size_t i = 0; i < n; ++i) global_ids[i] = i;
-  auto point_search_new = yac_point_sphere_part_search_new(n, gps.coordinates_xyz, global_ids);
-  free(global_ids);
-  return (void *) point_search_new;
+  auto yacPointSearch = yac_point_sphere_part_search_new(n, gps.coordinates_xyz, global_ids);
+  delete[] global_ids;
+  return (void *) yacPointSearch;
 }
 
 static void
@@ -356,9 +361,8 @@ gps_destroy_full(void *search_container)
   auto full = (gpsFull *) search_container;
   if (full)
     {
-      if (full->pts) free(full->pts[0]);
-      if (full->pts) free(full->pts);
-      free(full);
+      if (full->pts) delete[] full->pts;
+      delete full;
     }
 }
 
@@ -373,24 +377,17 @@ gps_create_full(size_t n, const Varray<double> &lons, const Varray<double> &lats
 {
   if (Options::cdoVerbose) cdo_print("Init full grid search: n=%zu", n);
 
-  auto full = (gpsFull *) calloc(1, sizeof(gpsFull));
-
-  double **p = (double **) malloc(n * sizeof(double *));
-  p[0] = (double *) malloc(3 * n * sizeof(double));
-  for (size_t i = 1; i < n; ++i) p[i] = p[0] + i * 3;
+  auto full = new gpsFull;
+  full->pts = new double[n][3];
 
 #ifdef HAVE_OPENMP4
 #pragma omp simd
 #endif
-  for (size_t i = 0; i < n; ++i)
-    {
-      gcLLtoXYZ(lons[i], lats[i], p[i]);
-    }
+  for (size_t i = 0; i < n; ++i) { gcLLtoXYZ(lons[i], lats[i], full->pts[i]); }
 
   full->n = n;
   full->plons = lons.data();
   full->plats = lats.data();
-  full->pts = p;
 
   return (void *) full;
 }
@@ -409,9 +406,9 @@ print_method(PointSearchMethod method)
 void
 grid_point_search_create(GridPointSearch &gps, const Varray<double> &lons, const Varray<double> &lats, PointSearchMethod method)
 {
-  const auto n = lons.size();
+  auto n = lons.size();
 
-  gps.is_cyclic = false;
+  gps.isCyclic = false;
   gps.is_curve = false;
   gps.dims[0] = n;
   gps.dims[1] = 0;
@@ -436,7 +433,7 @@ grid_point_search_create(GridPointSearch &gps, const Varray<double> &lons, const
   else cdo_abort("%s::method undefined!", __func__);
   // clang-format on
 
-  gps.searchRadius = cdoDefaultRadius();
+  gps.searchRadius = cdo_get_search_radius_inRadians();
 
   gps.in_use = true;
 }
@@ -445,7 +442,7 @@ void
 grid_point_search_create(GridPointSearch &gps, bool xIsCyclic, size_t dims[2], size_t n, const Varray<double> &lons,
                          const Varray<double> &lats)
 {
-  gps.is_cyclic = xIsCyclic;
+  gps.isCyclic = xIsCyclic;
   gps.is_curve = (n != 1 && n == dims[0] * dims[1]);
   gps.dims[0] = dims[0];
   gps.dims[1] = dims[1];
@@ -470,7 +467,7 @@ grid_point_search_create(GridPointSearch &gps, bool xIsCyclic, size_t dims[2], s
   else cdo_abort("%s::method undefined!", __func__);
   // clang-format on
 
-  gps.searchRadius = cdoDefaultRadius();
+  gps.searchRadius = cdo_get_search_radius_inRadians();
 
   gps.in_use = true;
 }
@@ -492,12 +489,12 @@ grid_point_search_delete(GridPointSearch &gps)
       if      (gps.method == PointSearchMethod::kdtree)     gps_destroy_kdtree(gps.search_container);
       else if (gps.method == PointSearchMethod::nanoflann)
         {
-          delete ((PointCloud<double> *) gps.pointcloud);
+          delete ((PointCloud<double> *) gps.pointCloud);
           delete ((nfTree_t *) gps.search_container);
         }
       else if (gps.method == PointSearchMethod::spherepart)
         {
-          free(gps.coordinates_xyz);
+          delete[] gps.coordinates_xyz;
           gps_destroy_spherepart(gps.search_container);
         }
       else if (gps.method == PointSearchMethod::full)       gps_destroy_full(gps.search_container);
@@ -515,7 +512,7 @@ gps_nearest_kdtree(void *search_container, double lon, double lat, double search
   auto kdt = (kdTree_t *) search_container;
   if (kdt == nullptr) return 0;
 
-  const auto sqrDistMax = cdo::sqr(searchRadius);
+  auto sqrDistMax = cdo::sqr(searchRadius);
   auto sqrDist = sqrDistMax;
 
   double query_pt[3];
@@ -525,7 +522,7 @@ gps_nearest_kdtree(void *search_container, double lon, double lat, double search
     for (int i = 0; i < 3; ++i)
       if (query_pt[i] < gps.min[i] || query_pt[i] > gps.max[i]) return 0;
 
-  const auto node = kd_nearest(kdt->node, query_pt, &sqrDist, 3);
+  auto node = kd_nearest(kdt->node, query_pt, &sqrDist, 3);
 
   if (node && sqrDist < sqrDistMax)
     {
@@ -544,7 +541,7 @@ gps_nearest_nanoflann(void *search_container, double lon, double lat, double sea
   auto nft = (nfTree_t *) search_container;
   if (nft == nullptr) return 0;
 
-  const auto sqrDistMax = cdo::sqr(searchRadius);
+  auto sqrDistMax = cdo::sqr(searchRadius);
 
   double query_pt[3];
   gcLLtoXYZ(lon, lat, query_pt);
@@ -553,10 +550,10 @@ gps_nearest_nanoflann(void *search_container, double lon, double lat, double sea
     for (int i = 0; i < 3; ++i)
       if (query_pt[i] < gps.min[i] || query_pt[i] > gps.max[i]) return 0;
 
-  const size_t num_results = 1;
+  constexpr size_t numResults = 1;
   size_t retIndex;
   double sqrDist;
-  nanoflann::KNNResultSet<double> resultSet(sqrDistMax, num_results);
+  nanoflann::KNNResultSet<double> resultSet(sqrDistMax, numResults);
   resultSet.init(&retIndex, &sqrDist);
   nft->findNeighbors(resultSet, query_pt, nanoflann::SearchParams(10));
 
@@ -613,14 +610,14 @@ gps_nearest_full(void *search_container, double lon, double lat, double searchRa
   auto full = (gpsFull *) search_container;
   if (full == nullptr) return 0;
 
-  const auto sqrDistMax = cdo::sqr(searchRadius);
+  auto sqrDistMax = cdo::sqr(searchRadius);
 
   double query_pt[3];
   gcLLtoXYZ(lon, lat, query_pt);
 
   size_t n = full->n;
   size_t closestpt = n;
-  double **pts = full->pts;
+  auto pts = full->pts;
   double sqrDist = FLT_MAX;
   for (size_t i = 0; i < n; ++i)
     {
@@ -642,7 +639,7 @@ gps_nearest_full(void *search_container, double lon, double lat, double searchRa
   return 0;
 }
 
-bool point_in_quad(bool is_cyclic, size_t nx, size_t ny, size_t i, size_t j, size_t adds[4], double lons[4], double lats[4],
+bool point_in_quad(bool isCyclic, size_t nx, size_t ny, size_t i, size_t j, size_t adds[4], double lons[4], double lats[4],
                    double plon, double plat, const double *centerLon, const double *centerLat);
 
 static size_t
@@ -650,11 +647,11 @@ llindex_in_quad(const GridPointSearch &gps, size_t index, double lon, double lat
 {
   if (index != GPS_NOT_FOUND)
     {
-      const auto nx = gps.dims[0];
-      const auto ny = gps.dims[1];
+      auto nx = gps.dims[0];
+      auto ny = gps.dims[1];
       size_t adds[4];
       double lons[4], lats[4];
-      const auto isCyclic = gps.is_cyclic;
+      auto isCyclic = gps.isCyclic;
       for (int k = 0; k < 4; ++k)
         {
           // Determine neighbor addresses
@@ -676,7 +673,7 @@ grid_point_search_nearest(const GridPointSearch &gps, double lon, double lat, si
   if (gps.in_use)
     {
       size_t nadds = 0;
-      const auto searchRadius = gps.searchRadius;
+      auto searchRadius = gps.searchRadius;
       void *sc = gps.search_container;
       // clang-format off
       if      (gps.method == PointSearchMethod::kdtree)     nadds = gps_nearest_kdtree(sc, lon, lat, searchRadius, addr, dist, gps);
@@ -698,16 +695,14 @@ grid_point_search_nearest(const GridPointSearch &gps, double lon, double lat, si
 }
 
 static size_t
-gps_qnearest_kdtree(GridPointSearch &gps, double lon, double lat, double searchRadius, size_t nnn, size_t *adds, double *dist)
+gps_qnearest_kdtree(const GridPointSearch &gps, double lon, double lat, double searchRadius, size_t nnn, size_t *adds, double *dist)
 {
   size_t nadds = 0;
 
   auto kdt = (kdTree_t *) gps.search_container;
   if (kdt == nullptr) return nadds;
 
-  const auto sqrDistMax = cdo::sqr(searchRadius);
-  kdata_t sqrDist = sqrDistMax;
-  pqueue *result = nullptr;
+  auto sqrDistMax = cdo::sqr(searchRadius);
 
   kdata_t query_pt[3];
   gcLLtoXYZ(lon, lat, query_pt);
@@ -718,23 +713,21 @@ gps_qnearest_kdtree(GridPointSearch &gps, double lon, double lat, double searchR
 
   if (gps.in_use)
     {
-      result = kd_qnearest(kdt->node, query_pt, &sqrDist, nnn, 3);
+      kdata_t sqrDist = sqrDistMax;
+      auto result = kd_qnearest(kdt->node, query_pt, &sqrDist, nnn, 3);
       if (result)
         {
-          size_t index;
           resItem *p;
           while (pqremove_min(result, &p))
             {
-              index = p->node->index;
-              sqrDist = p->dist_sq;
-              free(p);  // Free the result node taken from the heap
-
-              if (sqrDist < sqrDistMax)
+              if (p->dist_sq < sqrDistMax)
                 {
-                  adds[nadds] = index;
-                  dist[nadds] = std::sqrt(sqrDist);
+                  adds[nadds] = p->node->index;
+                  dist[nadds] = std::sqrt(p->dist_sq);
                   nadds++;
                 }
+
+              free(p);  // Free the result node taken from the heap
             }
           free(result->d);  // free the heap
           free(result);     // and free the heap information structure
@@ -753,7 +746,7 @@ gps_qnearest_nanoflann(const GridPointSearch &gps, double lon, double lat, doubl
   auto nft = (nfTree_t *) gps.search_container;
   if (nft == nullptr) return nadds;
 
-  const auto sqrDistMax = cdo::sqr(searchRadius);
+  auto sqrDistMax = cdo::sqr(searchRadius);
 
   double query_pt[3];
   gcLLtoXYZ(lon, lat, query_pt);
@@ -769,7 +762,7 @@ gps_qnearest_nanoflann(const GridPointSearch &gps, double lon, double lat, doubl
 }
 
 static size_t
-gps_qnearest_spherepart(GridPointSearch &gps, double lon, double lat, double searchArcRadius, size_t nnn, size_t *adds,
+gps_qnearest_spherepart(const GridPointSearch &gps, double lon, double lat, double searchArcRadius, size_t nnn, size_t *adds,
                         double *dist)
 {
   size_t nadds = 0;
@@ -796,11 +789,11 @@ gps_qnearest_spherepart(GridPointSearch &gps, double lon, double lat, double sea
 
       if (num_local_point_ids > 0)
         {
-          const auto maxadds = (num_local_point_ids < nnn) ? num_local_point_ids : nnn;
+          auto maxadds = (num_local_point_ids < nnn) ? num_local_point_ids : nnn;
           nadds = 0;
           for (size_t i = 0; i < maxadds; ++i)
             {
-              const auto angle = std::acos(cos_angles[i]);
+              auto angle = std::acos(cos_angles[i]);
               if (angle < searchArcRadius)
                 {
                   adds[nadds] = local_point_ids[i];
@@ -810,21 +803,21 @@ gps_qnearest_spherepart(GridPointSearch &gps, double lon, double lat, double sea
             }
         }
 
-      free(cos_angles);
-      free(local_point_ids);
+      if (cos_angles) free(cos_angles);
+      if (local_point_ids) free(local_point_ids);
     }
 
   return nadds;
 }
 
 size_t
-grid_point_search_qnearest(GridPointSearch &gps, double lon, double lat, size_t nnn, size_t *adds, double *dist)
+grid_point_search_qnearest(const GridPointSearch &gps, double lon, double lat, size_t nnn, size_t *adds, double *dist)
 {
   size_t nadds = 0;
 
   if (gps.in_use)
     {
-      const auto searchRadius = gps.searchRadius;
+      auto searchRadius = gps.searchRadius;
       // clang-format off
       if      (gps.method == PointSearchMethod::kdtree)     nadds = gps_qnearest_kdtree(gps, lon, lat, searchRadius, nnn, adds, dist);
       else if (gps.method == PointSearchMethod::nanoflann)  nadds = gps_qnearest_nanoflann(gps, lon, lat, searchRadius, nnn, adds, dist);
@@ -834,11 +827,11 @@ grid_point_search_qnearest(GridPointSearch &gps, double lon, double lat, size_t
 
       if (!gps.extrapolate && gps.is_curve)
         {
-          const auto naddsmax = nadds;
+          auto naddsmax = nadds;
           nadds = 0;
           for (size_t i = 0; i < naddsmax; ++i)
             {
-              const auto index = llindex_in_quad(gps, adds[i], lon, lat);
+              auto index = llindex_in_quad(gps, adds[i], lon, lat);
               if (index != GPS_NOT_FOUND)
                 {
                   adds[nadds] = adds[i];
@@ -853,8 +846,8 @@ grid_point_search_qnearest(GridPointSearch &gps, double lon, double lat, size_t
 }
 
 size_t
-grid_point_search_distance_qnearest(GridPointSearch &gps, double searchRadius, double lon, double lat, size_t nnn, size_t *adds,
-                                    double *dist)
+grid_point_search_distance_qnearest(const GridPointSearch &gps, double searchRadius, double lon, double lat, size_t nnn,
+                                    size_t *adds, double *dist)
 {
   size_t nadds = 0;
 
@@ -869,11 +862,11 @@ grid_point_search_distance_qnearest(GridPointSearch &gps, double searchRadius, d
 
       if (!gps.extrapolate && gps.is_curve)
         {
-          const auto naddsmax = nadds;
+          auto naddsmax = nadds;
           nadds = 0;
           for (size_t i = 0; i < naddsmax; ++i)
             {
-              const auto index = llindex_in_quad(gps, adds[i], lon, lat);
+              auto index = llindex_in_quad(gps, adds[i], lon, lat);
               if (index != GPS_NOT_FOUND)
                 {
                   adds[nadds] = adds[i];
@@ -889,8 +882,5 @@ grid_point_search_distance_qnearest(GridPointSearch &gps, double searchRadius, d
 
 GridPointSearch::~GridPointSearch()
 {
-  if (search_container != nullptr)
-    {
-      cdo_warning("search_container was not freed or not set to nullptr after free!");
-    }
+  if (search_container != nullptr) { cdo_warning("search_container was not freed or not set to nullptr after free!"); }
 }
