@@ -24,14 +24,13 @@ skip_nondigit_lines(FILE *gfp)
 
   while (1)
     {
-      do
-        c = fgetc(gfp);
+      do c = fgetc(gfp);
       while ((isspace(c) || c == ',') && c != EOF);
 
       if (c == EOF || isdigit(c) || c == '.' || c == '+' || c == '-' || c == 'N')
         break;  // N: for NaN
       else
-        while (c != '\n' && c != EOF) c = fgetc(gfp);
+        while (c != '\n' && c != '\r' && c != EOF) c = fgetc(gfp);
     }
 
   ungetc(c, gfp);
@@ -46,7 +45,7 @@ input_ival(FILE *gfp, int &ival)
 
   ival = 0;
 
-  return fscanf(gfp, "%d", &ival);
+  return std::fscanf(gfp, "%d", &ival);
 }
 
 size_t
@@ -61,7 +60,7 @@ input_darray(FILE *gfp, size_t n_values, std::vector<double> &array)
 
       if (feof(gfp)) break;
 
-      read_items += fscanf(gfp, "%lg", &array[i]);
+      read_items += std::fscanf(gfp, "%lg", &array[i]);
 
       if (feof(gfp)) break;
     }
