@@ -15,7 +15,6 @@
 #include "cdi_uuid.h"
 #include "cdo_options.h"
 #include "process_int.h"
-#include "cdo_cdi_wrapper.h"
 #include "griddes.h"
 #include "util_wildcards.h"
 #include "grid_read_pingo.h"
@@ -38,7 +37,7 @@ getoptname(char *optname, const char *optstring, int nopt)
   if (pend)
     {
       pend = strchr(pname, ',');
-      const size_t namelen = (pend == nullptr) ? strlen(pname) : pend - pname;
+      size_t namelen = (pend == nullptr) ? strlen(pname) : pend - pname;
       memcpy(optname, pname, namelen);
       optname[namelen] = '\0';
       nerr = 0;
@@ -54,7 +53,7 @@ genXboundsRegular(GridDesciption &grid)
   grid.xbounds.resize(grid.xsize * grid.nvertex);
   for (size_t i = 0; i < grid.xsize - 1; ++i)
     {
-      const auto value = 0.5 * (grid.xvals[i] + grid.xvals[i + 1]);
+      auto value = 0.5 * (grid.xvals[i] + grid.xvals[i + 1]);
       grid.xbounds[2 * i + 1] = value;
       grid.xbounds[2 * (i + 1)] = value;
     }
@@ -74,12 +73,12 @@ genXboundsRegular(GridDesciption &grid)
 static void
 genYboundsRegular(GridDesciption &grid)
 {
-  const auto lrev = (grid.yvals[0] > grid.yvals[grid.ysize - 1]);
+  auto lrev = (grid.yvals[0] > grid.yvals[grid.ysize - 1]);
   grid.nvertex = 2;
   grid.ybounds.resize(grid.ysize * grid.nvertex);
   for (size_t i = 0; i < grid.ysize - 1; ++i)
     {
-      const auto value = 0.5 * (grid.yvals[i] + grid.yvals[i + 1]);
+      auto value = 0.5 * (grid.yvals[i] + grid.yvals[i + 1]);
       if (lrev)
         {
           grid.ybounds[2 * i] = value;
@@ -109,6 +108,19 @@ grid_define(GridDesciption &grid)
 {
   int gridID = CDI_UNDEFID;
 
+  if (grid.type == GRID_PROJECTION && grid.projection == "healpix")
+    {
+      if (grid.healpixNside <= 0) cdo_abort("healpix nside undefined!");
+      gridID = gridCreate(grid.type, grid.size);
+      cdiDefKeyString(gridID, CDI_GLOBAL, CDI_KEY_DIMNAME, "cells");
+      cdiDefKeyString(gridID, CDI_GLOBAL, CDI_KEY_GRIDMAP_VARNAME, "healpix");
+      cdiDefKeyString(gridID, CDI_GLOBAL, CDI_KEY_GRIDMAP_NAME, grid.projection.c_str());
+      cdiDefAttTxt(gridID, CDI_GLOBAL, "grid_mapping_name", (int) grid.projection.size(), grid.projection.c_str());
+      cdiDefAttInt(gridID, CDI_GLOBAL, "healpix_nside", CDI_DATATYPE_INT32, 1, &grid.healpixNside);
+      cdiDefAttTxt(gridID, CDI_GLOBAL, "healpix_order", (int) grid.healpixOrder.size(), grid.healpixOrder.c_str());
+      return gridID;
+    }
+
   switch (grid.type)
     {
     case GRID_GENERIC:
@@ -120,13 +132,15 @@ grid_define(GridDesciption &grid)
       {
         if (grid.size != 1)
           {
-            if (grid.xsize == 0 && grid.type != GRID_PROJECTION && grid.type != GRID_GAUSSIAN_REDUCED) cdo_abort("xsize undefined!");
+            if (grid.xsize == 0 && grid.type != GRID_PROJECTION && grid.type != GRID_GAUSSIAN_REDUCED)
+              cdo_abort("xsize undefined!");
             if (grid.ysize == 0 && grid.type != GRID_PROJECTION) cdo_abort("ysize undefined!");
           }
 
         if (grid.size == 0) grid.size = grid.xsize * grid.ysize;
 
-        if (grid.type != GRID_PROJECTION && grid.type != GRID_GAUSSIAN_REDUCED && grid.xsize && grid.size != grid.xsize * grid.ysize)
+        if (grid.type != GRID_PROJECTION && grid.type != GRID_GAUSSIAN_REDUCED && grid.xsize
+            && grid.size != grid.xsize * grid.ysize)
           cdo_abort("Inconsistent grid declaration: xsize*ysize!=gridsize (xsize=%zu ysize=%zu gridsize=%zu)", grid.xsize,
                     grid.ysize, grid.size);
 
@@ -140,17 +154,17 @@ grid_define(GridDesciption &grid)
 
         if (grid.nvertex) gridDefNvertex(gridID, grid.nvertex);
 
-        const auto def_xfirst = IS_NOT_EQUAL(grid.xfirst, undefGridValue);
-        const auto def_yfirst = IS_NOT_EQUAL(grid.yfirst, undefGridValue);
-        const auto def_xlast = IS_NOT_EQUAL(grid.xlast, undefGridValue);
-        const auto def_ylast = IS_NOT_EQUAL(grid.ylast, undefGridValue);
-        const auto def_xinc = IS_NOT_EQUAL(grid.xinc, undefGridValue);
-        const auto def_yinc = IS_NOT_EQUAL(grid.yinc, undefGridValue);
+        auto def_xfirst = IS_NOT_EQUAL(grid.xfirst, undefGridValue);
+        auto def_yfirst = IS_NOT_EQUAL(grid.yfirst, undefGridValue);
+        auto def_xlast = IS_NOT_EQUAL(grid.xlast, undefGridValue);
+        auto def_ylast = IS_NOT_EQUAL(grid.ylast, undefGridValue);
+        auto def_xinc = IS_NOT_EQUAL(grid.xinc, undefGridValue);
+        auto def_yinc = IS_NOT_EQUAL(grid.yinc, undefGridValue);
         if ((def_xfirst || def_xlast || def_xinc) && grid.xvals.size() == 0)
           {
-            const auto xfirst = def_xfirst ? grid.xfirst : 0.0;
-            const auto xlast = def_xlast ? grid.xlast : 0.0;
-            const auto xinc = def_xinc ? grid.xinc : 0.0;
+            auto xfirst = def_xfirst ? grid.xfirst : 0.0;
+            auto xlast = def_xlast ? grid.xlast : 0.0;
+            auto xinc = def_xinc ? grid.xinc : 0.0;
             grid.xvals.resize(grid.xsize);
             grid_gen_xvals(grid.xsize, xfirst, xlast, xinc, grid.xvals.data());
             if (grid.genBounds && grid.xbounds.size() == 0 /*&& grid.xsize > 1*/) genXboundsRegular(grid);
@@ -158,9 +172,9 @@ grid_define(GridDesciption &grid)
 
         if ((def_yfirst || def_ylast || def_yinc) && grid.yvals.size() == 0)
           {
-            const auto yfirst = def_yfirst ? grid.yfirst : 0.0;
-            const auto ylast = def_ylast ? grid.ylast : yfirst;
-            const auto yinc = def_yinc ? grid.yinc : 0.0;
+            auto yfirst = def_yfirst ? grid.yfirst : 0.0;
+            auto ylast = def_ylast ? grid.ylast : yfirst;
+            auto yinc = def_yinc ? grid.yinc : 0.0;
             grid.yvals.resize(grid.ysize);
             if (grid.type == GRID_GAUSSIAN && grid.genBounds)
               {
@@ -222,7 +236,7 @@ grid_define(GridDesciption &grid)
                 cdiDefKeyInt(gridID, CDI_GLOBAL, CDI_KEY_NUMBEROFGRIDUSED, grid.number);
                 if (grid.position >= 0) cdiDefKeyInt(gridID, CDI_GLOBAL, CDI_KEY_NUMBEROFGRIDINREFERENCE, grid.position);
               }
-            if (*grid.path) cdiDefKeyString(gridID, CDI_GLOBAL, CDI_KEY_REFERENCEURI, grid.path);
+            if (grid.path.size()) cdiDefKeyString(gridID, CDI_GLOBAL, CDI_KEY_REFERENCEURI, grid.path.c_str());
           }
 
         if (grid.xvals.size()) gridDefXvals(gridID, grid.xvals.data());
@@ -275,15 +289,17 @@ grid_define(GridDesciption &grid)
 
   if (!cdiUUIDIsNull(grid.uuid)) cdiDefKeyBytes(gridID, CDI_GLOBAL, CDI_KEY_UUID, grid.uuid, CDI_UUID_SIZE);
 
-  if (grid.xname[0]) cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_NAME, grid.xname);
-  if (grid.xlongname[0]) cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_LONGNAME, grid.xlongname);
-  if (grid.xunits[0]) cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_UNITS, grid.xunits);
-  if (grid.yname[0]) cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_NAME, grid.yname);
-  if (grid.ylongname[0]) cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_LONGNAME, grid.ylongname);
-  if (grid.yunits[0]) cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_UNITS, grid.yunits);
-  if (grid.xdimname[0]) cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_DIMNAME, grid.xdimname);
-  if (grid.ydimname[0]) cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_DIMNAME, grid.ydimname);
-  if (grid.vdimname[0]) cdiDefKeyString(gridID, CDI_GLOBAL, CDI_KEY_VDIMNAME, grid.vdimname);
+  // clang-format off
+  if (grid.xname.size())     cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_NAME, grid.xname.c_str());
+  if (grid.xlongname.size()) cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_LONGNAME, grid.xlongname.c_str());
+  if (grid.xunits.size())    cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_UNITS, grid.xunits.c_str());
+  if (grid.yname.size())     cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_NAME, grid.yname.c_str());
+  if (grid.ylongname.size()) cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_LONGNAME, grid.ylongname.c_str());
+  if (grid.yunits.size())    cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_UNITS, grid.yunits.c_str());
+  if (grid.xdimname.size())  cdiDefKeyString(gridID, CDI_XAXIS, CDI_KEY_DIMNAME, grid.xdimname.c_str());
+  if (grid.ydimname.size())  cdiDefKeyString(gridID, CDI_YAXIS, CDI_KEY_DIMNAME, grid.ydimname.c_str());
+  if (grid.vdimname.size())  cdiDefKeyString(gridID, CDI_GLOBAL, CDI_KEY_VDIMNAME, grid.vdimname.c_str());
+  // clang-format on
 
   return gridID;
 }
@@ -294,25 +310,24 @@ gridFromMPAS(const char *filename)
   int mpasGridID = -1;
 
   open_lock();
-  const auto streamID = streamOpenRead(filename);
+  auto streamID = streamOpenRead(filename);
   open_unlock();
   if (streamID >= 0)
     {
-      const auto vlistID = streamInqVlist(streamID);
-      const auto nvars = vlistNvars(vlistID);
+      auto vlistID = streamInqVlist(streamID);
+      auto nvars = vlistNvars(vlistID);
       int latCellID = -1, lonCellID = -1, areaCellID = -1;
       int latVertexID = -1, lonVertexID = -1, verticesOnCellID = -1;
-      char varname[CDI_MAX_NAME];
       for (int varID = 0; varID < nvars; ++varID)
         {
-          vlistInqVarName(vlistID, varID, varname);
+          auto varname = cdo::inq_var_name(vlistID, varID);
           // clang-format off
-          if      (cdo_cmpstr(varname, "latCell"))   latCellID = varID;
-          else if (cdo_cmpstr(varname, "lonCell"))   lonCellID = varID;
-          else if (cdo_cmpstr(varname, "latVertex")) latVertexID = varID;
-          else if (cdo_cmpstr(varname, "lonVertex")) lonVertexID = varID;
-          else if (cdo_cmpstr(varname, "areaCell"))  areaCellID = varID;
-          else if (cdo_cmpstr(varname, "verticesOnCell")) verticesOnCellID = varID;
+          if      (varname == "latCell")   latCellID = varID;
+          else if (varname == "lonCell")   lonCellID = varID;
+          else if (varname == "latVertex") latVertexID = varID;
+          else if (varname == "lonVertex") lonVertexID = varID;
+          else if (varname == "areaCell")  areaCellID = varID;
+          else if (varname == "verticesOnCell") verticesOnCellID = varID;
           // clang-format on
         }
 
@@ -324,15 +339,15 @@ gridFromMPAS(const char *filename)
           return -1;
         }
 
-      const auto maxEdges = gridInqXsize(vlistInqVarGrid(vlistID, verticesOnCellID));
-      const auto ncells = gridInqSize(vlistInqVarGrid(vlistID, latCellID));
+      auto maxEdges = gridInqXsize(vlistInqVarGrid(vlistID, verticesOnCellID));
+      auto ncells = gridInqSize(vlistInqVarGrid(vlistID, latCellID));
       std::vector<double> latCell(ncells), lonCell(ncells), areaCell(ncells);
-      const auto nvertices = gridInqSize(vlistInqVarGrid(vlistID, latVertexID));
+      auto nvertices = gridInqSize(vlistInqVarGrid(vlistID, latVertexID));
       std::vector<double> latVertex(nvertices), lonVertex(nvertices);
       std::vector<double> verticesOnCell(maxEdges * ncells);
       std::vector<double> xbounds(maxEdges * ncells), ybounds(maxEdges * ncells);
 
-      const auto nrecs = streamInqTimestep(streamID, 0);
+      auto nrecs = streamInqTimestep(streamID, 0);
       for (int recID = 0; recID < nrecs; ++recID)
         {
           size_t nmiss;
@@ -360,7 +375,7 @@ gridFromMPAS(const char *filename)
       for (size_t i = 0; i < ncells; ++i)
         for (size_t k = 0; k < maxEdges; ++k)
           {
-            const auto cellIndex = std::lround(verticesOnCell[i * maxEdges + k]);
+            auto cellIndex = std::lround(verticesOnCell[i * maxEdges + k]);
             if (cellIndex == 0)
               {
                 if (k > nv) nv = k;
@@ -374,11 +389,8 @@ gridFromMPAS(const char *filename)
       for (size_t i = 0; i < ncells; ++i)
         for (size_t k = 0; k < nv; ++k)
           {
-            const auto cellIndex = std::lround(verticesOnCell[i * maxEdges + k]);
-            if (cellIndex < 0 || cellIndex > (long) nvertices)
-              {
-                withBounds = false;
-              }
+            auto cellIndex = std::lround(verticesOnCell[i * maxEdges + k]);
+            if (cellIndex < 0 || cellIndex > (long) nvertices) { withBounds = false; }
             else if (cellIndex == 0)
               {
                 if (k == (nv - 1))
@@ -498,12 +510,12 @@ cdo_define_grid(const char *pgridfile)
         {
           Debug(cdoDebug, "Grid from CDI file");
           open_lock();
-          const auto streamID = streamOpenRead(filename);
+          auto streamID = streamOpenRead(filename);
           open_unlock();
           if (streamID >= 0)
             {
-              const auto vlistID = streamInqVlist(streamID);
-              const auto ngrids = vlistNgrids(vlistID);
+              auto vlistID = streamInqVlist(streamID);
+              auto ngrids = vlistNgrids(vlistID);
               if (gridno < 1 || gridno > ngrids) cdo_abort("Grid number %d not available in %s!", gridno, filename);
               gridID = vlistGrid(vlistID, gridno - 1);
               streamClose(streamID);
@@ -513,17 +525,17 @@ cdo_define_grid(const char *pgridfile)
       if (gridID == -1)
         {
           Debug(cdoDebug, "grid from ASCII file");
-          auto gfp = fopen(filename, "r");
+          auto gfp = std::fopen(filename, "r");
           gridID = grid_read(gfp, filename);
-          fclose(gfp);
+          std::fclose(gfp);
         }
 
       if (gridID == -1)
         {
           Debug(cdoDebug, "grid from PINGO file");
-          auto gfp = fopen(filename, "r");
+          auto gfp = std::fopen(filename, "r");
           gridID = grid_read_pingo(gfp);
-          fclose(gfp);
+          std::fclose(gfp);
         }
 
       if (gridID == -1) cdo_abort("Invalid grid description file %s!", filename);
@@ -547,8 +559,5 @@ cdo_set_grids(const char *gridarg)
   char gridfile[4096];
   int nfile = 0;
 
-  while (getoptname(gridfile, gridarg, nfile++) == 0)
-    {
-      (void) cdo_define_grid(gridfile);
-    }
+  while (getoptname(gridfile, gridarg, nfile++) == 0) { (void) cdo_define_grid(gridfile); }
 }
