@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 
 #include <cdi.h>
@@ -30,7 +20,7 @@ readInstitution(const char *instfile)
   char name[1024], longname[1024];
   int center = CDI_UNDEFID, subcenter = CDI_UNDEFID;
 
-  auto instfp = fopen(instfile, "r");
+  auto instfp = std::fopen(instfile, "r");
   if (instfp == nullptr) return CDI_UNDEFID;
 
   while (cdo::readline(instfp, line, 1024))
@@ -49,7 +39,7 @@ readInstitution(const char *instfile)
 
       if (nvar == 2 && maxvar == 4)
         {
-          if (!isdigit((int) pline[0])) cdoAbort("wrong format in line %d. Missing subcenter!", lnr);
+          if (!isdigit((int) pline[0])) cdo_abort("wrong format in line %d. Missing subcenter!", lnr);
 
           subcenter = atoi(pline);
         }
@@ -59,7 +49,7 @@ readInstitution(const char *instfile)
       if ((nvar == 4 && maxvar == 4) || (nvar == 2 && maxvar == 2)) strcpy(longname, pline);
     }
 
-  fclose(instfp);
+  std::fclose(instfp);
 
   auto instID = institutInq(center, subcenter, name, longname);
   if (instID == CDI_UNDEFID) instID = institutDef(center, subcenter, name, longname);
@@ -68,14 +58,14 @@ readInstitution(const char *instfile)
 }
 
 void
-defineInstitution(const char *instarg)
+define_institution(const char *instarg)
 {
   const char *instname = instarg;
   int instID = readInstitution(instname);
 
   if (instID == CDI_UNDEFID) instID = institutInq(0, 0, instname, nullptr);
 
-  if (instID == CDI_UNDEFID) cdoAbort("institution <%s> not found", instname);
+  if (instID == CDI_UNDEFID) cdo_abort("institution <%s> not found", instname);
 
   CdoDefault::InstID = instID;
 }
