@@ -40,7 +40,7 @@ public:
     m_dist.resize(m_maxNeighbors);
   }
 
-  knnWeightsType(const size_t maxNeighbors) : m_maxNeighbors(maxNeighbors) { init(); }
+  knnWeightsType(size_t maxNeighbors) : m_maxNeighbors(maxNeighbors) { init(); }
 
   inline size_t
   maxNeighbors() const
@@ -55,13 +55,13 @@ public:
   }
 
   inline void
-  initAddr(const size_t numNeighbors)
+  initAddr(size_t numNeighbors)
   {
     for (size_t i = 0; i < numNeighbors; ++i) m_addr[i] = SIZE_MAX;
   }
 
   inline void
-  initDist(const size_t numNeighbors)
+  initDist(size_t numNeighbors)
   {
     for (size_t i = 0; i < numNeighbors; ++i) m_dist[i] = DBL_MAX;
   }
@@ -79,7 +79,7 @@ public:
   }
 
   inline bool
-  distance_is_less(const double distance, const double distx, const size_t addr, const size_t addrx)
+  distance_is_less(double distance, double distx, size_t addr, size_t addrx)
   {
     constexpr double cmp_tol = 1.e-12;
     // return (distance < distx || (distance <= distx && addr < addrx));
@@ -87,7 +87,7 @@ public:
   }
 
   inline void
-  storeDistance(const size_t addr, const double distance, const size_t numNeighbors)
+  storeDistance(size_t addr, double distance, size_t numNeighbors)
   {
     assert(numNeighbors <= m_maxNeighbors);
     m_numNeighbors = numNeighbors;
@@ -120,13 +120,13 @@ public:
   }
 
   inline void
-  storeDistance(const size_t addr, const double distance)
+  storeDistance(size_t addr, double distance)
   {
     storeDistance(addr, distance, m_maxNeighbors);
   }
 
   inline void
-  setDistance(const size_t *addr, const double *distance, const size_t numNeighbors)
+  setDistance(const size_t *addr, const double *distance, size_t numNeighbors)
   {
     assert(numNeighbors <= m_maxNeighbors);
     m_numNeighbors = numNeighbors;
@@ -145,7 +145,7 @@ public:
   }
 
   size_t
-  normalizeWeights(const double dist_tot, size_t numNeighbors)
+  normalizeWeights(double dist_tot, size_t numNeighbors)
   {
     // Normalize weights and store the link
     size_t nadds = 0;
@@ -186,7 +186,7 @@ public:
   }
 
   size_t
-  computeWeights(const Varray<short> &grid_mask)
+  computeWeights(const Varray<short> &gridMask)
   {
     // Compute weights based on inverse distance if mask is false, eliminate those points
 
@@ -195,7 +195,7 @@ public:
     for (size_t n = 0; n < m_maxNeighbors; ++n)
       {
         m_mask[n] = false;
-        if (m_addr[n] < SIZE_MAX && grid_mask[m_addr[n]])
+        if (m_addr[n] < SIZE_MAX && gridMask[m_addr[n]])
           {
             m_dist[n] = 1.0 / m_dist[n];
             dist_tot += m_dist[n];
@@ -207,7 +207,7 @@ public:
   }
 
   size_t
-  computeWeights(const Varray<uint8_t> &grid_mask, const double searchRadius, const double weight0, const double weightR)
+  computeWeights(const Varray<uint8_t> &grid_mask, double searchRadius, double weight0, double weightR)
   {
     // Compute weights based on inverse distance if mask is false, eliminate those points
 
@@ -227,15 +227,6 @@ public:
     return normalizeWeights(dist_tot, m_numNeighbors);
   }
 
-  template <typename T>
-  double
-  arrayWeightsSum(const T *array) const
-  {
-    double result = 0.0;
-    for (size_t n = 0; n < m_numNeighbors; ++n) result += array[m_addr[n]] * m_dist[n];
-    return result;
-  }
-
   template <typename T>
   double
   arrayWeightsSum(const Varray<T> &array) const
