@@ -21,7 +21,7 @@ public:
   int
   read(FILE *fp, const char *_name)
   {
-    const int filedes = fileno(fp);
+    int filedes = fileno(fp);
     struct stat buf;
     const size_t filesize = (fstat(filedes, &buf) == 0) ? (size_t) buf.st_size : 0;
     if (filesize == 0)
