@@ -5,7 +5,7 @@
 #include "cdo_output.h"
 #include "compare.h"
 #include "magics_template_parser.h"
-#include "string_utilities.h"
+#include "util_string.h"
 
 #ifdef HAVE_LIBXML2
 #include <libxml/parser.h>
@@ -47,10 +47,7 @@ magics_template_parser(void *node)
         {
           if (DBG) printf("Version %s \n", value);
 
-          if (atof(value) > 3.0f)
-            {
-              return 1;
-            }
+          if (atof(value) > 3.0f) { return 1; }
         }
     }
 
@@ -71,10 +68,7 @@ magics_template_parser(void *node)
 
           if (cur_node->properties == nullptr)
             {
-              if (cur_node->children == nullptr)
-                {
-                  printf("NO ATTRIBUTES!!!\n");
-                }
+              if (cur_node->children == nullptr) { printf("NO ATTRIBUTES!!!\n"); }
             }
           else
             {
@@ -117,8 +111,8 @@ _set_magics_parameter_value(const char *, const char *, const char *)
 {
   int ret_flag = 0;
 #ifdef HAVE_LIBMAGICS
-  const char *sep_char = ",";
-  const char *search_char = ";";
+  char sep_char = ',';
+  const char search_char = ';';
 
   if (param_name == nullptr)
     {
@@ -162,10 +156,7 @@ _set_magics_parameter_value(const char *, const char *, const char *)
     }
 
   // MAGICS++ FLOAT TYPE PARAMETERS
-  else if (cdo_cmpstr(param_type, "float"))
-    {
-      mag_setr(param_name, atof(param_value));
-    }
+  else if (cdo_cmpstr(param_type, "float")) { mag_setr(param_name, atof(param_value)); }
 
   // MAGICS++ FLOAT ARRAY  TYPE    PARAMETERS
   else if (cdo_cmpstr(param_type, "floatarray"))
@@ -174,64 +165,57 @@ _set_magics_parameter_value(const char *, const char *, const char *)
 #if 0
       fprintf(stderr, "param_name : %s\tparam_value: %s\n", param_name, param_value);
 #endif
-      if (strchr(param_value, ';')) sep_char = ";";
-      const auto splitStrings = cstr_split_with_seperator(param_value, sep_char);
+      if (strchr(param_value, ';')) sep_char = ';';
+      const auto splitStrings = split_with_seperator(param_value, sep_char);
       if (splitStrings.size())
         {
           std::vector<double> float_param_list(splitStrings.size());
-          for (int i = 0; i < (int)splitStrings.size(); ++i)
+          for (int i = 0; i < (int) splitStrings.size(); ++i)
             {
 #if 0
 	      fprintf(stderr, "%d %d %s\n", i, (int)splitStrings.size(), splitStrings[i].c_str());
 #endif
               float_param_list[i] = std::stod(splitStrings[i]);
             }
-          mag_set1r(param_name, float_param_list.data(), (int)splitStrings.size());
+          mag_set1r(param_name, float_param_list.data(), (int) splitStrings.size());
         }
     }
 
   // MAGICS++ INT TYPE    PARAMETERS
-  else if (cdo_cmpstr(param_type, "int"))
-    {
-      mag_seti(param_name, atoi(param_value));
-    }
+  else if (cdo_cmpstr(param_type, "int")) { mag_seti(param_name, atoi(param_value)); }
 
   // MAGICS++ INT ARRAY  TYPE    PARAMETERS
   else if (cdo_cmpstr(param_type, "intarray"))
     {
-      if (strchr(param_value, ';')) sep_char = ";";
-      const auto splitStrings = cstr_split_with_seperator(param_value, sep_char);
+      if (strchr(param_value, ';')) sep_char = ';';
+      const auto splitStrings = split_with_seperator(param_value, sep_char);
       if (splitStrings.size())
         {
           std::vector<int> int_param_list(splitStrings.size());
-          for (int i = 0; i < (int)splitStrings.size(); ++i)
-            {
-              int_param_list[i] = std::stoi(splitStrings[i]);
-            }
-          mag_set1i(param_name, int_param_list.data(), (int)splitStrings.size());
+          for (int i = 0; i < (int) splitStrings.size(); ++i) { int_param_list[i] = std::stoi(splitStrings[i]); }
+          mag_set1i(param_name, int_param_list.data(), (int) splitStrings.size());
         }
     }
 
   // MAGICS++ STRING TYPE    PARAMETERS
-  else if (cdo_cmpstr(param_type, "string"))
-    {
-      mag_setc(param_name, param_value);
-    }
+  else if (cdo_cmpstr(param_type, "string")) { mag_setc(param_name, param_value); }
 
   // MAGICS++ STRINGARRAY  TYPE    PARAMETERS
   else if (cdo_cmpstr(param_type, "stringarray"))
     {
-      if (DBG) fprintf(stderr, "Input strarr is %s  Sep char is %s Search char is %s\n", param_value, sep_char, search_char);
-      if (strstr(param_value, ";")) sep_char = ";";
+      if (DBG) fprintf(stderr, "Input strarr is %s  Sep char is %c Search char is %c\n", param_value, sep_char, search_char);
+      if (strstr(param_value, ";")) sep_char = ';';
 
-      if (DBG) fprintf(stderr, "Input strarr is %s  Sep char is %s\n", param_value, sep_char);
-      const auto splitStrings = cstr_split_with_seperator(param_value, sep_char);
+      if (DBG) fprintf(stderr, "Input strarr is %s  Sep char is %c\n", param_value, sep_char);
+      const auto splitStrings = split_with_seperator(param_value, sep_char);
 
-      if (DBG) fprintf(stderr, "Input strarr is %s split str count is %d Sep char is %s\n", param_value, (int)splitStrings.size(), sep_char);
+      if (DBG)
+        fprintf(stderr, "Input strarr is %s split str count is %d Sep char is %c\n", param_value, (int) splitStrings.size(),
+                sep_char);
 
-      const char **split_str = (const char **) malloc(splitStrings.size() * sizeof(char*));
+      const char **split_str = (const char **) malloc(splitStrings.size() * sizeof(char *));
       for (size_t k = 0; k < splitStrings.size(); ++k) split_str[k] = splitStrings[k].c_str();
-      mag_set1c(param_name, split_str, (int)splitStrings.size());
+      mag_set1c(param_name, split_str, (int) splitStrings.size());
       free(split_str);
     }
   else
