@@ -10,48 +10,47 @@
 
 #include "cdo_options.h"
 #include "cdo_output.h"
-#include "process_int.h"
 #include "pmlist.h"
 #include "convert_units.h"
 #include "param_conversion.h"
 #include "parse_literals.h"
 #include "cdo_cmor.h"
 #include "cdo_cdi_wrapper.h"
+#include "compare.h"
 
 int string_to_param(const char *paramstr);
 
 void
-mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, CmorVar *var, bool &lvalid_min, bool &lvalid_max,
+mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, CmorVar *var, bool &hasValidMin, bool &hasValidMax,
        int ptab, bool isnPtmodeName)
 {
-  const char *value = (kv.nvalues > 0) ? kv.values[0].c_str() : nullptr;
-  const bool lv1 = (kv.nvalues == 1);
+  const auto &value = kv.values[0];
+  auto lv1 = (kv.nvalues == 1);
 
-  // printf("key=%s  value=%s\n", key, value ? value : "");
+  // printf("key=%s  value=>%s<\n", key.c_str(), value.c_str());
 
   // clang-format off
   if (!var)
     {
       if (key == "cn")
         {
-          char name[CDI_MAX_NAME];
-          vlistInqVarName(vlistID, varID, name);
-          if (name[0] != 0) cdiDefAttTxt(vlistID, varID, "original_name", (int) strlen(name), parameter_to_word(name));
-          cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, parameter_to_word(value));
+          auto name = cdo::inq_var_name(vlistID, varID);
+          if (name[0] != 0) cdiDefAttTxt(vlistID, varID, "original_name", (int) name.size(), name.c_str());
+          cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, parameter_to_word(value.c_str()));
         }
       else if (key == "u")
-        cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, value);
+        cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, value.c_str());
       else if (key == "cm")
-        cdiDefAttTxt(vlistID, varID, "cell_methods", (int) strlen(value), value);
+        cdiDefAttTxt(vlistID, varID, "cell_methods", (int) value.size(), value.c_str());
       else if (key == "ca")
-        cdiDefAttTxt(vlistID, varID, "character_axis", (int) strlen(value), value);
+        cdiDefAttTxt(vlistID, varID, "character_axis", (int) value.size(), value.c_str());
       else if (key == "za")
-        cdiDefAttTxt(vlistID, varID, "z_axis", (int) strlen(value), value);
+        cdiDefAttTxt(vlistID, varID, "z_axis", (int) value.size(), value.c_str());
       else if (key == "vc")
-        cdiDefAttTxt(vlistID, varID, "variable_comment", (int) strlen(value), value);
+        cdiDefAttTxt(vlistID, varID, "variable_comment", (int) value.size(), value.c_str());
       else if (key == "p")
         {
-          if (!isspace(value[0])) cdiDefAttTxt(vlistID, varID, "positive", (int) strlen(value), value);
+          if (!isspace(value[0])) cdiDefAttTxt(vlistID, varID, "positive", (int) value.size(), value.c_str());
         }
       else
         {
@@ -60,20 +59,20 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
     }
   else
     {
-      if      (lv1 && key == "standard_name") cdiDefKeyString(vlistID, varID, CDI_KEY_STDNAME, value);
-      else if (lv1 && key == "long_name") cdiDefKeyString(vlistID, varID, CDI_KEY_LONGNAME, value);
-      else if (lv1 && key == "units") cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, value);
+      if      (lv1 && key == "standard_name") cdiDefKeyString(vlistID, varID, CDI_KEY_STDNAME, value.c_str());
+      else if (lv1 && key == "long_name") cdiDefKeyString(vlistID, varID, CDI_KEY_LONGNAME, value.c_str());
+      else if (lv1 && key == "units") cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, value.c_str());
       else if (lv1 && key == "name")
         {
-          if (isnPtmodeName) cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, parameter_to_word(value));
+          if (isnPtmodeName) cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, parameter_to_word(value.c_str()));
         }
       else if (lv1 && key == "out_name")
         {
-          const auto outname = parameter_to_word(value);
-          if (!cdo_cmpstr(var->name, outname))
+          auto outname = parameter_to_word(value);
+          if (var->name != outname)
             {
-              cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, outname);
-              cdiDefAttTxt(vlistID, varID, "original_name", (int) strlen(var->name), var->name);
+              cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, outname.c_str());
+              cdiDefAttTxt(vlistID, varID, "original_name", (int) var->name.size(), var->name.c_str());
             }
         }
       else if (lv1 && key == "param")
@@ -87,12 +86,12 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
       else if (lv1 && key == "uvRelativeToGrid")
         cdiDefKeyInt(vlistID, varID, CDI_KEY_UVRELATIVETOGRID, parameter_to_bool(value));
       else if (lv1 && key == "comment")
-        cdiDefAttTxt(vlistID, varID, key.c_str(), (int) strlen(value), value);
+        cdiDefAttTxt(vlistID, varID, key.c_str(), (int) value.size(), value.c_str());
       else if (lv1 && key == "chunktype") ;
       else if (lv1 && key == "cell_methods")
-        cdiDefAttTxt(vlistID, varID, key.c_str(), (int) strlen(value), value);
+        cdiDefAttTxt(vlistID, varID, key.c_str(), (int) value.size(), value.c_str());
       else if (lv1 && key == "cell_measures")
-        cdiDefAttTxt(vlistID, varID, key.c_str(), (int) strlen(value), value);
+        cdiDefAttTxt(vlistID, varID, key.c_str(), (int) value.size(), value.c_str());
       else if (lv1 && key == "delete") var->remove = parameter_to_bool(value);
       else if (lv1 && key == "convert") var->convert = parameter_to_bool(value);
       else if (lv1 && key == "factor")
@@ -103,8 +102,8 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
         }
       else if (lv1 && (key == "missval" || key == "missing_value"))
         {
-          const auto missval = parameter_to_double(value);
-          const auto missval_old = vlistInqVarMissval(vlistID, varID);
+          auto missval = parameter_to_double(value);
+          auto missval_old = vlistInqVarMissval(vlistID, varID);
           if (!DBL_IS_EQUAL(missval, missval_old))
             {
               if (Options::cdoVerbose) cdo_print("%s - change missval from %g to %g", var->name, missval_old, missval);
@@ -115,12 +114,12 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
         }
       else if (lv1 && key == "valid_min")
         {
-          lvalid_min = true;
+          hasValidMin = true;
           var->valid_min = parameter_to_double(value);
         }
       else if (lv1 && key == "valid_max")
         {
-          lvalid_max = true;
+          hasValidMax = true;
           var->valid_max = parameter_to_double(value);
         }
       else if (lv1 && key == "ok_min_mean_abs")
@@ -135,7 +134,7 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
         }
       else if (lv1 && (key == "datatype" || key == "type"))
         {
-          const auto datatype = cdo_str_to_datatype(parameter_to_word(value));
+          auto datatype = cdo::str_to_datatype(parameter_to_word(value));
           if (datatype != -1) vlistDefVarDatatype(vlistID, varID, datatype);
         }
       else if (lv1 && key == "dimensions")
@@ -148,7 +147,7 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
           int nvalues = kv.nvalues;
           if (nvalues == 1 && rvalue.empty()) nvalues = 0;
 
-          const int dtype = literals_find_datatype(nvalues, values);
+          int dtype = literals_find_datatype(nvalues, values);
 
           if (dtype == CDI_DATATYPE_INT8 || dtype == CDI_DATATYPE_INT16 || dtype == CDI_DATATYPE_INT32)
             {
@@ -164,8 +163,7 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
             }
           else
             {
-              const int len = (int)rvalue.size();
-              cdiDefAttTxt(vlistID, varID, key.c_str(), len, rvalue.c_str());
+              cdiDefAttTxt(vlistID, varID, key.c_str(), (int)rvalue.size(), rvalue.c_str());
             }
         }
     }
