@@ -185,6 +185,9 @@ void   *Fourier(void *argument);
 void   *Gengrid(void *argument);
 #define GengridOperators                  {"gengrid"}
 
+void   *Getgridcell(void *argument);
+#define GetgridcellOperators              {"gridcellindex"}
+
 void   *Gradsdes(void *argument);
 #define GradsdesOperators                 {"gradsdes", "dumpmap"}
 
@@ -200,6 +203,9 @@ void   *Gridsearch(void *argument);
 void   *Harmonic(void *argument);
 #define HarmonicOperators                 {"harmonic"}
 
+void   *Healpix(void *argument);
+#define HealpixOperators                  {"hpupgrade", "hpdegrade"}
+
 void   *Histogram(void *argument);
 #define HistogramOperators                {"histcount", "histsum", "histmean", "histfreq"}
 
@@ -254,6 +260,9 @@ void   *Invertlev(void *argument);
 void   *Lic(void *argument);
 #define LicOperators                      {"lic"}
 
+void   *Longinfo(void *argument);
+#define LonginfoOperators                 {"linfo"}
+
 void   *MapReduce(void *argument);
 #define MapReduceOperators                {"reducegrid"}
 
@@ -325,21 +334,29 @@ void   *Recttocomplex(void *argument);
 void   *Regres(void *argument);
 #define RegresOperators                   {"regres"}
 
-void   *Remap(void *argument);
-#define RemapOperators                    {"remap"}
-#define RemapbilOperators                 {"remapbil", "genbil"}
-#define RemapbicOperators                 {"remapbic", "genbic"}
-#define RemapnnOperators                  {"remapnn", "gennn"}
-#define RemapdisOperators                 {"remapdis", "gendis"}
-#define RemapconOperators                 {"remapcon", "gencon"}
-#define Remapycon2Operators               {"remapycon2test", "genycon2test"}
-#define RemapsconOperators                {"remapscon", "genscon"}
-#define Remapcon2Operators                {"remapcon2", "gencon2"}
-#define RemaplafOperators                 {"remaplaf", "genlaf"}
-#define RemapavgOperators                 {"remapavgtest"}
-
 void   *Remapweights(void *argument);
-#define RemapweightsOperators             {"verifyweights", "writeremapscrip"}
+#define GenbilOperators                   {"genbil"}
+#define GenbicOperators                   {"genbic"}
+#define GennnOperators                    {"gennn"}
+#define GendisOperators                   {"gendis"}
+#define GenconOperators                   {"gencon"}
+#define Genycon2Operators                 {"genycon2test"}
+#define GensconOperators                  {"genscon"}
+#define Gencon2Operators                  {"gencon2"}
+#define GenlafOperators                   {"genlaf"}
+
+void   *Remapgrid(void *argument);
+#define RemapOperators                    {"remap"}
+#define RemapbilOperators                 {"remapbil"}
+#define RemapbicOperators                 {"remapbic"}
+#define RemapnnOperators                  {"remapnn"}
+#define RemapdisOperators                 {"remapdis"}
+#define RemapconOperators                 {"remapcon"}
+#define Remapycon2Operators               {"remapycon2test"}
+#define RemapsconOperators                {"remapscon"}
+#define Remapcon2Operators                {"remapcon2"}
+#define RemaplafOperators                 {"remaplaf"}
+#define RemapavgOperators                 {"remapavgtest"}
 
 void   *Remapeta(void *argument);
 #define RemapetaOperators                 {"remapeta", "remapeta_s", "remapeta_z"}
@@ -456,7 +473,8 @@ void   *Showattribute(void *argument);
 #define ShowattributeOperators            {"showattribute", "showattsvar"}
 
 void   *Sinfo(void *argument);
-#define SinfoOperators                    {"sinfo", "sinfop", "sinfon", "sinfoc", "seinfo", "seinfop", "seinfon", "seinfoc", "xsinfo", "xsinfop", "xsinfon", "xsinfoc"}
+#define SinfoOperators                    {"sinfo", "sinfop", "sinfon", "sinfoc", "seinfo", "seinfop", "seinfon", "seinfoc"}
+#define XSinfoOperators                   {"xsinfo", "xsinfop", "xsinfon", "xsinfoc"}
 
 void   *Smooth(void *argument);
 #define SmoothOperators                   {"smooth", "smooth9"}
@@ -480,6 +498,9 @@ void   *Spectrum(void *argument);
 void   *Split(void *argument);
 #define SplitOperators                    {"splitcode", "splitparam", "splitname", "splitlevel", "splitgrid", "splitzaxis", "splittabnum"}
 
+void   *Splitdate(void *argument);
+#define SplitdateOperators                {"splitdate", "splitdatetime"}
+
 void   *Splitrec(void *argument);
 #define SplitrecOperators                 {"splitrec"}
 
@@ -513,8 +534,8 @@ void   *Testdata(void *argument);
 void   *Tests(void *argument);
 #define TestsOperators                    {"normal", "studentt", "chisquare", "beta", "fisher"}
 
-void   *Timfill(void *argument);
-#define TimfillOperators                  {"setmisstonntime"}
+void   *Timfillmiss(void *argument);
+#define TimfillmissOperators              {"timfillmiss"}
 
 void   *Timsort(void *argument);
 #define TimsortOperators                  {"timsort"}
@@ -590,6 +611,9 @@ void   *Varrms(void *argument);
 void   *Varsstat(void *argument);
 #define VarsstatOperators                 {"varsrange", "varsmin", "varsmax", "varssum", "varsmean", "varsavg", "varsstd", "varsstd1", "varsvar", "varsvar1"}
 
+void   *Vertfillmiss(void *argument);
+#define VertfillmissOperators             {"vertfillmiss"}
+
 void   *Vertintap(void *argument);
 #define VertintapOperators                {"ap2pl", "ap2plx", "ap2hl", "ap2hlx"}
 
@@ -614,6 +638,9 @@ void   *Vertwind(void *argument);
 void   *Verifygrid(void *argument);
 #define VerifygridOperators               {"verifygrid"}
 
+void   *Verifyweights(void *argument);
+#define VerifyweightsOperators            {"verifyweights", "writeremapscrip"}
+
 void   *Wind(void *argument);
 #define WindOperators                     {"uv2dv", "uv2dvl", "dv2uv", "dv2uvl"}
 
@@ -658,6 +685,10 @@ void   *Ymonarith(void *argument);
 #define YmonarithOperators                {"ymonadd", "ymonsub", "ymonmul", "ymondiv"}
 #define YseasarithOperators               {"yseasadd", "yseassub", "yseasmul", "yseasdiv"}
 
+void   *Ymoncomp(void *argument);
+#define YmoncompOperators                 {"ymoneq", "ymonne", "ymonle", "ymonlt", "ymonge", "ymongt"}
+#define YseascompOperators                {"yseaseq", "yseasne", "yseasle", "yseaslt", "yseasge", "yseasgt"}
+
 void   *Ymonpctl(void *argument);
 #define YmonpctlOperators                 {"ymonpctl"}
 
