@@ -1,10 +1,7 @@
 #ifndef MODULE_INFO_H
 #define MODULE_INFO_H
 
-#include "string_utilities.h"
 #include <string>
-#include <vector>
-#include <iostream>
 #include <map>
 
 const std::string s_obase = "obase";
@@ -12,6 +9,7 @@ const std::string s_arbIn = "arbitrary";
 const std::string s_filesOnly = "filesOnly";
 const std::string s_onlyFirst = "onlyFirst";
 const std::string s_noOutput = "noOutput";
+
 struct ModListOptions
 {
   bool printAll = false;
