@@ -74,18 +74,20 @@ static const module_t module_Fldcor         = {"Fldcor"         ,Fldstat2
 static const module_t module_Fldcovar       = {"Fldcovar"       ,Fldstat2       , FldcovarHelp      , FldcovarOperators       , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_Fourier        = {"Fourier"        ,Fourier        , FourierHelp       , FourierOperators        , EXPOSED  , CDI_COMP , 1  , 1     , NoRestriction };
 static const module_t module_Gengrid        = {"Gengrid"        ,Gengrid        , {}                , GengridOperators        , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
+static const module_t module_Getgridcell    = {"Getgridcell"    ,Getgridcell    , GetgridcellHelp   , GetgridcellOperators    , EXPOSED  , CDI_BOTH , 1  , 0     , NoRestriction };
 static const module_t module_Gradsdes       = {"Gradsdes"       ,Gradsdes       , GradsdesHelp      , GradsdesOperators       , EXPOSED  , CDI_REAL , 1  , 0     , FilesOnly };
 static const module_t module_Gridboxstat    = {"Gridboxstat"    ,Gridboxstat    , GridboxstatHelp   , GridboxstatOperators    , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Gridcell       = {"Gridcell"       ,Gridcell       , GridcellHelp      , GridcellOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Gridsearch     = {"Gridsearch"     ,Gridsearch     , {}                , GridsearchOperators     , EXPOSED  , CDI_REAL , 0  , 0     , NoRestriction };
 static const module_t module_Harmonic       = {"Harmonic"       ,Harmonic       , {}                , HarmonicOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Healpix        = {"Healpix"        ,Healpix        , HealpixHelp       , HealpixOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Histogram      = {"Histogram"      ,Histogram      , HistogramHelp     , HistogramOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Importamsr     = {"Importamsr"     ,Importamsr     , ImportamsrHelp    , ImportamsrOperators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Importbinary   = {"Importbinary"   ,Importbinary   , ImportbinaryHelp  , ImportbinaryOperators   , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias ("import_grads", "import_binary")} };
 static const module_t module_Importcmsaf    = {"Importcmsaf"    ,Importcmsaf    , ImportcmsafHelp   , ImportcmsafOperators    , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Importobs      = {"Importobs"      ,Importobs      , {}                , ImportobsOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Importfv3grid  = {"Importfv3grid"  ,Importfv3grid  , {}                , Importfv3gridOperators  , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Info           = {"Info"           ,Info           , InfoHelp          , InfoOperators           , EXPOSED  , CDI_BOTH , -1 , 0     , NoRestriction};
+static const module_t module_Info           = {"Info"           ,Info           , InfoHelp          , InfoOperators           , EXPOSED  , CDI_BOTH , -1 , 0     , NoRestriction };
 static const module_t module_Input          = {"Input"          ,Input          , InputHelp         , InputOperators          , EXPOSED  , CDI_REAL , 0  , 1     , NoRestriction };
 static const module_t module_Intgrid        = {"Intgrid"        ,Intgrid        , {}                , IntgridOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction ,  {Alias ("intgrid", "intgridbil")}};
 static const module_t module_Intgridtraj    = {"Intgridtraj"    ,Intgridtraj    , {}                , IntgridtrajOperators    , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
@@ -98,6 +100,7 @@ static const module_t module_Invert         = {"Invert"         ,Invert
 static const module_t module_Invertlev      = {"Invertlev"      ,Invertlev      , InvertlevHelp     , InvertlevOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Selsurface     = {"Selsurface"     ,Selsurface     , SelsurfaceHelp    , SelsurfaceOperators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Lic            = {"Lic"            ,Lic            , {}                , LicOperators            , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Longnfo        = {"Longinfo"       ,Longinfo       , {}                , LonginfoOperators       , EXPOSED  , CDI_REAL , 1 ,  0     , NoRestriction };
 static const module_t module_MapReduce      = {"MapReduce"      ,MapReduce      , MapReduceHelp     , MapReduceOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Maskbox        = {"Maskbox"        ,Maskbox        , MaskboxHelp       , MaskboxOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Maskregion     = {"Maskregion"     ,Maskbox        , MaskregionHelp    , MaskregionOperators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
@@ -119,23 +122,31 @@ static const module_t module_Outputgmt      = {"Outputgmt"      ,Outputgmt
 static const module_t module_Pack           = {"Pack"           ,Pack           , PackHelp          , PackOperators           , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Pardup         = {"Pardup"         ,Pardup         , {}                , PardupOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Pinfo          = {"Pinfo"          ,Pinfo          , {}                , PinfoOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Query          = {"Query"          ,Query          , {}                , QueryOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Query          = {"Query"          ,Query          , {}                , QueryOperators          , EXPOSED  , CDI_REAL , 1  , 1     , FilesOnly };
 static const module_t module_Pressure       = {"Pressure"       ,Pressure       , {}                , PressureOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias ("deltap_fl","deltap"),Alias("fpressure", "pressure_fl"), Alias("hpressure", "pressure_hl")}};
 static const module_t module_Recttocomplex  = {"Recttocomplex"  ,Recttocomplex  , {}                , RecttocomplexOperators  , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_Regres         = {"Regres"         ,Regres         , RegresHelp        , RegresOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remap          = {"Remap"          ,Remap          , RemapHelp         , RemapOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapbil       = {"Remapbil"       ,Remap          , RemapbilHelp      , RemapbilOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapbic       = {"Remapbic"       ,Remap          , RemapbicHelp      , RemapbicOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapnn        = {"Remapnn"        ,Remap          , RemapnnHelp       , RemapnnOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapdis       = {"Remapdis"       ,Remap          , RemapdisHelp      , RemapdisOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapcon       = {"Remapcon"       ,Remap          , RemapconHelp      , RemapconOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias ("remapycon", "remapcon"), Alias("genycon", "gencon")}};
-static const module_t module_Remapycon2     = {"Remapycon2"     ,Remap          , Remapcon2Help     , Remapycon2Operators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapscon      = {"Remapscon"      ,Remap          , {}                , RemapsconOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapcon2      = {"Remapcon2"      ,Remap          , Remapcon2Help     , Remapcon2Operators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remaplaf       = {"Remaplaf"       ,Remap          , RemaplafHelp      , RemaplafOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remap          = {"Remap"          ,Remapgrid      , RemapHelp         , RemapOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapbil       = {"Remapbil"       ,Remapgrid      , RemapbilHelp      , RemapbilOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapbic       = {"Remapbic"       ,Remapgrid      , RemapbicHelp      , RemapbicOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapnn        = {"Remapnn"        ,Remapgrid      , RemapnnHelp       , RemapnnOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapdis       = {"Remapdis"       ,Remapgrid      , RemapdisHelp      , RemapdisOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapcon       = {"Remapcon"       ,Remapgrid      , RemapconHelp      , RemapconOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias ("remapycon", "remapcon")} };
+static const module_t module_Remapycon2     = {"Remapycon2"     ,Remapgrid      , Remapcon2Help     , Remapycon2Operators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapscon      = {"Remapscon"      ,Remapgrid      , {}                , RemapsconOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapcon2      = {"Remapcon2"      ,Remapgrid      , Remapcon2Help     , Remapcon2Operators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remaplaf       = {"Remaplaf"       ,Remapgrid      , RemaplafHelp      , RemaplafOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapavg       = {"Remapavg"       ,Remapgrid      , {}                , RemapavgOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Genbil         = {"Genbil"         ,Remapweights   , RemapbilHelp      , GenbilOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Genbic         = {"Genbic"         ,Remapweights   , RemapbicHelp      , GenbicOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Gennn          = {"Gennn"          ,Remapweights   , RemapnnHelp       , GennnOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Gendis         = {"Gendis"         ,Remapweights   , RemapdisHelp      , GendisOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Gencon         = {"Gencon"         ,Remapweights   , RemapconHelp      , GenconOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias("genycon", "gencon")} };
+static const module_t module_Genycon2       = {"Genycon2"       ,Remapweights   , Remapcon2Help     , Genycon2Operators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Genscon        = {"Genscon"        ,Remapweights   , {}                , GensconOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Gencon2        = {"Gencon2"        ,Remapweights   , Remapcon2Help     , Gencon2Operators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Genlaf         = {"Genlaf"         ,Remapweights   , RemaplafHelp      , GenlafOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Remapstat      = {"Remapstat"      ,Remapstat      , RemapstatHelp     , RemapstatOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapavg       = {"Remapavg"       ,Remap          , {}                , RemapavgOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapweights   = {"Remapweights"   ,Remapweights   , {}                , RemapweightsOperators   , EXPOSED  , CDI_REAL , 0  , 0     , NoRestriction };
 static const module_t module_Remapeta       = {"Remapeta"       ,Remapeta       , RemapetaHelp      , RemapetaOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Replace        = {"Replace"        ,Replace        , ReplaceHelp       , ReplaceOperators        , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_Replacevalues  = {"Replacevalues"  ,Replacevalues  , ReplacevaluesHelp , ReplacevaluesOperators  , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
@@ -149,7 +160,7 @@ static const module_t module_Seaspctl       = {"Seaspctl"       ,Seaspctl
 static const module_t module_Seasstat       = {"Seasstat"       ,Seasstat       , SeasstatHelp      , SeasstatOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Seasmonstat    = {"Seasmonstat"    ,Seasmonstat    , {}                , SeasmonstatOperators    , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Selbox         = {"Selbox"         ,Selbox         , SelboxHelp        , SelboxOperators         , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
-static const module_t module_Selgridcell    = {"Selgridcell"    ,Selgridcell    , SelgridcellHelp   , SelgridcellOperators    , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction,   {Alias ("selindex", "selgridcell")}};
+static const module_t module_Selgridcell    = {"Selgridcell"    ,Selgridcell    , SelgridcellHelp   , SelgridcellOperators    , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
 static const module_t module_Select         = {"Select"         ,Select         , SelectHelp        , SelectOperators         , EXPOSED  , CDI_BOTH , -1 , 1     , NoRestriction };
 static const module_t module_Selvar         = {"Selvar"         ,Selvar         , SelvarHelp        , SelvarOperators         , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction,   {Alias ("selvar", "selname"), Alias("delvar"  , "delname"),Alias("selgridname"     , "selgrid")} };
 static const module_t module_Selrec         = {"Selrec"         ,Selrec         , SelvarHelp        , SelrecOperators         , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
@@ -171,9 +182,10 @@ static const module_t module_Setrcaname     = {"Setrcaname"     ,Setrcaname
 static const module_t module_Settime        = {"Settime"        ,Settime        , SettimeHelp       , SettimeOperators        , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
 static const module_t module_Setzaxis       = {"Setzaxis"       ,Setzaxis       , SetzaxisHelp      , SetzaxisOperators       , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
 static const module_t module_Shiftxy        = {"Shiftxy"        ,Shiftxy        , ShiftxyHelp       , ShiftxyOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Showinfo       = {"Showinfo"       ,Showinfo       , ShowinfoHelp      , ShowinfoOperators       , EXPOSED  , CDI_BOTH , 1  , 0     , NoRestriction ,  {Alias ("showvar", "showname")}};
+static const module_t module_Showinfo       = {"Showinfo"       ,Showinfo       , ShowinfoHelp      , ShowinfoOperators       , EXPOSED  , CDI_BOTH , 1  , 0     , NoRestriction ,  {Alias ("showvar", "showname")} };
 static const module_t module_Showattribute  = {"Showattribute"  ,Showattribute  , ShowattributeHelp , ShowattributeOperators  , EXPOSED  , CDI_REAL , 1  , 0     , NoRestriction };
-static const module_t module_Sinfo          = {"Sinfo"          ,Sinfo          , SinfoHelp         , SinfoOperators          , EXPOSED  , CDI_BOTH , -1 , 0     , NoRestriction,   {Alias ("infov", "infon"),Alias("sinfov", "sinfon") ,Alias("infos", "sinfo")} };
+static const module_t module_Sinfo          = {"Sinfo"          ,Sinfo          , SinfoHelp         , SinfoOperators          , EXPOSED  , CDI_BOTH , -1 , 0     , NoRestriction,   {Alias ("infov", "infon"),Alias("sinfov", "sinfon")} };
+static const module_t module_XSinfo         = {"XSinfo"         ,Sinfo          , XSinfoHelp        , XSinfoOperators         , EXPOSED  , CDI_BOTH , -1 , 0     , NoRestriction };
 static const module_t module_Smooth         = {"Smooth"         ,Smooth         , SmoothHelp        , SmoothOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Sort           = {"Sort"           ,Sort           , {}                , SortOperators           , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias ("sortvar", "sortname")} };
 static const module_t module_Sorttimestamp  = {"Sorttimestamp"  ,Sorttimestamp  , {}                , SorttimestampOperators  , EXPOSED  , CDI_REAL , -1 , 1     , NoRestriction };
@@ -182,6 +194,7 @@ static const module_t module_Spectral       = {"Spectral"       ,Spectral
 static const module_t module_Specconv       = {"Specconv"       ,Spectral       , SpecconvHelp      , SpecconvOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Spectrum       = {"Spectrum"       ,Spectrum       , {}                , SpectrumOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Split          = {"Split"          ,Split          , SplitHelp         , SplitOperators          , EXPOSED  , CDI_BOTH , 1  , OBASE , NoRestriction,   {Alias ("splitvar", "splitname")} };
+static const module_t module_Splitdate      = {"Splitdate"      ,Splitdate      , SplitdateHelp     , SplitdateOperators      , EXPOSED  , CDI_BOTH , 1  , OBASE , OnlyFirst };
 static const module_t module_Splitrec       = {"Splitrec"       ,Splitrec       , SplitHelp         , SplitrecOperators       , EXPOSED  , CDI_BOTH , 1  , OBASE , NoRestriction };
 static const module_t module_Splitsel       = {"Splitsel"       ,Splitsel       , SplitselHelp      , SplitselOperators       , EXPOSED  , CDI_BOTH , 1  , OBASE , OnlyFirst };
 static const module_t module_Splittime      = {"Splittime"      ,Splittime      , SplittimeHelp     , SplittimeOperators      , EXPOSED  , CDI_BOTH , 1  , OBASE , OnlyFirst };
@@ -205,7 +218,7 @@ static const module_t module_Monpctl        = {"Monpctl"        ,Timpctl
 static const module_t module_Daypctl        = {"Daypctl"        ,Timpctl        , DaypctlHelp       , DaypctlOperators        , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
 static const module_t module_Hourpctl       = {"Hourpctl"       ,Timpctl        , HourpctlHelp      , HourpctlOperators       , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
 static const module_t module_Timselpctl     = {"Timselpctl"     ,Timselpctl     , TimselpctlHelp    , TimselpctlOperators     , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
-static const module_t module_Timfill        = {"Timfill"        ,Timfill        , {}                , TimfillOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Timfillmiss    = {"Timfillmiss"    ,Timfillmiss    , TimfillmissHelp   , TimfillmissOperators    , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Timsort        = {"Timsort"        ,Timsort        , TimsortHelp       , TimsortOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias ("sort", "timsort")} };
 static const module_t module_Timselstat     = {"Timselstat"     ,Timselstat     , TimselstatHelp    , TimselstatOperators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_XTimstat       = {"XTimstat"       ,XTimstat       , {}                , XTimstatOperators       , INTERNAL , CDI_BOTH , 1  , 1     , NoRestriction };
@@ -224,10 +237,11 @@ static const module_t module_Transpose      = {"Transpose"      ,Transpose
 static const module_t module_Trend          = {"Trend"          ,Trend          , TrendHelp         , TrendOperators          , EXPOSED  , CDI_REAL , 1  , 2     , OnlyFirst     };
 static const module_t module_Trendarith     = {"Trendarith"     ,Trendarith     , TrendarithHelp    , TrendarithOperators     , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
 static const module_t module_Tstepcount     = {"Tstepcount"     ,Tstepcount     , {}                , TstepcountOperators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Unpack         = {"Unpack"         ,Unpack         , {}                , UnpackOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Unpack         = {"Unpack"         ,Unpack         , UnpackHelp        , UnpackOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Vargen         = {"Vargen"         ,Vargen         , VargenHelp        , VargenOperators         , EXPOSED  , CDI_REAL , 0  , 1     , NoRestriction,   {Alias ("for", "seq")} };
 static const module_t module_Varrms         = {"Varrms"         ,Varrms         , {}                , VarrmsOperators         , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_Varsstat       = {"Varsstat"       ,Varsstat       , VarsstatHelp      , VarsstatOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Vertfillmiss   = {"Vertfillmiss"   ,Vertfillmiss   , VertfillmissHelp  , VertfillmissOperators   , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Vertintap      = {"Vertintap"      ,Vertintap      , VertintapHelp     , VertintapOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Vertintgh      = {"Vertintgh"      ,Vertintgh      , VertintghHelp     , VertintghOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Vertintml      = {"Vertintml"      ,Vertintml      , VertintmlHelp     , VertintmlOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
@@ -236,6 +250,7 @@ static const module_t module_Vertstat       = {"Vertstat"       ,Vertstat
 static const module_t module_Vertcum        = {"Vertcum"        ,Vertcum        , {}                , VertcumOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Vertwind       = {"Vertwind"       ,Vertwind       , {}                , VertwindOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Verifygrid     = {"Verifygrid"     ,Verifygrid     , VerifygridHelp    , VerifygridOperators     , EXPOSED  , CDI_REAL , 1  , 0     , NoRestriction };
+static const module_t module_Verifyweights  = {"Verifyweights"  ,Verifyweights  , {}                , VerifyweightsOperators  , EXPOSED  , CDI_REAL , 0  , 0     , NoRestriction };
 static const module_t module_Wind           = {"Wind"           ,Wind           , WindHelp          , WindOperators           , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Wind2          = {"Wind2"          ,Wind           , Wind2Help         , Wind2Operators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Writegrid      = {"Writegrid"      ,Writegrid      , {}                , WritegridOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
@@ -252,6 +267,8 @@ static const module_t module_Yhourstat      = {"Yhourstat"      ,Yhourstat
 static const module_t module_Dhourstat      = {"Dhourstat"      ,Yhourstat      , DhourstatHelp     , DhourstatOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Ymonarith      = {"Ymonarith"      ,Ymonarith      , YmonarithHelp     , YmonarithOperators      , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction,   {Alias ("anomaly","ymonsub")}};
 static const module_t module_Yseasarith     = {"Yseasarith"     ,Ymonarith      , YseasarithHelp    , YseasarithOperators     , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
+static const module_t module_Ymoncomp       = {"Ymoncomp"       ,Ymoncomp       , YmoncompHelp      , YmoncompOperators       , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
+static const module_t module_Yseascomp      = {"Yseascomp"      ,Ymoncomp       , {}                , YseascompOperators      , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_Ymonpctl       = {"Ymonpctl"       ,Ymonpctl       , YmonpctlHelp      , YmonpctlOperators       , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
 static const module_t module_Ymonstat       = {"Ymonstat"       ,Ymonstat       , YmonstatHelp      , YmonstatOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Yseaspctl      = {"Yseaspctl"      ,Yseaspctl      , YseaspctlHelp     , YseaspctlOperators      , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
@@ -262,7 +279,7 @@ static const module_t module_EcaCsu         = {"EcaCsu"         ,EcaCsu
 static const module_t module_EcaCwdi        = {"EcaCwdi"        ,EcaCwdi        , EcaCwdiHelp       , EcaCwdiOperators        , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_EcaCwfi        = {"EcaCwfi"        ,EcaCwfi        , EcaCwfiHelp       , EcaCwfiOperators        , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_EcaEtr         = {"EcaEtr"         ,EcaEtr         , EcaEtrHelp        , EcaEtrOperators         , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
-static const module_t module_EcaEtccdi      = {"EcaEtccdi"      ,EcaEtccdi      , EcaEtccdiHelp     , EcaEtccdiOperators      , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
+static const module_t module_EcaEtccdi      = {"EcaEtccdi"      ,EcaEtccdi      , EcaEtccdiHelp     , EcaEtccdiOperators      , EXPOSED  , CDI_REAL , 3  , 1     , FilesOnly };
 static const module_t module_EcaFd          = {"EcaFd"          ,EcaFd          , EcaFdHelp         , EcaFdOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_EcaGsl         = {"EcaGsl"         ,EcaGsl         , EcaGslHelp        , EcaGslOperators         , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_EcaHd          = {"EcaHd"          ,EcaHd          , EcaHdHelp         , EcaHdOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
