@@ -83,10 +83,7 @@ pipe_t::pipe_inq_timestep(int p_tsID)
             data_is_float = false;
             read_cond.notify_all();
           }
-        else
-          {
-            Debug(PIPE, "%s has no data", name);
-          }
+        else { Debug(PIPE, "%s has no data", name); }
 
         recInq_cond.notify_all(); /* o.k. ??? */
 
@@ -146,10 +143,7 @@ pipe_t::pipe_def_timestep(int p_vlistID, int p_tsID)
     if (p_tsID != tsIDw) cdo_abort("unexpected p_tsID %d(%d) for %s", p_tsID, tsIDw, name);
 
     int numrecs = 0;
-    if (p_tsID == 0)
-      {
-        numrecs = vlistNrecs(p_vlistID);
-      }
+    if (p_tsID == 0) { numrecs = vlistNrecs(p_vlistID); }
     else
       {
         auto vlistID = p_vlistID;
@@ -294,10 +288,7 @@ pipe_t::pipe_read_pipe_record(double *const p_data, int vlistID, size_t *const p
     {
       for (size_t i = 0; i < datasize; ++i) p_data[i] = (double) data_f[i];
     }
-  else
-    {
-      memcpy(p_data, data_d, datasize * sizeof(double));
-    }
+  else { memcpy(p_data, data_d, datasize * sizeof(double)); }
 
   *p_nmiss = nmiss;
   return datasize;
@@ -311,10 +302,7 @@ pipe_t::pipe_read_pipe_record(float *const p_data, int vlistID, size_t *const p_
   auto datasize = gridInqSize(vlistInqVarGrid(vlistID, varID));
   if (vlistNumber(vlistID) != CDI_REAL) datasize *= 2;
 
-  if (data_is_float)
-    {
-      memcpy(p_data, data_f, datasize * sizeof(float));
-    }
+  if (data_is_float) { memcpy(p_data, data_f, datasize * sizeof(float)); }
   else
     {
       for (size_t i = 0; i < datasize; ++i) p_data[i] = (float) data_d[i];
@@ -338,14 +326,8 @@ pipe_t::pipe_read_record(int p_vlistID, double *const p_data, size_t *const p_nm
         write_cond.wait(lock);
       }
 
-    if (hasdata)
-      {
-        nvals = pipe_read_pipe_record(p_data, p_vlistID, p_nmiss);
-      }
-    else
-      {
-        cdo_abort("data type %d not implemented", hasdata);
-      }
+    if (hasdata) { nvals = pipe_read_pipe_record(p_data, p_vlistID, p_nmiss); }
+    else { cdo_abort("data type %d not implemented", hasdata); }
 
     Debug(PIPE, name.c_str(), " read record ", recIDr);
 
@@ -372,14 +354,8 @@ pipe_t::pipe_read_record(int p_vlistID, float *const p_data, size_t *const p_nmi
         write_cond.wait(lock);
       }
 
-    if (hasdata)
-      {
-        nvals = pipe_read_pipe_record(p_data, p_vlistID, p_nmiss);
-      }
-    else
-      {
-        cdo_abort("data type %d not implemented", hasdata);
-      }
+    if (hasdata) { nvals = pipe_read_pipe_record(p_data, p_vlistID, p_nmiss); }
+    else { cdo_abort("data type %d not implemented", hasdata); }
 
     Debug(PIPE, name.c_str(), " read record ", recIDr);
 
