@@ -59,7 +59,7 @@ public:
 
 private:
   PipeStream() = delete;
-  std::shared_ptr<pipe_t> m_pipe;
+  std::shared_ptr<pipe_t> m_pipe = std::make_shared<pipe_t>();
   pthread_t rthreadID;  // read  thread ID
   pthread_t wthreadID;  // write thread ID
   void waitForPipe();
