@@ -91,11 +91,11 @@ public:
   /**
    * Adds a Process as child and creates and adds a new pipe stream.
    */
-  void add_child(const std::shared_ptr<Process>&child_process);
+  void add_child(const std::shared_ptr<Process> &child_process);
   /**
    * Adds a Process as parent and adds the parents input stream to out streams.
    */
-  void add_parent(const std::shared_ptr<Process>&parent_process);
+  void add_parent(const std::shared_ptr<Process> &parent_process);
   /**
    * Compares the wanted and current stream counts.
    * @return if the wanted count is -1 this function always returns false.
@@ -134,19 +134,24 @@ public:
   void validate();
   void handle_process_err();
 
-  bool has_out_stream(const CdoStreamID p_streamPtr);
-  bool has_in_stream(const CdoStreamID p_streamPtr);
+  bool has_out_stream(CdoStreamID p_streamPtr);
+  bool has_in_stream(CdoStreamID p_streamPtr);
   bool has_no_pipes();
   size_t inq_nvals();
   const char *get_out_stream_name();
   size_t get_oper_argc();
   std::string get_argv(int idx);
   const std::string get_obase();
-  void set_obase(const std::string &obase){m_obase = obase;} //TODO into cc
+  void
+  set_obase(const std::string &obase)
+  {
+    m_obase = obase;
+  }  // TODO into cc
   bool input_is_variable();
   int get_id();
 
   void init_process(const std::string &p_operatorName, const std::vector<std::string> &p_arguments);
+  void close_streams();
 
 private:
   Process();
