@@ -21,37 +21,35 @@ static std::string parse_err_msg = "";
 static const int IS_OBASE = -1;
 
 void
-ProcessManager::buildProcessTree(std::vector<std::shared_ptr<Parser::Node>> roots)
+ProcessManager::buildProcessTree(std::vector<std::shared_ptr<Node>> roots)
 {
-  Debug("Building process Tree");
-  std::shared_ptr<Parser::Node> node = roots[0]->isFile ? roots[0]->children[0] : roots[0];
+  Debug(PROCESS,"Building process Tree");
+  std::shared_ptr<Node> node = roots[0]->isFile ? roots[0]->children[0] : roots[0];
 
   auto first_process = create_process(node->oper, split_args(node->arguments));
-  if (node->numOut == IS_OBASE)
+  if (node->numOut() == IS_OBASE)
     {
-      Debug("Setting obase for %s", node->oper);
+      Debug(PROCESS,"Setting obase for %s", node->oper);
       first_process->set_obase(roots[0]->oper);
     }
-  else if (node->numOut > 0)
+  else if (node->numOut() > 0)
     {
       for (const auto &n : roots)
         {
-          Debug("adding out files to %s", node->oper);
+          Debug(PROCESS,"adding out files to %s", node->oper);
           first_process->add_file_out_stream(n->oper);
         }
     }
 
   for (const auto &c : node->children)
     {
-      Debug("Building %s", c->oper);
       if (c->isFile)
         {
-          Debug("Adding file in stream: %s", c->oper);
+          Debug(PROCESS,"Adding file in stream: %s", c->oper);
           first_process->add_file_in_stream(c->oper);
         }
       else
         {
-          Debug("building Node for %s", c->oper);
           auto c_ptr = build_node(c);
           first_process->add_child(c_ptr);
           c_ptr->add_parent(first_process);
@@ -63,20 +61,20 @@ ProcessManager::buildProcessTree(std::vector<std::shared_ptr<Parser::Node>> root
 }
 
 std::shared_ptr<Process>
-ProcessManager::build_node(std::shared_ptr<Parser::Node> parent_node)
+ProcessManager::build_node(std::shared_ptr<Node> parent_node)
 {
-  Debug("Building process for ptr %s", parent_node->oper);
+  Debug(PROCESS,"Building process for %s", parent_node->oper);
   auto parent_process = create_process(parent_node->oper, split_args(parent_node->arguments));
   for (auto child_node : parent_node->children)
     {
       if (child_node->isFile)
         {
-          Debug("Adding file in stream: %s", child_node->oper);
+          Debug(PROCESS,"Adding file in stream: %s", child_node->oper);
           parent_process->add_file_in_stream(child_node->oper);
         }
       else
         {
-          Debug("Building Process for %s", child_node->oper);
+          Debug(PROCESS,"Building Process for %s", child_node->oper);
           auto child_process = build_node(child_node);
           parent_process->add_child(child_process);
           child_process->add_parent(parent_process);
@@ -95,7 +93,7 @@ ProcessManager::run_processes()
           /*TEMP*/
           if (!Options::silentMode && (cdo::stdoutIsTerminal || Options::cdoVerbose))
             {
-              //MpMO::Print(Green("%s: ") + "Process started", idProcessPair.second->prompt);
+              // MpMO::Print(Green("%s: ") + "Process started", idProcessPair.second->prompt);
               set_text_color(stdout, GREEN);
               fprintf(stdout, "%s: ", idProcessPair.second->prompt);
               reset_text_color(stdout);
@@ -173,7 +171,7 @@ ProcessManager::get_operator_argv(std::string operatorArguments)
       while ((pos = operatorArguments.find(delimiter)) != std::string::npos)
         {
           argument_vector.push_back(operatorArguments.substr(0, pos));
-          Debug("added argument %s", argument_vector.back());
+          Debug(PROCESS,"added argument %s", argument_vector.back());
           operatorArguments.erase(0, pos + 1);
         }
       argument_vector.push_back(operatorArguments);
@@ -185,18 +183,17 @@ std::vector<std::string>
 ProcessManager::split_args(std::string operatorArguments)
 {
   if (operatorArguments.empty()) return {};
-  Debug(PROCESS, "Setting operator arguments: %s", operatorArguments);
+  Debug(PROCESS, "Setting operator arguments: '%s'", operatorArguments);
   std::vector<std::string> argument_vector = {};
   constexpr char delimiter = ',';
   size_t pos;
   while ((pos = operatorArguments.find(delimiter)) != std::string::npos)
     {
       argument_vector.push_back(operatorArguments.substr(0, pos));
-      Debug("added argument %s", argument_vector.back());
+      Debug(PROCESS,"added argument %s", argument_vector.back());
       operatorArguments.erase(0, pos + 1);
     }
   argument_vector.push_back(operatorArguments);
-  Debug("returning %d arguments", argument_vector.size());
   return argument_vector;
 }
 
