@@ -11,6 +11,7 @@
 
 #include <pthread.h>
 #include "node.h"
+#include "modules.h"
 
 // cdo includes
 
@@ -52,10 +53,9 @@ public:
   int get_num_active_processes();
   const std::shared_ptr<Process> &get_process_from_id(int p_processID);
 
-  void buildProcessTree(std::vector<std::shared_ptr<Parser::Node>> root);
-
-  std::shared_ptr<Process> build_node(std::shared_ptr<Parser::Node> ptr);
+  void buildProcessTree(std::vector<std::shared_ptr<Node>> root);
 
+  std::shared_ptr<Process> build_node(std::shared_ptr<Node> ptr);
 };
 
 #endif
