@@ -27,7 +27,7 @@
 #include "cdo_default_values.h"
 #include "process.h"
 
-thread_local Process* localProcess;
+thread_local Process *localProcess;
 static int NumProcessActive = 0;
 
 int
@@ -60,12 +60,12 @@ process_def_var_num(int nvars)
 int
 cdo_stream_inq_timestep(CdoStreamID p_pstreamptr, int tsID)
 {
-  Debug(PROCESS, "%s pstreamID %d", p_pstreamptr->m_name, p_pstreamptr->get_id());
+  Debug(PROCESS_INT, "%s pstreamID %d", p_pstreamptr->m_name, p_pstreamptr->get_id());
   const auto nrecs = p_pstreamptr->inq_timestep(tsID);
   if (nrecs && tsID == p_pstreamptr->getTsID())
     {
       localProcess->ntimesteps++;
-      Debug(PROCESS, "Timestep cnt for localProcess: %s: %d", localProcess->prompt, localProcess->ntimesteps);
+      Debug(PROCESS_INT, "Timestep cnt for localProcess: %s: %d", localProcess->prompt, localProcess->ntimesteps);
     }
   return nrecs;
 }
@@ -123,10 +123,8 @@ get_input()
   std::string line;
   std::string fline = "";
 
-  do
-    {
+  do {
       std::getline(std::cin, line);
-      // std::cout << line << std::endl;
       fline += line;
     }
   while (std::string(line).find("\\") != std::string::npos);
@@ -188,6 +186,12 @@ cdo_operator_name(int operID)
   return localProcess->oper[operID].name.c_str();
 }
 
+std::string
+cdo_module_name()
+{
+  return get_module_name_to(cdo_operator_name(cdo_operator_id()));
+}
+
 const char *
 cdo_operator_enter(int operID)
 {
@@ -209,7 +213,7 @@ cdo_stream_cnt(void)
 CdoStreamID
 cdo_open_read(int inStreamIDX)
 {
-  Debug(PROCESS, "Getting in stream %d of process %d", inStreamIDX, localProcess->m_ID);
+  Debug(PROCESS_INT, "Getting in stream %d of process %d", inStreamIDX, localProcess->m_ID);
 
   if (localProcess->get_stream_cnt_in() < inStreamIDX || inStreamIDX < 0)
     cdo_abort("instream %d of process %d not found", inStreamIDX, localProcess->m_ID);
@@ -228,7 +232,7 @@ CdoStreamID
 cdo_open_write(int p_outStreamIDX, int filetype)
 {
   if (filetype == CDI_UNDEFID) filetype = cdo_filetype();
-  Debug(PROCESS, "Getting out stream %d of process %d", p_outStreamIDX, localProcess->m_ID);
+  Debug(PROCESS_INT, "Getting out stream %d of process %d", p_outStreamIDX, localProcess->m_ID);
 
   const int outStreamIDX = p_outStreamIDX - localProcess->inputStreams.size();
   if (outStreamIDX > localProcess->get_stream_cnt_out() || outStreamIDX < 0)
@@ -283,7 +287,7 @@ cdoGetOutStreamName()
 const std::shared_ptr<Process>
 cdoGetInputChild(int p_inID)
 {
-  for (const std::shared_ptr<Process>&processPtr : localProcess->childProcesses)
+  for (const std::shared_ptr<Process> &processPtr : localProcess->childProcesses)
     {
       if (processPtr->has_out_stream(localProcess->inputStreams[p_inID])) return processPtr;
     }
@@ -300,19 +304,19 @@ const char *
 cdo_get_stream_name(int p_streamIndex)
 {
   const char *streamName = nullptr;
-  Debug(PROCESS, "stridx %d", p_streamIndex);
+  Debug(PROCESS_INT, "stridx %d", p_streamIndex);
   if (p_streamIndex >= static_cast<int>(localProcess->inputStreams.size()))
     {
-      Debug(PROCESS, "Getting output stream name %d", p_streamIndex);
+      Debug(PROCESS_INT, "Getting output stream name %d", p_streamIndex);
       streamName = cdoGetOutStreamName();
     }
   else
     {
-      Debug(PROCESS, "Getting input stream name %d", p_streamIndex);
+      Debug(PROCESS_INT, "Getting input stream name %d", p_streamIndex);
       streamName = cdoGetInStreamName(p_streamIndex);
     }
 
-  Debug(PROCESS, "StreamName is: %s", streamName);
+  Debug(PROCESS_INT, "StreamName is: %s", streamName);
 
   return streamName;
 }
@@ -350,10 +354,10 @@ cdo_initialize(void *p_process)
 #ifdef HAVE_LIBPTHREAD
   localProcess->threadID = pthread_self();
 #endif
-  Debug(PROCESS, "Initializing process: %s (id: %d)", localProcess->operatorName , localProcess->get_id());
+  Debug(PROCESS_INT, "Initializing process: %s (id: %d)", localProcess->operatorName, localProcess->get_id());
 
 #ifdef HAVE_LIBPTHREAD
-  Debug(PROCESS, "process %d thread %ld", localProcess->m_ID, pthread_self());
+  Debug(PROCESS_INT, "process %d thread %ld", localProcess->m_ID, pthread_self());
 #endif
 }
 
@@ -368,14 +372,17 @@ extern "C" size_t getPeakRSS();
 void
 cdo_finish(void)
 {
-  Debug(PROCESS, "Finishing process: %d", localProcess->m_ID);
+  assert(((void) "Internal error: module not initialized!", (localProcess != nullptr)));
+
+  Debug(PROCESS_INT, "Finishing process: %d", localProcess->m_ID);
 
 #ifdef HAVE_LIBPTHREAD
-  Debug(PROCESS, "process %d thread %ld", localProcess->m_ID, pthread_self());
+  Debug(PROCESS_INT, "process %d thread %ld", localProcess->m_ID, pthread_self());
 #endif
 
   if (!Options::silentMode && (cdo::stdoutIsTerminal || Options::cdoVerbose)) localProcess->print_processed_values();
 
+  // localProcess->close_streams();
   localProcess->set_inactive();
   NumProcessActive--;
 }
@@ -384,10 +391,16 @@ cdo_finish(void)
 void
 cdo_stream_close(CdoStreamID pstreamPtr)
 {
-  Debug(PROCESS, "Adding %d to pstream %d %s", localProcess->inq_nvals(), pstreamPtr->get_id(), pstreamPtr->m_name);
+  Debug(PROCESS_INT, "Adding %d to pstream %d %s", localProcess->inq_nvals(), pstreamPtr->get_id(), pstreamPtr->m_name);
   pstreamPtr->close();
 }
 
+void
+cdo_close_streams()
+{
+  localProcess->close_streams();
+}
+
 /******************************************************************/
 /* Functions that only work on streamID's and do not need process */
 /******************************************************************/
@@ -397,7 +410,7 @@ cdo_stream_inq_vlist(CdoStreamID p_pstreamPtr)
 {
   if (p_pstreamPtr == nullptr) return -1;
 
-  Debug(PROCESS, "Inquiring Vlist from pstream %d", p_pstreamPtr->get_id());
+  Debug(PROCESS_INT, "Inquiring Vlist from pstream %d", p_pstreamPtr->get_id());
   const auto vlistID = p_pstreamPtr->inq_vlist();
   if (vlistNumber(vlistID) == CDI_COMP && cdo_stream_number() == CDI_REAL)
     cdo_abort("Fields with complex numbers are not supported by this operator!");
@@ -512,7 +525,7 @@ cdo_read_record(CdoStreamID streamID, Field3D &field, int levelID, size_t *nmiss
 void
 cdo_copy_record(CdoStreamID pstreamPtrDest, CdoStreamID pstreamPtrSrc)
 {
-  Debug(PROCESS, "pstreamIDdest = %d pstreamIDsrc = %d", pstreamPtrDest->get_id(), pstreamPtrSrc->get_id());
+  Debug(PROCESS_INT, "pstreamIDdest = %d pstreamIDsrc = %d", pstreamPtrDest->get_id(), pstreamPtrSrc->get_id());
   pstreamPtrDest->copyRecord(pstreamPtrSrc);
 }
 
