@@ -14,6 +14,7 @@
 #include "remap_vars.h"
 #include "remap_grid_cell_search.h"
 #include "grid_point_search.h"
+#include "mpim_grid/grid_healpix.h"
 
 #ifndef M_PI
 #define M_PI 3.14159265358979323846264338327950288
@@ -31,54 +32,51 @@ constexpr double TINY = 1.e-14;
 enum class RemapGridType
 {
   Undefined,
+  HealPix,
   Reg2D,
-  Curve2D,
   Unstruct
 };
 
 #define REMAP_GRID_BASIS_SRC 1
 #define REMAP_GRID_BASIS_TGT 2
 
-enum class SubmapType
-{
-  NONE,
-  LAF,
-  SUM,
-  AVG
-};
-
 struct LonLatPoint
 {
   double lon = 0.0, lat = 0.0;
-  LonLatPoint() {};
-  LonLatPoint(double _lon, double _lat) : lon(_lon), lat(_lat) {};
+  LonLatPoint(){};
+  LonLatPoint(double _lon, double _lat) : lon(_lon), lat(_lat){};
 };
 
-struct // RemapGrid
+// clang-format off
+struct  // RemapGrid
 #ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 RemapGrid
+// clang-format on
 {
-  int gridID;
-  int tmpgridID;
-  RemapGridType type;
-  int rank;                 // rank of the grid
-  size_t size;              // total points on the grid
-  size_t num_cell_corners;  // number of corners for each grid cell
+  std::string name;
+  RemapGridType type = RemapGridType::Undefined;
+  int gridID = -1;
+  int tmpgridID = -1;
+  int rank = 0;                 // rank of the grid
+  size_t size = 0;              // total points on the grid
+  size_t num_cell_corners = 0;  // number of corners for each grid cell
 
-  bool lneed_cell_corners;
-  bool luse_cell_corners;   // use corners for bounding boxes
+  int nside = 0;
+  HpOrder order = HpOrder::Undef;
 
-  bool lextrapolate;
-  bool non_global;
-  bool is_cyclic;
+  bool needCellCorners = false;
+  bool useCellCorners = false;  // use corners for bounding boxes
 
-  size_t dims[2];           // size of grid dimension
+  bool doExtrapolate = false;
+  bool isCyclic = false;
 
-  int nvgp;                 // size of vgpm
-  Varray<int> vgpm;         // flag which cells are valid
-  Varray<short> mask;       // flag which cells participate
+  size_t dims[2] = { 0, 0 };  // size of grid dimension
+
+  int nvgp = 0;        // size of vgpm
+  Varray<int> vgpm;    // flag which cells are valid
+  Varray<short> mask;  // flag which cells participate
 
   Varray<double> reg2d_center_lon;  // reg2d lon/lat coordinates for
   Varray<double> reg2d_center_lat;  // each grid center in radians
@@ -90,15 +88,17 @@ RemapGrid
   Varray<double> cell_corner_lon;  // lon/lat coordinates for
   Varray<double> cell_corner_lat;  // each grid corner in radians
 
-  Varray<double> cell_area;        // total area of each grid cell
-  Varray<double> cell_frac;        // fractional area of grid cells participating in remapping
+  Varray<double> cell_area;  // total area of each grid cell
+  Varray<double> cell_frac;  // fractional area of grid cells participating in remapping
 };
 
-struct // GridSearchBins
+// clang-format off
+struct  // GridSearchBins
 #ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 GridSearchBins
+// clang-format on
 {
   unsigned nbins;                // num of bins for restricted search
   size_t ncells;                 // total number of grid cells (cell_bound_box)
@@ -107,11 +107,13 @@ GridSearchBins
   Varray<float> cell_bound_box;  // lon/lat bounding box for use
 };
 
-struct // RemapSearch
+// clang-format off
+struct  // RemapSearch
 #ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 RemapSearch
+// clang-format on
 {
   RemapGrid *srcGrid;
   RemapGrid *tgtGrid;
@@ -123,16 +125,18 @@ RemapSearch
   GridCellSearch gcs;
 };
 
-struct // RemapType
+// clang-format off
+struct  // RemapType
 #ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 RemapType
+// clang-format on
 {
-  int nused;
-  int gridID;
-  size_t gridsize;
-  size_t nmiss;
+  int nused = 0;
+  int gridID = -1;
+  size_t gridsize = 0;
+  size_t nmiss = 0;
   RemapGrid srcGrid;
   RemapGrid tgtGrid;
   RemapVars vars;
@@ -144,19 +148,21 @@ RemapType
 #define REMAP_NUM_SRCH_BINS 4
 #define REMAP_GENWEIGHTS 5
 
+int remap_check_mask_indices(const size_t (&indices)[4], const Varray<short> &mask);
+
 void remap_set_threshhold(double threshhold);
 void remap_set_int(int remapvar, int value);
 
-void remap_init_grids(RemapMethod mapType, bool lextrapolate, int gridID1, RemapGrid &srcGrid, int gridID2, RemapGrid &tgtGrid);
+void remap_init_grids(RemapMethod mapType, bool doExtrapolate, int gridID1, RemapGrid &srcGrid, int gridID2, RemapGrid &tgtGrid);
 
-void remap_grid_init(RemapGrid &grid);
 void remap_grid_free(RemapGrid &grid);
 void remap_grid_alloc(RemapMethod mapType, RemapGrid &grid);
 void remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &srcGrid, RemapGrid &tgtGrid);
 void remap_search_free(RemapSearch &search);
 
-void remap_search_points(RemapSearch &rsearch, const LonLatPoint &llp, knnWeightsType &knnWeights);
-int remap_search_square(RemapSearch &rsearch, const LonLatPoint &llp, size_t (&src_add)[4], double (&src_lats)[4], double (&src_lons)[4]);
+void remap_search_points(RemapSearch &rsearch, const LonLatPoint &llpoint, knnWeightsType &knnWeights);
+int remap_search_square(RemapSearch &rsearch, const LonLatPoint &llpoint, size_t (&src_add)[4], double (&srcLats)[4],
+                        double (&srcLons)[4]);
 size_t remap_search_cells(RemapSearch &rsearch, bool isReg2dCell, GridCell &gridCell, Varray<size_t> &srchAddr);
 
 void remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv);
@@ -176,35 +182,66 @@ template <typename T>
 void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &array, RemapGradients &gradients);
 void remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients);
 
-void sort_add(size_t num_links, size_t num_wts, size_t *add1, size_t *add2, double *weights);
-void sort_iter(size_t num_links, size_t num_wts, size_t *add1, size_t *add2, double *weights, int parent);
+void sort_add(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *weights);
+void sort_iter(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *weights, int parent);
 
-void remap_write_data_scrip(const char *interp_file, RemapMethod mapType, SubmapType submapType, int numNeighbors, int remapOrder,
-                         RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv);
-void remap_read_data_scrip(const char *interp_file, int gridID1, int gridID2, RemapMethod &mapType, SubmapType &submapType,
-                        int &numNeighbors, int &remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv);
+void remap_write_data_scrip(const char *weightsfile, const RemapSwitches &remapSwitches, RemapGrid &srcGrid, RemapGrid &tgtGrid,
+                            RemapVars &rv);
+RemapSwitches remap_read_data_scrip(const std::string &weightsfile, int gridID1, int gridID2, RemapGrid &srcGrid,
+                                    RemapGrid &tgtGrid, RemapVars &rv);
 
 void calc_lat_bins(GridSearchBins &searchBins);
 size_t get_srch_cells(size_t tgtCellIndex, GridSearchBins &tgtBins, GridSearchBins &srcBins, float *tgt_cell_bound_box,
                       Varray<size_t> &srch_add);
 
-int grid_search_square_reg_2d_NN (size_t nx, size_t ny, size_t *nbr_add, double *nbr_dist, double plat, double plon,
-                            const Varray<double> &src_center_lat, const Varray<double> &src_center_lon);
+int grid_search_square_reg_2d_NN(size_t nx, size_t ny, size_t *nbr_add, double *nbr_dist, double plat, double plon,
+                                 const Varray<double> &src_center_lat, const Varray<double> &src_center_lon);
 
-int grid_search_square_reg_2d(RemapGrid *srcGrid, size_t (&src_add)[4], double (&src_lats)[4], double (&src_lons)[4], double plat, double plon);
+int grid_search_square_reg_2d(RemapGrid *srcGrid, size_t (&src_add)[4], double (&srcLats)[4], double (&srcLons)[4], double plat,
+                              double plon);
 
 bool point_in_quad(bool isCyclic, size_t nx, size_t ny, size_t i, size_t j, size_t adds[4], double lons[4], double lats[4],
-                 double plon, double plat, const double *centerLon, const double *centerLat);
+                   double plon, double plat, const double *centerLon, const double *centerLat);
 
-int grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], double (&src_lats)[4], double (&src_lons)[4], double plat, double plon,
-                                GridSearchBins &srcBins);
+int grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], double (&srcLats)[4], double (&srcLons)[4],
+                                     double plat, double plon, GridSearchBins &srcBins);
 
-std::pair<double, double> remap_find_weights(const LonLatPoint &llpoint, const double (&src_lons)[4], const double (&src_lats)[4]);
+std::pair<double, double> remap_find_weights(const LonLatPoint &llpoint, const double (&srcLons)[4], const double (&srcLats)[4]);
 
-int rect_grid_search(size_t &ii, size_t &jj, double x, double y, size_t nxm, size_t nym, const Varray<double> &xm, const Varray<double> &ym);
+int rect_grid_search(size_t &ii, size_t &jj, double x, double y, size_t nxm, size_t nym, const Varray<double> &xm,
+                     const Varray<double> &ym);
 
-LonLatPoint remapgrid_get_lonlat(RemapGrid *grid, size_t cell_add);
+LonLatPoint remapgrid_get_lonlat(RemapGrid *grid, size_t index);
 
-void remap_check_area(size_t grid_size, double *cell_area, const char *name);
+void remap_check_area(size_t grid_size, const Varray<double> &cell_area, const char *name);
+
+template <typename T>
+void
+remap_set_mask(size_t gridsize, const Varray<T> &v, T missval, Varray<short> &mask)
+{
+  if (std::isnan(missval))
+    {
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+      for (size_t i = 0; i < gridsize; ++i) mask[i] = !dbl_is_equal(v[i], missval);
+    }
+  else
+    {
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+      for (size_t i = 0; i < gridsize; ++i) mask[i] = !is_equal(v[i], missval);
+    }
+}
+
+inline void
+remap_set_mask(size_t gridsize, const Field &field1, double missval, Varray<short> &imask)
+{
+  if (field1.memType == MemType::Float)
+    remap_set_mask(gridsize, field1.vec_f, (float) missval, imask);
+  else
+    remap_set_mask(gridsize, field1.vec_d, missval, imask);
+}
 
 #endif /* REMAP_H */
