@@ -29,15 +29,13 @@ check_lon_bounds(double offset, double src_lon_min, double src_lon_max, double &
   bound_lon2 += offset;
   if (bound_lon1 < src_lon_min && bound_lon2 > src_lon_min) bound_lon1 = src_lon_min;
   if (bound_lon2 > src_lon_max && bound_lon1 < src_lon_max) bound_lon2 = src_lon_max;
-
 }
 
 static void
 debug_message(const char *txt, long imin, long imax, long jmin, long jmax, const Varray<double> &src_corner_lon)
 {
-  printf("%s:  lonMin=%g lonMax=%g  iMin=%ld iMax=%ld  jMin=%ld jMax %ld  numCells=%ld\n", txt,
-         RAD2DEG * src_corner_lon[imin], RAD2DEG * src_corner_lon[imax + 1],
-         imin, imax, jmin, jmax, (jmax - jmin + 1) * (imax - imin + 1));
+  printf("%s:  lonMin=%g lonMax=%g  iMin=%ld iMax=%ld  jMin=%ld jMax %ld  numCells=%ld\n", txt, RAD2DEG * src_corner_lon[imin],
+         RAD2DEG * src_corner_lon[imax + 1], imin, imax, jmin, jmax, (jmax - jmin + 1) * (imax - imin + 1));
 }
 
 static size_t
@@ -49,8 +47,8 @@ getSrchCellsReg2d(const size_t *src_grid_dims, const Varray<double> &src_corner_
   long ny = src_grid_dims[1];
   size_t numSearchCells = 0;  // num cells in restricted search arrays
 
-  const long nxp1 = nx + 1;
-  const long nyp1 = ny + 1;
+  long nxp1 = nx + 1;
+  long nyp1 = ny + 1;
 
   auto src_lon_min = src_corner_lon[0];
   auto src_lon_max = src_corner_lon[nx];
@@ -65,7 +63,7 @@ getSrchCellsReg2d(const size_t *src_grid_dims, const Varray<double> &src_corner_
 
   auto bound_lon1 = tgt_cell_bound_box[2];
   auto bound_lon2 = tgt_cell_bound_box[3];
-  //debug = (bound_lon1 <= 0 && bound_lon2 >= 0);
+  // debug = (bound_lon1 <= 0 && bound_lon2 >= 0);
 
   if (bound_lon1 <= src_lon_max && bound_lon2 >= src_lon_min)
     {
