@@ -6,10 +6,10 @@
 */
 
 #include <atomic>
-#include <algorithm> // std::sort
+#include <algorithm>  // std::sort
 
 #include "process_int.h"
-#include "cdo_wtime.h"
+#include "cdo_timer.h"
 #include "remap.h"
 #include "remap_store_link.h"
 #include "cdo_options.h"
@@ -82,7 +82,7 @@ cellsearch_free(CellSearch &search)
 static void
 boundbox_from_corners1r(size_t ic, size_t nc, const Varray<double> &cornerLon, const Varray<double> &cornerLat, float *boundBox)
 {
-  const auto inc = ic * nc;
+  auto inc = ic * nc;
 
   float clat = cornerLat[inc];
   float clon = cornerLon[inc];
@@ -144,17 +144,14 @@ cdo_compute_overlap_areas(size_t numSearchCells, CellSearch &search, const GridC
 }
 
 static double
-get_edge_direction(double * ref_corner, double * corner_a, double * corner_b)
+get_edge_direction(double *ref_corner, double *corner_a, double *corner_b)
 {
   double edge_norm[3];
   crossproduct_ld(corner_a, corner_b, edge_norm);
   normalise_vector(edge_norm);
 
   // sine of the angle between the edge and the reference corner
-  double angle =
-    edge_norm[0] * ref_corner[0] +
-    edge_norm[1] * ref_corner[1] +
-    edge_norm[2] * ref_corner[2];
+  double angle = edge_norm[0] * ref_corner[0] + edge_norm[1] * ref_corner[1] + edge_norm[2] * ref_corner[2];
 
   // if the reference corner is directly on the edge
   // (for small angles sin(x)==x)
@@ -166,7 +163,7 @@ get_edge_direction(double * ref_corner, double * corner_a, double * corner_b)
 static void
 cdo_compute_concave_overlap_areas(size_t numSearchCells, CellSearch &search, const GridCell &gridCell)
 {
-  const auto targetCell = gridCell.yacGridCell;
+  auto targetCell = gridCell.yacGridCell;
   auto &overlapAreas = search.partialAreas;
   auto &overlapCells = search.overlapCells;
   auto &sourceCells = search.gridCells;
@@ -198,13 +195,13 @@ cdo_compute_concave_overlap_areas(size_t numSearchCells, CellSearch &search, con
   //  first corner, therefore we can skip them)
   for (size_t cornerIdx = 1; cornerIdx < targetCell.num_corners - 1; ++cornerIdx)
     {
-      const auto cornerA = targetCell.coordinates_xyz[cornerIdx];
-      const auto cornerB = targetCell.coordinates_xyz[(cornerIdx + 1)];
+      auto cornerA = targetCell.coordinates_xyz[cornerIdx];
+      auto cornerB = targetCell.coordinates_xyz[(cornerIdx + 1)];
 
       // if the current edge has a length of zero
       if (points_are_identically(cornerA, cornerB)) continue;
 
-      const auto edgeDirection = get_edge_direction(baseCorner, cornerA, cornerB);
+      auto edgeDirection = get_edge_direction(baseCorner, cornerA, cornerB);
 
       partialCell.coordinates_xyz[1][0] = cornerA[0];
       partialCell.coordinates_xyz[1][1] = cornerA[1];
@@ -236,25 +233,25 @@ cdo_compute_concave_overlap_areas(size_t numSearchCells, CellSearch &search, con
 }
 
 static void
-set_cell_coordinates_yac(RemapGridType remapGridType, const size_t cellIndex, const size_t numCorners, const RemapGrid *remapGrid,
+set_cell_coordinates_yac(RemapGridType remapGridType, size_t cellIndex, size_t numCorners, const RemapGrid *remapGrid,
                          const struct grid_cell &yacGridCell, double *x, double *y)
 {
-  const auto storeXY = (x && y);
+  auto storeXY = (x && y);
   auto xyz = yacGridCell.coordinates_xyz;
 
   if (remapGridType == RemapGridType::Reg2D)
     {
-      const auto nx = remapGrid->dims[0];
-      const auto iy = cellIndex / nx;
-      const auto ix = cellIndex - iy * nx;
-      const auto reg2d_corner_lon = &remapGrid->reg2d_corner_lon[ix];
-      const auto reg2d_corner_lat = &remapGrid->reg2d_corner_lat[iy];
-      static const int xi[4] = { 0, 1, 1, 0 };
-      static const int yi[4] = { 0, 0, 1, 1 };
+      auto nx = remapGrid->dims[0];
+      auto iy = cellIndex / nx;
+      auto ix = cellIndex - iy * nx;
+      auto reg2d_corner_lon = &remapGrid->reg2d_corner_lon[ix];
+      auto reg2d_corner_lat = &remapGrid->reg2d_corner_lat[iy];
+      constexpr int xi[4] = { 0, 1, 1, 0 };
+      constexpr int yi[4] = { 0, 0, 1, 1 };
       for (int k = 0; k < 4; ++k)
         {
-          const auto lon = reg2d_corner_lon[xi[k]];
-          const auto lat = reg2d_corner_lat[yi[k]];
+          auto lon = reg2d_corner_lon[xi[k]];
+          auto lat = reg2d_corner_lat[yi[k]];
           gcLLtoXYZ(lon, lat, xyz[k]);
           if (storeXY)
             {
@@ -265,8 +262,8 @@ set_cell_coordinates_yac(RemapGridType remapGridType, const size_t cellIndex, co
     }
   else
     {
-      const auto cell_corner_lon = &remapGrid->cell_corner_lon[cellIndex * numCorners];
-      const auto cell_corner_lat = &remapGrid->cell_corner_lat[cellIndex * numCorners];
+      auto cell_corner_lon = &remapGrid->cell_corner_lon[cellIndex * numCorners];
+      auto cell_corner_lat = &remapGrid->cell_corner_lat[cellIndex * numCorners];
       for (size_t i = 0; i < numCorners; ++i) gcLLtoXYZ(cell_corner_lon[i], cell_corner_lat[i], xyz[i]);
 
       if (storeXY)
@@ -281,35 +278,34 @@ set_cell_coordinates_yac(RemapGridType remapGridType, const size_t cellIndex, co
 }
 
 static void
-set_cell_coordinates(RemapGridType remapGridType, const size_t cellIndex, const size_t numCorners, const RemapGrid *remapGrid,
+set_cell_coordinates(RemapGridType remapGridType, size_t cellIndex, size_t numCorners, const RemapGrid *remapGrid,
                      const GridCell &gridCell)
 {
-  set_cell_coordinates_yac(remapGridType, cellIndex, numCorners, remapGrid, gridCell.yacGridCell,
-                           gridCell.coordinates_x, gridCell.coordinates_y);
+  set_cell_coordinates_yac(remapGridType, cellIndex, numCorners, remapGrid, gridCell.yacGridCell, gridCell.coordinates_x,
+                           gridCell.coordinates_y);
 }
 
 static void
-set_coordinates_yac(const size_t numCells, RemapGridType remapGridType, const Varray<size_t> &cellIndices,
-                    const size_t numCorners, const RemapGrid *remapGrid, const Varray<grid_cell> &yacGridCell)
+set_coordinates_yac(size_t numCells, RemapGridType remapGridType, const Varray<size_t> &cellIndices, size_t numCorners,
+                    const RemapGrid *remapGrid, const Varray<grid_cell> &yacGridCell)
 {
   for (size_t i = 0; i < numCells; ++i)
     set_cell_coordinates_yac(remapGridType, cellIndices[i], numCorners, remapGrid, yacGridCell[i], nullptr, nullptr);
 }
 
 static void
-set_coordinates_yac(const double (*xyzCoords)[3], const size_t numCells, const Varray<size_t> &cellIndices,
-                    const size_t numCorners, const Varray<grid_cell> &yacGridCell)
+set_coordinates_yac(const double (*xyzCoords)[3], size_t numCells, const Varray<size_t> &cellIndices, size_t numCorners,
+                    const Varray<grid_cell> &yacGridCell)
 {
   for (size_t i = 0; i < numCells; ++i)
     {
-      const auto offset = cellIndices[i] * numCorners;
+      auto offset = cellIndices[i] * numCorners;
       auto xyz = yacGridCell[i].coordinates_xyz;
       for (size_t k = 0; k < numCorners; ++k)
-        for (size_t l = 0; l < 3; ++l)
-          xyz[k][l] = xyzCoords[offset + k][l];
+        for (size_t l = 0; l < 3; ++l) xyz[k][l] = xyzCoords[offset + k][l];
     }
 }
- 
+
 static void
 gridcell_init_yac(GridCell &gridCell, size_t numCorners, enum yac_edge_type *edgeType)
 {
@@ -337,18 +333,15 @@ get_lonlat_circle_index(RemapGridType remapGridType, size_t gridsize, size_t num
 
   if (numCorners == 4)
     {
-      if (remapGridType == RemapGridType::Reg2D)
-        {
-          lonlatCircleIndex = 1;
-        }
+      if (remapGridType == RemapGridType::Reg2D) { lonlatCircleIndex = 1; }
       else
         {
-          const size_t iadd = (gridsize < 100) ? 1 : gridsize / 30 - 1;
+          size_t iadd = (gridsize < 100) ? 1 : gridsize / 30 - 1;
           size_t num_i = 0, num_eq0 = 0, num_eq1 = 0;
 
           for (size_t i = 0; i < gridsize; i += iadd)
             {
-              const auto i4 = i * 4;
+              auto i4 = i * 4;
               num_i++;
               // clang-format off
               if (is_equal(clon[i4 + 1], clon[i4 + 2]) && is_equal(clon[i4 + 3], clon[i4 + 0]) &&
@@ -377,8 +370,8 @@ get_lonlat_circle_index(RemapGridType remapGridType, size_t gridsize, size_t num
 static int
 get_lonlat_circle_index(RemapGrid *remapGrid)
 {
-  const auto gridsize = remapGrid->size;
-  const auto numCorners = remapGrid->num_cell_corners;
+  auto gridsize = remapGrid->size;
+  auto numCorners = remapGrid->num_cell_corners;
   const auto &clon = remapGrid->cell_corner_lon;
   const auto &clat = remapGrid->cell_corner_lat;
   return get_lonlat_circle_index(remapGrid->type, gridsize, numCorners, clon, clat);
@@ -388,7 +381,7 @@ static void
 normalize_weights(RemapGrid *tgtGrid, RemapVars &rv)
 {
   // Include centroids in weights and normalize using target cell area if requested
-  auto num_links = rv.num_links;
+  auto numLinks = rv.numLinks;
   auto num_wts = rv.num_wts;
 
   if (rv.normOpt == NormOpt::DESTAREA)
@@ -397,11 +390,11 @@ normalize_weights(RemapGrid *tgtGrid, RemapVars &rv)
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-      for (size_t n = 0; n < num_links; ++n)
+      for (size_t i = 0; i < numLinks; ++i)
         {
-          const auto i = rv.tgtCellIndices[n];  // current linear address for target grid cell
-          const auto normFactor = is_not_equal(cellArea[i], 0.0) ? 1.0 / cellArea[i] : 0.0;
-          rv.wts[n * num_wts] *= normFactor;
+          auto index = rv.tgtCellIndices[i];  // current linear address for target grid cell
+          auto normFactor = is_not_equal(cellArea[index], 0.0) ? 1.0 / cellArea[index] : 0.0;
+          rv.wts[i * num_wts] *= normFactor;
         }
     }
   else if (rv.normOpt == NormOpt::FRACAREA)
@@ -410,11 +403,11 @@ normalize_weights(RemapGrid *tgtGrid, RemapVars &rv)
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-      for (size_t n = 0; n < num_links; ++n)
+      for (size_t i = 0; i < numLinks; ++i)
         {
-          const auto i = rv.tgtCellIndices[n];  // current linear address for target grid cell
-          const auto normFactor = is_not_equal(cellFrac[i], 0.0) ? 1.0 / cellFrac[i] : 0.0;
-          rv.wts[n * num_wts] *= normFactor;
+          auto index = rv.tgtCellIndices[i];  // current linear address for target grid cell
+          auto normFactor = is_not_equal(cellFrac[index], 0.0) ? 1.0 / cellFrac[index] : 0.0;
+          rv.wts[i * num_wts] *= normFactor;
         }
     }
   else if (rv.normOpt == NormOpt::NONE)
@@ -427,12 +420,12 @@ normalize_weights(NormOpt normOpt, double cellArea, double cellFrac, size_t numW
 {
   if (normOpt == NormOpt::DESTAREA)
     {
-      const auto normFactor = is_not_equal(cellArea, 0.0) ? 1.0 / cellArea : 0.0;
+      auto normFactor = is_not_equal(cellArea, 0.0) ? 1.0 / cellArea : 0.0;
       for (size_t i = 0; i < numWeights; ++i) weights[i] *= normFactor;
     }
   else if (normOpt == NormOpt::FRACAREA)
     {
-      const auto normFactor = is_not_equal(cellFrac, 0.0) ? 1.0 / cellFrac : 0.0;
+      auto normFactor = is_not_equal(cellFrac, 0.0) ? 1.0 / cellFrac : 0.0;
       for (size_t i = 0; i < numWeights; ++i) weights[i] *= normFactor;
     }
   else if (normOpt == NormOpt::NONE)
@@ -449,12 +442,9 @@ correct_weights(double cellArea, size_t numWeights, Varray<double> &weights)
 }
 
 static void
-sort_weights(size_t numWeights, Varray<size_t> &searchIndices, Varray<double> &weights)
+sort_weights(size_t numWeights, Varray<size_t> &indices, Varray<double> &weights)
 {
-  size_t n;
-  for (n = 1; n < numWeights; ++n)
-    if (searchIndices[n] < searchIndices[n - 1]) break;
-  if (n == numWeights) return;
+  if (is_sorted_list(numWeights, indices.data())) return;
 
   if (numWeights > 1)
     {
@@ -466,19 +456,19 @@ sort_weights(size_t numWeights, Varray<size_t> &searchIndices, Varray<double> &w
 
       Varray<IndexWeightX> indexWeights(numWeights);
 
-      for (n = 0; n < numWeights; ++n)
+      for (size_t i = 0; i < numWeights; ++i)
         {
-          indexWeights[n].index = searchIndices[n];
-          indexWeights[n].weight = weights[n];
+          indexWeights[i].index = indices[i];
+          indexWeights[i].weight = weights[i];
         }
 
-      const auto compareIndex = [](const auto &a, const auto &b) noexcept { return a.index < b.index; };
+      auto compareIndex = [](const auto &a, const auto &b) noexcept { return a.index < b.index; };
       std::sort(indexWeights.begin(), indexWeights.end(), compareIndex);
 
-      for (n = 0; n < numWeights; ++n)
+      for (size_t i = 0; i < numWeights; ++i)
         {
-          searchIndices[n] = indexWeights[n].index;
-          weights[n] = indexWeights[n].weight;
+          indices[i] = indexWeights[i].index;
+          weights[i] = indexWeights[i].weight;
         }
     }
 }
@@ -486,8 +476,8 @@ sort_weights(size_t numWeights, Varray<size_t> &searchIndices, Varray<double> &w
 static void
 reg2d_bound_box(RemapGrid *remapGrid, double *gridBoundBox)
 {
-  const auto nx = remapGrid->dims[0];
-  const auto ny = remapGrid->dims[1];
+  auto nx = remapGrid->dims[0];
+  auto ny = remapGrid->dims[1];
   const auto &reg2d_corner_lon = remapGrid->reg2d_corner_lon;
   const auto &reg2d_corner_lat = remapGrid->reg2d_corner_lat;
 
@@ -511,23 +501,23 @@ scale_cellfrac(size_t numCells, Varray<double> &cellFrac, const Varray<double> &
 }
 
 static void
-vec_add_weights(Varray<double> &vec, size_t numWeights, const Varray<double> &weights, const Varray<size_t> &searchIndices)
+vec_add_weights(Varray<double> &vec, size_t numWeights, const Varray<double> &weights, const Varray<size_t> &indices)
 {
   for (size_t i = 0; i < numWeights; ++i)
     {
-      const auto weight = weights[i];
-      const auto cellIndex = searchIndices[i];
+      auto weight = weights[i];
+      auto index = indices[i];
 #ifndef __PGI
 #ifdef _OPENMP
 #pragma omp atomic
 #endif
-      vec[cellIndex] += weight;
+      vec[index] += weight;
 #endif
     }
 }
 
 static size_t
-remove_invalid_areas(size_t numSearchCells, Varray<double> &areas, Varray<size_t> &searchIndices)
+remove_invalid_areas(size_t numSearchCells, Varray<double> &areas, Varray<size_t> &indices)
 {
   size_t n = 0;
   for (size_t i = 0; i < numSearchCells; ++i)
@@ -535,7 +525,7 @@ remove_invalid_areas(size_t numSearchCells, Varray<double> &areas, Varray<size_t
       if (areas[i] > 0.0)
         {
           areas[n] = areas[i];
-          searchIndices[n] = searchIndices[i];
+          indices[n] = indices[i];
           n++;
         }
     }
@@ -544,16 +534,16 @@ remove_invalid_areas(size_t numSearchCells, Varray<double> &areas, Varray<size_t
 }
 
 static size_t
-remove_invalid_weights(size_t gridSize, size_t numWeights, Varray<double> &weights, Varray<size_t> &searchIndices)
+remove_invalid_weights(size_t gridSize, size_t numWeights, Varray<double> &weights, Varray<size_t> &indices)
 {
   size_t n = 0;
   for (size_t i = 0; i < numWeights; ++i)
     {
-      const auto cellIndex = (weights[i] > 0.0) ? searchIndices[i] : gridSize;
-      if (cellIndex != gridSize)
+      auto index = (weights[i] > 0.0) ? indices[i] : gridSize;
+      if (index != gridSize)
         {
           weights[n] = weights[i];
-          searchIndices[n] = cellIndex;
+          indices[n] = index;
           n++;
         }
     }
@@ -562,22 +552,21 @@ remove_invalid_weights(size_t gridSize, size_t numWeights, Varray<double> &weigh
 }
 
 static size_t
-remove_unmask_weights(const Varray<short> &gridMask, size_t numWeights, Varray<double> &weights,
-                      Varray<size_t> &searchIndices)
+remove_unmask_weights(const Varray<short> &gridMask, size_t numWeights, Varray<double> &weights, Varray<size_t> &indices)
 {
   size_t n = 0;
   for (size_t i = 0; i < numWeights; ++i)
     {
-      const auto cellIndex = searchIndices[i];
+      auto index = indices[i];
       /*
         Store the appropriate addresses and weights.
         Also add contributions to cell areas.
         The source grid mask is the master mask.
       */
-      if (gridMask[cellIndex])
+      if (gridMask[index])
         {
           weights[n] = weights[i];
-          searchIndices[n] = cellIndex;
+          indices[n] = index;
           n++;
         }
     }
@@ -600,7 +589,7 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
 
   progress::init();
 
-  const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  cdo::timer timer;
 
   auto srcGridSize = srcGrid->size;
   auto tgtGridSize = tgtGrid->size;
@@ -618,13 +607,13 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
 
   if (srcNumCorners == 4)
     {
-      const auto lonlatCircleIndex = get_lonlat_circle_index(srcGrid);
+      auto lonlatCircleIndex = get_lonlat_circle_index(srcGrid);
       if (lonlatCircleIndex >= 0) srcEdgeType = &lonlatCircleType[lonlatCircleIndex];
     }
 
   if (tgtNumCorners == 4)
     {
-      const auto lonlatCircleIndex = get_lonlat_circle_index(tgtGrid);
+      auto lonlatCircleIndex = get_lonlat_circle_index(tgtGrid);
       if (lonlatCircleIndex >= 0)
         {
           tgtCellType = LON_LAT_CELL;
@@ -649,15 +638,16 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
 
   std::vector<WeightLinks> weightLinks(tgtGridSize);
 
-  std::atomic<size_t> atomicCount{0};
+  std::atomic<size_t> atomicCount{ 0 };
 
   size_t numSearchCellsStat[3] = { 0, 100000, 0 };
 
   extern CellSearchMethod cellSearchMethod;
   auto useCellsearch = (cellSearchMethod == CellSearchMethod::spherepart || srcGridType == RemapGridType::Reg2D);
 
-  Varray<Varray<size_t>> searchIndices2(Threading::ompNumThreads);
-  if (!useCellsearch) for (int i = 0; i < Threading::ompNumThreads; ++i) searchIndices2[i].resize(srcGridSize);
+  Varray<Varray<size_t>> indices2(Threading::ompNumThreads);
+  if (!useCellsearch)
+    for (int i = 0; i < Threading::ompNumThreads; ++i) indices2[i].resize(srcGridSize);
 
   // Loop over target grid
 
@@ -666,13 +656,13 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
 #endif
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
-      const auto ompthID = cdo_omp_get_thread_num();
+      auto ompthID = cdo_omp_get_thread_num();
       auto &cellSearch = cellSearch2[ompthID];
-      auto &searchIndices = searchIndices2[ompthID];
+      auto &indices = indices2[ompthID];
       auto &tgtGridCell = tgtGridCell2[ompthID];
 
       atomicCount++;
-      if (ompthID == 0) progress::update(0, 1, (double)atomicCount / tgtGridSize);
+      if (ompthID == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
 
       weightLinks[tgtCellIndex].nlinks = 0;
 
@@ -684,8 +674,8 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
       size_t numSearchCells;
       if (useCellsearch)
         {
-          // numSearchCells = remap_search_cells(remapSearch, tgtCellType == LON_LAT_CELL, tgtGridCell, searchIndices);
-          numSearchCells = remap_search_cells(remapSearch, tgtGridType == RemapGridType::Reg2D, tgtGridCell, searchIndices);
+          // numSearchCells = remap_search_cells(remapSearch, tgtCellType == LON_LAT_CELL, tgtGridCell, indices);
+          numSearchCells = remap_search_cells(remapSearch, tgtGridType == RemapGridType::Reg2D, tgtGridCell, indices);
         }
       else
         {
@@ -693,8 +683,7 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
           boundbox_from_corners1r(tgtCellIndex, tgtNumCorners, tgtGrid->cell_corner_lon, tgtGrid->cell_corner_lat,
                                   tgtCellBoundBoxR);
 
-          numSearchCells
-              = get_srch_cells(tgtCellIndex, remapSearch.tgtBins, remapSearch.srcBins, tgtCellBoundBoxR, searchIndices);
+          numSearchCells = get_srch_cells(tgtCellIndex, remapSearch.tgtBins, remapSearch.srcBins, tgtCellBoundBoxR, indices);
         }
 
       if (1 && Options::cdoVerbose)
@@ -713,9 +702,9 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
       cellsearch_realloc(numSearchCells, cellSearch);
 
       if (remapSearch.gcs.xyzCoords)
-        set_coordinates_yac(remapSearch.gcs.xyzCoords, numSearchCells, searchIndices, numCellCorners, cellSearch.gridCells);
+        set_coordinates_yac(remapSearch.gcs.xyzCoords, numSearchCells, indices, numCellCorners, cellSearch.gridCells);
       else
-        set_coordinates_yac(numSearchCells, srcGridType, searchIndices, numCellCorners, srcGrid, cellSearch.gridCells);
+        set_coordinates_yac(numSearchCells, srcGridType, indices, numCellCorners, srcGrid, cellSearch.gridCells);
 
       if (tgtNumCorners < 4 || tgtCellType == LON_LAT_CELL)
         cdo_compute_overlap_areas(numSearchCells, cellSearch, tgtGridCell);
@@ -724,24 +713,24 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
 
       auto &partialWeights = cellSearch.partialAreas;
 
-      auto numWeights = remove_invalid_areas(numSearchCells, partialWeights, searchIndices);
+      auto numWeights = remove_invalid_areas(numSearchCells, partialWeights, indices);
 
-      const auto tgtCellArea = gridcell_area(tgtGridCell.yacGridCell);
+      auto tgtCellArea = gridcell_area(tgtGridCell.yacGridCell);
       tgtGrid->cell_area[tgtCellIndex] = tgtCellArea;
 
       if (rv.normOpt == NormOpt::FRACAREA) correct_weights(tgtCellArea, numWeights, partialWeights);
 
-      numWeights = remove_invalid_weights(srcGridSize, numWeights, partialWeights, searchIndices);
+      numWeights = remove_invalid_weights(srcGridSize, numWeights, partialWeights, indices);
 
-      vec_add_weights(srcGrid->cell_area, numWeights, partialWeights, searchIndices);
+      vec_add_weights(srcGrid->cell_area, numWeights, partialWeights, indices);
 
-      numWeights = remove_unmask_weights(srcGrid->mask, numWeights, partialWeights, searchIndices);
+      numWeights = remove_unmask_weights(srcGrid->mask, numWeights, partialWeights, indices);
 
-      vec_add_weights(srcGrid->cell_frac, numWeights, partialWeights, searchIndices);
+      vec_add_weights(srcGrid->cell_frac, numWeights, partialWeights, indices);
 
       tgtGrid->cell_frac[tgtCellIndex] = varray_sum(numWeights, partialWeights);
 
-      store_weightlinks(1, numWeights, searchIndices.data(), partialWeights.data(), tgtCellIndex, weightLinks);
+      store_weightlinks(1, numWeights, indices.data(), partialWeights.data(), tgtCellIndex, weightLinks);
     }
 
   progress::update(0, 1, 1);
@@ -764,7 +753,7 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
   // Normalize weights using target cell area if requested
   normalize_weights(tgtGrid, rv);
 
-  if (Options::cdoVerbose) cdo_print("Total number of links = %zu", rv.num_links);
+  if (Options::cdoVerbose) cdo_print("Total number of links = %zu", rv.numLinks);
 
   scale_cellfrac(srcGridSize, srcGrid->cell_frac, srcGrid->cell_area);
   scale_cellfrac(tgtGridSize, tgtGrid->cell_frac, tgtGrid->cell_area);
@@ -772,13 +761,13 @@ remap_conserv_weights(RemapSearch &remapSearch, RemapVars &rv)
   // Perform some error checking on final weights
   if (doCheck)
     {
-      remap_check_area(srcGridSize, &srcGrid->cell_area[0], "Source");
-      remap_check_area(tgtGridSize, &tgtGrid->cell_area[0], "Target");
+      remap_check_area(srcGridSize, srcGrid->cell_area, "Source");
+      remap_check_area(tgtGridSize, tgtGrid->cell_area, "Target");
 
       remap_vars_check_weights(rv);
     }
 
-  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", timer.elapsed());
 }  // remap_conserv_weights
 
 template <typename T>
@@ -793,7 +782,7 @@ conserv_remap(const Varray<T> &srcArray, size_t numWeights, const Varray<double>
 
 template <typename T>
 static void
-remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArray, Varray<T> &tgtArray, T missval)
+remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArray, Varray<T> &tgtArray, T missval, size_t nmiss)
 {
   auto srcGrid = remapSearch.srcGrid;
   auto tgtGrid = remapSearch.tgtGrid;
@@ -808,16 +797,17 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
 
   progress::init();
 
-  const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  cdo::timer timer;
 
   auto srcGridSize = srcGrid->size;
   auto tgtGridSize = tgtGrid->size;
 
-  Varray<short> srcGridMask(srcGridSize);
-#ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
-#endif
-  for (size_t i = 0; i < srcGridSize; ++i) srcGridMask[i] = !dbl_is_equal(srcArray[i], missval);
+  Varray<short> srcGridMask;
+  if (nmiss)
+    {
+      srcGridMask.resize(srcGridSize, 1);
+      remap_set_mask(srcGridSize, srcArray, missval, srcGridMask);
+    }
 
   auto srcNumCorners = srcGrid->num_cell_corners;
   auto tgtNumCorners = tgtGrid->num_cell_corners;
@@ -832,13 +822,13 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
 
   if (srcNumCorners == 4)
     {
-      const auto lonlatCircleIndex = get_lonlat_circle_index(srcGrid);
+      auto lonlatCircleIndex = get_lonlat_circle_index(srcGrid);
       if (lonlatCircleIndex >= 0) srcEdgeType = &lonlatCircleType[lonlatCircleIndex];
     }
 
   if (tgtNumCorners == 4)
     {
-      const auto lonlatCircleIndex = get_lonlat_circle_index(tgtGrid);
+      auto lonlatCircleIndex = get_lonlat_circle_index(tgtGrid);
       if (lonlatCircleIndex >= 0)
         {
           tgtCellType = LON_LAT_CELL;
@@ -861,30 +851,31 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
   // double srcGridBoundBox[4];
   // if (srcGridType == RemapGridType::Reg2D) reg2d_bound_box(srcGrid, srcGridBoundBox);
 
-  std::atomic<size_t> atomicCount{0};
+  std::atomic<size_t> atomicCount{ 0 };
 
   size_t numSearchCellsStat[3] = { 0, 100000, 0 };
 
   extern CellSearchMethod cellSearchMethod;
   auto useCellsearch = (cellSearchMethod == CellSearchMethod::spherepart || srcGridType == RemapGridType::Reg2D);
 
-  Varray<Varray<size_t>> searchIndices2(Threading::ompNumThreads);
-  if (!useCellsearch) for (int i = 0; i < Threading::ompNumThreads; ++i) searchIndices2[i].resize(srcGridSize);
+  Varray<Varray<size_t>> indices2(Threading::ompNumThreads);
+  if (!useCellsearch)
+    for (int i = 0; i < Threading::ompNumThreads; ++i) indices2[i].resize(srcGridSize);
 
-  // Loop over target grid
+      // Loop over target grid
 
 #ifdef _OPENMP
 #pragma omp parallel for schedule(dynamic) default(shared)
 #endif
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
-      const auto ompthID = cdo_omp_get_thread_num();
+      auto ompthID = cdo_omp_get_thread_num();
       auto &cellSearch = cellSearch2[ompthID];
-      auto &searchIndices = searchIndices2[ompthID];
+      auto &indices = indices2[ompthID];
       auto &tgtGridCell = tgtGridCell2[ompthID];
 
       atomicCount++;
-      if (ompthID == 0) progress::update(0, 1, (double)atomicCount / tgtGridSize);
+      if (ompthID == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
 
       tgtArray[tgtCellIndex] = missval;
 
@@ -896,8 +887,8 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
       size_t numSearchCells;
       if (useCellsearch)
         {
-          // numSearchCells = remap_search_cells(remapSearch, tgtCellType == LON_LAT_CELL, tgtGridCell, searchIndices);
-          numSearchCells = remap_search_cells(remapSearch, tgtGridType == RemapGridType::Reg2D, tgtGridCell, searchIndices);
+          // numSearchCells = remap_search_cells(remapSearch, tgtCellType == LON_LAT_CELL, tgtGridCell, indices);
+          numSearchCells = remap_search_cells(remapSearch, tgtGridType == RemapGridType::Reg2D, tgtGridCell, indices);
         }
       else
         {
@@ -905,8 +896,7 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
           boundbox_from_corners1r(tgtCellIndex, tgtNumCorners, tgtGrid->cell_corner_lon, tgtGrid->cell_corner_lat,
                                   tgtCellBoundBoxR);
 
-          numSearchCells
-              = get_srch_cells(tgtCellIndex, remapSearch.tgtBins, remapSearch.srcBins, tgtCellBoundBoxR, searchIndices);
+          numSearchCells = get_srch_cells(tgtCellIndex, remapSearch.tgtBins, remapSearch.srcBins, tgtCellBoundBoxR, indices);
         }
 
       if (1 && Options::cdoVerbose)
@@ -925,9 +915,9 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
       cellsearch_realloc(numSearchCells, cellSearch);
 
       if (remapSearch.gcs.xyzCoords)
-        set_coordinates_yac(remapSearch.gcs.xyzCoords, numSearchCells, searchIndices, numCellCorners, cellSearch.gridCells);
+        set_coordinates_yac(remapSearch.gcs.xyzCoords, numSearchCells, indices, numCellCorners, cellSearch.gridCells);
       else
-        set_coordinates_yac(numSearchCells, srcGridType, searchIndices, numCellCorners, srcGrid, cellSearch.gridCells);
+        set_coordinates_yac(numSearchCells, srcGridType, indices, numCellCorners, srcGrid, cellSearch.gridCells);
 
       if (tgtNumCorners < 4 || tgtCellType == LON_LAT_CELL)
         cdo_compute_overlap_areas(numSearchCells, cellSearch, tgtGridCell);
@@ -936,24 +926,24 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
 
       auto &partialWeights = cellSearch.partialAreas;
 
-      auto numWeights = remove_invalid_areas(numSearchCells, partialWeights, searchIndices);
+      auto numWeights = remove_invalid_areas(numSearchCells, partialWeights, indices);
 
-      const auto tgtCellArea = gridcell_area(tgtGridCell.yacGridCell);
+      auto tgtCellArea = gridcell_area(tgtGridCell.yacGridCell);
       tgtGrid->cell_area[tgtCellIndex] = tgtCellArea;
 
       if (normOpt == NormOpt::FRACAREA) correct_weights(tgtCellArea, numWeights, partialWeights);
 
-      numWeights = remove_invalid_weights(srcGridSize, numWeights, partialWeights, searchIndices);
-      numWeights = remove_unmask_weights(srcGridMask, numWeights, partialWeights, searchIndices);
+      numWeights = remove_invalid_weights(srcGridSize, numWeights, partialWeights, indices);
+      if (srcGridMask.size() > 0) numWeights = remove_unmask_weights(srcGridMask, numWeights, partialWeights, indices);
 
       tgtGrid->cell_frac[tgtCellIndex] = varray_sum(numWeights, partialWeights);
 
       if (numWeights)
         {
-          sort_weights(numWeights, searchIndices, partialWeights);
+          sort_weights(numWeights, indices, partialWeights);
           // Normalize weights using cell target area if requested
           normalize_weights(normOpt, tgtCellArea, tgtGrid->cell_frac[tgtCellIndex], numWeights, partialWeights);
-          tgtArray[tgtCellIndex] = conserv_remap(srcArray, numWeights, partialWeights, searchIndices);
+          tgtArray[tgtCellIndex] = conserv_remap(srcArray, numWeights, partialWeights, indices);
         }
     }
 
@@ -976,9 +966,9 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Varray<T> &srcArr
   scale_cellfrac(tgtGridSize, tgtGrid->cell_frac, tgtGrid->cell_area);
 
   // Perform some error checking on final weights
-  if (doCheck) remap_check_area(tgtGridSize, &tgtGrid->cell_area[0], "Target");
+  if (doCheck) remap_check_area(tgtGridSize, tgtGrid->cell_area, "Target");
 
-  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", timer.elapsed());
 }  // remap_conserv
 
 void
@@ -987,24 +977,24 @@ remap_conserv(NormOpt normOpt, RemapSearch &remapSearch, const Field &field1, Fi
   if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
 
   if (field1.memType == MemType::Float)
-    remap_conserv(normOpt, remapSearch, field1.vec_f, field2.vec_f, (float) field1.missval);
+    remap_conserv(normOpt, remapSearch, field1.vec_f, field2.vec_f, (float) field1.missval, field1.nmiss);
   else
-    remap_conserv(normOpt, remapSearch, field1.vec_d, field2.vec_d, field1.missval);
+    remap_conserv(normOpt, remapSearch, field1.vec_d, field2.vec_d, field1.missval, field1.nmiss);
 }
 
 template <typename T>
 static size_t
 remove_missing_weights(const Varray<T> &srcArray, T missval, size_t numWeights, Varray<double> &partialWeights,
-                       Varray<size_t> &searchIndices)
+                       Varray<size_t> &indices)
 {
   size_t n = 0;
   for (size_t i = 0; i < numWeights; ++i)
     {
-      const auto cellIndex = searchIndices[i];
+      auto cellIndex = indices[i];
       if (!dbl_is_equal(srcArray[cellIndex], missval))
         {
           partialWeights[n] = partialWeights[i];
-          searchIndices[n] = cellIndex;
+          indices[n] = cellIndex;
           n++;
         }
     }
@@ -1025,7 +1015,7 @@ latitude_area(double latMin, double latMax)
 }
 
 void
-remap_weights_zonal_mean(const int gridID1, const int gridID2, Varray2D<size_t> &remapIndices, Varray2D<double> &remapWeights)
+remap_weights_zonal_mean(int gridID1, int gridID2, Varray2D<size_t> &remapIndices, Varray2D<double> &remapWeights)
 {
   constexpr double scaleFactor = 1000000000.0;
   auto gridsize1 = gridInqSize(gridID1);
@@ -1038,7 +1028,7 @@ remap_weights_zonal_mean(const int gridID1, const int gridID2, Varray2D<size_t>
   cdo_grid_to_radian(gridID1, CDI_XAXIS, gridsize1 * nv1, xbounds1.data(), "source grid longitude bounds");
   cdo_grid_to_radian(gridID1, CDI_YAXIS, gridsize1 * nv1, ybounds1.data(), "source grid latitude bounds");
 
-  Varray<int> yminmax1(gridsize1 * 2);
+  Varray<int> ymin1(gridsize1), ymax1(gridsize1);
 
 #ifdef _OPENMP
 #pragma omp parallel for schedule(static) default(shared)
@@ -1049,12 +1039,12 @@ remap_weights_zonal_mean(const int gridID1, const int gridID2, Varray2D<size_t>
       auto maxval = ybounds1[i * nv1];
       for (size_t k = 1; k < nv1; ++k)
         {
-          const auto val = ybounds1[i * nv1 + k];
-          if (val > maxval) maxval = val;
-          if (val < minval) minval = val;
+          auto val = ybounds1[i * nv1 + k];
+          maxval = std::max(maxval, val);
+          minval = std::min(minval, val);
         }
-      yminmax1[i * 2] = scaleFactor * minval;
-      yminmax1[i * 2 + 1] = scaleFactor * maxval;
+      ymin1[i] = scaleFactor * minval;
+      ymax1[i] = scaleFactor * maxval;
     }
 
   auto ysize2 = gridInqYsize(gridID2);
@@ -1072,21 +1062,20 @@ remap_weights_zonal_mean(const int gridID1, const int gridID2, Varray2D<size_t>
 #endif
   for (size_t i2 = 0; i2 < ysize2; ++i2)
     {
-      int latBounds[2]
-          = { static_cast<int>(scaleFactor * ybounds2[2 * i2]), static_cast<int>(scaleFactor * ybounds2[2 * i2 + 1]) };
+      int latBounds[2] = { static_cast<int>(scaleFactor * ybounds2[2 * i2]), static_cast<int>(scaleFactor * ybounds2[2 * i2 + 1]) };
       if (latBounds[0] > latBounds[1]) std::swap(latBounds[0], latBounds[1]);
 
       size_t numSearchCells = 0;
       for (size_t i1 = 0; i1 < gridsize1; ++i1)
         {
-          if (yminmax1[i1 * 2] < latBounds[1] && yminmax1[i1 * 2 + 1] > latBounds[0]) numSearchCells++;
+          if (ymin1[i1] < latBounds[1] && ymax1[i1] > latBounds[0]) numSearchCells++;
         }
 
       remapIndices[i2].resize(numSearchCells);
       size_t n = 0;
       for (size_t i1 = 0; i1 < gridsize1; ++i1)
         {
-          if (yminmax1[i1 * 2] < latBounds[1] && yminmax1[i1 * 2 + 1] > latBounds[0]) remapIndices[i2][n++] = i1;
+          if (ymin1[i1] < latBounds[1] && ymax1[i1] > latBounds[0]) remapIndices[i2][n++] = i1;
         }
 
       // printf("lat %zu found %zu of %zu\n", i2 + 1, numSearchCells, gridsize1);
@@ -1099,7 +1088,7 @@ remap_weights_zonal_mean(const int gridID1, const int gridID2, Varray2D<size_t>
 
   if (nv1 == 4)
     {
-      const auto lonlatCircleIndex = get_lonlat_circle_index(RemapGridType::Undefined, gridsize1, nv1, xbounds1, ybounds1);
+      auto lonlatCircleIndex = get_lonlat_circle_index(RemapGridType::Undefined, gridsize1, nv1, xbounds1, ybounds1);
       if (lonlatCircleIndex >= 0) srcEdgeType = &lonlatCircleType[lonlatCircleIndex];
     }
 
@@ -1108,14 +1097,14 @@ remap_weights_zonal_mean(const int gridID1, const int gridID2, Varray2D<size_t>
 #endif
   for (size_t i2 = 0; i2 < ysize2; ++i2)
     {
-      const auto normOpt(NormOpt::FRACAREA);
+      auto normOpt(NormOpt::FRACAREA);
       double latBounds[2] = { ybounds2[2 * i2], ybounds2[2 * i2 + 1] };
       if (latBounds[0] > latBounds[1]) std::swap(latBounds[0], latBounds[1]);
 
-      const auto tgtCellArea = latitude_area(latBounds[0], latBounds[1]);
+      auto tgtCellArea = latitude_area(latBounds[0], latBounds[1]);
       // printf("tgtCellArea %zu %g\n", i2 + 1, tgtCellArea);
 
-      const auto numSearchCells = remapIndices[i2].size();
+      auto numSearchCells = remapIndices[i2].size();
 
       CellSearch search;
       search.numCellCorners = nv1;
@@ -1125,10 +1114,10 @@ remap_weights_zonal_mean(const int gridID1, const int gridID2, Varray2D<size_t>
 
       for (size_t j = 0; j < numSearchCells; ++j)
         {
-          const auto cellIndex = remapIndices[i2][j];
+          auto cellIndex = remapIndices[i2][j];
           auto xyz = search.gridCells[j].coordinates_xyz;
-          const auto cell_corner_lon = &xbounds1[cellIndex * nv1];
-          const auto cell_corner_lat = &ybounds1[cellIndex * nv1];
+          auto cell_corner_lon = &xbounds1[cellIndex * nv1];
+          auto cell_corner_lat = &ybounds1[cellIndex * nv1];
           for (size_t i = 0; i < nv1; ++i) gcLLtoXYZ(cell_corner_lon[i], cell_corner_lat[i], xyz[i]);
         }
 
@@ -1168,24 +1157,24 @@ remap_zonal_mean(const Varray2D<size_t> &remapIndices, const Varray2D<double> &r
   for (size_t i2 = 0; i2 < ysize2; ++i2)
     {
       auto numWeights = remapWeights[i2].size();
-      Varray<size_t> searchIndices(numWeights);
-      for (size_t i = 0; i < numWeights; ++i) searchIndices[i] = remapIndices[i2][i];
+      Varray<size_t> indices(numWeights);
+      for (size_t i = 0; i < numWeights; ++i) indices[i] = remapIndices[i2][i];
       Varray<double> partialWeights(numWeights);
       for (size_t i = 0; i < numWeights; ++i) partialWeights[i] = remapWeights[i2][i];
 
-      numWeights = remove_missing_weights(srcArray, missval, numWeights, partialWeights, searchIndices);
+      numWeights = remove_missing_weights(srcArray, missval, numWeights, partialWeights, indices);
 
       tgtArray[i2] = missval;
 
       if (numWeights)
         {
-          const auto normOpt(NormOpt::FRACAREA);
-          const auto tgtCellArea = 0.0;  // not needed for NormOpt::FRACAREA
-          const auto tgtCellFrac = varray_sum(numWeights, partialWeights);
-          sort_weights(numWeights, searchIndices, partialWeights);
+          auto normOpt(NormOpt::FRACAREA);
+          auto tgtCellArea = 0.0;  // not needed for NormOpt::FRACAREA
+          auto tgtCellFrac = varray_sum(numWeights, partialWeights);
+          sort_weights(numWeights, indices, partialWeights);
           // Normalize weights using cell target area if requested
           normalize_weights(normOpt, tgtCellArea, tgtCellFrac, numWeights, partialWeights);
-          tgtArray[i2] = conserv_remap(srcArray, numWeights, partialWeights, searchIndices);
+          tgtArray[i2] = conserv_remap(srcArray, numWeights, partialWeights, indices);
         }
     }
 
