@@ -6,7 +6,7 @@
 */
 
 #include "process_int.h"
-#include "cdo_wtime.h"
+#include "cdo_timer.h"
 #include "remap.h"
 #include "remap_store_link_cnsrv.h"
 #include "cdo_options.h"
@@ -1122,7 +1122,7 @@ static void
 normalize_weights(RemapGrid *tgtGrid, RemapVars &rv, std::vector<double> &src_centroid_lat, std::vector<double> &src_centroid_lon)
 {
   /* Include centroids in weights and normalize using destination area if requested */
-  long num_links = rv.num_links;
+  long numLinks = rv.numLinks;
   // srcCellIndex: current linear address for source grid cell
   // tgtCellIndex: current linear address for target grid cell
   double *weights = &rv.wts[0];
@@ -1130,9 +1130,9 @@ normalize_weights(RemapGrid *tgtGrid, RemapVars &rv, std::vector<double> &src_ce
   if (rv.normOpt == NormOpt::DESTAREA)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(num_links, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
+#pragma omp parallel for default(none) shared(numLinks, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
 #endif
-      for (long n = 0; n < num_links; ++n)
+      for (long n = 0; n < numLinks; ++n)
         {
           const auto src_add = rv.srcCellIndices[n];
           const auto tgt_add = rv.tgtCellIndices[n];
@@ -1144,9 +1144,9 @@ normalize_weights(RemapGrid *tgtGrid, RemapVars &rv, std::vector<double> &src_ce
   else if (rv.normOpt == NormOpt::FRACAREA)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(num_links, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
+#pragma omp parallel for default(none) shared(numLinks, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
 #endif
-      for (long n = 0; n < num_links; ++n)
+      for (long n = 0; n < numLinks; ++n)
         {
           const auto src_add = rv.srcCellIndices[n];
           const auto tgt_add = rv.tgtCellIndices[n];
@@ -1162,9 +1162,9 @@ normalize_weights(RemapGrid *tgtGrid, RemapVars &rv, std::vector<double> &src_ce
   else if (rv.normOpt == NormOpt::NONE)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(num_links, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
+#pragma omp parallel for default(none) shared(numLinks, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
 #endif
-      for (long n = 0; n < num_links; ++n)
+      for (long n = 0; n < numLinks; ++n)
         {
           const auto src_add = rv.srcCellIndices[n];
           const auto norm_factor = ONE;
@@ -1187,12 +1187,12 @@ srvout(const char *fname, int nlon, int nlat, double *data)
   ihead[6] = 0;
   ihead[7] = 0;
 
-  FILE *fp = fopen(fname, "w");
+  FILE *fp = std::fopen(fname, "w");
   fprintf(fp, "%d %d %d %d %d %d %d %d\n", ihead[0], ihead[1], ihead[2], ihead[3], ihead[4], ihead[5], ihead[6], ihead[7]);
 
   for (int i = 0; i < nlon * nlat; ++i) fprintf(fp, "%g\n", data[i]);
 
-  fclose(fp);
+  std::fclose(fp);
 }
 
 /*
@@ -1234,7 +1234,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
       cdo_print("South threshhold: %g", south_thresh);
     }
 
-  double start = Options::cdoVerbose ? cdo_get_wtime() : 0;
+  cdo::timer timer;
 
   long srcGridSize = srcGrid->size;
   long tgtGridSize = tgtGrid->size;
@@ -1274,16 +1274,15 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
       maxSearchCells[i] = 0;
     }
 
-  Varray<Varray<size_t>> srch_add(Threading::ompNumThreads); // global address of cells in srch arrays
+  Varray<Varray<size_t>> srch_add(Threading::ompNumThreads);  // global address of cells in srch arrays
   for (int i = 0; i < Threading::ompNumThreads; ++i) srch_add[i].resize(tgtGridSize);
 
   srch_corners = tgtNumCorners;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none)                                                                                    \
-    shared(findex, rsearch, num_wts, src_centroid_lon, src_centroid_lat, grid_store, rv, Options::cdoVerbose, max_subseg, \
-           srch_corner_lat, srch_corner_lon, maxSearchCells, srcNumCorners, srch_corners, srcGrid, tgtGrid,      \
-           tgtGridSize, srcGridSize, srch_add)
+#pragma omp parallel for default(none) shared(findex, rsearch, num_wts, src_centroid_lon, src_centroid_lat, grid_store, rv,      \
+                                              Options::cdoVerbose, max_subseg, srch_corner_lat, srch_corner_lon, maxSearchCells, \
+                                              srcNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize, srcGridSize, srch_add)
 #endif
   for (long srcCellIndex = 0; srcCellIndex < srcGridSize; ++srcCellIndex)
     {
@@ -1468,10 +1467,9 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   findex = 0;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none)                                                                                    \
-    shared(findex, rsearch, num_wts, tgt_centroid_lon, tgt_centroid_lat, grid_store, rv, Options::cdoVerbose, max_subseg, \
-           srch_corner_lat, srch_corner_lon, maxSearchCells, tgtNumCorners, srch_corners, srcGrid, tgtGrid,      \
-           tgtGridSize, srcGridSize, srch_add)
+#pragma omp parallel for default(none) shared(findex, rsearch, num_wts, tgt_centroid_lon, tgt_centroid_lat, grid_store, rv,      \
+                                              Options::cdoVerbose, max_subseg, srch_corner_lat, srch_corner_lon, maxSearchCells, \
+                                              tgtNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize, srcGridSize, srch_add)
 #endif
   for (long tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
@@ -1656,7 +1654,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 
   grid_store_delete(grid_store);
 
-  if (rv.num_links != rv.max_links) remap_vars_resize(rv, rv.num_links);
+  if (rv.numLinks != rv.maxLinks) remap_vars_resize(rv, rv.numLinks);
 
   /* Finish centroid computation */
 
@@ -1685,24 +1683,24 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   /*
   if ( 1 )
     {
-      num_links = rv.num_links;
+      numLinks = rv.numLinks;
 
       if ( Options::cdoVerbose )
-        for ( long n = 0; n < num_links; n++ )
+        for ( long n = 0; n < numLinks; n++ )
           printf("wts1: %d %g\n", n, rv.wts[3*n]);
 
-      for ( long n = 0; n < num_links; n++ )
+      for ( long n = 0; n < numLinks; n++ )
         {
           if ( rv.wts[3*n] < 0 )
             {
               int i, n2, nd;
 
-              for ( n2 = n+1; n2 < num_links; n2++ )
+              for ( n2 = n+1; n2 < numLinks; n2++ )
                 if ( rv.wts[3*n2] >= 0 ) break;
 
               nd = n2-n;
-              num_links -= nd;
-              for ( i = n; i < num_links; i++ )
+              numLinks -= nd;
+              for ( i = n; i < numLinks; i++ )
                 {
                   rv.wts[3*i]   = rv.wts[3*(i+nd)];
                   rv.wts[3*i+1] = rv.wts[3*(i+nd)+1];
@@ -1714,18 +1712,18 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
             }
         }
 
-     if ( Options::cdoVerbose ) cdo_print("Removed number of links = %zu", rv.num_links - num_links);
+     if ( Options::cdoVerbose ) cdo_print("Removed number of links = %zu", rv.numLinks - numLinks);
 
-      rv.num_links = num_links;
+      rv.numLinks = numLinks;
     }
   */
 
   /* Include centroids in weights and normalize using destination area if requested */
   normalize_weights(tgtGrid, rv, src_centroid_lat, src_centroid_lon);
 
-  long num_links = rv.num_links;
+  long numLinks = rv.numLinks;
 
-  if (Options::cdoVerbose) cdo_print("Total number of links = %zu", rv.num_links);
+  if (Options::cdoVerbose) cdo_print("Total number of links = %zu", rv.numLinks);
 
   for (long n = 0; n < srcGridSize; ++n)
     if (IS_NOT_EQUAL(srcGrid->cell_area[n], 0)) srcGrid->cell_frac[n] /= srcGrid->cell_area[n];
@@ -1737,8 +1735,8 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 
   if (lcheck)
     {
-      remap_check_area(srcGridSize, &srcGrid->cell_area[0], "Source");
-      remap_check_area(tgtGridSize, &tgtGrid->cell_area[0], "Target");
+      remap_check_area(srcGridSize, srcGrid->cell_area, "Source");
+      remap_check_area(tgtGridSize, tgtGrid->cell_area, "Target");
 
       for (long n = 0; n < srcGridSize; ++n)
         {
@@ -1760,7 +1758,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 
       remap_vars_check_weights(rv);
 
-      for (long n = 0; n < num_links; ++n)
+      for (long n = 0; n < numLinks; ++n)
         {
           long tgtCellIndex = rv.tgtCellIndices[n];
           tgt_centroid_lat[tgtCellIndex] += rv.wts[3 * n];
@@ -1782,5 +1780,5 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
         }
     }  // lcheck
 
-  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", timer.elapsed());
 }  // remap_conserv_weights_scrip
