@@ -32,7 +32,7 @@ static void
 nce(int istat)
 {
   // This routine provides a simple interface to NetCDF error message routine.
-  if (istat != NC_NOERR) cdo_abort(nc_strerror(istat));
+  if (istat != NC_NOERR) cdo_abort("%s", nc_strerror(istat));
 }
 
 static void
@@ -219,7 +219,9 @@ static int
 inq_varid(int ncId, const char *name)
 {
   int varId = -1;
-  nce(nc_inq_varid(ncId, name, &varId));
+  auto status = nc_inq_varid(ncId, name, &varId);
+  if (status != NC_NOERR) cdo_warning("var name not found: %s", name);
+  nce(status);
   return varId;
 }
 
@@ -228,7 +230,9 @@ inq_dimlen(int ncId, const char *name)
 {
   size_t dimlen = 0;
   int dimId = -1;
-  nce(nc_inq_dimid(ncId, name, &dimId));
+  auto status = nc_inq_dimid(ncId, name, &dimId);
+  if (status != NC_NOERR) cdo_warning("dim name not found: %s", name);
+  nce(status);
   nce(nc_inq_dimlen(ncId, dimId, &dimlen));
   return dimlen;
 }
@@ -286,6 +290,9 @@ remap_write_data_scrip(const char *weightsfile, const RemapSwitches &remapSwitch
   auto mapMethod = set_map_method_cstr(remapSwitches, needGridarea);
   put_att_text(ncId, NC_GLOBAL, "map_method", mapMethod);
 
+  if (remapSwitches.mapType == RemapMethod::DISTWGT && remapSwitches.numNeighbors > 1 && remapSwitches.numNeighbors != 4)
+    nce(nc_put_att_int(ncId, NC_GLOBAL, "num_neighbors", NC_INT, 1L, &remapSwitches.numNeighbors));
+
   // Remap order
   if (remapSwitches.mapType == RemapMethod::CONSERV_SCRIP && remapSwitches.submapType == SubmapType::NONE)
     nce(nc_put_att_int(ncId, NC_GLOBAL, "remap_order", NC_INT, 1L, &remapSwitches.remapOrder));
@@ -294,13 +301,8 @@ remap_write_data_scrip(const char *weightsfile, const RemapSwitches &remapSwitch
   put_att_text(ncId, NC_GLOBAL, "conventions", "SCRIP");
 
   // Source and destination grid names
-  char srcGridName[64] = "source grid";
-  gridName(gridInqType(srcGrid.gridID), srcGridName);
-  put_att_text(ncId, NC_GLOBAL, "source_grid", srcGridName);
-
-  char tgtGridName[64] = "dest grid";
-  gridName(gridInqType(tgtGrid.gridID), tgtGridName);
-  put_att_text(ncId, NC_GLOBAL, "dest_grid", tgtGridName);
+  put_att_text(ncId, NC_GLOBAL, "source_grid", srcGrid.name.c_str());
+  put_att_text(ncId, NC_GLOBAL, "dest_grid", tgtGrid.name.c_str());
 
   // History
   auto dateAndTimeInSec = time(NULL);
@@ -330,7 +332,7 @@ remap_write_data_scrip(const char *weightsfile, const RemapSwitches &remapSwitch
   auto nc_dstgrdrank_id = def_dim(ncId, "dst_grid_rank", tgtGrid.rank);
 
   // Define map size dimensions
-  auto nc_numlinks_id = def_dim(ncId, "numLinks", rv.numLinks);
+  auto nc_numlinks_id = def_dim(ncId, "num_links", rv.numLinks);
   auto nc_numwgts_id = def_dim(ncId, "num_wgts", rv.num_wts);
 
   // Define grid dimensions
@@ -528,13 +530,22 @@ get_maptype(int ncId)
       if (status == NC_NOERR) remapSwitches.remapOrder = iatt;
     }
   else if (cdo_cmpstrLenRhs(mapMethod, "Bilinear"))
-    remapSwitches.mapType = RemapMethod::BILINEAR;
+    {
+      remapSwitches.mapType = RemapMethod::BILINEAR;
+    }
   else if (cdo_cmpstrLenRhs(mapMethod, "Bicubic"))
-    remapSwitches.mapType = RemapMethod::BICUBIC;
+    {
+      remapSwitches.mapType = RemapMethod::BICUBIC;
+    }
   else if (cdo_cmpstrLenRhs(mapMethod, "Distance"))
     {
+      int numNeighbors = 4;
+      int iatt;
+      int status = nc_get_att_int(ncId, NC_GLOBAL, "num_neighbors", &iatt);
+      if (status == NC_NOERR && iatt > 0) numNeighbors = iatt;
+
       remapSwitches.mapType = RemapMethod::DISTWGT;
-      remapSwitches.numNeighbors = 4;
+      remapSwitches.numNeighbors = numNeighbors;
     }
   else if (cdo_cmpstrLenRhs(mapMethod, "Nearest"))
     {
@@ -624,17 +635,17 @@ remap_read_data_scrip(const std::string &weightsfile, int gridID1, int gridID2,
 
   // Source and destination grid names
 
-  auto srcGridName = get_text_attribute(ncId, NC_GLOBAL, "source_grid");
-  auto tgtGridName = get_text_attribute(ncId, NC_GLOBAL, "dest_grid");
+  srcGrid.name = get_text_attribute(ncId, NC_GLOBAL, "source_grid");
+  tgtGrid.name = get_text_attribute(ncId, NC_GLOBAL, "dest_grid");
 
-  if (Options::cdoVerbose) cdo_print("Remapping between: %s and %s", srcGridName, tgtGridName);
+  if (Options::cdoVerbose) cdo_print("Remapping between: %s and %s", srcGrid.name, tgtGrid.name);
 
   // Read dimension information
   srcGrid.size = inq_dimlen(ncId, "src_grid_size");
   // if (srcGrid.size != gridInqSize(gridID1)) cdo_abort("Source grids have different size!");
 
   tgtGrid.size = inq_dimlen(ncId, "dst_grid_size");
-  ;
+
   // if (tgtGrid.size != gridInqSize(gridID2)) cdo_abort("Target grids have different size!");
 
   int nc_srcgrdcorn_id;
@@ -660,7 +671,7 @@ remap_read_data_scrip(const std::string &weightsfile, int gridID1, int gridID2,
   srcGrid.rank = inq_dimlen(ncId, "src_grid_rank");
   tgtGrid.rank = inq_dimlen(ncId, "dst_grid_rank");
 
-  rv.numLinks = inq_dimlen(ncId, "numLinks");
+  rv.numLinks = inq_dimlen(ncId, "num_links");
   // if (rv.numLinks == 0) cdo_abort("Number of remap links is 0, no remap weights found!");
 
   rv.num_wts = inq_dimlen(ncId, "num_wgts");
