@@ -15,8 +15,8 @@
 static void
 calcBinAddr(GridSearchBins &searchBins)
 {
-  const size_t ncells = searchBins.ncells;
-  const size_t nbins = searchBins.nbins;
+  size_t ncells = searchBins.ncells;
+  size_t nbins = searchBins.nbins;
   size_t *bin_addr = &searchBins.bin_addr[0];
   const float *bin_lats = &searchBins.bin_lats[0];
   const float *cell_bound_box = &searchBins.cell_bound_box[0];
@@ -29,12 +29,12 @@ calcBinAddr(GridSearchBins &searchBins)
 
   for (size_t nele = 0; nele < ncells; ++nele)
     {
-      const size_t nele4 = nele << 2;
-      const float cell_bound_box_lat1 = cell_bound_box[nele4];
-      const float cell_bound_box_lat2 = cell_bound_box[nele4 + 1];
+      size_t nele4 = nele << 2;
+      float cell_bound_box_lat1 = cell_bound_box[nele4];
+      float cell_bound_box_lat2 = cell_bound_box[nele4 + 1];
       for (size_t n = 0; n < nbins; ++n)
         {
-          const size_t n2 = n << 1;
+          size_t n2 = n << 1;
           if (cell_bound_box_lat1 <= bin_lats[n2 + 1] && cell_bound_box_lat2 >= bin_lats[n2])
             {
               bin_addr[n2] = std::min(nele, bin_addr[n2]);
@@ -47,10 +47,10 @@ calcBinAddr(GridSearchBins &searchBins)
 void
 calc_lat_bins(GridSearchBins &searchBins)
 {
-  const size_t nbins = searchBins.nbins;
-  const double dlat = PI / nbins;  // lat interval for search bins
+  size_t nbins = searchBins.nbins;
+  double dlat = PI / nbins;  // lat interval for search bins
 
-  if (Options::cdoVerbose) cdo_print("Using %zu latitude bins to restrict search.", nbins);
+  if (Options::cdoVerbose) cdo_print("Using %zu latitude bins to restrict search", nbins);
 
   if (nbins > 0)
     {
@@ -67,10 +67,11 @@ calc_lat_bins(GridSearchBins &searchBins)
 }
 
 size_t
-get_srch_cells(size_t tgtCellIndex, GridSearchBins &tgtBins, GridSearchBins &srcBins, float *tgt_cell_bound_box, Varray<size_t> &srch_add)
+get_srch_cells(size_t tgtCellIndex, GridSearchBins &tgtBins, GridSearchBins &srcBins, float *tgt_cell_bound_box,
+               Varray<size_t> &srch_add)
 {
-  const size_t nbins = srcBins.nbins;
-  const size_t srcGridSize = srcBins.ncells;
+  size_t nbins = srcBins.nbins;
+  size_t srcGridSize = srcBins.ncells;
   const size_t *bin_addr1 = &tgtBins.bin_addr[0];
   const size_t *bin_addr2 = &srcBins.bin_addr[0];
 
@@ -155,12 +156,12 @@ static int
 gridSearchSquareCurv2dNNScrip(size_t min_add, size_t max_add, size_t *nbr_add, double *nbr_dist, double plat, double plon,
                               const double *src_center_lat, const double *src_center_lon)
 {
-  int search_result = 0;
+  int searchResult = 0;
 
-  const auto tgtCoslat = std::cos(plat);
-  const auto tgtSinlat = std::sin(plat);
-  const auto tgtCoslon = std::cos(plon);
-  const auto tgtSinlon = std::sin(plon);
+  auto tgtCoslat = std::cos(plat);
+  auto tgtSinlat = std::sin(plat);
+  auto tgtCoslon = std::cos(plon);
+  auto tgtSinlon = std::sin(plon);
 
   double dist_min = DBL_MAX;
   for (int n = 0; n < 4; ++n) nbr_dist[n] = DBL_MAX;
@@ -183,7 +184,7 @@ gridSearchSquareCurv2dNNScrip(size_t min_add, size_t max_add, size_t *nbr_add, d
                       nbr_add[i] = nbr_add[i - 1];
                       nbr_dist[i] = nbr_dist[i - 1];
                     }
-                  search_result = -1;
+                  searchResult = -1;
                   nbr_add[n] = srch_add;
                   nbr_dist[n] = distance;
                   dist_min = nbr_dist[3];
@@ -198,7 +199,7 @@ gridSearchSquareCurv2dNNScrip(size_t min_add, size_t max_add, size_t *nbr_add, d
   for (int n = 0; n < 4; ++n) distance += nbr_dist[n];
   for (int n = 0; n < 4; ++n) nbr_dist[n] /= distance;
 
-  return search_result;
+  return searchResult;
 }
 
 static int
@@ -227,7 +228,7 @@ quadCrossProducts(double plon, double plat, double *lons, double *lats)
   // corner_loop
   for (n = 0; n < 4; ++n)
     {
-      const int next_n = (n + 1) % 4;
+      int next_n = (n + 1) % 4;
       /*
         Here we take the cross product of the vector making up each box side
         with the vector formed by the vertex and search point.
@@ -245,7 +246,7 @@ quadCrossProducts(double plon, double plat, double *lons, double *lats)
       if      (vec2_lon >  3.0 * PIH) vec2_lon -= PI2;
       else if (vec2_lon < -3.0 * PIH) vec2_lon += PI2;
 
-      const double crossProduct = vec1_lon * vec2_lat - vec2_lon * vec1_lat;
+      double crossProduct = vec1_lon * vec2_lat - vec2_lon * vec1_lat;
 
       // If cross product is less than ZERO, this cell doesn't work
       // 2008-10-16 Uwe Schulzweida: bug fix for cross_product eq zero
@@ -271,11 +272,11 @@ bool
 point_in_quad(bool isCyclic, size_t nx, size_t ny, size_t i, size_t j, size_t adds[4], double lons[4], double lats[4], double plon,
               double plat, const double *centerLon, const double *centerLat)
 {
-  bool search_result = false;
-  const size_t ip1 = (i < (nx - 1)) ? i + 1 : isCyclic ? 0 : i;
-  const size_t jp1 = (j < (ny - 1)) ? j + 1 : j;
+  bool searchResult = false;
+  size_t ip1 = (i < (nx - 1)) ? i + 1 : isCyclic ? 0 : i;
+  size_t jp1 = (j < (ny - 1)) ? j + 1 : j;
 
-  if (i == ip1 || j == jp1) return search_result;
+  if (i == ip1 || j == jp1) return searchResult;
 
   size_t idx[4];
   idx[0] = j * nx + i;
@@ -286,28 +287,28 @@ point_in_quad(bool isCyclic, size_t nx, size_t ny, size_t i, size_t j, size_t ad
   for (int k = 0; k < 4; ++k) lons[k] = centerLon[idx[k]];
   for (int k = 0; k < 4; ++k) lats[k] = centerLat[idx[k]];
 
-  const int n = quadCrossProducts(plon, plat, lons, lats);
+  int n = quadCrossProducts(plon, plat, lons, lats);
 
   // If cross products all same sign, we found the location
   if (n >= 4)
     {
       for (int k = 0; k < 4; ++k) adds[k] = idx[k];
-      search_result = true;
+      searchResult = true;
     }
 
-  return search_result;
+  return searchResult;
 }
 
 int
-grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], double (&src_lats)[4], double (&src_lons)[4],
+grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], double (&srcLats)[4], double (&srcLons)[4],
                                  double plat, double plon, GridSearchBins &srcBins)
 {
   /*
     Output variables:
 
     int    src_add[4]              ! address of each corner point enclosing P
-    double src_lats[4]             ! latitudes  of the four corner points
-    double src_lons[4]             ! longitudes of the four corner points
+    double srcLats[4]             ! latitudes  of the four corner points
+    double srcLons[4]             ! longitudes of the four corner points
 
     Input variables:
 
@@ -323,15 +324,15 @@ grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], doubl
 
     int src_bin_addr[][2]          ! latitude bins for restricting
   */
-  int search_result = 0;
+  int searchResult = 0;
 
-  const size_t nbins = srcBins.nbins;
+  size_t nbins = srcBins.nbins;
   const size_t *src_bin_addr = &srcBins.bin_addr[0];
   const float *bin_lats = &srcBins.bin_lats[0];
   const float *srcGridBoundBox = &srcBins.cell_bound_box[0];
 
-  const float rlat = plat;
-  const float rlon = plon;
+  float rlat = plat;
+  float rlon = plon;
 
   // restrict search first using bins
 
@@ -343,7 +344,7 @@ grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], doubl
 
   for (size_t n = 0; n < nbins; ++n)
     {
-      const size_t n2 = n << 1;
+      size_t n2 = n << 1;
       if (rlat >= bin_lats[n2] && rlat <= bin_lats[n2 + 1])
         {
           if (src_bin_addr[n2] < min_add) min_add = src_bin_addr[n2];
@@ -353,15 +354,15 @@ grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], doubl
 
   /* Now perform a more detailed search */
 
-  const size_t nx = srcGrid->dims[0];
-  const size_t ny = srcGrid->dims[1];
+  size_t nx = srcGrid->dims[0];
+  size_t ny = srcGrid->dims[1];
 
   for (size_t srch_add = min_add; srch_add <= max_add; ++srch_add)
     {
-      const size_t srch_add4 = srch_add << 2;
+      size_t srch_add4 = srch_add << 2;
       /* First check bounding box */
-      if (rlon >= srcGridBoundBox[srch_add4 + 2] && rlon <= srcGridBoundBox[srch_add4 + 3]
-          && rlat >= srcGridBoundBox[srch_add4] && rlat <= srcGridBoundBox[srch_add4 + 1])
+      if (rlon >= srcGridBoundBox[srch_add4 + 2] && rlon <= srcGridBoundBox[srch_add4 + 3] && rlat >= srcGridBoundBox[srch_add4]
+          && rlat <= srcGridBoundBox[srch_add4 + 1])
         {
           /* We are within bounding box so get really serious */
 
@@ -369,11 +370,11 @@ grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], doubl
           size_t j = srch_add / nx;
           size_t i = srch_add - j * nx;
 
-          if (point_in_quad(srcGrid->is_cyclic, nx, ny, i, j, src_add, src_lons, src_lats, plon, plat,
+          if (point_in_quad(srcGrid->isCyclic, nx, ny, i, j, src_add, srcLons, srcLats, plon, plat,
                             srcGrid->cell_center_lon.data(), srcGrid->cell_center_lat.data()))
             {
-              search_result = 1;
-              return search_result;
+              searchResult = 1;
+              return searchResult;
             }
 
           /* Otherwise move on to next cell */
@@ -384,16 +385,16 @@ grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], doubl
   /*
     If no cell found, point is likely either in a box that straddles either pole or is outside the grid.
     Fall back to a distance-weighted average of the four closest points. Go ahead and compute weights here,
-    but store in src_lats and return -add to prevent the parent routine from computing bilinear weights.
+    but store in srcLats and return -add to prevent the parent routine from computing bilinear weights.
   */
-  if (!srcGrid->lextrapolate) return search_result;
+  if (!srcGrid->doExtrapolate) return searchResult;
 
   /*
     printf("Could not find location for %g %g\n", plat*RAD2DEG, plon*RAD2DEG);
     printf("Using nearest-neighbor average for this point\n");
   */
-  search_result = gridSearchSquareCurv2dNNScrip(min_add, max_add, src_add, src_lats, plat, plon, srcGrid->cell_center_lat.data(),
+  searchResult = gridSearchSquareCurv2dNNScrip(min_add, max_add, src_add, srcLats, plat, plon, srcGrid->cell_center_lat.data(),
                                                 srcGrid->cell_center_lon.data());
 
-  return search_result;
+  return searchResult;
 }
