@@ -13,46 +13,40 @@
 #include "remap.h"
 #include "remap_store_link.h"
 
+bool
+is_sorted_list(size_t n, const size_t *list)
+{
+  for (size_t i = 1; i < n; ++i)
+    if (list[i] < list[i - 1]) return false;
+  return true;
+}
+
 static int
 qcompare_index(const void *a, const void *b)
 {
-  const size_t x = ((const IndexWeight *) a)->index;
-  const size_t y = ((const IndexWeight *) b)->index;
-  return ((x > y) - (x < y)) * 2 + (x > y) - (x < y);
+  return (((const IndexWeight *) a)->index < ((const IndexWeight *) b)->index);
 }
 
 static int
 qcompare_index4(const void *a, const void *b)
 {
-  const size_t x = ((const IndexWeight4 *) a)->index;
-  const size_t y = ((const IndexWeight4 *) b)->index;
-  return ((x > y) - (x < y)) * 2 + (x > y) - (x < y);
+  return (((const IndexWeight4 *) a)->index < ((const IndexWeight4 *) b)->index);
 }
 
 static void
 sort_indexWeights(size_t numWeights, IndexWeight *indexWeights)
 {
-  size_t n;
-  for (n = 1; n < numWeights; ++n)
-    if (indexWeights[n].index < indexWeights[n - 1].index) break;
-  if (n == numWeights) return;
-
   std::qsort(indexWeights, numWeights, sizeof(IndexWeight), qcompare_index);
 }
 
 static void
 sort_indexWeights4(IndexWeight4 *indexWeights)
 {
-  int n;
-  for (n = 1; n < 4; ++n)
-    if (indexWeights[n].index < indexWeights[n - 1].index) break;
-  if (n == 4) return;
-
   std::qsort(indexWeights, 4, sizeof(IndexWeight4), qcompare_index4);
 }
 
 void
-store_weightlinks(int doAlloc, size_t numWeights, size_t *searchIndices, double *weights, size_t cellIndex,
+store_weightlinks(int doAlloc, size_t numWeights, size_t *indices, double *weights, size_t cellIndex,
                   std::vector<WeightLinks> &weightLinks)
 {
   weightLinks[cellIndex].nlinks = 0;
@@ -62,13 +56,13 @@ store_weightlinks(int doAlloc, size_t numWeights, size_t *searchIndices, double
     {
       auto indexWeights = doAlloc ? (IndexWeight *) Malloc(numWeights * sizeof(IndexWeight)) : weightLinks[cellIndex].indexWeights;
 
-      for (size_t n = 0; n < numWeights; ++n)
+      for (size_t i = 0; i < numWeights; ++i)
         {
-          indexWeights[n].index = searchIndices[n];
-          indexWeights[n].weight = weights[n];
+          indexWeights[i].index = indices[i];
+          indexWeights[i].weight = weights[i];
         }
 
-      if (numWeights > 1) sort_indexWeights(numWeights, indexWeights);
+      if (numWeights > 1 && !is_sorted_list(numWeights, indices)) sort_indexWeights(numWeights, indexWeights);
 
       weightLinks[cellIndex].nlinks = numWeights;
 
@@ -77,20 +71,20 @@ store_weightlinks(int doAlloc, size_t numWeights, size_t *searchIndices, double
 }
 
 void
-store_weightlinks_bicubic(size_t *searchIndices, double (&weights)[4][4], size_t cellIndex, std::vector<WeightLinks4> &weightLinks)
+store_weightlinks_bicubic(size_t *indices, double (&weights)[4][4], size_t cellIndex, std::vector<WeightLinks4> &weightLinks)
 {
   weightLinks[cellIndex].nlinks = 0;
   weightLinks[cellIndex].offset = 0;
 
   auto indexWeights = weightLinks[cellIndex].indexWeights;
 
-  for (int n = 0; n < 4; ++n)
+  for (int i = 0; i < 4; ++i)
     {
-      indexWeights[n].index = searchIndices[n];
-      for (int k = 0; k < 4; ++k) indexWeights[n].weight[k] = weights[n][k];
+      indexWeights[i].index = indices[i];
+      for (int k = 0; k < 4; ++k) indexWeights[i].weight[k] = weights[i][k];
     }
 
-  sort_indexWeights4(indexWeights);
+  if (!is_sorted_list(4, indices)) sort_indexWeights4(indexWeights);
 
   weightLinks[cellIndex].nlinks = 4;
 }
@@ -108,8 +102,8 @@ weight_links_to_remap_links(int doAlloc, size_t gridSize, std::vector<WeightLink
         }
     }
 
-  rv.max_links = nlinks;
-  rv.num_links = nlinks;
+  rv.maxLinks = nlinks;
+  rv.numLinks = nlinks;
 
   if (nlinks)
     {
@@ -126,12 +120,12 @@ weight_links_to_remap_links(int doAlloc, size_t gridSize, std::vector<WeightLink
 #endif
       for (size_t i = 0; i < gridSize; ++i)
         {
-          const auto num_links = weightLinks[i].nlinks;
-          if (num_links)
+          const auto numLinks = weightLinks[i].nlinks;
+          if (numLinks)
             {
               const auto offset = weightLinks[i].offset;
               IndexWeight *indexWeights = weightLinks[i].indexWeights;
-              for (size_t ilink = 0; ilink < num_links; ++ilink)
+              for (size_t ilink = 0; ilink < numLinks; ++ilink)
                 {
                   srcCellIndices[offset + ilink] = indexWeights[ilink].index;
                   tgtCellIndices[offset + ilink] = i;
@@ -144,8 +138,8 @@ weight_links_to_remap_links(int doAlloc, size_t gridSize, std::vector<WeightLink
         {
           for (size_t i = 0; i < gridSize; ++i)
             {
-              const auto num_links = weightLinks[i].nlinks;
-              if (num_links) Free(weightLinks[i].indexWeights);
+              const auto numLinks = weightLinks[i].nlinks;
+              if (numLinks) Free(weightLinks[i].indexWeights);
             }
         }
       else
@@ -168,8 +162,8 @@ weight_links_4_to_remap_links(size_t gridSize, std::vector<WeightLinks4> &weight
         }
     }
 
-  rv.max_links = nlinks;
-  rv.num_links = nlinks;
+  rv.maxLinks = nlinks;
+  rv.numLinks = nlinks;
   if (nlinks)
     {
       rv.srcCellIndices.resize(nlinks);
@@ -184,12 +178,12 @@ weight_links_4_to_remap_links(size_t gridSize, std::vector<WeightLinks4> &weight
 #endif
       for (size_t i = 0; i < gridSize; ++i)
         {
-          const auto num_links = weightLinks[i].nlinks;
-          if (num_links)
+          const auto numLinks = weightLinks[i].nlinks;
+          if (numLinks)
             {
               const auto offset = weightLinks[i].offset;
               const auto indexWeights = weightLinks[i].indexWeights;
-              for (size_t ilink = 0; ilink < num_links; ++ilink)
+              for (size_t ilink = 0; ilink < numLinks; ++ilink)
                 {
                   srcCellIndices[offset + ilink] = indexWeights[ilink].index;
                   tgtCellIndices[offset + ilink] = i;
