@@ -7,7 +7,7 @@
 
 #include "field.h"
 #include "process_int.h"
-#include "cdo_wtime.h"
+#include "cdo_timer.h"
 #include "cdo_options.h"
 #include "remap_vars.h"
 #include "timer.h"
@@ -25,66 +25,60 @@ template <typename T1, typename T2>
 static void
 remapFirstOrder(Varray<T2> &tgtArray, const RemapVars &rv, const Varray<T1> &srcArray)
 {
-  auto num_links = rv.num_links;
+  auto numLinks = rv.numLinks;
   auto num_wts = rv.num_wts;
   const auto &map_wts = rv.wts;
   const auto &tgt_add = rv.tgtCellIndices;
   const auto &src_add = rv.srcCellIndices;
   const auto &links = rv.links;
-  const auto links_per_value = rv.links_per_value;
+  auto linksPerValue = rv.linksPerValue;
 
   if (links.option)
     {
 #ifdef HAVE_OPENMP4
 #pragma omp parallel for simd default(shared) schedule(static)
 #endif
-      for (size_t n = 0; n < num_links; ++n) tgtArray[tgt_add[n]] = static_cast<T2>(0.0);
+      for (size_t i = 0; i < numLinks; ++i) tgtArray[tgt_add[i]] = static_cast<T2>(0.0);
 
-      for (size_t j = 0; j < links.num_blks; ++j)
+      for (size_t j = 0; j < links.numBlocks; ++j)
         {
           const auto &tgt_addx = links.tgt_add[j];
           const auto &src_addx = links.src_add[j];
           const auto &windex = links.w_index[j];
-          auto nlinks = links.num_links[j];
+          auto nlinks = links.numLinks[j];
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-          for (size_t n = 0; n < nlinks; ++n)
-            {
-              tgtArray[tgt_addx[n]] += srcArray[src_addx[n]] * map_wts[num_wts * windex[n]];
-            }
+          for (size_t i = 0; i < nlinks; ++i) { tgtArray[tgt_addx[i]] += srcArray[src_addx[i]] * map_wts[num_wts * windex[i]]; }
         }
     }
   else
     {
-      auto lpv = links_per_value;
+      auto lpv = linksPerValue;
       if (lpv > 0)
         {
-          size_t nlinks = num_links / lpv;
+          size_t nlinks = numLinks / lpv;
 
           if (lpv == 1)
             {
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-              for (size_t n = 0; n < nlinks; ++n)
-                {
-                  tgtArray[tgt_add[n]] = srcArray[src_add[n]] * map_wts[n];
-                }
+              for (size_t i = 0; i < nlinks; ++i) { tgtArray[tgt_add[i]] = srcArray[src_add[i]] * map_wts[i]; }
             }
           else if (lpv == 4)
             {
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-              for (size_t n = 0; n < nlinks; ++n)
+              for (size_t i = 0; i < nlinks; ++i)
                 {
-                  const auto noff = n * 4;
+                  auto noff = i * 4;
                   tgtArray[tgt_add[noff]] = srcArray[src_add[noff]] * map_wts[num_wts * (noff)]
-                                             + srcArray[src_add[noff + 1]] * map_wts[num_wts * (noff + 1)]
-                                             + srcArray[src_add[noff + 2]] * map_wts[num_wts * (noff + 2)]
-                                             + srcArray[src_add[noff + 3]] * map_wts[num_wts * (noff + 3)];
+                                            + srcArray[src_add[noff + 1]] * map_wts[num_wts * (noff + 1)]
+                                            + srcArray[src_add[noff + 2]] * map_wts[num_wts * (noff + 2)]
+                                            + srcArray[src_add[noff + 3]] * map_wts[num_wts * (noff + 3)];
                 }
             }
           else
@@ -92,9 +86,9 @@ remapFirstOrder(Varray<T2> &tgtArray, const RemapVars &rv, const Varray<T1> &src
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-              for (size_t n = 0; n < nlinks; ++n)
+              for (size_t i = 0; i < nlinks; ++i)
                 {
-                  const auto noff = n * lpv;
+                  auto noff = i * lpv;
                   tgtArray[tgt_add[noff]] = srcArray[src_add[noff]] * map_wts[num_wts * noff];
                   for (size_t k = 1; k < (size_t) lpv; ++k)
                     tgtArray[tgt_add[noff]] += srcArray[src_add[noff + k]] * map_wts[num_wts * (noff + k)];
@@ -106,12 +100,12 @@ remapFirstOrder(Varray<T2> &tgtArray, const RemapVars &rv, const Varray<T1> &src
 #ifdef SX
 #pragma cdir nodep
 #endif
-          for (size_t n = 0; n < num_links; ++n) tgtArray[tgt_add[n]] = static_cast<T2>(0.0);
+          for (size_t i = 0; i < numLinks; ++i) tgtArray[tgt_add[i]] = static_cast<T2>(0.0);
 
-          for (size_t n = 0; n < num_links; ++n)
+          for (size_t i = 0; i < numLinks; ++i)
             {
-              // printf("%5zu %5zu %5zu %g # tgt_add src_add n\n", tgt_add[n], src_add[n], n, map_wts[num_wts*n]);
-              tgtArray[tgt_add[n]] += srcArray[src_add[n]] * map_wts[num_wts * n];
+              // printf("%5zu %5zu %5zu %g # tgt_add src_add n\n", tgt_add[i], src_add[i], i, map_wts[num_wts*i]);
+              tgtArray[tgt_add[i]] += srcArray[src_add[i]] * map_wts[num_wts * i];
             }
         }
     }
@@ -125,8 +119,8 @@ remapSecondOrder(Varray<T2> &tgtArray, const RemapVars &rv, const Varray<T1> &sr
   const auto &grad2 = gradients.grad_lon;
   const auto &grad3 = gradients.grad_latlon;
 
-  const auto num_links = rv.num_links;
-  const auto num_wts = rv.num_wts;
+  auto numLinks = rv.numLinks;
+  auto num_wts = rv.num_wts;
   const auto &map_wts = rv.wts;
   const auto &tgt_add = rv.tgtCellIndices;
   const auto &src_add = rv.srcCellIndices;
@@ -134,24 +128,24 @@ remapSecondOrder(Varray<T2> &tgtArray, const RemapVars &rv, const Varray<T1> &sr
 #ifdef SX
 #pragma cdir nodep
 #endif
-  for (size_t n = 0; n < num_links; ++n) tgtArray[tgt_add[n]] = static_cast<T2>(0.0);
+  for (size_t n = 0; n < numLinks; ++n) tgtArray[tgt_add[n]] = static_cast<T2>(0.0);
 
   if (num_wts == 3)
     {
-      for (size_t n = 0; n < num_links; ++n)
+      for (size_t n = 0; n < numLinks; ++n)
         {
-          const auto i = src_add[n];
-          const auto w = &map_wts[3 * n];
+          auto i = src_add[n];
+          auto w = &map_wts[3 * n];
           tgtArray[tgt_add[n]] += srcArray[i] * w[0] + grad1[i] * w[1] + grad2[i] * w[2];
           // printf("%zu %zu %.5f %.5f %.5f %.5f %.5f\n", n, src_add[n], grad1[i], grad2[i], w[0], w[1], w[2]);
         }
     }
   else if (num_wts == 4)
     {
-      for (size_t n = 0; n < num_links; ++n)
+      for (size_t n = 0; n < numLinks; ++n)
         {
-          const auto i = src_add[n];
-          const auto w = &map_wts[4 * n];
+          auto i = src_add[n];
+          auto w = &map_wts[4 * n];
           tgtArray[tgt_add[n]] += srcArray[i] * w[0] + grad1[i] * w[1] + grad2[i] * w[2] + grad3[i] * w[3];
         }
     }
@@ -178,21 +172,17 @@ remap(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv, con
 
       tgtArray  array for remapped field on target grid
   */
-  extern int timer_remap;
-
-  const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  cdo::timer timer;
 
   // Check the order of the interpolation
 
-  const auto firstOrder = (gradients.grad_lat.size() == 0);
+  auto firstOrder = (gradients.grad_lat.size() == 0);
 
 #ifdef HAVE_OPENMP4
 #pragma omp parallel for simd default(shared) schedule(static)
 #endif
   for (size_t n = 0; n < tgtSize; ++n) tgtArray[n] = missval;
 
-  if (Options::Timer) timer_start(timer_remap);
-
   if (firstOrder)  // First order remapping
     {
       remapFirstOrder(tgtArray, rv, srcArray);
@@ -202,30 +192,28 @@ remap(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv, con
       remapSecondOrder(tgtArray, rv, srcArray, gradients);
     }
 
-  if (Options::cdoVerbose) cdo_print("Remap: %.2f seconds", cdo_get_wtime() - start);
-
-  if (Options::Timer) timer_stop(timer_remap);
+  if (Options::cdoVerbose) cdo_print("Remap: %.2f seconds", timer.elapsed());
 }
 
 void
-remap(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1, RemapGradients &gradients)
+remap_field(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1, RemapGradients &gradients)
 {
   if (memtype_is_float_float(field1.memType, field2.memType))
-    remap(field2.vec_f, (float)missval, gridsize2, rv, field1.vec_f, gradients);
+    remap(field2.vec_f, (float) missval, gridsize2, rv, field1.vec_f, gradients);
   else if (memtype_is_float_double(field1.memType, field2.memType))
     remap(field2.vec_d, missval, gridsize2, rv, field1.vec_f, gradients);
   else if (memtype_is_double_float(field1.memType, field2.memType))
-    remap(field2.vec_f, (float)missval, gridsize2, rv, field1.vec_d, gradients);
+    remap(field2.vec_f, (float) missval, gridsize2, rv, field1.vec_d, gradients);
   else
     remap(field2.vec_d, missval, gridsize2, rv, field1.vec_d, gradients);
 }
 
 static size_t
-get_max_add(size_t num_links, size_t size, const Varray<size_t> &add)
+get_max_add(size_t numLinks, size_t size, const Varray<size_t> &add)
 {
   std::vector<size_t> isum(size, 0);
 
-  for (size_t n = 0; n < num_links; ++n) isum[add[n]]++;
+  for (size_t n = 0; n < numLinks; ++n) isum[add[n]]++;
 
   size_t max_add = 0;
   for (size_t i = 0; i < size; ++i)
@@ -241,7 +229,7 @@ binary_search_int(const Varray<size_t> &array, size_t len, size_t value)
 
   while (low <= high)
     {
-      const auto midpoint = low + (high - low) / 2;
+      auto midpoint = low + (high - low) / 2;
 
       // check to see if value is equal to item in array
       if (value == array[midpoint]) return midpoint;
@@ -274,17 +262,17 @@ remap_laf(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
     Output:
       tgtArray : array for remapped field on target grid
   */
-  auto num_links = rv.num_links;
-  auto num_wts = rv.num_wts;              // num of weights used in remapping
-  const auto &map_wts = rv.wts;           // remapping weights for each link
+  auto numLinks = rv.numLinks;
+  auto num_wts = rv.num_wts;                // num of weights used in remapping
+  const auto &map_wts = rv.wts;             // remapping weights for each link
   const auto &tgt_add = rv.tgtCellIndices;  // target address for each link
   const auto &src_add = rv.srcCellIndices;  // source address for each link
 
   varray_fill(tgtSize, tgtArray, missval);
 
-  if (num_links == 0) return;
+  if (numLinks == 0) return;
 
-  auto max_cls = get_max_add(num_links, tgtSize, tgt_add);
+  auto max_cls = get_max_add(numLinks, tgtSize, tgt_add);
 
 #ifdef _OPENMP
   Varray2D<T1> src_cls2(Threading::ompNumThreads, Varray<T1>(max_cls));
@@ -294,8 +282,8 @@ remap_laf(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
   Varray<double> src_wts(max_cls);
 #endif
 
-  for (size_t n = 0; n < num_links; ++n)
-    if (DBL_IS_EQUAL(tgtArray[tgt_add[n]], missval)) tgtArray[tgt_add[n]] = 0.0;
+  for (size_t n = 0; n < numLinks; ++n)
+    if (dbl_is_equal(tgtArray[tgt_add[n]], missval)) tgtArray[tgt_add[n]] = 0.0;
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(dynamic, 1)
@@ -304,7 +292,7 @@ remap_laf(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
     {
       size_t k, ncls;
 #ifdef _OPENMP
-      const auto ompthID = cdo_omp_get_thread_num();
+      auto ompthID = cdo_omp_get_thread_num();
       auto &src_cls = src_cls2[ompthID];
       auto &src_wts = src_wts2[ompthID];
 #endif
@@ -312,12 +300,12 @@ remap_laf(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
       varray_fill(src_wts, 0.0);
       /*
       ncls = 0;
-      for ( n = 0; n < num_links; n++ )
+      for ( n = 0; n < numLinks; n++ )
         {
           if ( i == tgt_add[n] )
             {
               for ( k = 0; k < ncls; k++ )
-                if ( IS_EQUAL(srcArray[src_add[n]], src_cls[k]) ) break;
+                if ( is_equal(srcArray[src_add[n]], src_cls[k]) ) break;
 
               if ( k == ncls )
                 {
@@ -333,13 +321,13 @@ remap_laf(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
       {
         size_t min_add = 1, max_add = 0;
 
-        auto n = binary_search_int(tgt_add, num_links, i);
+        auto n = binary_search_int(tgt_add, numLinks, i);
 
-        if (n < num_links)
+        if (n < numLinks)
           {
             min_add = n;
 
-            for (n = min_add + 1; n < num_links; ++n)
+            for (n = min_add + 1; n < numLinks; ++n)
               if (i != tgt_add[n]) break;
 
             max_add = n;
@@ -353,10 +341,10 @@ remap_laf(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
         ncls = 0;
         for (n = min_add; n < max_add; ++n)
           {
-            const auto value = srcArray[src_add[n]];
+            auto value = srcArray[src_add[n]];
 
             for (k = 0; k < ncls; ++k)
-              if (IS_EQUAL(value, src_cls[k])) break;
+              if (is_equal(value, src_cls[k])) break;
 
             if (k == ncls)
               {
@@ -406,8 +394,8 @@ template <typename T1, typename T2>
 static void
 remap_avg(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv, const Varray<T1> &srcArray)
 {
-  const auto num_links = rv.num_links;
-  const auto num_wts = rv.num_wts;          // num of weights used in remapping
+  auto numLinks = rv.numLinks;
+  auto num_wts = rv.num_wts;                // num of weights used in remapping
   const auto &map_wts = rv.wts;             // remapping weights for each link
   const auto &tgt_add = rv.tgtCellIndices;  // target address for each link
   const auto &src_add = rv.srcCellIndices;  // source address for each link
@@ -420,10 +408,10 @@ remap_avg(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
 #ifdef SX
 #pragma cdir nodep
 #endif
-  for (size_t n = 0; n < num_links; ++n)
-    if (DBL_IS_EQUAL(tgtArray[tgt_add[n]], missval)) tgtArray[tgt_add[n]] = 0.0;
+  for (size_t n = 0; n < numLinks; ++n)
+    if (dbl_is_equal(tgtArray[tgt_add[n]], missval)) tgtArray[tgt_add[n]] = 0.0;
 
-  for (size_t n = 0; n < num_links; ++n)
+  for (size_t n = 0; n < numLinks; ++n)
     {
       // printf("%5d %5d %5d %g # tgt_add src_add n\n", tgt_add[n], src_add[n], n, map_wts[num_wts*n]);
       // tgtArray[tgt_add[n]] += srcArray[src_add[n]]*map_wts[num_wts*n];
@@ -454,13 +442,13 @@ remap_avg(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
       {
         size_t min_add = 1, max_add = 0;
 
-        auto n = binary_search_int(tgt_add, num_links, i);
+        auto n = binary_search_int(tgt_add, numLinks, i);
 
-        if (n < num_links)
+        if (n < numLinks)
           {
             min_add = n;
 
-            for (n = min_add + 1; n < num_links; ++n)
+            for (n = min_add + 1; n < numLinks; ++n)
               if (i != tgt_add[n]) break;
 
             max_add = n;
@@ -471,13 +459,13 @@ remap_avg(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
             min_add = n;
           }
 
-        // const auto nadds = (max_add - min_add) + 1;
-        // const double lim = 0.1 / nadds;
-        const double lim = 0.0;
+        // auto nadds = (max_add - min_add) + 1;
+        // double lim = 0.1 / nadds;
+        constexpr double lim = 0.0;
         for (n = min_add; n < max_add; ++n)
           {
-            const auto value = srcArray[src_add[n]];
-            if (map_wts[num_wts * n] > lim && !DBL_IS_EQUAL(value, missval))
+            auto value = srcArray[src_add[n]];
+            if (map_wts[num_wts * n] > lim && !dbl_is_equal(value, missval))
               {
                 sum += value;
                 // wts += map_wts[num_wts * n];
@@ -490,7 +478,7 @@ remap_avg(Varray<T2> &tgtArray, T2 missval, size_t tgtSize, const RemapVars &rv,
       // printf("%zu %zu %g %g\n", i+1, nvalues, wts, sum);
       // max_values += nvalues;
     }
-  // printf("max_values = %zu  num_links = %zu\n", max_values, num_links);
+  // printf("max_values = %zu  numLinks = %zu\n", max_values, numLinks);
 }
 
 void
@@ -518,92 +506,92 @@ remap_vars_init(RemapMethod mapType, int remapOrder, RemapVars &rv)
   rv.num_wts = (mapType == RemapMethod::CONSERV_SCRIP) ? 3 : ((mapType == RemapMethod::BICUBIC) ? 4 : 1);
   if (mapType == RemapMethod::CONSERV && remapOrder == 2) rv.num_wts = 3;
 
-  rv.links_per_value = -1;
-  rv.num_links = 0;
-  rv.max_links = 0;
+  rv.linksPerValue = -1;
+  rv.numLinks = 0;
+  rv.maxLinks = 0;
   rv.resize_increment = 1024;
 
   rv.links.option = false;
-  rv.links.max_links = 0;
-  rv.links.num_blks = 0;
+  rv.links.maxLinks = 0;
+  rv.links.numBlocks = 0;
 }
 
 void
 remap_vars_ensure_size(RemapVars &rv, size_t size)
 {
-  if (size >= rv.max_links)
+  if (size >= rv.maxLinks)
     {
-      while (size >= rv.max_links) rv.max_links += rv.resize_increment;
+      while (size >= rv.maxLinks) rv.maxLinks += rv.resize_increment;
 
-      rv.srcCellIndices.resize(rv.max_links);
-      rv.tgtCellIndices.resize(rv.max_links);
-      rv.wts.resize(rv.num_wts * rv.max_links);
+      rv.srcCellIndices.resize(rv.maxLinks);
+      rv.tgtCellIndices.resize(rv.maxLinks);
+      rv.wts.resize(rv.num_wts * rv.maxLinks);
     }
 }
 
 void
 remap_vars_resize(RemapVars &rv, size_t size)
 {
-  rv.max_links = size;
+  rv.maxLinks = size;
 
-  rv.srcCellIndices.resize(rv.max_links);
-  rv.tgtCellIndices.resize(rv.max_links);
-  rv.wts.resize(rv.num_wts * rv.max_links);
+  rv.srcCellIndices.resize(rv.maxLinks);
+  rv.tgtCellIndices.resize(rv.maxLinks);
+  rv.wts.resize(rv.num_wts * rv.maxLinks);
 }
 
 void
 remap_vars_reorder(RemapVars &rv)
 {
-  size_t nval = 0, num_blks = 0;
+  size_t nval = 0, numBlocks = 0;
 
-  const auto num_links = rv.num_links;
+  auto numLinks = rv.numLinks;
 
   printf("remap_vars_reorder\n");
-  printf("  num_links %zu\n", num_links);
+  printf("  numLinks %zu\n", numLinks);
   rv.links.option = true;
 
   size_t lastval = -1;
-  size_t max_links = 0;
-  for (size_t n = 0; n < num_links; ++n)
+  size_t maxLinks = 0;
+  for (size_t n = 0; n < numLinks; ++n)
     {
       if (rv.tgtCellIndices[n] == lastval)
         nval++;
       else
         {
-          if (nval > num_blks) num_blks = nval;
+          if (nval > numBlocks) numBlocks = nval;
           nval = 1;
-          max_links++;
+          maxLinks++;
           lastval = rv.tgtCellIndices[n];
         }
     }
 
-  if (num_blks)
+  if (numBlocks)
     {
-      rv.links.max_links = max_links;
-      rv.links.num_blks = num_blks;
+      rv.links.maxLinks = maxLinks;
+      rv.links.numBlocks = numBlocks;
 
-      printf("num_links %zu  max_links %zu  num_blks %zu\n", rv.num_links, max_links, num_blks);
+      printf("numLinks %zu  maxLinks %zu  numBlocks %zu\n", rv.numLinks, maxLinks, numBlocks);
 
-      rv.links.num_links.resize(num_blks);
-      rv.links.tgt_add.resize(num_blks);
-      rv.links.src_add.resize(num_blks);
-      rv.links.w_index.resize(num_blks);
+      rv.links.numLinks.resize(numBlocks);
+      rv.links.tgt_add.resize(numBlocks);
+      rv.links.src_add.resize(numBlocks);
+      rv.links.w_index.resize(numBlocks);
     }
 
-  for (size_t j = 0; j < num_blks; ++j)
+  for (size_t j = 0; j < numBlocks; ++j)
     {
-      rv.links.tgt_add[j].resize(max_links);
-      rv.links.src_add[j].resize(max_links);
-      rv.links.w_index[j].resize(max_links);
+      rv.links.tgt_add[j].resize(maxLinks);
+      rv.links.src_add[j].resize(maxLinks);
+      rv.links.w_index[j].resize(maxLinks);
     }
 
-  for (size_t j = 0; j < num_blks; ++j)
+  for (size_t j = 0; j < numBlocks; ++j)
     {
       nval = 0;
       lastval = -1;
       size_t nlinks = 0;
 
-      for (size_t n = 0; n < num_links; ++n)
+      for (size_t n = 0; n < numLinks; ++n)
         {
           if (rv.tgtCellIndices[n] == lastval)
             nval++;
@@ -622,7 +610,7 @@ remap_vars_reorder(RemapVars &rv)
             }
         }
 
-      rv.links.num_links[j] = nlinks;
+      rv.links.numLinks[j] = nlinks;
       printf("loop %zu  nlinks %zu\n", j + 1, nlinks);
     }
 }
@@ -643,11 +631,11 @@ remap_vars_free(RemapVars &rv)
         {
           rv.links.option = false;
 
-          if (rv.links.num_blks)
+          if (rv.links.numBlocks)
             {
-              varray_free(rv.links.num_links);
-              const auto num_blks = rv.links.num_blks;
-              for (size_t i = 0; i < num_blks; ++i)
+              varray_free(rv.links.numLinks);
+              auto numBlocks = rv.links.numBlocks;
+              for (size_t i = 0; i < numBlocks; ++i)
                 {
                   varray_free(rv.links.src_add[i]);
                   varray_free(rv.links.tgt_add[i]);
@@ -667,14 +655,14 @@ remap_vars_free(RemapVars &rv)
 void
 remap_vars_check_weights(const RemapVars &rv)
 {
-  const auto num_links = rv.num_links;
-  const auto num_wts = rv.num_wts;
-  const auto normOpt = rv.normOpt;
+  auto numLinks = rv.numLinks;
+  auto num_wts = rv.num_wts;
+  auto normOpt = rv.normOpt;
   const auto &src_add = rv.srcCellIndices;
   const auto &tgt_add = rv.tgtCellIndices;
   const auto &wts = rv.wts;
 
-  for (size_t n = 0; n < num_links; ++n)
+  for (size_t n = 0; n < numLinks; ++n)
     {
       if (wts[n * num_wts] < -0.01)
         cdo_print("Map weight < 0! grid1idx=%zu grid2idx=%zu nlink=%zu wts=%g", src_add[n], tgt_add[n], n, wts[n * num_wts]);
