@@ -55,15 +55,13 @@
 #include <cdi.h>
 
 #include "cdo_options.h"
+#include "cdo_timer.h"
 #include "cimdOmp.h"
 #include "process_int.h"
-#include "cdo_wtime.h"
 #include <mpim_grid.h>
 #include "gridreference.h"
 #include "remap.h"
 
-#define IS_REG2D_GRID(gridID) (gridInqType(gridID) == GRID_LONLAT || gridInqType(gridID) == GRID_GAUSSIAN)
-
 static bool remap_gen_weights = true;
 static bool remap_write_remap = false;
 static int remap_num_srch_bins = 180;
@@ -71,6 +69,18 @@ static int remap_num_srch_bins = 180;
 constexpr size_t DEFAULT_MAX_ITER = 100;
 size_t remap_max_iter = DEFAULT_MAX_ITER;  // Max iteration count for i, j iteration
 
+int
+remap_check_mask_indices(const size_t (&indices)[4], const Varray<short> &mask)
+{
+  int searchResult = 1;
+  if (mask.size() > 0)
+    {
+      for (int i = 0; i < 4; ++i)
+        if (mask[indices[i]] == 0) searchResult = 0;
+    }
+  return searchResult;
+}
+
 void
 remap_set_int(int remapvar, int value)
 {
@@ -92,8 +102,8 @@ boundboxFromCorners(size_t size, size_t nc, const Varray<double> &corner_lon, co
 #endif
   for (size_t i = 0; i < size; ++i)
     {
-      const size_t i4 = (i << 2);  // *4
-      const size_t inc = i * nc;
+      size_t i4 = (i << 2);  // *4
+      size_t inc = i * nc;
       float clat = corner_lat[inc];
       float clon = corner_lon[inc];
       bound_box[i4 + 0] = clat;
@@ -121,15 +131,15 @@ boundboxFromCenter(bool lonIsCyclic, size_t size, size_t nx, size_t ny, const Va
 #endif
   for (size_t n = 0; n < size; ++n)
     {
-      const size_t n4 = (n << 2);
+      size_t n4 = (n << 2);
 
       // Find N,S and NE points to this grid point
 
-      const size_t j = n / nx;
-      const size_t i = n - j * nx;
+      size_t j = n / nx;
+      size_t i = n - j * nx;
 
-      const size_t ip1 = (i < (nx - 1)) ? i + 1 : lonIsCyclic ? 0 : i;
-      const size_t jp1 = (j < (ny - 1)) ? j + 1 : j;
+      size_t ip1 = (i < (nx - 1)) ? i + 1 : lonIsCyclic ? 0 : i;
+      size_t jp1 = (j < (ny - 1)) ? j + 1 : j;
 
       size_t idx[4];
       idx[0] = n;
@@ -159,23 +169,28 @@ boundboxFromCenter(bool lonIsCyclic, size_t size, size_t nx, size_t ny, const Va
 }
 
 LonLatPoint
-remapgrid_get_lonlat(RemapGrid *grid, size_t cell_add)
+remapgrid_get_lonlat(RemapGrid *grid, size_t index)
 {
   double lon, lat;
 
   if (grid->type == RemapGridType::Reg2D)
     {
-      const auto nx = grid->dims[0];
-      const auto iy = cell_add / nx;
-      const auto ix = cell_add - iy * nx;
+      auto nx = grid->dims[0];
+      auto iy = index / nx;
+      auto ix = index - iy * nx;
       lat = grid->reg2d_center_lat[iy];
       lon = grid->reg2d_center_lon[ix];
       if (lon < 0) lon += PI2;
     }
+  else if (grid->type == RemapGridType::HealPix)
+    {
+      hp_index_to_lonlat(grid->order, grid->nside, index, &lon, &lat);
+      // if (lon < 0) lon += PI2;
+    }
   else
     {
-      lat = grid->cell_center_lat[cell_add];
-      lon = grid->cell_center_lon[cell_add];
+      lat = grid->cell_center_lat[index];
+      lon = grid->cell_center_lon[index];
     }
 
   return LonLatPoint(lon, lat);
@@ -257,7 +272,7 @@ check_lon_boundbox_range(size_t nlons, float *bound_box)
 #endif
   for (size_t n = 0; n < nlons; ++n)
     {
-      const auto n4 = n << 2;
+      auto n4 = n << 2;
       if (std::fabs(bound_box[n4 + 3] - bound_box[n4 + 2]) > PI_f)
         {
           bound_box[n4 + 2] = 0.0f;
@@ -276,7 +291,7 @@ check_lat_boundbox_range(size_t nlats, float *bound_box, Varray<double> &lats)
 #endif
   for (size_t n = 0; n < nlats; ++n)
     {
-      const auto n4 = n << 2;
+      auto n4 = n << 2;
       if ((float) lats[n] < bound_box[n4]) bound_box[n4] = -PIH_f;
       if ((float) lats[n] > bound_box[n4 + 1]) bound_box[n4 + 1] = PIH_f;
     }
@@ -289,7 +304,7 @@ grid_check_lat_borders_rad(size_t n, Varray<double> &ybounds)
 {
   constexpr double YMAX = PIH;
   constexpr double YLIM = 88 * DEG2RAD;
-  const auto lrev = (ybounds[0] > ybounds[n - 1]);
+  auto lrev = (ybounds[0] > ybounds[n - 1]);
   if (lrev)
     {
       if (ybounds[0] > ybounds[1])
@@ -338,13 +353,13 @@ convert_bounds_reg2d(size_t n, const Varray<double> &boundsIn, Varray<double> &b
 static void
 remap_define_reg2d(int gridID, RemapGrid &grid, bool conservMapping, const char *txt)
 {
-  const auto nx = grid.dims[0];
-  const auto ny = grid.dims[1];
-  const auto nxp1 = nx + 1;
-  const auto nyp1 = ny + 1;
+  auto nx = grid.dims[0];
+  auto ny = grid.dims[1];
+  auto nxp1 = nx + 1;
+  auto nyp1 = ny + 1;
 
   auto nxm = nx;
-  if (grid.is_cyclic) nxm++;
+  if (grid.isCyclic) nxm++;
 
   if (grid.size != nx * ny) cdo_abort("Internal error, wrong dimensions!");
 
@@ -364,7 +379,7 @@ remap_define_reg2d(int gridID, RemapGrid &grid, bool conservMapping, const char
     for (size_t i = 1; i < nx; ++i)
       if (grid.reg2d_center_lon[i] < grid.reg2d_center_lon[i - 1]) grid.reg2d_center_lon[i] += PI2;
 
-  if (grid.is_cyclic) grid.reg2d_center_lon[nx] = grid.reg2d_center_lon[0] + PI2;
+  if (grid.isCyclic) grid.reg2d_center_lon[nx] = grid.reg2d_center_lon[0] + PI2;
 
   grid.reg2d_corner_lon.resize(nxp1);
   grid.reg2d_corner_lat.resize(nyp1);
@@ -398,114 +413,142 @@ remap_define_reg2d(int gridID, RemapGrid &grid, bool conservMapping, const char
 }
 
 static void
-remapDefineGrid(RemapMethod mapType, int gridID, RemapGrid &grid, const char *txt)
+init_mask(int gridID, RemapGrid &grid)
+{
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+  for (size_t i = 0; i < grid.size; ++i) grid.mask[i] = 1;
+
+  if (gridInqMask(gridID, nullptr))
+    {
+      std::vector<int> mask(grid.size);
+      gridInqMask(gridID, &mask[0]);
+      for (size_t i = 0; i < grid.size; ++i)
+        if (mask[i] == 0) grid.mask[i] = 0;
+    }
+}
+
+static void
+remap_define_grid(RemapMethod mapType, int gridID, RemapGrid &grid, const char *txt)
 {
   bool destroyGrid = false;
   int gridID_gme = -1;
 
-  const auto gridtype = gridInqType(grid.gridID);
-  if (gridtype != GRID_UNSTRUCTURED && gridtype != GRID_CURVILINEAR)
+  auto gridtype = gridInqType(grid.gridID);
+  auto isHealpixGrid = (grid.type == RemapGridType::HealPix);
+
+  if (isHealpixGrid)
+    {
+      auto [nside, order] = cdo::get_healpix_params(gridID);
+      grid.nside = nside;
+      grid.order = order;
+    }
+
+  if (gridtype != GRID_UNSTRUCTURED && gridtype != GRID_CURVILINEAR && !isHealpixGrid)
     {
-      constexpr auto withBounds = true;
       if (gridtype == GRID_GME)
         {
-          gridID_gme = gridToUnstructured(grid.gridID, withBounds);
+          gridID_gme = gridToUnstructured(grid.gridID, NeedCorners::Yes);
           grid.nvgp = gridInqSize(gridID_gme);
           gridID = gridDuplicate(gridID_gme);
           gridCompress(gridID);
-          grid.luse_cell_corners = true;
+          grid.useCellCorners = true;
         }
-      else if (gridtype == GRID_GAUSSIAN_REDUCED || (gridtype == GRID_PROJECTION && gridInqProjType(gridID) == CDI_PROJ_HEALPIX))
+      else if (gridtype == GRID_GAUSSIAN_REDUCED || is_healpix_grid(gridID))
         {
           destroyGrid = true;
-          gridID = gridToUnstructured(grid.gridID, withBounds);
+          gridID = gridToUnstructured(grid.gridID, NeedCorners::Yes);
         }
       else if (remap_write_remap || grid.type != RemapGridType::Reg2D)
         {
           destroyGrid = true;
-          gridID = gridToCurvilinear(grid.gridID, withBounds);
+          gridID = gridToCurvilinear(grid.gridID, NeedCorners::Yes);
         }
     }
 
-  auto gridsize = grid.size = gridInqSize(gridID);
+  grid.name = is_healpix_grid(grid.gridID) ? "healpix" : gridNamePtr(gridtype);
+  grid.size = gridInqSize(gridID);
 
-  grid.dims[0] = gridInqXsize(gridID);
+  grid.dims[0] = isHealpixGrid ? grid.size : gridInqXsize(gridID);
   grid.dims[1] = gridInqYsize(gridID);
-  if (gridInqType(grid.gridID) != GRID_UNSTRUCTURED && gridInqType(gridID) != GRID_UNSTRUCTURED)
+  if (gridtype != GRID_UNSTRUCTURED && gridInqType(gridID) != GRID_UNSTRUCTURED && !isHealpixGrid)
     {
-      if (grid.dims[0] == 0) cdo_abort("%s grid without longitude coordinates!", gridNamePtr(gridInqType(grid.gridID)));
-      if (grid.dims[1] == 0) cdo_abort("%s grid without latitude coordinates!", gridNamePtr(gridInqType(grid.gridID)));
+      if (grid.dims[0] == 0) cdo_abort("%s grid without longitude coordinates!", gridNamePtr(gridtype));
+      if (grid.dims[1] == 0) cdo_abort("%s grid without latitude coordinates!", gridNamePtr(gridtype));
     }
 
-  grid.is_cyclic = (gridIsCircular(gridID) > 0);
+  grid.isCyclic = (gridIsCircular(gridID) > 0);
 
-  grid.rank = (gridInqType(gridID) == GRID_UNSTRUCTURED) ? 1 : 2;
+  grid.rank = (gridInqType(gridID) == GRID_UNSTRUCTURED || isHealpixGrid) ? 1 : 2;
 
   grid.num_cell_corners = (gridInqType(gridID) == GRID_UNSTRUCTURED) ? gridInqNvertex(gridID) : 4;
 
   remap_grid_alloc(mapType, grid);
 
   // Initialize logical mask
-
-#ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
-#endif
-  for (size_t i = 0; i < gridsize; ++i) grid.mask[i] = 1;
-
-  if (gridInqMask(gridID, nullptr))
-    {
-      std::vector<int> mask(gridsize);
-      gridInqMask(gridID, &mask[0]);
-      for (size_t i = 0; i < gridsize; ++i)
-        if (mask[i] == 0) grid.mask[i] = 0;
-    }
+  init_mask(gridID, grid);
 
   if (!remap_write_remap && grid.type == RemapGridType::Reg2D) return;
 
-  if (!gridHasCoordinates(gridID)) cdo_abort("%s grid cell center coordinates missing!", txt);
-
-  gridInqXvals(gridID, grid.cell_center_lon.data());
-  gridInqYvals(gridID, grid.cell_center_lat.data());
-
-  if (grid.lneed_cell_corners)
+  if (isHealpixGrid)
     {
-      if (!gridHasBounds(gridID)) cdo_abort("%s grid cell corner coordinates missing!", txt);
+      if (remap_write_remap)
+        {
+          if (grid.cell_center_lon.size() == 0 || grid.cell_center_lat.size() == 0)
+            cdo_abort("Internal problem - lonlat coordinates not allocated!");
 
-      gridInqXbounds(gridID, grid.cell_corner_lon.data());
-      gridInqYbounds(gridID, grid.cell_corner_lat.data());
+          for (size_t i = 0; i < grid.size; ++i)
+            hp_index_to_lonlat(grid.order, grid.nside, i, &grid.cell_center_lon[i], &grid.cell_center_lat[i]);
+        }
     }
-
-  if (gridInqType(grid.gridID) == GRID_GME) gridInqMaskGME(gridID_gme, &grid.vgpm[0]);
-
-  // Convert lat/lon units if required
-  cdo_grid_to_radian(gridID, CDI_XAXIS, grid.size, grid.cell_center_lon.data(), "grid center lon");
-  cdo_grid_to_radian(gridID, CDI_YAXIS, grid.size, grid.cell_center_lat.data(), "grid center lat");
-  if (grid.num_cell_corners && grid.lneed_cell_corners)
+  else
     {
-      cdo_grid_to_radian(gridID, CDI_XAXIS, grid.num_cell_corners * grid.size, grid.cell_corner_lon.data(), "grid corner lon");
-      cdo_grid_to_radian(gridID, CDI_YAXIS, grid.num_cell_corners * grid.size, grid.cell_corner_lat.data(), "grid corner lat");
+      if (!gridHasCoordinates(gridID)) cdo_abort("%s grid cell center coordinates missing!", txt);
+
+      gridInqXvals(gridID, grid.cell_center_lon.data());
+      gridInqYvals(gridID, grid.cell_center_lat.data());
+
+      if (grid.needCellCorners)
+        {
+          if (!gridHasBounds(gridID)) cdo_abort("%s grid cell corner coordinates missing!", txt);
+
+          gridInqXbounds(gridID, grid.cell_corner_lon.data());
+          gridInqYbounds(gridID, grid.cell_corner_lat.data());
+        }
+
+      if (gridInqType(grid.gridID) == GRID_GME) gridInqMaskGME(gridID_gme, &grid.vgpm[0]);
+
+      // Convert lat/lon units if required
+      cdo_grid_to_radian(gridID, CDI_XAXIS, grid.size, grid.cell_center_lon.data(), "grid center lon");
+      cdo_grid_to_radian(gridID, CDI_YAXIS, grid.size, grid.cell_center_lat.data(), "grid center lat");
+      if (grid.num_cell_corners && grid.needCellCorners)
+        {
+          cdo_grid_to_radian(gridID, CDI_XAXIS, grid.num_cell_corners * grid.size, grid.cell_corner_lon.data(), "grid corner lon");
+          cdo_grid_to_radian(gridID, CDI_YAXIS, grid.num_cell_corners * grid.size, grid.cell_corner_lat.data(), "grid corner lat");
+        }
+
+      // Convert longitudes to 0,2pi interval
+      check_lon_range(txt, grid.size, grid.cell_center_lon);
+      if (grid.num_cell_corners && grid.needCellCorners)
+        check_lon_range(nullptr, grid.num_cell_corners * grid.size, grid.cell_corner_lon);
+
+      // Make sure input latitude range is within the machine values for +/- pi/2
+      check_lat_range(txt, grid.size, grid.cell_center_lat);
+      if (grid.num_cell_corners && grid.needCellCorners)
+        check_lat_range(nullptr, grid.num_cell_corners * grid.size, grid.cell_corner_lat);
     }
 
   if (destroyGrid) gridDestroy(gridID);
-
-  // Convert longitudes to 0,2pi interval
-  check_lon_range(txt, grid.size, grid.cell_center_lon);
-  if (grid.num_cell_corners && grid.lneed_cell_corners)
-    check_lon_range(nullptr, grid.num_cell_corners * grid.size, grid.cell_corner_lon);
-
-  // Make sure input latitude range is within the machine values for +/- pi/2
-  check_lat_range(txt, grid.size, grid.cell_center_lat);
-  if (grid.num_cell_corners && grid.lneed_cell_corners)
-    check_lat_range(nullptr, grid.num_cell_corners * grid.size, grid.cell_corner_lat);
 }
 
 // Compute bounding boxes for restricting future grid searches
 static void
 cell_bounding_boxes(RemapGrid &grid, float *cell_bound_box, int remap_grid_basis)
 {
-  if (grid.luse_cell_corners)
+  if (grid.useCellCorners)
     {
-      if (grid.lneed_cell_corners)
+      if (grid.needCellCorners)
         {
           if (Options::cdoVerbose) cdo_print("Grid: boundboxFromCorners");
           boundboxFromCorners(grid.size, grid.num_cell_corners, grid.cell_corner_lon, grid.cell_corner_lat, cell_bound_box);
@@ -514,7 +557,7 @@ cell_bounding_boxes(RemapGrid &grid, float *cell_bound_box, int remap_grid_basis
         {
           if (Options::cdoVerbose) cdo_print("Grid: bounds missing -> full grid search!");
 
-          const auto gridsize = grid.size;
+          auto gridsize = grid.size;
           for (size_t i = 0; i < gridsize; ++i)
             {
               cell_bound_box[i * 4] = -PIH_f;
@@ -529,15 +572,15 @@ cell_bounding_boxes(RemapGrid &grid, float *cell_bound_box, int remap_grid_basis
       if (Options::cdoVerbose) cdo_print("Grid: boundboxFromCenter");
       if (grid.rank != 2) cdo_abort("Internal problem, grid rank = %d!", grid.rank);
 
-      const auto nx = grid.dims[0];
-      const auto ny = grid.dims[1];
-      boundboxFromCenter(grid.is_cyclic, grid.size, nx, ny, grid.cell_center_lon, grid.cell_center_lat, cell_bound_box);
+      auto nx = grid.dims[0];
+      auto ny = grid.dims[1];
+      boundboxFromCenter(grid.isCyclic, grid.size, nx, ny, grid.cell_center_lon, grid.cell_center_lat, cell_bound_box);
     }
 
-  if (remap_grid_basis == REMAP_GRID_BASIS_SRC || grid.lneed_cell_corners) check_lon_boundbox_range(grid.size, cell_bound_box);
+  if (remap_grid_basis == REMAP_GRID_BASIS_SRC || grid.needCellCorners) check_lon_boundbox_range(grid.size, cell_bound_box);
 
   // Try to check for cells that overlap poles
-  if (remap_grid_basis == REMAP_GRID_BASIS_SRC || grid.lneed_cell_corners)
+  if (remap_grid_basis == REMAP_GRID_BASIS_SRC || grid.needCellCorners)
     check_lat_boundbox_range(grid.size, cell_bound_box, grid.cell_center_lat);
 }
 
@@ -549,41 +592,25 @@ remap_grid_alloc(RemapMethod mapType, RemapGrid &grid)
   // only needed for srcGrid and remap_gen_weights
   grid.mask.resize(grid.size);
 
-  if (remap_write_remap || grid.type != RemapGridType::Reg2D)
+  if (remap_write_remap || (grid.type != RemapGridType::Reg2D && grid.type != RemapGridType::HealPix))
     {
       grid.cell_center_lon.resize(grid.size);
       grid.cell_center_lat.resize(grid.size);
     }
 
-  const auto needCellarea = (mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV);
+  auto needCellarea = (mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV);
   if (needCellarea) grid.cell_area.resize(grid.size, 0.0);
 
-  if (remap_gen_weights)
-    {
-      grid.cell_frac.resize(grid.size, 0.0);
-    }
+  if (remap_gen_weights || mapType == RemapMethod::CONSERV) { grid.cell_frac.resize(grid.size, 0.0); }
 
-  if (grid.lneed_cell_corners && grid.num_cell_corners > 0)
+  if (grid.needCellCorners && grid.num_cell_corners > 0)
     {
-      const auto nalloc = grid.num_cell_corners * grid.size;
+      auto nalloc = grid.num_cell_corners * grid.size;
       grid.cell_corner_lon.resize(nalloc, 0);
       grid.cell_corner_lat.resize(nalloc, 0);
     }
 }
 
-void
-remap_grid_init(RemapGrid &grid)
-{
-  grid.tmpgridID = -1;
-  grid.type = RemapGridType::Undefined;
-
-  grid.num_cell_corners = 0;
-  grid.luse_cell_corners = false;
-  grid.lneed_cell_corners = false;
-
-  grid.nvgp = 0;
-}
-
 void
 remap_grid_free(RemapGrid &grid)
 {
@@ -611,15 +638,13 @@ check_for_convex_cells(RemapGrid &tgtGrid)
 {
   if (tgtGrid.type == RemapGridType::Reg2D) return;
 
-  const auto numCellCorners = tgtGrid.num_cell_corners;
+  auto numCellCorners = tgtGrid.num_cell_corners;
   if (numCellCorners <= 4) return;
 
   auto numCells = tgtGrid.size;
   if (numCells > 1000) numCells = 1000;
 
-  for (size_t i = 0; i < numCells; ++i)
-    {
-    }
+  for (size_t i = 0; i < numCells; ++i) {}
 }
 
 void
@@ -648,19 +673,21 @@ remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &srcGrid,
                        && (cellSearchMethod == CellSearchMethod::spherepart || srcGrid.type == RemapGridType::Reg2D);
 
   const char *searchMethodStr = NULL;
-  const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  cdo::timer timer;
 
   if (usePointsearch)
     {
       searchMethodStr = "Point search";
-      const auto xIsCyclic = srcGrid.is_cyclic;
-      if (srcGrid.type == RemapGridType::Reg2D)
+      auto xIsCyclic = srcGrid.isCyclic;
+      if (srcGrid.type == RemapGridType::HealPix)
+        grid_point_search_create_healpix(search.gps, srcGrid.size, srcGrid.nside, srcGrid.order);
+      else if (srcGrid.type == RemapGridType::Reg2D)
         grid_point_search_create_reg_2d(search.gps, xIsCyclic, srcGrid.dims, srcGrid.reg2d_center_lon, srcGrid.reg2d_center_lat);
       else
         grid_point_search_create(search.gps, xIsCyclic, srcGrid.dims, srcGrid.size, srcGrid.cell_center_lon,
                                  srcGrid.cell_center_lat);
 
-      if (srcGrid.lextrapolate) grid_point_search_extrapolate(search.gps);
+      if (srcGrid.doExtrapolate) grid_point_search_extrapolate(search.gps);
     }
   else if (useCellsearch)
     {
@@ -677,7 +704,7 @@ remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &srcGrid,
     {
       searchMethodStr = "Latitude bins";
       search.srcBins.cell_bound_box.resize(4 * srcGrid.size);
-      if (tgtGrid.luse_cell_corners) search.tgtBins.cell_bound_box.resize(4 * tgtGrid.size);
+      if (tgtGrid.useCellCorners) search.tgtBins.cell_bound_box.resize(4 * tgtGrid.size);
 
       cell_bounding_boxes(srcGrid, &search.srcBins.cell_bound_box[0], REMAP_GRID_BASIS_SRC);
       cell_bounding_boxes(tgtGrid, &search.tgtBins.cell_bound_box[0], REMAP_GRID_BASIS_TGT);
@@ -692,7 +719,7 @@ remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &srcGrid,
         }
     }
 
-  if (Options::cdoVerbose && searchMethodStr) cdo_print("%s created: %.2f seconds", searchMethodStr, cdo_get_wtime() - start);
+  if (Options::cdoVerbose && searchMethodStr) cdo_print("%s created: %.2f seconds", searchMethodStr, timer.elapsed());
 }
 
 void
@@ -711,51 +738,58 @@ remap_search_free(RemapSearch &search)
 }
 
 void
-remap_init_grids(RemapMethod mapType, bool lextrapolate, int gridID1, RemapGrid &srcGrid, int gridID2, RemapGrid &tgtGrid)
+remap_init_grids(RemapMethod mapType, bool doExtrapolate, int gridID1, RemapGrid &srcGrid, int gridID2, RemapGrid &tgtGrid)
 {
   auto reg2d_srcGridID = gridID1;
   auto reg2d_tgtGridID = gridID2;
 
-  remap_grid_init(srcGrid);
-  remap_grid_init(tgtGrid);
-
   if (mapType == RemapMethod::BILINEAR || mapType == RemapMethod::BICUBIC || mapType == RemapMethod::DISTWGT
       || mapType == RemapMethod::CONSERV)
     {
-      if (IS_REG2D_GRID(gridID1)) srcGrid.type = RemapGridType::Reg2D;
-      // srcGrid.type = 0;
+      if (is_reg2d_grid(gridID1))
+        srcGrid.type = RemapGridType::Reg2D;
+      else if (is_healpix_grid(gridID1) && mapType == RemapMethod::BILINEAR)
+        srcGrid.type = RemapGridType::HealPix;
+      else if (is_healpix_grid(gridID1) && mapType == RemapMethod::DISTWGT && !remap_gen_weights)
+        srcGrid.type = RemapGridType::HealPix;
     }
 
   //#ifdef YAC_CELL_SEARCH
-  // if (IS_REG2D_GRID(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
+  // if (is_reg2d_grid(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
   //#else
   if (srcGrid.type == RemapGridType::Reg2D)
     {
-      if (IS_REG2D_GRID(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
+      if (is_reg2d_grid(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
       // else srcGrid.type = -1;
     }
   //#endif
 
-  if (!remap_gen_weights && IS_REG2D_GRID(gridID2) && tgtGrid.type != RemapGridType::Reg2D)
+  if (!remap_gen_weights && is_reg2d_grid(gridID2) && tgtGrid.type != RemapGridType::Reg2D)
     {
       if (mapType == RemapMethod::DISTWGT) tgtGrid.type = RemapGridType::Reg2D;
-      if (mapType == RemapMethod::BILINEAR && srcGrid.type == RemapGridType::Reg2D) tgtGrid.type = RemapGridType::Reg2D;
+      if (mapType == RemapMethod::BILINEAR && (srcGrid.type == RemapGridType::Reg2D || srcGrid.type == RemapGridType::HealPix))
+        tgtGrid.type = RemapGridType::Reg2D;
     }
 
-  srcGrid.lextrapolate = lextrapolate;
+  if (!remap_gen_weights && is_healpix_grid(gridID2))
+    {
+      if (mapType == RemapMethod::BILINEAR || mapType == RemapMethod::DISTWGT) tgtGrid.type = RemapGridType::HealPix;
+    }
+
+  srcGrid.doExtrapolate = doExtrapolate;
 
   if (mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV)
     {
-      if (srcGrid.type != RemapGridType::Reg2D)
+      if (srcGrid.type != RemapGridType::Reg2D && srcGrid.type != RemapGridType::HealPix)
         {
-          srcGrid.luse_cell_corners = true;
-          srcGrid.lneed_cell_corners = true;
+          srcGrid.useCellCorners = true;
+          srcGrid.needCellCorners = true;
         }
 
       if (tgtGrid.type != RemapGridType::Reg2D)
         {
-          tgtGrid.luse_cell_corners = true;
-          tgtGrid.lneed_cell_corners = true;
+          tgtGrid.useCellCorners = true;
+          tgtGrid.needCellCorners = true;
         }
     }
 
@@ -764,40 +798,37 @@ remap_init_grids(RemapMethod mapType, bool lextrapolate, int gridID1, RemapGrid
 
   if (gridInqType(gridID1) == GRID_UNSTRUCTURED && !gridHasCoordinates(gridID1))
     {
-      const auto reference = dereferenceGrid(gridID1);
+      auto reference = dereferenceGrid(gridID1);
       if (reference.isValid) srcGrid.gridID = gridID1 = reference.gridID;
       if (reference.notFound) cdo_abort("Reference to source grid not found!");
     }
 
   if (gridInqType(gridID2) == GRID_UNSTRUCTURED && !gridHasCoordinates(gridID2))
     {
-      const auto reference = dereferenceGrid(gridID2);
+      auto reference = dereferenceGrid(gridID2);
       if (reference.isValid) tgtGrid.gridID = gridID2 = reference.gridID;
       if (reference.notFound) cdo_abort("Reference to target grid not found!");
     }
 
-  const auto sgridID = srcGrid.gridID;
-  if (gridInqSize(sgridID) > 1 && gridProjIsSupported(sgridID))
+  auto sgridID = srcGrid.gridID;
+  if (gridInqSize(sgridID) > 1 && gridProjIsSupported(sgridID) && srcGrid.type != RemapGridType::HealPix)
     {
-      const bool withBounds = srcGrid.lneed_cell_corners;
-      if (gridInqProjType(sgridID) == CDI_PROJ_HEALPIX)
-        gridID1 = gridToUnstructured(srcGrid.gridID, withBounds);
+      auto needCorners = srcGrid.needCellCorners ? NeedCorners::Yes : NeedCorners::No;
+      if (is_healpix_grid(sgridID))
+        gridID1 = gridToUnstructured(srcGrid.gridID, needCorners);
       else
-        gridID1 = gridToCurvilinear(srcGrid.gridID, withBounds);
+        gridID1 = gridToCurvilinear(srcGrid.gridID, needCorners);
       srcGrid.gridID = gridID1;
       srcGrid.tmpgridID = srcGrid.gridID;
     }
 
   // if (srcGrid.type != RemapGridType::Reg2D)
-  remapDefineGrid(mapType, gridID1, srcGrid, "Source");
-  remapDefineGrid(mapType, gridID2, tgtGrid, "Target");
+  remap_define_grid(mapType, gridID1, srcGrid, "Source");
+  remap_define_grid(mapType, gridID2, tgtGrid, "Target");
 
-  if (srcGrid.type == RemapGridType::Reg2D || tgtGrid.type == RemapGridType::Reg2D)
-    {
-      const auto conservMapping = (mapType == RemapMethod::CONSERV);
-      if (srcGrid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_srcGridID, srcGrid, conservMapping, "source");
-      if (tgtGrid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_tgtGridID, tgtGrid, conservMapping, "target");
-    }
+  auto conservMapping = (mapType == RemapMethod::CONSERV);
+  if (srcGrid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_srcGridID, srcGrid, conservMapping, "source");
+  if (tgtGrid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_tgtGridID, tgtGrid, conservMapping, "target");
 }
 
 /*****************************************************************************/
@@ -807,8 +838,8 @@ static void
 remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv, const Varray<T1> &array1,
            const Varray<T2> &array2, double missval)
 {
-  const T1 mv1 = missval;
-  const T2 mv2 = missval;
+  T1 mv1 = missval;
+  T2 mv2 = missval;
 
   cdo_print("%s order mapping from grid1 to grid2:", (remapOrder == 2) ? "Second" : "First");
   cdo_print("----------------------------------------------");
@@ -825,42 +856,35 @@ remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv
     {
       cdo_print("  Conservation:");
       double sum = 0.0;
-      for (size_t n = 0; n < srcGrid.size; ++n)
-        if (!DBL_IS_EQUAL(array1[n], mv1)) sum += array1[n] * srcGrid.cell_area[n] * srcGrid.cell_frac[n];
+      for (size_t i = 0; i < srcGrid.size; ++i)
+        if (!dbl_is_equal(array1[i], mv1)) sum += array1[i] * srcGrid.cell_area[i] * srcGrid.cell_frac[i];
       cdo_print("  Grid1 Integral = %g", sum);
 
       sum = 0;
-      for (size_t n = 0; n < tgtGrid.size; ++n)
-        if (!DBL_IS_EQUAL(array2[n], mv2)) sum += array2[n] * tgtGrid.cell_area[n] * tgtGrid.cell_frac[n];
+      for (size_t i = 0; i < tgtGrid.size; ++i)
+        if (!dbl_is_equal(array2[i], mv2)) sum += array2[i] * tgtGrid.cell_area[i] * tgtGrid.cell_frac[i];
       cdo_print("  Grid2 Integral = %g", sum);
-      /*
-      for ( n = 0; n < srcGrid.size; n++ )
-       fprintf(stderr, "1 %d %g %g %g\n", n, array1[n], srcGrid.cell_area[n],
-      srcGrid.cell_frac[n]); for ( n = 0; n < tgtGrid.size; n++ )
-        fprintf(stderr, "2 %d %g %g %g\n", n, array2[n], tgtGrid.cell_area[n],
-      tgtGrid.cell_frac[n]);
-      */
     }
 
   cdo_print("  Number of weights %zu", rv.num_wts);
-  cdo_print("  Number of sparse matrix entries %zu", rv.num_links);
+  cdo_print("  Number of sparse matrix entries %zu", rv.numLinks);
   cdo_print("  Total number of dest cells %zu", tgtGrid.size);
 
   std::vector<size_t> tgt_count(tgtGrid.size, 0);
 
 #ifdef HAVE_OPENMP4
-#pragma omp simd
+  //#pragma omp simd -> wrong result with clang
 #endif
-  for (size_t n = 0; n < rv.num_links; ++n) tgt_count[rv.tgtCellIndices[n]]++;
+  for (size_t i = 0; i < rv.numLinks; ++i) tgt_count[rv.tgtCellIndices[i]]++;
 
   size_t imin = SIZE_MAX;
   size_t imax = 0;
-  for (size_t n = 0; n < tgtGrid.size; ++n)
+  for (size_t i = 0; i < tgtGrid.size; ++i)
     {
-      if (tgt_count[n] > 0)
+      if (tgt_count[i] > 0)
         {
-          if (tgt_count[n] < imin) imin = tgt_count[n];
-          if (tgt_count[n] > imax) imax = tgt_count[n];
+          imin = std::min(imin, tgt_count[i]);
+          imax = std::max(imax, tgt_count[i]);
         }
     }
 
@@ -914,9 +938,9 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
 {
   if (grid.rank != 2) cdo_abort("Internal problem (remap_gradients), grid rank = %d!", grid.rank);
 
-  const auto gridSize = grid.size;
-  const auto nx = grid.dims[0];
-  const auto ny = grid.dims[1];
+  auto gridSize = grid.size;
+  auto nx = grid.dims[0];
+  auto ny = grid.dims[1];
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
@@ -929,8 +953,8 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
           auto delew = 0.5;
           auto delns = 0.5;
 
-          const auto j = n / nx + 1;
-          const auto i = n - (j - 1) * nx + 1;
+          auto j = n / nx + 1;
+          auto i = n - (j - 1) * nx + 1;
 
           auto ip1 = i + 1;
           auto im1 = i - 1;
@@ -1015,7 +1039,7 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
                 }
             }
 
-          const auto grad_lat_zero = delew * (array[ine] - array[inw]);
+          auto grad_lat_zero = delew * (array[ine] - array[inw]);
 
           if (!mask[ise])
             {
@@ -1063,7 +1087,7 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
                 }
             }
 
-          const auto grad_lon_zero = delew * (array[ise] - array[isw]);
+          auto grad_lon_zero = delew * (array[ise] - array[isw]);
           gradients.grad_latlon[n] = delns * (grad_lat_zero - grad_lon_zero);
         }
       else
@@ -1073,7 +1097,7 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
           gradients.grad_latlon[n] = 0.0;
         }
     }
-} // remap_gradients
+}  // remap_gradients
 
 // Explicit instantiation
 template void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<float> &array, RemapGradients &gradients);
@@ -1082,7 +1106,7 @@ template void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const
 void
 remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients)
 {
-  const auto gridSize = grid.size;
+  auto gridSize = grid.size;
   Varray<short> mask(gridSize);
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
@@ -1098,10 +1122,10 @@ remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients)
 /*****************************************************************************/
 
 void
-remap_check_area(size_t gridSize, double *cell_area, const char *name)
+remap_check_area(size_t gridSize, const Varray<double> &cell_area, const char *name)
 {
-  for (size_t n = 0; n < gridSize; ++n)
+  for (size_t i = 0; i < gridSize; ++i)
     {
-      if (cell_area[n] < -0.01) cdo_print("%s grid area error: %zu %g", name, n, cell_area[n]);
+      if (cell_area[i] < -0.01) cdo_print("%s grid area error: %zu %g", name, i, cell_area[i]);
     }
 }
