@@ -42,22 +42,22 @@ public:
 
   void verify() const;
   void print() const;
-  int nvalues(const int listIdx) const;
+  int nvalues(int listIdx) const;
   bool
-  isValidListIdx(const int listIdx) const noexcept
+  isValidListIdx(int listIdx) const noexcept
   {
     return (listIdx >= 0 && listIdx < (int) selList.size());
   }
 };
 
 #define SELINFO_ADD_INT(name, description) \
-  int name = 0;                    \
+  int name = 0;                            \
   int listIdx_##name = selinfo_add(selInfo, description, #name, SelType::INT)
 #define SELINFO_ADD_FLT(name, description) \
-  double name = 0;                 \
+  double name = 0;                         \
   int listIdx_##name = selinfo_add(selInfo, description, #name, SelType::FLT)
 #define SELINFO_ADD_WORD(name, description) \
-  const char *name = nullptr;       \
+  const char *name = nullptr;               \
   int listIdx_##name = selinfo_add(selInfo, description, #name, SelType::WORD)
 #define SELINFO_NVAL(name) selInfo.nvalues(listIdx_##name)
 #define SELINFO_CHECK_FLAG(name) selinfo_check_flag(selInfo, listIdx_##name)
@@ -71,8 +71,8 @@ public:
 #define SELINFO_DEF_VAL(name, valIdx, val) selinfo_def_val(selInfo, listIdx_##name, valIdx, val)
 
 int selinfo_add(SelectInfo &selInfo, const char *description, const char *name, SelType type);
-void selinfo_check_flag(const SelectInfo &selInfo, const int listIdx);
-void selinfo_check_range_flag(const SelectInfo &selInfo, const int listIdx);
+void selinfo_check_flag(const SelectInfo &selInfo, int listIdx);
+void selinfo_check_range_flag(const SelectInfo &selInfo, int listIdx);
 bool selinfo_check(SelectInfo &selInfo, int listIdx, void *par);
 bool selinfo_check_date(SelectInfo &selInfo, int listIdx, const char *par);
 bool selinfo_check_season(SelectInfo &selInfo, int listIdx, int month);
