@@ -16,11 +16,12 @@
 namespace cdo
 {
 
+// same result as std::lgamma()
 static double
 lngamma(double x)
 {
-  static const double cof[6] = { 76.18009172947146,  -86.50532032941677,    24.01409824083091,
-                                 -1.231739572450155, 0.1208650973866179e-2, -0.5395239384953e-5 };
+  constexpr double cof[6] = { 76.18009172947146,  -86.50532032941677,    24.01409824083091,
+                              -1.231739572450155, 0.1208650973866179e-2, -0.5395239384953e-5 };
 
   double b, a = b = x;
   double temp = a + 5.5;
@@ -39,7 +40,7 @@ gamma_help_1(double a, double x)
   double ap = a;
   double sum, del = sum = 1.0 / a;
 
-  for (int i = 1; i <= 100; ++i)
+  for (int i = 1; i <= 100; ++i) // 100 iterations
     {
       ap++;
       del *= x / ap;
@@ -60,12 +61,12 @@ gamma_help_2(double a, double x)
   constexpr double very_small = 1000.0 * DBL_MIN;
 
   double gln = lngamma(a);
-  double b = x + 1 - a;
-  double c = 1 / very_small;
-  double d = 1 / b;
+  double b = x + 1.0 - a;
+  double c = 1.0 / very_small;
+  double d = 1.0 / b;
   double h = d;
 
-  for (int i = 1; i <= 100; ++i)
+  for (int i = 1; i <= 100; ++i) // 100 iterations
     {
       double an = -i * (i - a);
       b += 2.0;
@@ -115,13 +116,13 @@ beta_help(double a, double b, double x)
   constexpr double very_small = 1000.0 * DBL_MIN;
   constexpr double eps = 3.e-07;
 
-  const auto qab = a + b;
-  const auto qap = a + 1;
-  const auto qam = a - 1;
+  auto qab = a + b;
+  auto qap = a + 1;
+  auto qam = a - 1;
   double c = 1.0;
   double d = 1.0 - qab * x / qap;
   if (std::fabs(d) < very_small) d = very_small;
-  d = 1 / d;
+  d = 1.0 / d;
   double h = d;
   for (int m = 1; m <= 100; ++m)
     {
@@ -184,8 +185,9 @@ normal_density(double x)
 double
 normal(double x)
 {
-  return (x > 0.0) ? 0.5 * (1.0 + incomplete_gamma(0.5, x * x / 2.0))
-                   : (x < 0.0) ? 0.5 * (1 - incomplete_gamma(0.5, x * x / 2.0)) : 0.5;
+  return (x > 0.0)   ? 0.5 * (1.0 + incomplete_gamma(0.5, x * x / 2.0))
+         : (x < 0.0) ? 0.5 * (1.0 - incomplete_gamma(0.5, x * x / 2.0))
+                     : 0.5;
 }
 
 double
@@ -208,7 +210,7 @@ normal_inv(double p)
       double x = 0.0;
       while (true)
         {
-          const double xx = x - (normal(x) - p) / normal_density(x);
+          double xx = x - (normal(x) - p) / normal_density(x);
           if (std::fabs(xx - x) < x * eps) break;
           x = xx;
         }
@@ -262,6 +264,7 @@ student_t_inv(double n, double p)
     }
 
   if (DBL_IS_EQUAL(n, last_n) && DBL_IS_EQUAL(p, last_p)) return last_x;
+
   if (DBL_IS_EQUAL(p, 0.5))
     return 0.0;
   else if (p < 0.5)
@@ -271,7 +274,7 @@ student_t_inv(double n, double p)
       double x = 0.0;
       while (true)
         {
-          const double xx = x - (student_t(n, x) - p) / student_t_density(n, x);
+          double xx = x - (student_t(n, x) - p) / student_t_density(n, x);
           if (std::fabs(xx - x) < x * eps) break;
           x = xx;
         }
@@ -368,16 +371,16 @@ chi_square_constants(double n, double p, double *c1, double *c2)
 
   while (true)
     {
-      const auto a11 = -chi_square_density(n, *c1);
-      const auto a12 = chi_square_density(n, *c2);
-      const auto a21 = -chi_square_density(n + 2, *c1);
-      const auto a22 = chi_square_density(n + 2, *c2);
-      const auto b1 = p + chi_square(n, *c1) - chi_square(n, *c2);
-      const auto b2 = p + chi_square(n + 2, *c1) - chi_square(n + 2, *c2);
+      auto a11 = -chi_square_density(n, *c1);
+      auto a12 = chi_square_density(n, *c2);
+      auto a21 = -chi_square_density(n + 2, *c1);
+      auto a22 = chi_square_density(n + 2, *c2);
+      auto b1 = p + chi_square(n, *c1) - chi_square(n, *c2);
+      auto b2 = p + chi_square(n + 2, *c1) - chi_square(n + 2, *c2);
       // Solve ((a11,a12),(a21,a22))*(delta_c1,delta_c2)==(b1,b2)
-      const auto det = a11 * a22 - a12 * a21;
-      const auto delta_c1 = (b1 * a22 - b2 * a12) / det;
-      const auto delta_c2 = (b2 * a11 - b1 * a21) / det;
+      auto det = a11 * a22 - a12 * a21;
+      auto delta_c1 = (b1 * a22 - b2 * a12) / det;
+      auto delta_c2 = (b2 * a11 - b1 * a21) / det;
       if (std::fabs(delta_c1) < *c1 * eps && std::fabs(delta_c2) < *c2 * eps) break;
       if (*c1 + delta_c1 >= n)
         *c1 = (n + *c1) / 2.0;
@@ -489,16 +492,16 @@ beta_distr_constants(double a, double b, double p, double *c1, double *c2)
 
   while (true)
     {
-      const auto a11 = -beta_distr_density(a, b, *c1);
-      const auto a12 = beta_distr_density(a, b, *c2);
-      const auto a21 = -beta_distr_density(a + 1, b, *c1);
-      const auto a22 = beta_distr_density(a + 1, b, *c2);
-      const auto b1 = p + beta_distr(a, b, *c1) - beta_distr(a, b, *c2);
-      const auto b2 = p + beta_distr(a + 1, b, *c1) - beta_distr(a + 1, b, *c2);
+      auto a11 = -beta_distr_density(a, b, *c1);
+      auto a12 = beta_distr_density(a, b, *c2);
+      auto a21 = -beta_distr_density(a + 1, b, *c1);
+      auto a22 = beta_distr_density(a + 1, b, *c2);
+      auto b1 = p + beta_distr(a, b, *c1) - beta_distr(a, b, *c2);
+      auto b2 = p + beta_distr(a + 1, b, *c1) - beta_distr(a + 1, b, *c2);
       // Solve ((a11,a12),(a21,a22))*(delta_c1,delta_c2)==(b1,b2)
-      const auto det = a11 * a22 - a12 * a21;
-      const auto delta_c1 = (b1 * a22 - b2 * a12) / det;
-      const auto delta_c2 = (b2 * a11 - b1 * a21) / det;
+      auto det = a11 * a22 - a12 * a21;
+      auto delta_c1 = (b1 * a22 - b2 * a12) / det;
+      auto delta_c2 = (b2 * a11 - b1 * a21) / det;
       if (std::fabs(delta_c1) < *c1 * eps && std::fabs(delta_c2) < *c2 * eps) break;
       if (*c1 + delta_c1 >= a / (a + b))
         *c1 = (a / (a + b) + *c1) / 2.0;
