@@ -12,10 +12,20 @@
 #include <iomanip>
 #include <sstream>
 #include <algorithm>
-#include <cdi.h>
-
 #include <regex>
 
+#include <cdi.h>
+#include "util_string.h"
+
+std::string
+getenv_string(const std::string &envVar)
+{
+  std::string envString;
+  auto envCstring = getenv(envVar.c_str());
+  if (envCstring) envString = envCstring;
+  return envString;
+}
+
 std::vector<std::string>
 split_string(const std::string &str, const std::string &delimiter)
 {
@@ -24,31 +34,31 @@ split_string(const std::string &str, const std::string &delimiter)
 }
 
 std::string
-string_to_upper(std::string p_str)
+string_to_upper(std::string str)
 {
-  std::transform(p_str.begin(), p_str.end(), p_str.begin(), [](unsigned char c) { return std::toupper(c); });
-  return p_str;
+  std::transform(str.begin(), str.end(), str.begin(), [](unsigned char c) { return std::toupper(c); });
+  return str;
 }
 
 std::string
-string_to_lower(std::string p_str)
+string_to_lower(std::string str)
 {
-  std::transform(p_str.begin(), p_str.end(), p_str.begin(), [](unsigned char c) { return std::tolower(c); });
-  return p_str;
+  std::transform(str.begin(), str.end(), str.begin(), [](unsigned char c) { return std::tolower(c); });
+  return str;
 }
 
 void
-cstr_to_lower_case(char *str)
+cstr_to_lower(char *cstr)
 {
-  if (str)
-    for (size_t i = 0; str[i]; ++i) str[i] = (char) tolower((int) str[i]);
+  if (cstr)
+    for (size_t i = 0; cstr[i]; ++i) cstr[i] = (char) tolower((int) cstr[i]);
 }
 
 void
-cstr_to_upper_case(char *str)
+cstr_to_upper(char *cstr)
 {
-  if (str)
-    for (size_t i = 0; str[i]; ++i) str[i] = (char) toupper((int) str[i]);
+  if (cstr)
+    for (size_t i = 0; cstr[i]; ++i) cstr[i] = (char) toupper((int) cstr[i]);
 }
 
 static void
@@ -80,7 +90,7 @@ get_scientific(double p_float_string)
 char *
 double_to_att_str(int digits, char *attstr, size_t len, double value)
 {
-  const auto ret = snprintf(attstr, len, "%#.*g", digits, value);
+  const auto ret = std::snprintf(attstr, len, "%#.*g", digits, value);
   assert(ret != -1 && ret < (int) len);
   trim_flt(attstr);
   return attstr;
@@ -118,3 +128,73 @@ calendar_to_cstr(int calendar)
   else                                     return "unknown";
   // clang-format on
 }
+
+std::vector<std::string>
+split_with_seperator(const std::string &sourceString, const char seperator)
+{
+  std::stringstream ss(sourceString);
+  std::string token;
+  std::vector<std::string> tokens;
+  while (std::getline(ss, token, seperator)) { tokens.push_back(token); }
+  return tokens;
+}
+
+bool
+string_is_float(const std::string &str)
+{
+  if (str.empty() || isspace(str[0])) return 0;
+
+  char *ptr = nullptr;
+  strtod(str.c_str(), &ptr);
+  return (*ptr == '\0');
+}
+
+bool
+string_is_int(const std::string &str)
+{
+  if (str.empty() || isspace(str[0])) return 0;
+
+  char *ptr = nullptr;
+  strtol(str.c_str(), &ptr, 10);
+  return (*ptr == '\0');
+}
+
+#include <iostream>
+/** Tokenizes a string with  delimiter ',' and returns a touple where first
+ * signals success and the second the result.
+ * If any of the tokens is not a integer the result is negative.
+ * With a negative result a empty
+ * list is returned with the result boolean.
+ **/
+std::tuple<bool, std::vector<std::string>>
+tokenize_comma_seperated_int_list(const std::string &args)
+{
+  auto tokens = split_with_seperator(args, ',');
+  bool res = true;
+  for (auto t : tokens)
+    {
+      if (!string_is_int(t))
+        {
+          res = false;
+          tokens = {};
+          break;
+        }
+    }
+  return { res, tokens };
+}
+
+// To replace a single char with another single char in a given string
+
+void
+cstr_replace_char(char *str_in, char orig_char, char rep_char)
+{
+  if (strchr(str_in, orig_char) == nullptr) return;
+
+  while (*str_in != '\0')
+    {
+      if (*str_in == orig_char) *str_in = rep_char;
+      str_in++;
+    }
+
+  return;
+}
