@@ -23,45 +23,46 @@ const auto dbl_is_equal = [](auto a, auto b) noexcept { return (std::isnan(a) ||
 
 // unary operators
 // clang-format off
-const auto unary_op_abs   = [](const double x) noexcept { return std::fabs(x); };
-const auto unary_op_int   = [](const double x) noexcept { return (int)(x); };
-const auto unary_op_nint  = [](const double x) noexcept { return std::round(x); };
-const auto unary_op_sqr   = [](const double x) noexcept { return x * x; };
-const auto unary_op_nop   = [](const double x) noexcept { return x; };
-const auto unary_op_reci  = [](const double x) noexcept { return 1.0 / x; };
-const auto unary_op_not   = [](const double x) noexcept { return is_equal(x, 0.0); };
-const auto unary_op_exp   = [](const double x) noexcept { return std::exp(x); };
-const auto unary_op_log   = [](const double x) noexcept { return std::log(x); };
-const auto unary_op_log10 = [](const double x) noexcept { return std::log10(x); };
-const auto unary_op_sin   = [](const double x) noexcept { return std::sin(x); };
-const auto unary_op_cos   = [](const double x) noexcept { return std::cos(x); };
-const auto unary_op_tan   = [](const double x) noexcept { return std::tan(x); };
-const auto unary_op_asin  = [](const double x) noexcept { return std::asin(x); };
-const auto unary_op_acos  = [](const double x) noexcept { return std::acos(x); };
-const auto unary_op_atan  = [](const double x) noexcept { return std::atan(x); };
+const auto unary_op_abs   = [](double x) noexcept { return std::fabs(x); };
+const auto unary_op_int   = [](double x) noexcept { return (int)(x); };
+const auto unary_op_nint  = [](double x) noexcept { return std::round(x); };
+const auto unary_op_sqr   = [](double x) noexcept { return x * x; };
+const auto unary_op_nop   = [](double x) noexcept { return x; };
+const auto unary_op_reci  = [](double x) noexcept { return 1.0 / x; };
+const auto unary_op_not   = [](double x) noexcept { return is_equal(x, 0.0); };
+const auto unary_op_exp   = [](double x) noexcept { return std::exp(x); };
+const auto unary_op_log   = [](double x) noexcept { return std::log(x); };
+const auto unary_op_log10 = [](double x) noexcept { return std::log10(x); };
+const auto unary_op_sin   = [](double x) noexcept { return std::sin(x); };
+const auto unary_op_cos   = [](double x) noexcept { return std::cos(x); };
+const auto unary_op_tan   = [](double x) noexcept { return std::tan(x); };
+const auto unary_op_asin  = [](double x) noexcept { return std::asin(x); };
+const auto unary_op_acos  = [](double x) noexcept { return std::acos(x); };
+const auto unary_op_atan  = [](double x) noexcept { return std::atan(x); };
 // clang-format on
 
 // binary operators
 // clang-format off
-const auto binary_op_LT  = [](const double x, const double y) noexcept { return x < y; };
-const auto binary_op_GT  = [](const double x, const double y) noexcept { return x > y; };
-const auto binary_op_LE  = [](const double x, const double y) noexcept { return x <= y; };
-const auto binary_op_GE  = [](const double x, const double y) noexcept { return x >= y; };
-const auto binary_op_NE  = [](const double x, const double y) noexcept { return is_not_equal(x, y); };
-const auto binary_op_EQ  = [](const double x, const double y) noexcept { return is_equal(x, y); };
-const auto binary_op_LEG = [](const double x, const double y) noexcept { return (x < y) ? -1.0 : (x > y); };
-const auto binary_op_AND = [](const double x, const double y) noexcept { return is_not_equal(x, 0.0) && is_not_equal(y, 0.0); };
-const auto binary_op_OR  = [](const double x, const double y) noexcept { return is_not_equal(x, 0.0) || is_not_equal(y, 0.0); };
-const auto binary_op_POW = [](const double x, const double y) noexcept { return std::pow(x, y); };
-const auto binary_op_ADD = [](const double x, const double y) noexcept { return x + y; };
-const auto binary_op_SUB = [](const double x, const double y) noexcept { return x - y; };
-const auto binary_op_MUL = [](const double x, const double y) noexcept { return x * y; };
-const auto binary_op_DIV = [](const double x, const double y) noexcept { return x / y; };
+const auto binary_op_LT  = [](double x, double y) noexcept { return x < y; };
+const auto binary_op_GT  = [](double x, double y) noexcept { return x > y; };
+const auto binary_op_LE  = [](double x, double y) noexcept { return x <= y; };
+const auto binary_op_GE  = [](double x, double y) noexcept { return x >= y; };
+const auto binary_op_NE  = [](double x, double y) noexcept { return is_not_equal(x, y); };
+const auto binary_op_EQ  = [](double x, double y) noexcept { return is_equal(x, y); };
+const auto binary_op_LEG = [](double x, double y) noexcept { return (x < y) ? -1.0 : (x > y); };
+const auto binary_op_AND = [](double x, double y) noexcept { return is_not_equal(x, 0.0) && is_not_equal(y, 0.0); };
+const auto binary_op_OR  = [](double x, double y) noexcept { return is_not_equal(x, 0.0) || is_not_equal(y, 0.0); };
+const auto binary_op_POW = [](double x, double y) noexcept { return std::pow(x, y); };
+const auto binary_op_ADD = [](double x, double y) noexcept { return x + y; };
+const auto binary_op_SUB = [](double x, double y) noexcept { return x - y; };
+const auto binary_op_MUL = [](double x, double y) noexcept { return x * y; };
+const auto binary_op_DIV = [](double x, double y) noexcept { return x / y; };
 // clang-format on
 
 //#define CHECK_UNUSED_VECTOR 1
 
 #ifdef CHECK_UNUSED_VECTOR
+// clang-format off
 template <typename T>
 class
 #ifdef WARN_UNUSED
@@ -112,6 +113,7 @@ CheckVector
  private:
   T dummy[1] {};
 };
+// clang-format on
 
 template <typename T>
 using Varray = CheckVector<T>;
@@ -132,7 +134,7 @@ using Varray3D = Varray2D<Varray<T>>;
 template <typename T>
 using Varray4D = Varray3D<Varray<T>>;
 
-
+// clang-format off
 struct MinMax
 {
   double min = DBL_MAX;
@@ -158,7 +160,7 @@ struct MinMaxMean : MinMax
   MinMaxMean(double rmin, double rmax, double rmean, size_t rn) : mean(rmean) { min = rmin; max = rmax; n = rn; };
   MinMaxMean(double rmin, double rmax, double rmean) : mean(rmean) { min = rmin; max = rmax; n = 0; };
 };
-
+// clang-format on
 
 template <typename T>
 inline void
@@ -183,8 +185,8 @@ varray_resize(Varray<T> &v, size_t count, const char *file, int line)
         }
       catch (const std::exception &e)
         {
-          std::cerr << "Exception caught when trying to allocate " << count << " vector elements: "
-                    << e.what() << " in " << file << ":" << line << '\n';
+          std::cerr << "Exception caught when trying to allocate " << count << " vector elements: " << e.what() << " in " << file
+                    << ":" << line << '\n';
           throw;
         }
     }
@@ -200,8 +202,8 @@ varray_resize(Varray<T> &v, size_t count, T value, const char *file, int line)
     }
   catch (const std::exception &e)
     {
-      std::cerr << "Exception caught when trying to allocate " << count << " vector elements: "
-                << e.what() << " in " << file << ":" << line << '\n';
+      std::cerr << "Exception caught when trying to allocate " << count << " vector elements: " << e.what() << " in " << file << ":"
+                << line << '\n';
       throw;
     }
 }
@@ -240,27 +242,27 @@ using Matrix = std::array<std::array<T, COL>, ROW>;
 #define POWMN(x, y) FPOWMN(x, y, missval1, missval2)
 #define SQRTMN(x) FSQRTMN(x, missval1)
 
-static inline double FADDMN(const double x, const double y, const double missval1, const double missval2)
+static inline double FADDMN(double x, double y, double missval1, double missval2)
 {
   return MADDMN(x, y);
 }
-static inline double FSUBMN(const double x, const double y, const double missval1, const double missval2)
+static inline double FSUBMN(double x, double y, double missval1, double missval2)
 {
   return MSUBMN(x, y);
 }
-static inline double FMULMN(const double x, const double y, const double missval1, const double missval2)
+static inline double FMULMN(double x, double y, double missval1, double missval2)
 {
   return MMULMN(x, y);
 }
-static inline double FDIVMN(const double x, const double y, const double missval1, const double missval2)
+static inline double FDIVMN(double x, double y, double missval1, double missval2)
 {
   return MDIVMN(x, y);
 }
-static inline double FPOWMN(const double x, const double y, const double missval1, const double missval2)
+static inline double FPOWMN(double x, double y, double missval1, double missval2)
 {
   return MPOWMN(x, y);
 }
-static inline double FSQRTMN(const double x, const double missval1)
+static inline double FSQRTMN(double x, double missval1)
 {
   return MSQRTMN(x);
 }
@@ -288,50 +290,51 @@ void array_add_array_mv(size_t len, double *array1, const double *array2, double
 
 template <typename T1, typename T2>
 void
-varray_fill(const size_t len, T1 *v, const T2 value)
+varray_fill(size_t len, T1 *v, T2 value)
 {
-  const T1 c = value;
+  T1 c = value;
   for (size_t i = 0; i < len; ++i) v[i] = c;
 }
 
 template <typename T1, typename T2>
 void
-varray_fill(Varray<T1> &v, const T2 value)
+varray_fill(Varray<T1> &v, T2 value)
 {
   varray_fill(v.size(), v.data(), value);
 }
 
 template <typename T1, typename T2>
 void
-varray_fill(const size_t len, Varray<T1> &v, const T2 value)
+varray_fill(size_t len, Varray<T1> &v, T2 value)
 {
   varray_fill(len, v.data(), value);
 }
 
 template <typename T1, typename T2>
 void
-array_copy(const size_t len, const T1 *array1, T2 *array2)
+array_copy(size_t len, const T1 *array1, T2 *array2)
 {
   for (size_t i = 0; i < len; ++i) array2[i] = array1[i];
 }
 
 template <typename T1, typename T2>
 void
-varray_copy(const size_t len, const Varray<T1> &v1, Varray<T2> &v2)
+varray_copy(size_t len, const Varray<T1> &v1, Varray<T2> &v2)
 {
   for (size_t i = 0; i < len; ++i) v2[i] = v1[i];
 }
 
 template <typename T1, typename T2>
 void
-varray_divc(const size_t len, Varray<T1> &v, const T2 value)
+varray_divc(size_t len, Varray<T1> &v, T2 value)
 {
-  const T1 c = value;
+  T1 c = value;
   for (size_t i = 0; i < len; ++i) v[i] /= c;
 }
 
 template <typename T, class UnaryOperation>
-void varray_transform(const Varray<T> &vIn, Varray<T> &vOut, UnaryOperation unary_op)
+void
+varray_transform(const Varray<T> &vIn, Varray<T> &vOut, UnaryOperation unary_op)
 {
   assert(vIn.size() > 0);
   assert(vOut.size() > 0);
@@ -380,7 +383,7 @@ T varray_max_mv(size_t len, const Varray<T> &v, T missval);
 template <typename T>
 T varray_range_mv(size_t len, const Varray<T> &v, T missval);
 
-double array_sum(const size_t len, const double *array);
+double array_sum(size_t len, const double *array);
 
 template <typename T>
 double varray_sum(size_t len, const Varray<T> &v);
