@@ -23,7 +23,7 @@ constexpr auto SCALEHEIGHT = -7000.0;
 constexpr auto SCALESLP = 101325.0;
 
 void
-height_to_pressure(double *phlev, const double *hlev, const long nphlev)
+height_to_pressure(double *phlev, const double *hlev, long nphlev)
 {
   for (long k = 0; k < nphlev; ++k)
     {
@@ -37,12 +37,9 @@ height_to_pressure(double *phlev, const double *hlev, const long nphlev)
 }
 
 void
-pressure_to_height(double *hlev, const double *plev, const long nphlev)
+pressure_to_height(double *hlev, const double *plev, long nphlev)
 {
-  for (long k = 0; k < nphlev; ++k)
-    {
-      hlev[k] = std::log(plev[k] / SCALESLP) * SCALEHEIGHT;
-    }
+  for (long k = 0; k < nphlev; ++k) { hlev[k] = std::log(plev[k] / SCALESLP) * SCALEHEIGHT; }
 }
 
 template <typename T>
@@ -69,7 +66,8 @@ vct_to_hybrid_pressure(T *restrict fullPress, T *halfPress, const double *restri
 }
 
 template void vct_to_hybrid_pressure(float *fullPress, float *halfPress, const double *vct, const float *ps, long nhlev, long ngp);
-template void vct_to_hybrid_pressure(double *fullPress, double *halfPress, const double *vct, const double *ps, long nhlev, long ngp);
+template void vct_to_hybrid_pressure(double *fullPress, double *halfPress, const double *vct, const double *ps, long nhlev,
+                                     long ngp);
 
 void
 extrapolate_P(double *restrict slp, const double *restrict halfPress, const double *restrict fullPress, const double *restrict geop,
@@ -80,10 +78,7 @@ extrapolate_P(double *restrict slp, const double *restrict halfPress, const doub
 
   for (long j = 0; j < ngp; ++j)
     {
-      if (geop[j] < 0.0001 && geop[j] > -0.0001)
-        {
-          slp[j] = halfPress[j];
-        }
+      if (geop[j] < 0.0001 && geop[j] > -0.0001) { slp[j] = halfPress[j]; }
       else
         {
           auto alpha = PlanetRD * zlapse * zrg;
@@ -132,10 +127,7 @@ extrapolate_T(double pres, double halfPress, double fullPress, double geop, doub
 
   // if (ztmsl > 290.5 && tstar <= 290.5) ztmsl = 290.5;
 
-  if (pres <= halfPress)
-    {
-      peval = ((halfPress - pres) * temp + (pres - fullPress) * tstar) / (halfPress - fullPress);
-    }
+  if (pres <= halfPress) { peval = ((halfPress - pres) * temp + (pres - fullPress) * tstar) / (halfPress - fullPress); }
   else
     {
       ztmsl = z1;
@@ -211,11 +203,8 @@ vertical_interp_T(const T *restrict geop, const T *restrict gt, T *pt, const T *
 
       for (long i = 0; i < ngp; ++i)
         {
-          const long nl = vertIndexLev[i];
-          if (nl < 0)
-            {
-              ptl[i] = missval;
-            }
+          long nl = vertIndexLev[i];
+          if (nl < 0) { ptl[i] = missval; }
           else
             {
               if (nl > nhlev - 2)
@@ -239,9 +228,9 @@ vertical_interp_T(const T *restrict geop, const T *restrict gt, T *pt, const T *
 template void vertical_interp_T(const float *restrict geop, const float *restrict gt, float *pt, const float *restrict fullPress,
                                 const float *restrict halfPress, const int *vertIndex, const double *restrict plev, long nplev,
                                 long ngp, long nhlev, double missval);
-template void vertical_interp_T(const double *restrict geop, const double *restrict gt, double *pt, const double *restrict fullPress,
-                                const double *restrict halfPress, const int *vertIndex, const double *restrict plev, long nplev,
-                                long ngp, long nhlev, double missval);
+template void vertical_interp_T(const double *restrict geop, const double *restrict gt, double *pt,
+                                const double *restrict fullPress, const double *restrict halfPress, const int *vertIndex,
+                                const double *restrict plev, long nplev, long ngp, long nhlev, double missval);
 
 template <typename T>
 void
@@ -267,10 +256,7 @@ vertical_interp_Z(const T *restrict geop, const T *restrict gz, T *pz, const T *
       for (long i = 0; i < ngp; ++i)
         {
           long nl = vertIndexLev[i];
-          if (nl < 0)
-            {
-              pzl[i] = missval;
-            }
+          if (nl < 0) { pzl[i] = missval; }
           else
             {
               if (pres > halfPress[(nl + 1) * ngp + i]) nl++;
@@ -296,9 +282,10 @@ vertical_interp_Z(const T *restrict geop, const T *restrict gz, T *pz, const T *
 template void vertical_interp_Z(const float *restrict geop, const float *restrict gz, float *pz, const float *restrict fullPress,
                                 const float *restrict halfPress, const int *vertIndex, const float *restrict gt,
                                 const double *restrict plev, long nplev, long ngp, long nhlev, double missval);
-template void vertical_interp_Z(const double *restrict geop, const double *restrict gz, double *pz, const double *restrict fullPress,
-                                const double *restrict halfPress, const int *vertIndex, const double *restrict gt,
-                                const double *restrict plev, long nplev, long ngp, long nhlev, double missval);
+template void vertical_interp_Z(const double *restrict geop, const double *restrict gz, double *pz,
+                                const double *restrict fullPress, const double *restrict halfPress, const int *vertIndex,
+                                const double *restrict gt, const double *restrict plev, long nplev, long ngp, long nhlev,
+                                double missval);
 
 template <typename T>
 static inline double
@@ -307,14 +294,15 @@ vertical_interp_X_kernel(const T *restrict arrayIn, const T *restrict levels3D,
 {
   const auto nh = nl + ngp;
   return (nl < 0) ? missval
-                  : ((nh >= ngp * nhlev) ? arrayIn[nl]
-                                         : arrayIn[nl] + (level - levels3D[nl]) * (arrayIn[nh] - arrayIn[nl]) / (levels3D[nh] - levels3D[nl]));
+                  : ((nh >= ngp * nhlev)
+                         ? arrayIn[nl]
+                         : arrayIn[nl] + (level - levels3D[nl]) * (arrayIn[nh] - arrayIn[nl]) / (levels3D[nh] - levels3D[nl]));
 }
 
 template <typename T>
 void
-vertical_interp_X(const T *restrict arrayIn3D, T *arrayOut3D, const T *levels3D, const int *vertIndex3D, const double *restrict levels, long numLevels,
-                  long ngp, long nhlev, double missval)
+vertical_interp_X(const T *restrict arrayIn3D, T *arrayOut3D, const T *levels3D, const int *vertIndex3D,
+                  const double *restrict levels, long numLevels, long ngp, long nhlev, double missval)
 {
   if (numLevels > 3)
     {
@@ -353,8 +341,8 @@ vertical_interp_X(const T *restrict arrayIn3D, T *arrayOut3D, const T *levels3D,
 // Explicit instantiation
 template void vertical_interp_X(const float *restrict arrayIn3D, float *arrayOut3D, const float *levels3D, const int *vertIndex3D,
                                 const double *levels, long numLevels, long ngp, long nhlev, double missval);
-template void vertical_interp_X(const double *restrict arrayIn3D, double *arrayOut3D, const double *levels3D, const int *vertIndex3D,
-                                const double *levels, long numLevels, long ngp, long nhlev, double missval);
+template void vertical_interp_X(const double *restrict arrayIn3D, double *arrayOut3D, const double *levels3D,
+                                const int *vertIndex3D, const double *levels, long numLevels, long ngp, long nhlev, double missval);
 
 template <typename T>
 void
